@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -57,18 +57,16 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         self.resultList.header().resizeSections(QHeaderView.ResizeToContents)
         self.resultList.header().setStretchLastSection(True)
         
-    def __createResultItem(self, parent, values):
+    def __createResultItem(self, parent, strings):
         """
         Private slot to create a new item in the result list.
         
         @param parent parent of the new item (QTreeWidget or QTreeWidgetItem)
-        @param values values to be displayed (list)
+        @param strings strings to be displayed (QStringList)
         @return the generated item
         """
-        itm = QTreeWidgetItem(parent)
-        for col in range(len(values)):
-            itm.setData(col, Qt.DisplayRole, values[col])
-        for col in range(1, 7):
+        itm = QTreeWidgetItem(parent, strings)
+        for col in range(1,7):
             itm.setTextAlignment(col, Qt.Alignment(Qt.AlignRight))
         return itm
         
@@ -76,6 +74,7 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         """
         Private method to resize the list columns.
         """
+        self.summaryList.doItemsLayout()
         self.summaryList.header().resizeSections(QHeaderView.ResizeToContents)
         self.summaryList.header().setStretchLastSection(True)
         
@@ -130,13 +129,13 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
                 stats = CodeMetrics.analyze(file, total)
                 
                 v = self.__getValues(loc, stats, 'TOTAL ')
-                fitm = self.__createResultItem(self.resultList, [file] + v)
+                fitm = self.__createResultItem(self.resultList, QStringList(file) + v)
                 
                 identifiers = stats.identifiers
                 for identifier in identifiers:
                     v = self.__getValues(loc, stats, identifier)
                     
-                    self.__createResultItem(fitm, [identifier] + v)
+                    self.__createResultItem(fitm, QStringList(identifier) + v)
                 self.resultList.expandItem(fitm)
                 
                 progress += 1
@@ -174,10 +173,10 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         @return list of values suitable for display (QStringList)
         """
         counters = stats.counters.get(identifier, {})
-        v = []
+        v = QStringList()
         for key in ('start', 'end', 'lines', 'nloc', 'comments', 'empty'):
             if counters.get(key, 0):
-                v.append(counters[key])
+                v.append(QString("%1").arg(loc.toString(counters[key]), 7, QChar(' ')))
             else:
                 v.append('')
         return v
