@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -38,7 +38,7 @@ class DCTestResult(TestResult):
         @param err The error traceback
         """
         TestResult.addFailure(self, test, err)
-        tracebackLines = apply(traceback.format_exception, err + (10,))
+        tracebackLines = traceback.format_exception(*(err + (10,)))
         self.parent.write('%s%s\n' % (ResponseUTTestFailed,
             unicode((unicode(test), tracebackLines))))
         
@@ -50,7 +50,7 @@ class DCTestResult(TestResult):
         @param err The error traceback
         """
         TestResult.addError(self, test, err)
-        tracebackLines = apply(traceback.format_exception, err + (10,))
+        tracebackLines = traceback.format_exception(*(err + (10,)))
         self.parent.write('%s%s\n' % (ResponseUTTestErrored,
             unicode((unicode(test), tracebackLines))))
         
