@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -13,21 +13,31 @@ import bdb
 import os
 import types
 import atexit
+import inspect
 
 from DebugProtocol import *
 
+gRecursionLimit = 64
+
 def printerr(s):
     """
     Module function used for debugging the debug client.
     
-    Arguments
-    
-    @param s the data to be printed
+    @param s data to be printed
     """
     import sys
     sys.__stderr__.write('%s\n' % unicode(s))
     sys.__stderr__.flush()
 
+def setRecursionLimit(limit):
+    """
+    Module function to set the recursion limit.
+    
+    @param limit recursion limit (integer)
+    """
+    global gRecursionLimit
+    gRecursionLimit = limit
+
 class DebugBase(bdb.Bdb):
     """
     Class implementing base class of the debugger.
@@ -48,6 +58,10 @@ class DebugBase(bdb.Bdb):
         
         self.breaks = self._dbgClient.breakpoints
         
+        self.__event = ""
+        self.__isBroken = ""
+        self.cFrame = None
+        
         # current frame we are at
         self.currentFrame = None
         
@@ -61,6 +75,9 @@ class DebugBase(bdb.Bdb):
         
         # initialize parent
         bdb.Bdb.reset(self)
+        
+        self.__recursionDepth = -1
+        self.setRecursionDepth(inspect.currentframe())
     
     def getCurrentFrame(self):
         """
@@ -69,7 +86,7 @@ class DebugBase(bdb.Bdb):
         @return the current frame
         """
         return self.currentFrame        
-            
+    
     def step(self, traceMode):
         """
         Public method to perform a step operation in this thread.
@@ -102,12 +119,42 @@ class DebugBase(bdb.Bdb):
         """
         self.currentFrame = None
         self.set_continue(special)
+    
+    def setRecursionDepth(self, frame):
+        """
+        Public method to determine the current recursion depth.
         
+        @param frame The current stack frame.
+        """
+        self.__recursionDepth = 0
+        while frame is not None:
+            self.__recursionDepth += 1
+            frame = frame.f_back
+    
+    def profile(self, frame, event, arg):
+        """
+        Public method used to trace some stuff independant of the debugger 
+        trace function.
+        
+        @param frame The current stack frame.
+        @param event The trace event (string)
+        @param arg The arguments
+        """
+        if event == 'return':  
+            self.cFrame = frame.f_back
+            self.__recursionDepth -= 1
+        elif event == 'call':
+            self.cFrame = frame
+            self.__recursionDepth += 1
+            if self.__recursionDepth > gRecursionLimit:
+                raise RuntimeError('maximum recursion depth exceeded\n'
+                    '(offending frame is two down the stack)')
+    
     def trace_dispatch(self, frame, event, arg):
         """
         Reimplemented from bdb.py to do some special things.
         
-        This speciality is to check the connection to the debug server
+        This specialty is to check the connection to the debug server
         for new events (i.e. new breakpoints) while we are going through
         the code.
         
@@ -122,6 +169,9 @@ class DebugBase(bdb.Bdb):
         # give the client a chance to push through new break points.
         self._dbgClient.eventPoll()
         
+        self.__event == event
+        self.__isBroken = False
+        
         if event == 'line':
             return self.dispatch_line(frame)
         if event == 'call':
@@ -182,6 +232,15 @@ class DebugBase(bdb.Bdb):
             if self.quitting: raise bdb.BdbQuit
         return self.trace_dispatch
 
+    def set_trace(self, frame = None):
+        """
+        Overridden method of bdb.py to do some special setup.
+        
+        @param frame frame to start debugging from
+        """
+        bdb.Bdb.set_trace(self, frame)
+        sys.setprofile(self.profile)
+    
     def set_continue(self, special):
         """
         Reimplemented from bdb.py to always get informed of exceptions.
@@ -202,8 +261,9 @@ class DebugBase(bdb.Bdb):
         It wraps call to bdb to clear the current frame properly.
         """
         self.currentFrame = None
+        sys.setprofile(None)
         bdb.Bdb.set_quit(self)
-        
+    
     def fix_frame_filename(self, frame):
         """
         Public method used to fixup the filename for a given frame.
@@ -409,7 +469,7 @@ class DebugBase(bdb.Bdb):
         return self.breaks.has_key(filename) and \
             lineno in self.breaks[filename] and \
             bdb.Breakpoint.bplist[filename, lineno][0] or None
-            
+    
     def __do_clear(self, filename, lineno):
         """
         Private method called to clear a temporary breakpoint.
@@ -420,7 +480,33 @@ class DebugBase(bdb.Bdb):
         self.clear_break(filename, lineno)
         self._dbgClient.write('%s%s,%d\n' % (ResponseClearBreak, filename, lineno))
 
-    def user_line(self,frame):
+    def getStack(self):
+        """
+        Public method to get the stack.
+        
+        @return list of lists with file name (string), line number (integer)
+            and function name (string)
+        """
+        fr = self.cFrame
+        stack = []
+        while fr is not None:
+            fname = self._dbgClient.absPath(self.fix_frame_filename(fr))
+            fline = fr.f_lineno
+            ffunc = fr.f_code.co_name
+            
+            if ffunc == '?':
+                ffunc = ''
+            
+            stack.append([fname, fline, ffunc])
+            
+            if fr == self._dbgClient.mainFrame:
+                fr = None
+            else:
+                fr = fr.f_back
+        
+        return stack
+    
+    def user_line(self, frame):
         """
         Reimplemented to handle the program about to execute a particular line.
         
@@ -465,7 +551,9 @@ class DebugBase(bdb.Bdb):
             else:
                 fr = fr.f_back
         
-        self._dbgClient.write('%s%s\n' % (ResponseLine,unicode(stack)))
+        self.__isBroken = True
+        
+        self._dbgClient.write('%s%s\n' % (ResponseLine, unicode(stack)))
         self._dbgClient.eventLoop()
 
     def user_exception(self,frame,(exctype,excval,exctb),unhandled=0):
@@ -480,19 +568,22 @@ class DebugBase(bdb.Bdb):
         """
         if exctype in [SystemExit, bdb.BdbQuit]:
             atexit._run_exitfuncs()
-            self._dbgClient.progTerminated(excval)
+            if isinstance(excval, int):
+                self._dbgClient.progTerminated(excval)
+            else:
+                self._dbgClient.progTerminated(excval.code)
             return
-            
+        
         elif exctype in [SyntaxError, IndentationError]:
             try:
                 message, (filename, linenr, charnr, text) = excval
-            except:
+            except ValueError:
                 exclist = []
             else:
                 exclist = [message, [filename, linenr, charnr]]
             
             self._dbgClient.write("%s%s\n" % (ResponseSyntax, unicode(exclist)))
-            
+        
         else:
             if type(exctype) in [types.ClassType,   # Python up to 2.4
                                  types.TypeType]:   # Python 2.5+
@@ -531,9 +622,9 @@ class DebugBase(bdb.Bdb):
             
             if exctb is None:
                 return
-            
-        self._dbgClient.eventLoop()
         
+        self._dbgClient.eventLoop()
+    
     def __extract_stack(self, exctb):
         """
         Private member to return a list of stack frames.
@@ -598,18 +689,34 @@ class DebugBase(bdb.Bdb):
         #XXX - think of a better way to do this.  It's only a convience for
         #debugging the debugger - when the debugger code is in the current
         #directory.
-        if os.path.basename(fn) in [
+        if os.path.basename(fn) in [\
             'AsyncFile.py', 'AsyncIO.py',
             'DebugConfig.py', 'DCTestResult.py',
             'DebugBase.py', 'DebugClientBase.py', 
             'DebugClientCapabilities.py', 'DebugClient.py', 
             'DebugClientThreads.py', 'DebugProtocol.py',
             'DebugThread.py', 'FlexCompleter.py',
-            'PyCoverage.py', 'PyProfile.py'] or \
-           os.path.dirname(fn).endswith("Cyclops"):
+            'PyProfile.py'] or \
+           os.path.dirname(fn).endswith("coverage"):
             return 1
 
         if self._dbgClient.shouldSkip(fn):
             return 1
         
         return 0
+    
+    def isBroken(self):
+        """
+        Public method to return the broken state of the debugger.
+        
+        @return flag indicating the broken state (boolean)
+        """
+        return self.__isBroken
+    
+    def getEvent(self):
+        """
+        Public method to return the last debugger event.
+        
+        @return last debugger event (string)
+        """
+        return self.__event
