@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -17,7 +17,6 @@ import time
 import imp
 import re
 import distutils.sysconfig
-import atexit
 
 
 from DebugProtocol import *
@@ -203,7 +202,7 @@ class DebugClientBase(object):
         self.localsFilterObjects = []
 
         self.pendingResponse = ResponseOK
-        self._fncache = {}
+        self.fncache = {}
         self.dircache = []
         self.inRawMode = 0
         self.mainProcStr = None     # used for the passive mode
@@ -464,7 +463,7 @@ class DebugClientBase(object):
                 return
 
             if cmd == RequestLoad:
-                self._fncache = {}
+                self.fncache = {}
                 self.dircache = []
                 sys.argv = []
                 wd, fn, args, tracePython = arg.split('|')
@@ -475,7 +474,8 @@ class DebugClientBase(object):
                     pass
                 sys.argv.append(fn)
                 sys.argv.extend(eval(args))
-                sys.path = self.__getSysPath(os.path.dirname(sys.argv[0]))
+                sys.path[0] = os.path.dirname(sys.argv[0])
+                sys.path.insert(0, '')
                 if wd == '':
                     os.chdir(sys.path[1])
                 else:
@@ -520,7 +520,8 @@ class DebugClientBase(object):
                     pass
                 sys.argv.append(fn)
                 sys.argv.extend(eval(args))
-                sys.path = self.__getSysPath(os.path.dirname(sys.argv[0]))
+                sys.path[0] = os.path.dirname(sys.argv[0])
+                sys.path.insert(0, '')
                 if wd == '':
                     os.chdir(sys.path[1])
                 else:
@@ -542,14 +543,8 @@ class DebugClientBase(object):
                 
                 self.debugMod.__dict__['__file__'] = sys.argv[0]
                 sys.modules['__main__'] = self.debugMod
-                res = 0
-                try:
-                    execfile(sys.argv[0], self.debugMod.__dict__)
-                except SystemExit as exc:
-                    res = exc.code
-                    atexit._run_exitfuncs()
+                execfile(sys.argv[0], self.debugMod.__dict__)
                 self.writestream.flush()
-                self.progTerminated(res)
                 return
 
             if cmd == RequestCoverage:
@@ -563,7 +558,8 @@ class DebugClientBase(object):
                     pass
                 sys.argv.append(fn)
                 sys.argv.extend(eval(args))
-                sys.path = self.__getSysPath(os.path.dirname(sys.argv[0]))
+                sys.path[0] = os.path.dirname(sys.argv[0])
+                sys.path.insert(0, '')
                 if wd == '':
                     os.chdir(sys.path[1])
                 else:
@@ -582,18 +578,11 @@ class DebugClientBase(object):
                     self.cover.erase()
                 sys.modules['__main__'] = self.debugMod
                 self.debugMod.__dict__['__file__'] = sys.argv[0]
-                self.running = sys.argv[0]
-                res = 0
                 self.cover.start()
-                try:
-                    execfile(sys.argv[0], self.debugMod.__dict__)
-                except SystemExit as exc:
-                    res = exc.code
-                    atexit._run_exitfuncs()
+                execfile(sys.argv[0], self.debugMod.__dict__)
                 self.cover.stop()
                 self.cover.save()
                 self.writestream.flush()
-                self.progTerminated(res)
                 return
 
             if cmd == RequestProfile:
@@ -608,7 +597,8 @@ class DebugClientBase(object):
                     pass
                 sys.argv.append(fn)
                 sys.argv.extend(eval(args))
-                sys.path = self.__getSysPath(os.path.dirname(sys.argv[0]))
+                sys.path[0] = os.path.dirname(sys.argv[0])
+                sys.path.insert(0, '')
                 if wd == '':
                     os.chdir(sys.path[1])
                 else:
@@ -625,16 +615,9 @@ class DebugClientBase(object):
                     self.prof.erase()
                 self.debugMod.__dict__['__file__'] = sys.argv[0]
                 sys.modules['__main__'] = self.debugMod
-                self.running = sys.argv[0]
-                res = 0
-                try:
-                    self.prof.run('execfile(%r)' % sys.argv[0])
-                except SystemExit as exc:
-                    res = exc.code
-                    atexit._run_exitfuncs()
+                self.prof.run('execfile(%r)' % sys.argv[0])
                 self.prof.save()
                 self.writestream.flush()
-                self.progTerminated(res)
                 return
 
             if cmd == RequestShutdown:
@@ -733,7 +716,7 @@ class DebugClientBase(object):
             if cmd == RequestEval:
                 try:
                     value = eval(arg, self.currentThread.getCurrentFrame().f_globals,
-                                      self.currentThread.getCurrentFrameLocals())
+                                      self.currentThread.getCurrentFrame().f_locals)
                 except:
                     # Report the exception and the traceback
                     try:
@@ -763,7 +746,7 @@ class DebugClientBase(object):
             
             if cmd == RequestExec:
                 _globals = self.currentThread.getCurrentFrame().f_globals
-                _locals = self.currentThread.getCurrentFrameLocals()
+                _locals = self.currentThread.getCurrentFrame().f_locals
                 try:
                     code = compile(arg + '\n', '<stdin>', 'single')
                     exec code in _globals, _locals
@@ -896,6 +879,8 @@ class DebugClientBase(object):
             sys.last_type, sys.last_value, sys.last_traceback = sys.exc_info()
             map(self.write,traceback.format_exception_only(sys.last_type,sys.last_value))
             self.buffer = ''
+
+            self.__exceptionRaised()
         else:
             if code is None:
                 self.pendingResponse = ResponseContinue
@@ -924,7 +909,7 @@ class DebugClientBase(object):
                                     cf = cf.f_back
                                     frmnr -= 1
                                 _globals = cf.f_globals
-                                _locals = self.currentThread.getCurrentFrameLocals()
+                                _locals = cf.f_locals
                         # reset sys.stdout to our redirector (unconditionally)
                         if _globals.has_key("sys"):
                             __stdout = _globals["sys"].stdout
@@ -959,6 +944,8 @@ class DebugClientBase(object):
 
                     map(self.write, list)
 
+                    self.__exceptionRaised()
+
     def __clientCapabilities(self):
         """
         Private method to determine the clients capabilities.
@@ -1087,20 +1074,12 @@ class DebugClientBase(object):
         if remoteAddress is None:                               # default: 127.0.0.1
             sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             sock.connect((DebugAddress, port))
-        else:
-            if "@@i" in remoteAddress:
-                remoteAddress, index = remoteAddress.split("@@i")
-            else:
-                index = 0
-            if ":" in remoteAddress:                              # IPv6
-                sockaddr = socket.getaddrinfo(
-                    remoteAddress, port, 0, 0, socket.SOL_TCP)[0][-1]
-                sock = socket.socket(socket.AF_INET6, socket.SOCK_STREAM)
-                sockaddr = sockaddr[:-1] + (int(index),)
-                sock.connect(sockaddr)
-            else:                                                   # IPv4
-                sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-                sock.connect((remoteAddress, port))
+        elif ":" in remoteAddress:                              # IPv6
+            sock = socket.socket(socket.AF_INET6, socket.SOCK_STREAM)
+            sock.connect((remoteAddress, port))
+        else:                                                   # IPv4
+            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            sock.connect((remoteAddress, port))
 
         self.readstream = AsyncFile(sock, sys.stdin.mode, sys.stdin.name)
         self.writestream = AsyncFile(sock, sys.stdout.mode, sys.stdout.name)
@@ -1139,16 +1118,16 @@ class DebugClientBase(object):
             return fn
 
         # Check the cache.
-        if self._fncache.has_key(fn):
-            return self._fncache[fn]
+        if self.fncache.has_key(fn):
+            return self.fncache[fn]
 
         # Search sys.path.
         for p in sys.path:
             afn = os.path.abspath(os.path.join(p,fn))
-            nafn = os.path.normcase(afn)
+            afn = os.path.normcase(afn)
 
-            if os.path.exists(nafn):
-                self._fncache[fn] = afn
+            if os.path.exists(afn):
+                self.fncache[fn] = afn
                 d = os.path.dirname(afn)
                 if (d not in sys.path) and (d not in self.dircache):
                     self.dircache.append(d)
@@ -1157,10 +1136,10 @@ class DebugClientBase(object):
         # Search the additional directory cache
         for p in self.dircache:
             afn = os.path.abspath(os.path.join(p,fn))
-            nafn = os.path.normcase(afn)
+            afn = os.path.normcase(afn)
             
-            if os.path.exists(nafn):
-                self._fncache[fn] = afn
+            if os.path.exists(afn):
+                self.fncache[fn] = afn
                 return afn
                 
         # Nothing found.
@@ -1182,11 +1161,6 @@ class DebugClientBase(object):
             if afn.startswith(d):
                 return 1
         
-        # special treatment for paths containing site-packages or dist-packages
-        for part in ["site-packages", "dist-packages"]:
-            if part in afn:
-                return 1
-        
         return 0
         
     def getRunning(self):
@@ -1229,9 +1203,6 @@ class DebugClientBase(object):
         @param scope 1 to report global variables, 0 for local variables (int)
         @param filter the indices of variable types to be filtered (list of int)
         """
-        if self.currentThread is None:
-            return
-        
         if scope == 0:
             self.framenr = frmnr
         
@@ -1271,9 +1242,6 @@ class DebugClientBase(object):
         @param scope 1 to report global variables, 0 for local variables (int)
         @param filter the indices of variable types to be filtered (list of int)
         """
-        if self.currentThread is None:
-            return
-        
         f = self.currentThread.getCurrentFrame()
         
         while f is not None and frmnr > 0:
@@ -1305,10 +1273,6 @@ class DebugClientBase(object):
             oaccess = ""
             odict = dict
             
-            qtVariable = False
-            qvar = None
-            qvtype = ""
-            
             while i < len(var):
                 if len(dict):
                     udict = dict
@@ -1374,15 +1338,6 @@ class DebugClientBase(object):
                             exec 'mdict = dict%s.__dict__' % access
                             ndict.update(mdict)
                             exec 'obj = dict%s' % access
-                            if "PyQt4." in str(type(obj)):
-                                qtVariable = True
-                                qvar = obj
-                                qvtype = ("%s" % type(qvar))[1:-1].split()[1][1:-1]
-                        except:
-                            pass
-                        try:
-                            exec 'mcdict = dict%s.__class__.__dict__' % access
-                            ndict.update(mcdict)
                             if mdict and not "sipThis" in mdict.keys():
                                 del rvar[0:2]
                                 access = ""
@@ -1399,22 +1354,13 @@ class DebugClientBase(object):
                             ndict.update(cdict)
                             exec 'obj = dict%s' % access
                             access = ""
-                            if "PyQt4." in str(type(obj)):
-                                qtVariable = True
-                                qvar = obj
-                                qvtype = ("%s" % type(qvar))[1:-1].split()[1][1:-1]
                         except:
                             pass
                     else:
                         try:
                             ndict.update(dict[var[i]].__dict__)
-                            ndict.update(dict[var[i]].__class__.__dict__)
                             del rvar[0]
                             obj = dict[var[i]]
-                            if "PyQt4." in str(type(obj)):
-                                qtVariable = True
-                                qvar = obj
-                                qvtype = ("%s" % type(qvar))[1:-1].split()[1][1:-1]
                         except:
                             pass
                         try:
@@ -1427,19 +1373,13 @@ class DebugClientBase(object):
                                     pass
                             ndict.update(cdict)
                             obj = dict[var[i]]
-                            if "PyQt4." in str(type(obj)):
-                                qtVariable = True
-                                qvar = obj
-                                qvtype = ("%s" % type(qvar))[1:-1].split()[1][1:-1]
                         except:
                             pass
                     odict = dict
                     dict = ndict
                 i += 1
             
-            if qtVariable:
-                vlist = self.__formatQt4Variable(qvar, qvtype)
-            elif ("sipThis" in dict.keys() and len(dict) == 1) or \
+            if ("sipThis" in dict.keys() and len(dict) == 1) or \
                (len(dict) == 0 and len(udict) > 0):
                 if access:
                     exec 'qvar = udict%s' % access
@@ -1454,49 +1394,30 @@ class DebugClientBase(object):
                 else:
                     vlist = []
             else:
-                qtVariable = False
-                if len(dict) == 0 and len(udict) > 0:
-                    if access:
-                        exec 'qvar = udict%s' % access
-                    # this has to be in line with VariablesViewer.indicators
-                    elif rvar and rvar[0][-2:] in ["[]", "()", "{}"]:
-                        exec 'qvar = udict["%s"][%s]' % (rvar[0][:-2], rvar[1])
-                    else:
-                        qvar = udict[var[-1]]
-                    qvtype = ("%s" % type(qvar))[1:-1].split()[1][1:-1]
-                    if qvtype.startswith("PyQt4"):
-                        qtVariable = True
-                
-                if qtVariable:
-                    vlist = self.__formatQt4Variable(qvar, qvtype)
+                # format the dictionary found
+                if dictkeys is None:
+                    dictkeys = dict.keys()
                 else:
-                    # format the dictionary found
-                    if dictkeys is None:
+                    # treatment for sequences and dictionaries
+                    if access:
+                        exec "dict = dict%s" % access
+                    else:
+                        dict = dict[dictkeys[0]]
+                    if isDict:
                         dictkeys = dict.keys()
                     else:
-                        # treatment for sequences and dictionaries
-                        if access:
-                            exec "dict = dict%s" % access
-                        else:
-                            dict = dict[dictkeys[0]]
-                        if isDict:
-                            dictkeys = dict.keys()
-                        else:
-                            dictkeys = range(len(dict))
-                    vlist = self.__formatVariablesList(dictkeys, dict, scope, filter, 
-                                                     formatSequences)
+                        dictkeys = range(len(dict))
+                vlist = self.__formatVariablesList(dictkeys, dict, scope, filter, 
+                                                 formatSequences)
             varlist.extend(vlist)
         
             if obj is not None and not formatSequences:
-                try:
-                    if unicode(repr(obj)).startswith('{'):
-                        varlist.append(('...', 'dict', "%d" % len(obj.keys())))
-                    elif unicode(repr(obj)).startswith('['):
-                        varlist.append(('...', 'list', "%d" % len(obj)))
-                    elif unicode(repr(obj)).startswith('('):
-                        varlist.append(('...', 'tuple', "%d" % len(obj)))
-                except:
-                    pass
+                if unicode(repr(obj)).startswith('{'):
+                    varlist.append(('...', 'dict', "%d" % len(obj.keys())))
+                elif unicode(repr(obj)).startswith('['):
+                    varlist.append(('...', 'list', "%d" % len(obj)))
+                elif unicode(repr(obj)).startswith('('):
+                    varlist.append(('...', 'tuple', "%d" % len(obj)))
         
         self.write('%s%s\n' % (ResponseVariable, unicode(varlist)))
         
@@ -1515,13 +1436,8 @@ class DebugClientBase(object):
         if qttype == 'QString':
             varlist.append(("", "QString", "%s" % unicode(value)))
         elif qttype == 'QStringList':
-            for i in range(value.count()):
-                varlist.append(("%d" % i, "QString", "%s" % unicode(value[i])))
-        elif qttype == 'QByteArray':
-            varlist.append(("hex", "QByteArray", "%s" % value.toHex()))
-            varlist.append(("base64", "QByteArray", "%s" % value.toBase64()))
-            varlist.append(("percent encoding", "QByteArray",
-                            "%s" % value.toPercentEncoding()))
+            for s in value:
+                varlist.append(("", "QString", "%s" % unicode(s)))
         elif qttype == 'QChar':
             varlist.append(("", "QChar", "%s" % unichr(value.unicode())))
             varlist.append(("", "int", "%d" % value.unicode()))
@@ -1696,14 +1612,7 @@ class DebugClientBase(object):
                         if valtype == "classobj":
                             if ConfigVarTypeStrings.index('instance') in filter:
                                 continue
-                        elif valtype == "sip.methoddescriptor":
-                            if ConfigVarTypeStrings.index('instance method') in filter:
-                                continue
-                        elif valtype == "sip.enumtype":
-                            if ConfigVarTypeStrings.index('class') in filter:
-                                continue
-                        elif not valtype.startswith("PySide") and \
-                             ConfigVarTypeStrings.index('other') in filter:
+                        elif ConfigVarTypeStrings.index('other') in filter:
                             continue
                     
                 try:
@@ -1819,7 +1728,7 @@ class DebugClientBase(object):
         self.__interact()
         
         # setup the debugger variables
-        self._fncache = {}
+        self.fncache = {}
         self.dircache = []
         self.mainFrame = None
         self.inRawMode = 0
@@ -1858,11 +1767,12 @@ class DebugClientBase(object):
         remoteAddress = self.__resolveHost(host)
         self.connectDebugger(port, remoteAddress, redirect)
         
-        self._fncache = {}
+        self.fncache = {}
         self.dircache = []
         sys.argv = progargs[:]
         sys.argv[0] = os.path.abspath(sys.argv[0])
-        sys.path = self.__getSysPath(os.path.dirname(sys.argv[0]))
+        sys.path[0] = os.path.dirname(sys.argv[0])
+        sys.path.insert(0, '')
         if wd == '':
             os.chdir(sys.path[1])
         else:
@@ -1948,7 +1858,7 @@ class DebugClientBase(object):
                     del args[0]
                     del args[0]
                 elif args[0] == '-p':
-                    port = int(args[1])
+                    port = long(args[1])
                     del args[0]
                     del args[0]
                 elif args[0] == '-w':
@@ -1967,14 +1877,6 @@ class DebugClientBase(object):
                 elif args[0] == '--no-encoding':
                     self.noencoding = True
                     del args[0]
-                elif args[0] == '--fork-child':
-                    self.fork_auto = True
-                    self.fork_child = True
-                    del args[0]
-                elif args[0] == '--fork-parent':
-                    self.fork_auto = True
-                    self.fork_child = False
-                    del args[0]
                 elif args[0] == '--':
                     del args[0]
                     break
@@ -1999,7 +1901,7 @@ class DebugClientBase(object):
             if sys.argv[1] == '':
                 del sys.argv[1]
             try:
-                port = int(sys.argv[1])
+                port = long(sys.argv[1])
             except (ValueError, IndexError):
                 port = -1
             try:
@@ -2066,19 +1968,3 @@ class DebugClientBase(object):
             return
         
         DebugClientOrigClose(fd)
-        
-    def __getSysPath(self, firstEntry):
-        """
-        Private slot to calculate a path list including the PYTHONPATH 
-        environment variable.
-        
-        @param firstEntry entry to be put first in sys.path (string)
-        @return path list for use as sys.path (list of strings)
-        """
-        sysPath = [path for path in os.environ.get("PYTHONPATH", "").split(os.pathsep) 
-                   if path not in sys.path] + sys.path[:]
-        if "" in sysPath:
-            sysPath.remove("")
-        sysPath.insert(0, firstEntry)
-        sysPath.insert(0, '')
-        return sysPath
