@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,7 +10,7 @@ Module defining type strings for the different Python types.
 ConfigVarTypeStrings = ['__', 'NoneType', 'type',\
         'bool', 'int', 'long', 'float', 'complex',\
         'str', 'unicode', 'tuple', 'list',\
-        'dict', 'dict-proxy', 'file', 'xrange',\
+        'dict', 'dict-proxy', 'set', 'file', 'xrange',\
         'slice', 'buffer', 'class', 'instance',\
         'instance method', 'property', 'generator',\
         'function', 'builtin_function_or_method', 'code', 'module',\
