@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -64,7 +64,6 @@ class DebugBase(bdb.Bdb):
         
         # current frame we are at
         self.currentFrame = None
-        self.currentFrameLocals = None
         
         # frame that we are stepping in, can be different than currentFrame
         self.stepFrame = None
@@ -88,14 +87,6 @@ class DebugBase(bdb.Bdb):
         """
         return self.currentFrame        
     
-    def getCurrentFrameLocals(self):
-        """
-        Public method to return the locals dictionary of the current frame.
-        
-        @return locals dictionary of the current frame
-        """
-        return self.currentFrameLocals        
-    
     def step(self, traceMode):
         """
         Public method to perform a step operation in this thread.
@@ -142,7 +133,7 @@ class DebugBase(bdb.Bdb):
     
     def profile(self, frame, event, arg):
         """
-        Public method used to trace some stuff independent of the debugger 
+        Public method used to trace some stuff independant of the debugger 
         trace function.
         
         @param frame The current stack frame.
@@ -546,9 +537,7 @@ class DebugBase(bdb.Bdb):
             self._dbgClient.mainFrame = frame
 
         self.currentFrame = frame
-        self.currentFrameLocals = frame.f_locals
-        # remember the locals because it is reinitialized when accessed
-
+        
         fr = frame
         stack = []
         while fr is not None:
@@ -588,14 +577,6 @@ class DebugBase(bdb.Bdb):
         exctype, excval, exctb = excinfo
         if exctype in [SystemExit, bdb.BdbQuit]:
             atexit._run_exitfuncs()
-            if excval is None:
-                excval = 0
-            elif isinstance(excval, str):
-                self._dbgClient.write(excval)
-                excval = 1
-            elif isinstance(excval, bytes):
-                self._dbgClient.write(excval.decode())
-                excval = 1
             if isinstance(excval, int):
                 self._dbgClient.progTerminated(excval)
             else:
@@ -634,8 +615,6 @@ class DebugBase(bdb.Bdb):
                 frlist.reverse()
                 
                 self.currentFrame = frlist[0]
-                self.currentFrameLocals = frlist[0].f_locals
-                # remember the locals because it is reinitialized when accessed
                 
                 for fr in frlist:
                     filename = self._dbgClient.absPath(self.fix_frame_filename(fr))
@@ -661,7 +640,7 @@ class DebugBase(bdb.Bdb):
         
         @param exctype type of the exception
         """
-        return str(exctype).replace("<class '", "").replace("'>", "")
+        return repr(exctype).replace("<class '", "").replace("'>", "")
     
     def __extract_stack(self, exctb):
         """
