@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -17,7 +17,7 @@ import time
 import imp
 import re
 import distutils.sysconfig
-import atexit
+import imp
 
 
 from DebugProtocol import *
@@ -178,7 +178,7 @@ class DebugClientBase(object):
         self.localsFilterObjects = []
 
         self.pendingResponse = ResponseOK
-        self._fncache = {}
+        self.fncache = {}
         self.dircache = []
         self.inRawMode = False
         self.mainProcStr = None     # used for the passive mode
@@ -450,7 +450,7 @@ class DebugClientBase(object):
                 return
 
             if cmd == RequestLoad:
-                self._fncache = {}
+                self.fncache = {}
                 self.dircache = []
                 sys.argv = []
                 wd, fn, args, tracePython = arg.split('|')
@@ -461,7 +461,8 @@ class DebugClientBase(object):
                     pass
                 sys.argv.append(fn)
                 sys.argv.extend(eval(args.replace("u'", "'")))
-                sys.path = self.__getSysPath(os.path.dirname(sys.argv[0]))
+                sys.path[0] = os.path.dirname(sys.argv[0])
+                sys.path.insert(0, '')
                 if wd == '':
                     os.chdir(sys.path[1])
                 else:
@@ -507,7 +508,8 @@ class DebugClientBase(object):
                     pass
                 sys.argv.append(fn)
                 sys.argv.extend(eval(args.replace("u'", "'")))
-                sys.path = self.__getSysPath(os.path.dirname(sys.argv[0]))
+                sys.path[0] = os.path.dirname(sys.argv[0])
+                sys.path.insert(0, '')
                 if wd == '':
                     os.chdir(sys.path[1])
                 else:
@@ -529,15 +531,8 @@ class DebugClientBase(object):
                 
                 self.debugMod.__dict__['__file__'] = sys.argv[0]
                 sys.modules['__main__'] = self.debugMod
-                res = 0
-                try:
-                    exec(open(sys.argv[0], encoding=self.__coding).read(),
-                         self.debugMod.__dict__)
-                except SystemExit as exc:
-                    res = exc.code
-                    atexit._run_exitfuncs()
+                exec(open(sys.argv[0]).read(), self.debugMod.__dict__)
                 self.writestream.flush()
-                self.progTerminated(res)
                 return
 
             if cmd == RequestProfile:
@@ -552,7 +547,8 @@ class DebugClientBase(object):
                     pass
                 sys.argv.append(fn)
                 sys.argv.extend(eval(args.replace("u'", "'")))
-                sys.path = self.__getSysPath(os.path.dirname(sys.argv[0]))
+                sys.path[0] = os.path.dirname(sys.argv[0])
+                sys.path.insert(0, '')
                 if wd == '':
                     os.chdir(sys.path[1])
                 else:
@@ -575,18 +571,9 @@ class DebugClientBase(object):
                 finally:
                     fp.close()
                 if script:
-                    if not script.endswith('\n'):
-                        script += '\n'
-                    self.running = sys.argv[0]
-                    res = 0
-                    try:
-                        self.prof.run(script)
-                    except SystemExit as exc:
-                        res = exc.code
-                        atexit._run_exitfuncs()
+                    self.prof.run("exec({0!r}\n)".format(script))
                     self.prof.save()
                     self.writestream.flush()
-                    self.progTerminated(res)
                 return
 
             if cmd == RequestCoverage:
@@ -600,7 +587,8 @@ class DebugClientBase(object):
                     pass
                 sys.argv.append(fn)
                 sys.argv.extend(eval(args.replace("u'", "'")))
-                sys.path = self.__getSysPath(os.path.dirname(sys.argv[0]))
+                sys.path[0] = os.path.dirname(sys.argv[0])
+                sys.path.insert(0, '')
                 if wd == '':
                     os.chdir(sys.path[1])
                 else:
@@ -619,27 +607,11 @@ class DebugClientBase(object):
                     self.cover.erase()
                 sys.modules['__main__'] = self.debugMod
                 self.debugMod.__dict__['__file__'] = sys.argv[0]
-                fp = open(sys.argv[0], encoding=self.__coding)
-                try:
-                    script = fp.read()
-                finally:
-                    fp.close()
-                if script:
-                    if not script.endswith('\n'):
-                        script += '\n'
-                    code = compile(script, sys.argv[0], 'exec')
-                    self.running = sys.argv[0]
-                    res = 0
-                    self.cover.start()
-                    try:
-                        exec(code, self.debugMod.__dict__)
-                    except SystemExit as exc:
-                        res = exc.code
-                        atexit._run_exitfuncs()
-                    self.cover.stop()
-                    self.cover.save()
-                    self.writestream.flush()
-                    self.progTerminated(res)
+                self.cover.start()
+                exec(open(sys.argv[0]).read(), self.debugMod.__dict__)
+                self.cover.stop()
+                self.cover.save()
+                self.writestream.flush()
                 return
 
             if cmd == RequestShutdown:
@@ -738,7 +710,7 @@ class DebugClientBase(object):
             if cmd == RequestEval:
                 try:
                     value = eval(arg, self.currentThread.getCurrentFrame().f_globals,
-                                      self.currentThread.getCurrentFrameLocals())
+                                      self.currentThread.getCurrentFrame().f_locals)
                 except:
                     # Report the exception and the traceback
                     try:
@@ -769,7 +741,7 @@ class DebugClientBase(object):
             
             if cmd == RequestExec:
                 _globals = self.currentThread.getCurrentFrame().f_globals
-                _locals = self.currentThread.getCurrentFrameLocals()
+                _locals = self.currentThread.getCurrentFrame().f_locals
                 try:
                     code = compile(arg + '\n', '<stdin>', 'single')
                     exec(code, _globals, _locals)
@@ -904,6 +876,8 @@ class DebugClientBase(object):
             for l in traceback.format_exception_only(sys.last_type, sys.last_value):
                 self.write(l)
             self.buffer = ''
+
+            self.__exceptionRaised()
         else:
             if code is None:
                 self.pendingResponse = ResponseContinue
@@ -932,7 +906,7 @@ class DebugClientBase(object):
                                     cf = cf.f_back
                                     frmnr -= 1
                                 _globals = cf.f_globals
-                                _locals = self.currentThread.getCurrentFrameLocals()
+                                _locals = cf.f_locals
                         # reset sys.stdout to our redirector (unconditionally)
                         if "sys" in _globals:
                             __stdout = _globals["sys"].stdout
@@ -968,6 +942,8 @@ class DebugClientBase(object):
                     for l in list:
                         self.write(l)
 
+                    self.__exceptionRaised()
+
     def __clientCapabilities(self):
         """
         Private method to determine the clients capabilities.
@@ -1096,20 +1072,12 @@ class DebugClientBase(object):
         if remoteAddress is None:                               # default: 127.0.0.1
             sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             sock.connect((DebugAddress, port))
-        else:
-            if "@@i" in remoteAddress:
-                remoteAddress, index = remoteAddress.split("@@i")
-            else:
-                index = 0
-            if ":" in remoteAddress:                              # IPv6
-                sockaddr = socket.getaddrinfo(
-                    remoteAddress, port, 0, 0, socket.SOL_TCP)[0][-1]
-                sock = socket.socket(socket.AF_INET6, socket.SOCK_STREAM)
-                sockaddr = sockaddr[:-1] + (int(index),)
-                sock.connect(sockaddr)
-            else:                                                   # IPv4
-                sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-                sock.connect((remoteAddress, port))
+        elif ":" in remoteAddress:                              # IPv6
+            sock = socket.socket(socket.AF_INET6, socket.SOCK_STREAM)
+            sock.connect((remoteAddress, port))
+        else:                                                   # IPv4
+            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            sock.connect((remoteAddress, port))
 
         self.readstream = AsyncFile(sock, sys.stdin.mode, sys.stdin.name)
         self.writestream = AsyncFile(sock, sys.stdout.mode, sys.stdout.name)
@@ -1148,16 +1116,16 @@ class DebugClientBase(object):
             return fn
 
         # Check the cache.
-        if fn in self._fncache:
-            return self._fncache[fn]
+        if fn in self.fncache:
+            return self.fncache[fn]
 
         # Search sys.path.
         for p in sys.path:
             afn = os.path.abspath(os.path.join(p, fn))
-            nafn = os.path.normcase(afn)
+            afn = os.path.normcase(afn)
 
-            if os.path.exists(nafn):
-                self._fncache[fn] = afn
+            if os.path.exists(afn):
+                self.fncache[fn] = afn
                 d = os.path.dirname(afn)
                 if (d not in sys.path) and (d not in self.dircache):
                     self.dircache.append(d)
@@ -1166,10 +1134,10 @@ class DebugClientBase(object):
         # Search the additional directory cache
         for p in self.dircache:
             afn = os.path.abspath(os.path.join(p, fn))
-            nafn = os.path.normcase(afn)
+            afn = os.path.normcase(afn)
             
-            if os.path.exists(nafn):
-                self._fncache[fn] = afn
+            if os.path.exists(afn):
+                self.fncache[fn] = afn
                 return afn
         
         # Nothing found.
@@ -1191,10 +1159,6 @@ class DebugClientBase(object):
             if afn.startswith(d):
                 return True
         
-        # special treatment for paths containing site-packages or dist-packages
-        for part in ["site-packages", "dist-packages"]:
-            if part in afn:
-                return True
         
         return False
     
@@ -1238,9 +1202,6 @@ class DebugClientBase(object):
         @param scope 1 to report global variables, 0 for local variables (int)
         @param filter the indices of variable types to be filtered (list of int)
         """
-        if self.currentThread is None:
-            return
-        
         if scope == 0:
             self.framenr = frmnr
         
@@ -1280,9 +1241,6 @@ class DebugClientBase(object):
         @param scope 1 to report global variables, 0 for local variables (int)
         @param filter the indices of variable types to be filtered (list of int)
         """
-        if self.currentThread is None:
-            return
-        
         f = self.currentThread.getCurrentFrame()
         
         while f is not None and frmnr > 0:
@@ -1314,10 +1272,6 @@ class DebugClientBase(object):
             oaccess = ""
             odict = dict
             
-            qtVariable = False
-            qvar = None
-            qvtype = ""
-            
             while i < len(var):
                 if len(dict):
                     udict = dict
@@ -1385,18 +1339,7 @@ class DebugClientBase(object):
                                  .format(access), globals(), loc)
                             mdict = loc["mdict"]
                             obj = loc["obj"]
-                            if "PyQt4." in str(type(obj)):
-                                qtVariable = True
-                                qvar = obj
-                                qvtype = str(type(qvar))[1:-1].split()[1][1:-1]
                             ndict.update(mdict)
-                        except:
-                            pass
-                        try:
-                            loc = {"dict": dict}
-                            exec('mcdict = dict{0!s}.__class__.__dict__'\
-                                 .format(access), globals(), loc)
-                            ndict.update(loc["mcdict"])
                             if mdict and not "sipThis" in mdict.keys():
                                 del rvar[0:2]
                                 access = ""
@@ -1417,22 +1360,13 @@ class DebugClientBase(object):
                             exec('obj = dict{0!s}'.format(access), globals(), loc)
                             obj = loc["obj"]
                             access = ""
-                            if "PyQt4." in str(type(obj)):
-                                qtVariable = True
-                                qvar = obj
-                                qvtype = str(type(qvar))[1:-1].split()[1][1:-1]
                         except:
                             pass
                     else:
                         try:
                             ndict.update(dict[var[i]].__dict__)
-                            ndict.update(dict[var[i]].__class__.__dict__)
                             del rvar[0]
                             obj = dict[var[i]]
-                            if "PyQt4." in str(type(obj)):
-                                qtVariable = True
-                                qvar = obj
-                                qvtype = str(type(qvar))[1:-1].split()[1][1:-1]
                         except:
                             pass
                         try:
@@ -1447,19 +1381,13 @@ class DebugClientBase(object):
                                     pass
                             ndict.update(loc["cdict"])
                             obj = dict[var[i]]
-                            if "PyQt4." in str(type(obj)):
-                                qtVariable = True
-                                qvar = obj
-                                qvtype = str(type(qvar))[1:-1].split()[1][1:-1]
                         except:
                             pass
                     odict = dict
                     dict = ndict
                 i += 1
             
-            if qtVariable:
-                vlist = self.__formatQt4Variable(qvar, qvtype)
-            elif ("sipThis" in dict.keys() and len(dict) == 1) or \
+            if ("sipThis" in dict.keys() and len(dict) == 1) or \
                (len(dict) == 0 and len(udict) > 0):
                 if access:
                     loc = {"udict" : udict}
@@ -1479,56 +1407,32 @@ class DebugClientBase(object):
                 else:
                     vlist = []
             else:
-                qtVariable = False
-                if len(dict) == 0 and len(udict) > 0:
-                    if access:
-                        loc = {"udict" : udict}
-                        exec('qvar = udict{0!s}'.format(access), globals(), loc)
-                        qvar = loc["qvar"]
-                    # this has to be in line with VariablesViewer.indicators
-                    elif rvar and rvar[0][-2:] in ["[]", "()", "{}"]:
-                        loc = {"udict" : udict}
-                        exec('qvar = udict["{0!s}"][{1!s}]'.format(rvar[0][:-2], rvar[1]), 
-                             globals(), loc)
-                        qvar = loc["qvar"]
-                    else:
-                        qvar = udict[var[-1]]
-                    qvtype = str(type(qvar))[1:-1].split()[1][1:-1]
-                    if qvtype.startswith("PyQt4"):
-                        qtVariable = True
-                
-                if qtVariable:
-                    vlist = self.__formatQt4Variable(qvar, qvtype)
+                # format the dictionary found
+                if dictkeys is None:
+                    dictkeys = dict.keys()
                 else:
-                    # format the dictionary found
-                    if dictkeys is None:
+                    # treatment for sequences and dictionaries
+                    if access:
+                        loc = {"dict" : dict}
+                        exec("dict = dict{0!s}".format(access), globals(), loc)
+                        dict = loc["dict"]
+                    else:
+                        dict = dict[dictkeys[0]]
+                    if isDict:
                         dictkeys = dict.keys()
                     else:
-                        # treatment for sequences and dictionaries
-                        if access:
-                            loc = {"dict" : dict}
-                            exec("dict = dict{0!s}".format(access), globals(), loc)
-                            dict = loc["dict"]
-                        else:
-                            dict = dict[dictkeys[0]]
-                        if isDict:
-                            dictkeys = dict.keys()
-                        else:
-                            dictkeys = range(len(dict))
-                    vlist = self.__formatVariablesList(dictkeys, dict, scope, filter, 
-                                                     formatSequences)
+                        dictkeys = range(len(dict))
+                vlist = self.__formatVariablesList(dictkeys, dict, scope, filter, 
+                                                   formatSequences)
             varlist.extend(vlist)
         
             if obj is not None and not formatSequences:
-                try:
-                    if repr(obj).startswith('{'):
-                        varlist.append(('...', 'dict', "{0:d}".format(len(obj.keys()))))
-                    elif repr(obj).startswith('['):
-                        varlist.append(('...', 'list', "{0:d}".format(len(obj))))
-                    elif repr(obj).startswith('('):
-                        varlist.append(('...', 'tuple', "{0:d}".format(len(obj))))
-                except:
-                    pass
+                if repr(obj).startswith('{'):
+                    varlist.append(('...', 'dict', "{0:d}".format(len(obj.keys()))))
+                elif repr(obj).startswith('['):
+                    varlist.append(('...', 'list', "{0:d}".format(len(obj))))
+                elif repr(obj).startswith('('):
+                    varlist.append(('...', 'tuple', "{0:d}".format(len(obj))))
         
         self.write('{0}{1}\n'.format(ResponseVariable, str(varlist)))
         
@@ -1544,15 +1448,14 @@ class DebugClientBase(object):
         """
         qttype = vtype.split('.')[-1]
         varlist = []
-        if qttype == 'QChar':
+        if qttype == 'QString':
+            varlist.append(("", "QString", "{0}".format(value)))
+        elif qttype == 'QStringList':
+            for s in value:
+                varlist.append(("", "QString", "{0}".format(s)))
+        elif qttype == 'QChar':
             varlist.append(("", "QChar", "{0}".format(chr(value.unicode()))))
             varlist.append(("", "int", "{0:d}".format(value.unicode())))
-        elif qttype == 'QByteArray':
-            varlist.append(("bytes", "QByteArray", "{0}".format(bytes(value))[2:-1]))
-            varlist.append(("hex", "QByteArray", "{0}".format(value.toHex())[2:-1]))
-            varlist.append(("base64", "QByteArray", "{0}".format(value.toBase64())[2:-1]))
-            varlist.append(("percent encoding", "QByteArray",
-                            "{0}".format(value.toPercentEncoding())[2:-1]))
         elif qttype == 'QPoint':
             varlist.append(("x", "int", "{0:d}".format(value.x())))
             varlist.append(("y", "int", "{0:d}".format(value.y())))
@@ -1717,12 +1620,6 @@ class DebugClientBase(object):
                 if valtype not in ConfigVarTypeStrings:
                     if ConfigVarTypeStrings.index('instance') in filter:
                         continue
-                    elif valtype == "sip.methoddescriptor":
-                        if ConfigVarTypeStrings.index('instance method') in filter:
-                            continue
-                    elif valtype == "sip.enumtype":
-                        if ConfigVarTypeStrings.index('class') in filter:
-                            continue
                     valtype = valtypestr
                 else:
                     try:
@@ -1732,14 +1629,7 @@ class DebugClientBase(object):
                         if valtype == "classobj":
                             if ConfigVarTypeStrings.index('instance') in filter:
                                 continue
-                        elif valtype == "sip.methoddescriptor":
-                            if ConfigVarTypeStrings.index('instance method') in filter:
-                                continue
-                        elif valtype == "sip.enumtype":
-                            if ConfigVarTypeStrings.index('class') in filter:
-                                continue
-                        elif not valtype.startswith("PySide") and \
-                             ConfigVarTypeStrings.index('other') in filter:
+                        elif ConfigVarTypeStrings.index('other') in filter:
                             continue
                 
                 try:
@@ -1855,7 +1745,7 @@ class DebugClientBase(object):
         self.__interact()
         
         # setup the debugger variables
-        self._fncache = {}
+        self.fncache = {}
         self.dircache = []
         self.mainFrame = None
         self.inRawMode = False
@@ -1894,11 +1784,12 @@ class DebugClientBase(object):
         remoteAddress = self.__resolveHost(host)
         self.connectDebugger(port, remoteAddress, redirect)
         
-        self._fncache = {}
+        self.fncache = {}
         self.dircache = []
         sys.argv = progargs[:]
         sys.argv[0] = os.path.abspath(sys.argv[0])
-        sys.path = self.__getSysPath(os.path.dirname(sys.argv[0]))
+        sys.path[0] = os.path.dirname(sys.argv[0])
+        sys.path.insert(0, '')
         if wd == '':
             os.chdir(sys.path[1])
         else:
@@ -2003,14 +1894,6 @@ class DebugClientBase(object):
                 elif args[0] == '--no-encoding':
                     self.noencoding = True
                     del args[0]
-                elif args[0] == '--fork-child':
-                    self.fork_auto = True
-                    self.fork_child = True
-                    del args[0]
-                elif args[0] == '--fork-parent':
-                    self.fork_auto = True
-                    self.fork_child = False
-                    del args[0]
                 elif args[0] == '--':
                     del args[0]
                     break
@@ -2103,19 +1986,3 @@ class DebugClientBase(object):
             return
         
         DebugClientOrigClose(fd)
-        
-    def __getSysPath(self, firstEntry):
-        """
-        Private slot to calculate a path list including the PYTHONPATH 
-        environment variable.
-        
-        @param firstEntry entry to be put first in sys.path (string)
-        @return path list for use as sys.path (list of strings)
-        """
-        sysPath = [path for path in os.environ.get("PYTHONPATH", "").split(os.pathsep) 
-                   if path not in sys.path] + sys.path[:]
-        if "" in sysPath:
-            sysPath.remove("")
-        sysPath.insert(0, firstEntry)
-        sysPath.insert(0, '')
-        return sysPath
