@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 =begin edoc
@@ -690,14 +690,6 @@ being debugged redirects them itself.
         if remoteAddress == nil
             sock = TCPSocket.new(DebugAddress, port)
         else
-            if remoteAddress =~ /@@i/
-                remoteAddress, interface = remoteAddress.split("@@i")
-            else
-                interface = 0
-            end
-            if remoteAddress.downcase =~ /^fe80/
-                remoteAddress = "%s%%%s" % [remoteAddress, interface]
-            end
             sock = TCPSocket.new(remoteAddress, port)
         end
         
