@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -14,7 +14,7 @@ import signal
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui import QMessageBox
-from PyQt4.QtNetwork import QTcpServer, QHostAddress, QHostInfo, QNetworkInterface
+from PyQt4.QtNetwork import QTcpServer, QHostAddress, QHostInfo
 
 from KdeQt import KQMessageBox
 from KdeQt.KQApplication import e4App
@@ -113,24 +113,18 @@ class DebugServer(QTcpServer):
         elif self.networkInterface == "allv6":
             hostAddress = QHostAddress(QHostAddress.AnyIPv6)
         else:
-            hostAddress = QHostAddress(self.networkInterface)
-        self.networkInterfaceName, self.networkInterfaceIndex = \
-            self.__getNetworkInterfaceAndIndex(self.networkInterface)
-        
+            hostAddress = QHostAddress(Preferences.getDebugger("NetworkInterface"))
         if Preferences.getDebugger("PassiveDbgEnabled"):
-            sock = Preferences.getDebugger("PassiveDbgPort") # default: 42424
-            self.listen(hostAddress, sock)
+            socket = Preferences.getDebugger("PassiveDbgPort") # default: 42424
+            self.listen(hostAddress, socket)
             self.passive = True
             self.passiveClientExited = False
         else:
-            if hostAddress.toString().toLower().startsWith("fe80"):
-                hostAddress.setScopeId(self.networkInterfaceName)
             self.listen(hostAddress)
             self.passive = False
         
         self.debuggerInterface = None
         self.debugging = False
-        self.running = False
         self.clientProcess = None
         self.clientType = Preferences.Prefs.settings.value(\
             'DebugClient/Type', QVariant('Python')).toString()
@@ -187,27 +181,7 @@ class DebugServer(QTcpServer):
             else:
                 return "%s@@v6" % QHostInfo.localHostName()
         else:
-            return "{0}@@i{1}".format(self.networkInterface,
-                                      self.networkInterfaceIndex)
-        
-    def __getNetworkInterfaceAndIndex(self, address):
-        """
-        Private method to determine the network interface and the interface index.
-        
-        @param address address to determine the info for (string or QString)
-        @return tuple of network interface name (string) and index (integer)
-        """
-        address = unicode(address)
-        if address not in ["all", "allv6"]:
-            for networkInterface in QNetworkInterface.allInterfaces():
-                addressEntries = networkInterface.addressEntries()
-                if len(addressEntries) > 0:
-                    for addressEntry in addressEntries:
-                        if addressEntry.ip().toString().toLower() == address.lower():
-                            return unicode(networkInterface.name()), \
-                                   networkInterface.index()
-        
-        return "", 0
+            return self.networkInterface
         
     def preferencesChanged(self):
         """
@@ -320,7 +294,6 @@ class DebugServer(QTcpServer):
         @keyparam runInConsole flag indicating to start the debugger in a 
             console window (boolean)
         """
-        self.running = False
         if not self.passive or not self.passiveClientExited: 
             if self.debuggerInterface and self.debuggerInterface.isConnected():
                 self.shutdownServer()
@@ -336,8 +309,9 @@ class DebugServer(QTcpServer):
                                 self.__clientProcessError)
                 self.disconnect(self.clientProcess, SIGNAL("readyReadStandardOutput()"), 
                                 self.__clientProcessOutput)
+                self.clientProcess.close()
                 self.clientProcess.kill()
-                self.clientProcess.waitForFinished(1000)
+                self.clientProcess.waitForFinished(10000)
                 self.clientProcess = None
             
             self.__createDebuggerInterface()
@@ -676,13 +650,11 @@ class DebugServer(QTcpServer):
         self.debuggerInterface.remoteLoad(fn, argv, wd, tracePython, autoContinue, 
                                           autoFork, forkChild)
         self.debugging = True
-        self.running = True
         self.__restoreBreakpoints()
         self.__restoreWatchpoints()
 
     def remoteRun(self, fn, argv, wd, env, autoClearShell = True,
-                  forProject = False, runInConsole = False, 
-                  autoFork = False, forkChild = False):
+                  forProject = False, runInConsole = False):
         """
         Public method to load a new program to run.
         
@@ -695,8 +667,6 @@ class DebugServer(QTcpServer):
         @keyparam forProject flag indicating a project related action (boolean)
         @keyparam runInConsole flag indicating to start the debugger in a 
             console window (boolean)
-        @keyparam autoFork flag indicating the automatic fork mode (boolean)
-        @keyparam forkChild flag indicating to debug the child after forking (boolean)
         """
         self.__autoClearShell = autoClearShell
         
@@ -709,9 +679,8 @@ class DebugServer(QTcpServer):
         
         self.remoteEnvironment(env)
         
-        self.debuggerInterface.remoteRun(fn, argv, wd, autoFork, forkChild)
+        self.debuggerInterface.remoteRun(fn, argv, wd)
         self.debugging = False
-        self.running = True
 
     def remoteCoverage(self, fn, argv, wd, env, autoClearShell = True,
                        erase = False, forProject = False, runInConsole = False):
@@ -743,7 +712,6 @@ class DebugServer(QTcpServer):
         
         self.debuggerInterface.remoteCoverage(fn, argv, wd, erase)
         self.debugging = False
-        self.running = True
 
     def remoteProfile(self, fn, argv, wd, env, autoClearShell = True,
                       erase = False, forProject = False, 
@@ -775,7 +743,6 @@ class DebugServer(QTcpServer):
         
         self.debuggerInterface.remoteProfile(fn, argv, wd, erase)
         self.debugging = False
-        self.running = True
 
     def remoteStatement(self, stmt):
         """
@@ -992,7 +959,6 @@ class DebugServer(QTcpServer):
         
         self.debuggerInterface.remoteUTPrepare(fn, tn, tfn, cov, covname, coverase)
         self.debugging = False
-        self.running = True
         
     def remoteUTRun(self):
         """
@@ -1084,8 +1050,7 @@ class DebugServer(QTcpServer):
         @param stackTrace list of stack entries with the exception position
             first. Each stack entry is a list giving the filename and the linenumber.
         """
-        if self.running:
-            self.emit(SIGNAL('clientException'), exceptionType, exceptionMessage, stackTrace)
+        self.emit(SIGNAL('clientException'), exceptionType, exceptionMessage, stackTrace)
         
     def clientSyntaxError(self, message, filename, lineNo, characterNo):
         """
@@ -1096,8 +1061,7 @@ class DebugServer(QTcpServer):
         @param lineNo line number of the syntax error position (integer)
         @param characterNo character number of the syntax error position (integer)
         """
-        if self.running:
-            self.emit(SIGNAL('clientSyntaxError'), message, filename, lineNo, characterNo)
+        self.emit(SIGNAL('clientSyntaxError'), message, filename, lineNo, characterNo)
         
     def clientExit(self, status):
         """
@@ -1114,7 +1078,6 @@ class DebugServer(QTcpServer):
             self.__createDebuggerInterface("None")
             self.clientOutput(self.trUtf8('\nNot connected\n'))
             self.clientStatement(False)
-        self.running = False
         
     def clientClearBreak(self, filename, lineno):
         """
@@ -1247,7 +1210,6 @@ class DebugServer(QTcpServer):
         print unicode(self.trUtf8("Passive debug connection received"))
         self.passiveClientExited = False
         self.debugging = True
-        self.running = True
         self.__restoreBreakpoints()
         self.__restoreWatchpoints()
         self.emit(SIGNAL('passiveDebugStarted'), fn, exc)
