@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -117,10 +117,9 @@ class DebuggerInterfacePython(QObject):
         @param program name of the executable to start (string)
         @param arguments arguments to be passed to the program (list of string)
         @param environment dictionary of environment settings to pass (dict of string)
-        @return the process object (QProcess) or None and an error string (QString)
+        @return the process object (QProcess) or None
         """
         proc = QProcess()
-        errorStr = QString()
         if environment is not None:
             env = QStringList()
             for key, value in environment.items():
@@ -131,10 +130,9 @@ class DebuggerInterfacePython(QObject):
             args.append(arg)
         proc.start(program, args)
         if not proc.waitForStarted(10000):
-            errorStr = proc.errorString()
             proc = None
         
-        return proc, errorStr
+        return proc
         
     def startRemote(self, port, runInConsole):
         """
@@ -181,13 +179,12 @@ class DebuggerInterfacePython(QObject):
                        [rhost, interpreter, os.path.abspath(debugClient),
                         noencoding, str(port), redirect, ipaddr]
                 args[0] = Utilities.getExecutablePath(args[0])
-                process, error = self.__startProcess(args[0], args[1:])
+                process = self.__startProcess(args[0], args[1:])
                 if process is None:
                     KQMessageBox.critical(None,
                         self.trUtf8("Start Debugger"),
                         self.trUtf8(\
-                            """<p>The debugger backend could not be started.</p>"""
-                            """<p>Reason: %1</p>""").arg(error))
+                            """<p>The debugger backend could not be started.</p>"""))
                 
                 # set translation function
                 if Preferences.getDebugger("PathTranslation"):
@@ -227,24 +224,21 @@ class DebuggerInterfacePython(QObject):
                        [interpreter, os.path.abspath(debugClient),
                         noencoding, str(port), '0', ipaddr]
                 args[0] = Utilities.getExecutablePath(args[0])
-                process, error = self.__startProcess(args[0], args[1:], clientEnv)
+                process = self.__startProcess(args[0], args[1:], clientEnv)
                 if process is None:
                     KQMessageBox.critical(None,
                         self.trUtf8("Start Debugger"),
                         self.trUtf8(\
-                            """<p>The debugger backend could not be started.</p>"""
-                            """<p>Reason: %1</p>""").arg(error))
+                            """<p>The debugger backend could not be started.</p>"""))
                 return process, self.__isNetworked
         
-        process, error = self.__startProcess(interpreter, 
+        process = self.__startProcess(interpreter, 
             [debugClient, noencoding, str(port), redirect, ipaddr], 
             clientEnv)
         if process is None:
             KQMessageBox.critical(None,
                 self.trUtf8("Start Debugger"),
-                self.trUtf8(
-                    """<p>The debugger backend could not be started.</p>"""
-                    """<p>Reason: %1</p>""").arg(error))
+                self.trUtf8("""<p>The debugger backend could not be started.</p>"""))
         return process, self.__isNetworked
 
     def startRemoteForProject(self, port, runInConsole):
@@ -280,13 +274,12 @@ class DebuggerInterfacePython(QObject):
                        [rhost, interpreter, os.path.abspath(debugClient),
                         noencoding, str(port), redirect, ipaddr]
                 args[0] = Utilities.getExecutablePath(args[0])
-                process, error = self.__startProcess(args[0], args[1:])
+                process = self.__startProcess(args[0], args[1:])
                 if process is None:
                     KQMessageBox.critical(None,
                         self.trUtf8("Start Debugger"),
                         self.trUtf8(\
-                            """<p>The debugger backend could not be started.</p>"""
-                            """<p>Reason: %1</p>""").arg(error))
+                            """<p>The debugger backend could not be started.</p>"""))
                 # set translation function
                 if project.getDebugProperty("PATHTRANSLATION"):
                     self.translateRemote = project.getDebugProperty("REMOTEPATH")
@@ -324,24 +317,21 @@ class DebuggerInterfacePython(QObject):
                        [interpreter, os.path.abspath(debugClient),
                         noencoding, str(port), '0', ipaddr]
                 args[0] = Utilities.getExecutablePath(args[0])
-                process, error = self.__startProcess(args[0], args[1:], clientEnv)
+                process = self.__startProcess(args[0], args[1:], clientEnv)
                 if process is None:
                     KQMessageBox.critical(None,
                         self.trUtf8("Start Debugger"),
                         self.trUtf8(\
-                            """<p>The debugger backend could not be started.</p>"""
-                            """<p>Reason: %1</p>""").arg(error))
+                            """<p>The debugger backend could not be started.</p>"""))
                 return process, self.__isNetworked
         
-        process, error = self.__startProcess(interpreter, 
+        process = self.__startProcess(interpreter, 
             [debugClient, noencoding, str(port), redirect, ipaddr], 
             clientEnv)
         if process is None:
             KQMessageBox.critical(None,
                 self.trUtf8("Start Debugger"),
-                self.trUtf8(
-                    """<p>The debugger backend could not be started.</p>"""
-                    """<p>Reason: %1</p>""").arg(error))
+                self.trUtf8("""<p>The debugger backend could not be started.</p>"""))
         return process, self.__isNetworked
 
     def getClientCapabilities(self):
@@ -356,7 +346,7 @@ class DebuggerInterfacePython(QObject):
         """
         Public slot to handle a new connection.
         
-        @param sock reference to the socket object (QTcpSocket)
+        @param sockreference to the socket object (QTcpSocket)
         @return flag indicating success (boolean)
         """
         # If we already have a connection, refuse this one.  It will be closed
@@ -448,19 +438,16 @@ class DebuggerInterfacePython(QObject):
             (RequestLoad, unicode(wd),
              unicode(fn), unicode(Utilities.parseOptionString(argv)), traceInterpreter))
         
-    def remoteRun(self, fn, argv, wd, autoFork = False, forkChild = False):
+    def remoteRun(self, fn, argv, wd):
         """
         Public method to load a new program to run.
         
         @param fn the filename to run (string)
         @param argv the commandline arguments to pass to the program (string or QString)
         @param wd the working directory for the program (string)
-        @keyparam autoFork flag indicating the automatic fork mode (boolean)
-        @keyparam forkChild flag indicating to debug the child after forking (boolean)
         """
         wd = self.translate(wd, False)
         fn = self.translate(os.path.abspath(unicode(fn)), False)
-        self.__sendCommand('%s%s\n' % (RequestForkMode, repr((autoFork, forkChild))))
         self.__sendCommand('%s%s|%s|%s\n' % \
             (RequestRun, unicode(wd),
              unicode(fn), unicode(Utilities.parseOptionString(argv))))
@@ -835,8 +822,6 @@ class DebuggerInterfacePython(QObject):
                         exctype = exclist[0]
                         excmessage = exclist[1]
                         stack = exclist[2:]
-                        if stack and stack[0] and stack[0][0] == "<string>":
-                            stack = []
                     except (IndexError, ValueError, SyntaxError):
                         exctype = None
                         excmessage = ''
