@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -36,30 +36,10 @@ class VariableItem(QTreeWidgetItem):
         @param dvalue value string (string or QString)
         @param dtype type string (string or QString)
         """
-        self.__value = QString(dvalue)
+        self.value = QString(dvalue)
         if len(dvalue) > 2048:     # 1024 * 2
             dvalue = QApplication.translate("VariableItem", 
                                             "<double click to show value>")
-            self.__tooltip = QString(dvalue)
-        else:
-            if Qt.mightBeRichText(dvalue):
-                self.__tooltip = Qt.escape(dvalue)
-            else:
-                self.__tooltip = dvalue
-            lines = QString(dvalue).split(QRegExp(r"\r\n|\r|\n"))
-            if len(lines) > 1:
-                # only show the first non-empty line;
-                # indicate skipped lines by <...> at the
-                # beginning and/or end
-                index = 0
-                while index < len(lines) - 1 and lines[index].isEmpty():
-                    index += 1
-                dvalue = QString("")
-                if index > 0:
-                    dvalue += QString("<...>")
-                dvalue += lines[index]
-                if index < len(lines) - 1:
-                    dvalue += QString("<...>")
         
         QTreeWidgetItem.__init__(self, parent, QStringList() << dvar << dvalue << dtype)
         
@@ -71,7 +51,7 @@ class VariableItem(QTreeWidgetItem):
         
         @return value of the item (QString)
         """
-        return self.__value
+        return self.value
         
     def data(self, column, role):
         """
@@ -85,7 +65,7 @@ class VariableItem(QTreeWidgetItem):
         @return requested data (QVariant)
         """
         if column == 1 and role == Qt.ToolTipRole:
-            return self.__tooltip
+            role = Qt.DisplayRole
         return QTreeWidgetItem.data(self, column, role)
         
     def attachDummy(self):
