@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,9 +8,8 @@ Module implementing a sidebar class.
 """
 
 from PyQt4.QtCore import SIGNAL,  SLOT, QEvent, QSize, Qt, QByteArray, \
-    QDataStream, QIODevice, QTimer
-from PyQt4.QtGui import QTabBar, QWidget, QStackedWidget, QBoxLayout, QToolButton, \
-    QSizePolicy
+                         QDataStream, QIODevice
+from PyQt4.QtGui import QTabBar, QWidget, QStackedWidget, QBoxLayout, QToolButton
 
 from KdeQt.KQApplication import e4App
 
@@ -28,12 +27,11 @@ class E4SideBar(QWidget):
     South = 2
     West  = 3
     
-    def __init__(self, orientation = None, delay = 200, parent = None):
+    def __init__(self, orientation = None, parent = None):
         """
         Constructor
         
         @param orientation orientation of the sidebar widget (North, East, South, West)
-        @param delay value for the expand/shrink delay in milliseconds (integer)
         @param parent parent widget (QWidget)
         """
         QWidget.__init__(self, parent)
@@ -41,8 +39,6 @@ class E4SideBar(QWidget):
         self.__tabBar = QTabBar()
         self.__tabBar.setDrawBase(True)
         self.__tabBar.setShape(QTabBar.RoundedNorth)
-        self.__tabBar.setUsesScrollButtons(True)
-        self.__tabBar.setDrawBase(False)
         self.__stackedWidget = QStackedWidget(self)
         self.__stackedWidget.setContentsMargins(0, 0, 0, 0)
         self.__autoHideButton = QToolButton()
@@ -62,13 +58,6 @@ class E4SideBar(QWidget):
         self.layout.addWidget(self.__stackedWidget)
         self.setLayout(self.layout)
         
-        # initialize the delay timer
-        self.__actionMethod = None
-        self.__delayTimer = QTimer(self)
-        self.__delayTimer.setSingleShot(True)
-        self.__delayTimer.setInterval(delay)
-        self.connect(self.__delayTimer, SIGNAL("timeout()"), self.__delayedAction)
-        
         self.__minimized = False
         self.__minSize = 0
         self.__maxSize = 0
@@ -101,74 +90,20 @@ class E4SideBar(QWidget):
         @param splitter reference to the splitter (QSplitter)
         """
         self.splitter = splitter
-        self.connect(self.splitter, SIGNAL("splitterMoved(int, int)"), 
-                     self.__splitterMoved)
-        self.splitter.setChildrenCollapsible(False)
-        index = self.splitter.indexOf(self)
-        self.splitter.setCollapsible(index, False)
-    
-    def __splitterMoved(self, pos, index):
-        """
-        Private slot to react on splitter moves.
-        
-        @param pos new position of the splitter handle (integer)
-        @param index index of the splitter handle (integer)
-        """
-        if self.splitter:
-            self.splitterSizes = self.splitter.sizes()
-    
-    def __delayedAction(self):
-        """
-        Private slot to handle the firing of the delay timer.
-        """
-        if self.__actionMethod is not None:
-            self.__actionMethod()
-    
-    def setDelay(self, delay):
-        """
-        Public method to set the delay value for the expand/shrink delay in milliseconds.
-        
-        @param delay value for the expand/shrink delay in milliseconds (integer)
-        """
-        self.__delayTimer.setInterval(delay)
-    
-    def delay(self):
-        """
-        Public method to get the delay value for the expand/shrink delay in milliseconds.
-        
-        @return value for the expand/shrink delay in milliseconds (integer)
-        """
-        return self.__delayTimer.interval()
-    
-    def __cancelDelayTimer(self):
-        """
-        Private method to cancel the current delay timer.
-        """
-        self.__delayTimer.stop()
-        self.__actionMethod = None
     
     def shrink(self):
         """
-        Public method to record a shrink request.
-        """
-        self.__delayTimer.stop()
-        self.__actionMethod = self.__shrinkIt
-        self.__delayTimer.start()
-   
-    def __shrinkIt(self):
-        """
-        Private method to shrink the sidebar.
+        Public method to shrink the sidebar.
         """
         self.__minimized = True
         self.__bigSize = self.size()
         if self.__orientation in [E4SideBar.North, E4SideBar.South]:
-            self.__minSize = self.minimumSizeHint().height()
+            self.__minSize = self.minimumHeight()
             self.__maxSize = self.maximumHeight()
         else:
-            self.__minSize = self.minimumSizeHint().width()
+            self.__minSize = self.minimumWidth()
             self.__maxSize = self.maximumWidth()
-        if self.splitter:
-            self.splitterSizes = self.splitter.sizes()
+        self.splitterSizes = self.splitter.sizes()
         
         self.__stackedWidget.hide()
         
@@ -176,18 +111,8 @@ class E4SideBar(QWidget):
             self.setFixedHeight(self.__tabBar.minimumSizeHint().height())
         else:
             self.setFixedWidth(self.__tabBar.minimumSizeHint().width())
-        
-        self.__actionMethod = None
     
     def expand(self):
-        """
-        Private method to record a expand request.
-        """
-        self.__delayTimer.stop()
-        self.__actionMethod = self.__expandIt
-        self.__delayTimer.start()
-    
-    def __expandIt(self):
         """
         Public method to expand the sidebar.
         """
@@ -195,17 +120,12 @@ class E4SideBar(QWidget):
         self.__stackedWidget.show()
         self.resize(self.__bigSize)
         if self.__orientation in [E4SideBar.North, E4SideBar.South]:
-            minSize = max(self.__minSize, self.minimumSizeHint().height())
-            self.setMinimumHeight(minSize)
+            self.setMinimumHeight(self.__minSize)
             self.setMaximumHeight(self.__maxSize)
         else:
-            minSize = max(self.__minSize, self.minimumSizeHint().width())
-            self.setMinimumWidth(minSize)
+            self.setMinimumWidth(self.__minSize)
             self.setMaximumWidth(self.__maxSize)
-        if self.splitter:
-            self.splitter.setSizes(self.splitterSizes)
-        
-        self.__actionMethod = None
+        self.splitter.setSizes(self.splitterSizes)
     
     def isMinimized(self):
         """
@@ -234,8 +154,10 @@ class E4SideBar(QWidget):
         if obj == self.__tabBar:
             if evt.type() == QEvent.MouseButtonPress:
                 pos = evt.pos()
+                index = -1
                 for i in range(self.__tabBar.count()):
                     if self.__tabBar.tabRect(i).contains(pos):
+                        index = i
                         break
                 
                 if i == self.__tabBar.currentIndex():
@@ -266,16 +188,10 @@ class E4SideBar(QWidget):
             used, if the second parameter is a QIcon)
         """
         if label:
-            index = self.__tabBar.addTab(iconOrLabel, label)
-            self.__tabBar.setTabToolTip(index, label)
+            self.__tabBar.addTab(iconOrLabel, label)
         else:
-            index = self.__tabBar.addTab(iconOrLabel)
-            self.__tabBar.setTabToolTip(index, iconOrLabel)
+            self.__tabBar.addTab(iconOrLabel)
         self.__stackedWidget.addWidget(widget)
-        if self.__orientation in [E4SideBar.North, E4SideBar.South]:
-            self.__minSize = self.minimumSizeHint().height()
-        else:
-            self.__minSize = self.minimumSizeHint().width()
     
     def insertTab(self, index, widget, iconOrLabel, label = None):
         """
@@ -289,16 +205,10 @@ class E4SideBar(QWidget):
             used, if the second parameter is a QIcon)
         """
         if label:
-            index = self.__tabBar.insertTab(index, iconOrLabel, label)
-            self.__tabBar.setTabToolTip(index, label)
+            self.__tabBar.insertTab(index, iconOrLabel, label)
         else:
-            index = self.__tabBar.insertTab(index, iconOrLabel)
-            self.__tabBar.setTabToolTip(index, iconOrLabel)
+            self.__tabBar.insertTab(index, iconOrLabel)
         self.__stackedWidget.insertWidget(index, widget)
-        if self.__orientation in [E4SideBar.North, E4SideBar.South]:
-            self.__minSize = self.minimumSizeHint().height()
-        else:
-            self.__minSize = self.minimumSizeHint().width()
     
     def removeTab(self, index):
         """
@@ -308,10 +218,6 @@ class E4SideBar(QWidget):
         """
         self.__stackedWidget.removeWidget(self.__stackedWidget.widget(index))
         self.__tabBar.removeTab(index)
-        if self.__orientation in [E4SideBar.North, E4SideBar.South]:
-            self.__minSize = self.minimumSizeHint().height()
-        else:
-            self.__minSize = self.minimumSizeHint().width()
     
     def clear(self):
         """
@@ -430,25 +336,21 @@ class E4SideBar(QWidget):
         """
         if orient == E4SideBar.North:
             self.__tabBar.setShape(QTabBar.RoundedNorth)
-            self.__tabBar.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
             self.barLayout.setDirection(QBoxLayout.LeftToRight)
             self.layout.setDirection(QBoxLayout.TopToBottom)
             self.layout.setAlignment(self.barLayout, Qt.AlignLeft)
         elif orient == E4SideBar.East:
             self.__tabBar.setShape(QTabBar.RoundedEast)
-            self.__tabBar.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Expanding)
             self.barLayout.setDirection(QBoxLayout.TopToBottom)
             self.layout.setDirection(QBoxLayout.RightToLeft)
             self.layout.setAlignment(self.barLayout, Qt.AlignTop)
         elif orient == E4SideBar.South:
             self.__tabBar.setShape(QTabBar.RoundedSouth)
-            self.__tabBar.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
             self.barLayout.setDirection(QBoxLayout.LeftToRight)
             self.layout.setDirection(QBoxLayout.BottomToTop)
             self.layout.setAlignment(self.barLayout, Qt.AlignLeft)
         elif orient == E4SideBar.West:
             self.__tabBar.setShape(QTabBar.RoundedWest)
-            self.__tabBar.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Expanding)
             self.barLayout.setDirection(QBoxLayout.TopToBottom)
             self.layout.setDirection(QBoxLayout.LeftToRight)
             self.layout.setAlignment(self.barLayout, Qt.AlignTop)
@@ -542,14 +444,13 @@ class E4SideBar(QWidget):
         @return saved state as a byte array (QByteArray)
         """
         if len(self.splitterSizes) == 0:
-            if self.splitter:
-                self.splitterSizes = self.splitter.sizes()
+            self.splitterSizes = self.splitter.sizes()
             self.__bigSize = self.size()
             if self.__orientation in [E4SideBar.North, E4SideBar.South]:
-                self.__minSize = self.minimumSizeHint().height()
+                self.__minSize = self.minimumHeight()
                 self.__maxSize = self.maximumHeight()
             else:
-                self.__minSize = self.minimumSizeHint().width()
+                self.__minSize = self.minimumWidth()
                 self.__maxSize = self.maximumWidth()
         
         data = QByteArray()
@@ -577,24 +478,17 @@ class E4SideBar(QWidget):
         if state.isEmpty():
             return False
         
-        if self.__orientation in [E4SideBar.North, E4SideBar.South]:
-            minSize = self.layout.minimumSize().height()
-            maxSize = self.maximumHeight()
-        else:
-            minSize = self.layout.minimumSize().width()
-            maxSize = self.maximumWidth()
-        
         data = QByteArray(state)
         stream = QDataStream(data, QIODevice.ReadOnly)
-        stream.readUInt16()  # version
+        version = stream.readUInt16()
         minimized = stream.readBool()
         
         if minimized:
             self.shrink()
         
         stream >> self.__bigSize
-        self.__minSize = max(stream.readUInt16(), minSize)
-        self.__maxSize = max(stream.readUInt16(), maxSize)
+        self.__minSize = stream.readUInt16()
+        self.__maxSize = stream.readUInt16()
         count = stream.readUInt16()
         self.splitterSizes = []
         for i in range(count):
@@ -620,9 +514,9 @@ class E4SideBar(QWidget):
         """
         self.__autoHide = not checked
         if self.__autoHide:
-            self.__autoHideButton.setIcon(UI.PixmapCache.getIcon("autoHideOn.png"))
+            self.__autoHideButton.setIcon(UI.PixmapCache.getIcon("autoHideOn"))
         else:
-            self.__autoHideButton.setIcon(UI.PixmapCache.getIcon("autoHideOff.png"))
+            self.__autoHideButton.setIcon(UI.PixmapCache.getIcon("autoHideOff"))
     
     def __appFocusChanged(self, old, now):
         """
@@ -645,8 +539,6 @@ class E4SideBar(QWidget):
         """
         if self.__autoHide and self.isMinimized():
             self.expand()
-        else:
-            self.__cancelDelayTimer()
     
     def leaveEvent(self, event):
         """
@@ -656,16 +548,3 @@ class E4SideBar(QWidget):
         """
         if self.__autoHide and not self.__hasFocus and not self.isMinimized():
             self.shrink()
-        else:
-            self.__cancelDelayTimer()
-    
-    def shutdown(self):
-        """
-        Public method to shut down the object.
-        
-        This method does some preparations so the object can be deleted properly.
-        It disconnects from the focusChanged signal in order to avoid trouble later
-        on.
-        """
-        self.disconnect(e4App(), SIGNAL("focusChanged(QWidget*, QWidget*)"), 
-                        self.__appFocusChanged)
