@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -50,7 +50,7 @@ class E4ToolBarManager(QObject):
     
     def __toolBarByName(self, name):
         """
-        Private slot to get a toolbar by its object name.
+        Private slot to get a toolbar by it's object name.
         
         @param name object name of the toolbar (string or QString)
         @return reference to the toolbar (QToolBar)
@@ -137,16 +137,14 @@ class E4ToolBarManager(QObject):
         newActionsWithSeparators = []
         actions = toolBar.actions()
         for action in actions:
-            actID = id(action)
             self.addAction(action, category)
-            if actID in self.__widgetActions:
-                self.__widgetActions[actID] = toolBar
+            if id(action) in self.__widgetActions:
+                self.__widgetActions[id(action)] = toolBar
             newActionsWithSeparators.append(action)
             if action.isSeparator():
                 action = None
             else:
-                if toolBar not in self.__actionToToolBars[actID]:
-                    self.__actionToToolBars[actID].append(toolBar)
+                self.__actionToToolBars[id(action)].append(toolBar)
             newActions.append(action)
         tbID = id(toolBar)
         self.__defaultToolBars[tbID] = newActions
@@ -259,11 +257,11 @@ class E4ToolBarManager(QObject):
     
     def resetToolBar(self, toolBar):
         """
-        Public method to reset a toolbar to its default state.
+        Public method to reset a toolbar to it's default state.
         
         @param toolBar reference to the toolbar to configure (QToolBar)
         """
-        if not self.isDefaultToolBar():
+        if not isDefaultToolBar():
             return
         self.setToolBar(toolBar, self.__defaultToolBars[id(toolBar)])
     
@@ -292,12 +290,11 @@ class E4ToolBarManager(QObject):
         return toolBar is not None and \
                id(toolBar) in self.__defaultToolBars
     
-    def createToolBar(self, title, name=None):
+    def createToolBar(self, title):
         """
         Public method to create a custom toolbar.
         
         @param title title to be used for the toolbar (QString)
-        @param name optional name for the new toolbar (QString)
         @return reference to the created toolbar (QToolBar)
         """
         if self.__mainWindow is None:
@@ -305,13 +302,12 @@ class E4ToolBarManager(QObject):
         
         toolBar = QToolBar(title, self.__mainWindow)
         toolBar.setToolTip(title)
-        if name is None:
-            index = 1
-            customPrefix = "__CustomPrefix__"
+        index = 1
+        customPrefix = "__CustomPrefix__"
+        name = "%s%d" % (customPrefix, index)
+        while self.__toolBarByName(name) is not None:
+            index += 1
             name = "%s%d" % (customPrefix, index)
-            while self.__toolBarByName(name) is not None:
-                index += 1
-                name = "%s%d" % (customPrefix, index)
         toolBar.setObjectName(name)
         self.__mainWindow.addToolBar(toolBar)
         
@@ -388,7 +384,7 @@ class E4ToolBarManager(QObject):
             return
         if action.isSeparator():
             return
-        if id(action) in self.__allActions:
+        if action in self.__allActions:
             return
         
         if action.metaObject().className() == "QWidgetAction":
@@ -558,7 +554,7 @@ class E4ToolBarManager(QObject):
                 toolBar.setWindowTitle(toolBarTitle)
                 oldCustomToolBars.remove(toolBar)
             else:
-                toolBar = self.createToolBar(toolBarTitle, objectName)
+                toolBar = self.createToolBar(toolBarTitle)
             if toolBar is not None:
                 toolBar.setObjectName(objectName)
                 self.setToolBar(toolBar, actions)
@@ -639,7 +635,7 @@ class E4ToolBarManager(QObject):
     
     def actionById(self, aID):
         """
-        Public method to get an action given its id.
+        Public method to get an action given it's id.
         
         @param aID id of the action object (integer)
         @return reference to the action (QAction)
@@ -650,7 +646,7 @@ class E4ToolBarManager(QObject):
     
     def toolBarById(self, tbID):
         """
-        Public method to get a toolbar given its id.
+        Public method to get a toolbar given it's id.
         
         @param tbID id of the toolbar object (integer)
         @return reference to the toolbar (QToolBar)
@@ -661,7 +657,7 @@ class E4ToolBarManager(QObject):
     
     def toolBarActions(self, tbID):
         """
-        Public method to get a toolbar's actions given its id.
+        Public method to get a toolbar's actions given it's id.
         
         @param tbID id of the toolbar object (integer)
         @return list of actions (list of QAction)
@@ -681,7 +677,7 @@ class E4ToolBarManager(QObject):
     
     def defaultToolBarActions(self, tbID):
         """
-        Public method to get a default toolbar's actions given its id.
+        Public method to get a default toolbar's actions given it's id.
         
         @param tbID id of the default toolbar object (integer)
         @return list of actions (list of QAction)
