@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -37,7 +37,6 @@ class AdBlockManager(QObject):
         QObject.__init__(self, parent)
         
         self.__loaded = False
-        self.__subscriptionsLoaded = False
         self.__enabled = False
         self.__adBlockDialog = None
         self.__adBlockNetwork = None
@@ -74,8 +73,6 @@ class AdBlockManager(QObject):
             return
         
         self.__enabled = enabled
-        if enabled:
-            self.__loadSubscriptions()
         self.emit(SIGNAL("rulesChanged()"))
     
     def network(self):
@@ -192,14 +189,13 @@ class AdBlockManager(QObject):
             return
         
         Preferences.setHelp("AdBlockEnabled", int(self.__enabled))
-        if self.__subscriptionsLoaded:
-            subscriptions = QStringList()
-            for subscription in self.__subscriptions:
-                if subscription is None:
-                    continue
-                subscriptions.append(QString.fromUtf8(subscription.url().toEncoded()))
-                subscription.saveRules()
-            Preferences.setHelp("AdBlockSubscriptions", subscriptions)
+        subscriptions = QStringList()
+        for subscription in self.__subscriptions:
+            if subscription is None:
+                continue
+            subscriptions.append(QString.fromUtf8(subscription.url().toEncoded()))
+            subscription.saveRules()
+        Preferences.setHelp("AdBlockSubscriptions", subscriptions)
     
     def load(self):
         """
@@ -211,37 +207,24 @@ class AdBlockManager(QObject):
         self.__loaded = True
         
         self.__enabled = bool(Preferences.getHelp("AdBlockEnabled"))
-        if self.__enabled:
-            self.__loadSubscriptions()
-    
-    def __loadSubscriptions(self):
-        """
-        Private method to load the set of subscriptions.
-        """
-        if self.__subscriptionsLoaded:
-            return
         
-        defaultSubscriptionUrl = \
-            "abp:subscribe?location=http://adblockplus.mozdev.org/easylist/easylist.txt&title=EasyList"
         defaultSubscriptions = QStringList()
         defaultSubscriptions.append(
             QString.fromUtf8(self.__customSubscriptionUrl().toEncoded()))
-        defaultSubscriptions.append(defaultSubscriptionUrl)
+        defaultSubscriptions.append(
+            "abp:subscribe?location=http://adblockplus.mozdev.org/easylist/easylist.txt&title=EasyList")
         
         subscriptions = Preferences.getHelp("AdBlockSubscriptions")
         if len(subscriptions) == 0:
             subscriptions = defaultSubscriptions
         for subscription in subscriptions:
             url = QUrl.fromEncoded(subscription.toUtf8())
-            adBlockSubscription = AdBlockSubscription(url, self, 
-                subscription == defaultSubscriptionUrl)
+            adBlockSubscription = AdBlockSubscription(url, self)
             self.connect(adBlockSubscription, SIGNAL("rulesChanged()"), 
                          self, SIGNAL("rulesChanged()"))
             self.connect(adBlockSubscription, SIGNAL("changed()"), 
                          self, SIGNAL("rulesChanged()"))
             self.__subscriptions.append(adBlockSubscription)
-        
-        self.__subscriptionsLoaded = True
     
     def showDialog(self):
         """
