@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -325,7 +325,7 @@ class BookmarksManager(QObject):
         """
         supportedFormats = QStringList() \
             << self.trUtf8("XBEL bookmarks").append(" (*.xbel *.xml)") \
-            << self.trUtf8("HTML Netscape bookmarks").append(" (*.html *.htm)")
+            << self.trUtf8("HTML Netscape bookmarks").append(" (*.html)")
         
         fileName = KQFileDialog.getOpenFileName(\
             None,
@@ -380,7 +380,7 @@ class BookmarksManager(QObject):
             None,
             self.trUtf8("Export Bookmarks"),
             "eric4_bookmarks.xbel",
-            self.trUtf8("XBEL bookmarks").append(" (*.xbel *.xml)"))
+            self.trUtf8("XBEL bookmarks").append(" (*.xbel, *.xml)"))
         if fileName.isEmpty():
             return
         
@@ -389,7 +389,7 @@ class BookmarksManager(QObject):
             KQMessageBox.critical(None,
                 self.trUtf8("Exporting Bookmarks"),
                 self.trUtf8("""Error exporting bookmarks to <b>%1</b>.""")\
-                    .arg(fileName))
+                    .arg(bookmarkFile))
     
     def __convertFromOldBookmarks(self):
         """
