@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -41,9 +41,6 @@ class DownloadDialog(QWidget, Ui_DownloadDialog):
         self.setupUi(self)
         self.setAttribute(Qt.WA_DeleteOnClose)
         
-        self.__windowTitleTemplate = self.trUtf8("Eric4 Download %1")
-        self.setWindowTitle(self.__windowTitleTemplate.arg(""))
-        
         self.__tryAgainButton = \
             self.buttonBox.addButton(self.trUtf8("Try Again"), 
                                      QDialogButtonBox.ActionRole)
@@ -67,7 +64,6 @@ class DownloadDialog(QWidget, Ui_DownloadDialog):
         self.__bytesReceived = 0
         self.__downloadTime = QTime()
         self.__output = QFile()
-        self.__initialized = False
     
     def initialize(self):
         """
@@ -82,9 +78,6 @@ class DownloadDialog(QWidget, Ui_DownloadDialog):
         self.__downloadFinished = False
         
         self.__url = self.__reply.url()
-        if not self.__getFileName():
-            return False
-        
         self.__reply.setParent(self)
         self.connect(self.__reply, SIGNAL("readyRead()"), self.__readyRead)
         self.connect(self.__reply, SIGNAL("error(QNetworkReply::NetworkError)"), 
@@ -98,12 +91,12 @@ class DownloadDialog(QWidget, Ui_DownloadDialog):
         # reset info
         self.infoLabel.clear()
         self.progressBar.setValue(0)
+        if not self.__getFileName():
+            return False
         
         # start timer for the download estimation
         self.__downloadTime.start()
         
-        self.__initialized = True
-        
         if self.__reply.error() != QNetworkReply.NoError:
             self.__networkError()
             self.__finished()
@@ -324,12 +317,9 @@ class DownloadDialog(QWidget, Ui_DownloadDialog):
         if total == -1:
             self.progressBar.setMaximum(0)
             self.progressBar.setValue(0)
-            self.setWindowTitle(self.__windowTitleTemplate.arg(""))
         else:
             self.progressBar.setMaximum(total)
             self.progressBar.setValue(received)
-            pc = "%d%%" % (received * 100 / total)
-            self.setWindowTitle(self.__windowTitleTemplate.arg(pc))
         self.__updateInfoLabel()
     
     def __updateInfoLabel(self):
@@ -439,18 +429,17 @@ class DownloadDialog(QWidget, Ui_DownloadDialog):
         """
         Protected method called when the dialog is closed.
         """
-        if self.__initialized:
-            self.__output.close()
-            
-            self.disconnect(self.__reply, SIGNAL("readyRead()"), self.__readyRead)
-            self.disconnect(self.__reply, SIGNAL("error(QNetworkReply::NetworkError)"), 
-                            self.__networkError)
-            self.disconnect(self.__reply, SIGNAL("downloadProgress(qint64, qint64)"), 
-                            self.__downloadProgress)
-            self.disconnect(self.__reply, SIGNAL("metaDataChanged()"), 
-                            self.__metaDataChanged)
-            self.disconnect(self.__reply, SIGNAL("finished()"), self.__finished)
-            self.__reply.close()
-            self.__reply.deleteLater()
-            
-            self.emit(SIGNAL("done()"))
+        self.__output.close()
+        
+        self.disconnect(self.__reply, SIGNAL("readyRead()"), self.__readyRead)
+        self.disconnect(self.__reply, SIGNAL("error(QNetworkReply::NetworkError)"), 
+                        self.__networkError)
+        self.disconnect(self.__reply, SIGNAL("downloadProgress(qint64, qint64)"), 
+                        self.__downloadProgress)
+        self.disconnect(self.__reply, SIGNAL("metaDataChanged()"), 
+                        self.__metaDataChanged)
+        self.disconnect(self.__reply, SIGNAL("finished()"), self.__finished)
+        self.__reply.close()
+        self.__reply.deleteLater()
+        
+        self.emit(SIGNAL("done()"))
