@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 
@@ -79,10 +79,10 @@ class JavaScriptEricObject(QObject):
     """
     # these must be in line with the strings used by the javascript part of the start page
     translations = [
-        QT_TRANSLATE_NOOP("JavaScriptEricObject", "Welcome to eric4 Web Browser!"), 
-        QT_TRANSLATE_NOOP("JavaScriptEricObject", "eric4 Web Browser"), 
+        QT_TRANSLATE_NOOP("JavaScriptEricObject", "Welcome to Eric Web Browser!"), 
+        QT_TRANSLATE_NOOP("JavaScriptEricObject", "Eric Web Browser"), 
         QT_TRANSLATE_NOOP("JavaScriptEricObject", "Search!"), 
-        QT_TRANSLATE_NOOP("JavaScriptEricObject", "About eric4"), 
+        QT_TRANSLATE_NOOP("JavaScriptEricObject", "About Eric"), 
     ]
     
     def __init__(self, mw, parent = None):
@@ -170,11 +170,6 @@ class HelpWebPage(QWebPage):
         self.__lastRequest = request
         self.__lastRequestType = type_
         
-        scheme = request.url().scheme()
-        if scheme in ["mailto", "ftp"]:
-            QDesktopServices.openUrl(request.url())
-            return False
-        
         return QWebPage.acceptNavigationRequest(self, frame, request, type_)
     
     def populateNetworkRequest(self, request):
@@ -183,12 +178,9 @@ class HelpWebPage(QWebPage):
         
         @param request reference to the network request object (QNetworkRequest)
         """
-        try:
-            request.setAttribute(QNetworkRequest.User + 100, QVariant(self))
-            request.setAttribute(QNetworkRequest.User + 101, 
-                                 QVariant(self.__lastRequestType))
-        except TypeError:
-            pass
+        request.setAttribute(QNetworkRequest.User + 100, QVariant(self))
+        request.setAttribute(QNetworkRequest.User + 101, 
+                             QVariant(self.__lastRequestType))
     
     def pageAttributeId(self):
         """
@@ -225,15 +217,6 @@ class HelpWebPage(QWebPage):
         try:
             if extension == QWebPage.ErrorPageExtension:
                 info = sip.cast(option, QWebPage.ErrorPageExtensionOption)
-                if info.error == 102:
-                    # this is something of a hack; hopefully it will work in the future
-                    return False
-                
-                if info.domain == QWebPage.QtNetwork and \
-                    info.error == QNetworkReply.OperationCanceledError and \
-                    info.errorString == "eric4:No Error":
-                        return False
-                
                 errorPage = sip.cast(output, QWebPage.ErrorPageExtensionReturn)
                 html = QString(notFoundPage_html)
                 urlString = QString.fromUtf8(info.url.toEncoded())
@@ -264,17 +247,6 @@ class HelpWebPage(QWebPage):
             pass
         
         return QWebPage.extension(self, extension, option, output)
-    
-    def userAgentForUrl(self, url):
-        """
-        Protected method to determine the user agent for the given URL.
-        
-        @param url URL to determine user agent for (QUrl)
-        @return user agent string (string)
-        """
-        agentList = QWebPage.userAgentForUrl(self, url).split(" ")
-        agentList[0] = "Mozilla/9.0"
-        return agentList.join(" ")
 
 ##########################################################################################
 
@@ -367,8 +339,6 @@ class HelpBrowser(QWebView):
         if frame is None:
             # called from QWebFrame.javaScriptWindowObjectCleared
             frame = self.sender()
-            if isinstance(frame, HelpWebPage):
-                frame = frame.mainFrame()
             if frame.url().scheme() == "pyrc" and frame.url().path() == "home":
                 if self.__javaScriptEricObject is None:
                     self.__javaScriptEricObject = JavaScriptEricObject(self.mw, self)
@@ -447,7 +417,7 @@ class HelpBrowser(QWebView):
             
             if not QFileInfo(name.toLocalFile()).exists():
                 QMessageBox.critical(None,
-                    self.trUtf8("eric4 Web Browser"),
+                    self.trUtf8("Web Browser"),
                     self.trUtf8("""<p>The file <b>%1</b> does not exist.</p>""")\
                         .arg(name.toLocalFile()),
                     QMessageBox.StandardButtons(\
@@ -461,7 +431,7 @@ class HelpBrowser(QWebView):
                 started = QDesktopServices.openUrl(name)
                 if not started:
                     KQMessageBox.critical(self,
-                        self.trUtf8("eric4 Web Browser"),
+                        self.trUtf8("Web Browser"),
                         self.trUtf8("""<p>Could not start a viewer"""
                         """ for file <b>%1</b>.</p>""").arg(name.path()))
                 return
@@ -469,14 +439,15 @@ class HelpBrowser(QWebView):
             started = QDesktopServices.openUrl(name)
             if not started:
                 KQMessageBox.critical(self,
-                    self.trUtf8("eric4 Web Browser"),
+                    self.trUtf8("Web Browser"),
                     self.trUtf8("""<p>Could not start an application"""
                     """ for URL <b>%1</b>.</p>""").arg(name.toString()))
             return
         elif name.scheme() == "javascript":
-            scriptSource = QUrl.fromPercentEncoding(name.toString(
-                QUrl.FormattingOptions(QUrl.TolerantMode | QUrl.RemoveScheme)).toAscii())
-            self.page().mainFrame().evaluateJavaScript(scriptSource)
+            scriptSource = name.toString()[11:]
+            res = self.page().mainFrame().evaluateJavaScript(scriptSource).toString()
+            if not res.isEmpty():
+                self.setHtml(res)
             return
         else:
             if name.toString().endsWith(".pdf") or \
@@ -486,7 +457,7 @@ class HelpBrowser(QWebView):
                 started = QDesktopServices.openUrl(name)
                 if not started:
                     KQMessageBox.critical(self,
-                        self.trUtf8("eric4 Web Browser"),
+                        self.trUtf8("Web Browser"),
                         self.trUtf8("""<p>Could not start a viewer"""
                         """ for file <b>%1</b>.</p>""").arg(name.path()))
                 return
@@ -622,14 +593,6 @@ class HelpBrowser(QWebView):
             evt.accept()
             return
         
-        if evt.modifiers() & Qt.ShiftModifier:
-            if evt.delta() < 0:
-                self.backward()
-            else:
-                self.forward()
-            evt.accept()
-            return
-        
         QWebView.wheelEvent(self, evt)
     
     def hasSelection(self):
@@ -834,19 +797,6 @@ class HelpBrowser(QWebView):
         dlg.setTitle(self.title())
         dlg.exec_()
     
-    def mousePressEvent(self, evt):
-        """
-        Protected method called by a mouse press event.
-        
-        @param evt reference to the mouse event (QMouseEvent)
-        """
-        if evt.button() == Qt.XButton1:
-            self.pageAction(QWebPage.Back).trigger()
-        elif evt.button() == Qt.XButton2:
-            self.pageAction(QWebPage.Forward).trigger()
-        else:
-            QWebView.mousePressEvent(self, evt)
-    
     def keyPressEvent(self, evt):
         """
         Protected method called by a key press.
@@ -937,7 +887,7 @@ class HelpBrowser(QWebView):
         """
         self.__isLoading = False
         self.mw.progressBar().hide()
-        self.mw.resetLoading(self, ok)
+        self.mw.resetLoading(self)
         
         self.__iconChanged()
         
@@ -962,7 +912,7 @@ class HelpBrowser(QWebView):
         
         req = QNetworkRequest(url)
         reply = self.mw.networkAccessManager().get(req)
-        self.__unsupportedContent(reply, requestFilename = True, download = True)
+        self.__unsupportedContent(reply, True)
     
     def __unsupportedContent(self, reply, requestFilename = None, download = False):
         """
@@ -997,11 +947,8 @@ class HelpBrowser(QWebView):
                 self.connect(dlg, SIGNAL("done()"), self.__downloadDone)
                 self.__downloadWindows.append(dlg)
                 dlg.show()
+            self.setUrl(self.url())
         else:
-            if reply.error() == QNetworkReply.OperationCanceledError and \
-               reply.errorString() == "eric4:No Error":
-                    return
-            
             replyUrl = reply.url()
             if replyUrl.isEmpty():
                 return
