@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,11 +9,6 @@ Module implementing a network access manager proxy for web pages.
 
 from PyQt4.QtCore import SIGNAL
 from PyQt4.QtNetwork import QNetworkAccessManager, QNetworkRequest
-try:
-    from PyQt4.QtNetwork import QSslError
-    SSL_AVAILABLE = True
-except ImportError:
-    SSL_AVAILABLE = False
 
 class NetworkAccessManagerProxy(QNetworkAccessManager):
     """
@@ -53,11 +48,10 @@ class NetworkAccessManagerProxy(QNetworkAccessManager):
         # do not steal ownership
         self.cookieJar().setParent(self.__class__.primaryManager)
         
-        if SSL_AVAILABLE:
-            self.connect(self, 
-                SIGNAL('sslErrors(QNetworkReply *, const QList<QSslError> &)'), 
-                self.__class__.primaryManager, 
-                SIGNAL('sslErrors(QNetworkReply *, const QList<QSslError> &)'))
+        self.connect(self, 
+            SIGNAL('sslErrors(QNetworkReply *, const QList<QSslError> &)'), 
+            self.__class__.primaryManager, 
+            SIGNAL('sslErrors(QNetworkReply *, const QList<QSslError> &)'))
         self.connect(self, 
             SIGNAL('proxyAuthenticationRequired(const QNetworkProxy &, QAuthenticator *)'),
             self.__class__.primaryManager, 
