@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -22,7 +22,6 @@ from PyQt4.QtNetwork import QNetworkRequest, QNetworkAccessManager
 from UI.Info import Program
 
 import Preferences
-import Utilities
 
 class OpenSearchEngine(QObject):
     """
@@ -32,6 +31,16 @@ class OpenSearchEngine(QObject):
     @signal suggestions(const QStringList&) emitted after the suggestions have 
             been received
     """
+    loc = Preferences.getUILanguage()
+    if loc == "System":
+        loc = QLocale.system().name()
+    if loc is None:
+        _language = QString("en")
+    elif loc == "C":
+        _language = QString()
+    else:
+        _language = loc[:2]
+    
     def __init__(self, parent = None):
         """
         Constructor
@@ -69,16 +78,11 @@ class OpenSearchEngine(QObject):
         @param searchTemplate template to be parsed (string or QString)
         @return parsed template (QString)
         """
-        locale = QLocale(Preferences.getHelp("SearchLanguage"))
-        language = locale.name().split("_")[0]
-        country = language.toLower()
-        
         result = QString(searchTemplate)
         result.replace("{count}", "20")
         result.replace("{startIndex}", "0")
         result.replace("{startPage}", "0")
-        result.replace("{language}", language)
-        result.replace("{country}", country)
+        result.replace("{language}", cls._language)
         result.replace("{inputEncoding}", "UTF-8")
         result.replace("{outputEncoding}", "UTF-8")
         result.replace("{searchTerms}", QString(QUrl.toPercentEncoding(searchTerm)))
@@ -440,8 +444,7 @@ class OpenSearchEngine(QObject):
         """
         Private slot to receive the suggestions.
         """
-        buffer = str(self.__suggestionsReply.readAll())
-        response = Utilities.decodeBytes(buffer)
+        response = unicode(self.__suggestionsReply.readAll(), "utf-8")
         response = response.strip()
         
         self.__suggestionsReply.close()
