@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -159,7 +159,7 @@ class OpenSearchManager(QObject):
     
     def __addEngineByUrl(self, url):
         """
-        Private method to add a new search engine given its URL.
+        Private method to add a new search engine given it's URL.
         
         @param url URL of the engine definition file (QUrl)
         @return flag indicating success (boolean)
@@ -233,7 +233,7 @@ class OpenSearchManager(QObject):
         
         engine = self.__engines[unicode(name)]
         for keyword in [k for k in self.__keywords if self.__keywords[k] == engine]:
-            del self.__keywords[keyword]
+            del self.__keywords[k]
         del self.__engines[unicode(name)]
         
         file_ = QDir(self.enginesDirectory()).filePath(self.generateEngineFileName(name))
@@ -301,8 +301,7 @@ class OpenSearchManager(QObject):
         Preferences.setHelp("WebSearchEngine", self.__current)
         keywords = []
         for k in self.__keywords:
-            if self.__keywords[k]:
-                keywords.append((k, self.__keywords[k].name()))
+            keywords.append((k, self.__keywords[k].name()))
         Preferences.setHelp("WebSearchKeywords", keywords)
     
     def loadDirectory(self, dirName):
