@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -13,7 +13,6 @@ from PyQt4.QtCore import QString, QStringList, QDir
 from PyQt4.QtGui import QFileDialog
 
 import Preferences
-import Globals
 
 if Preferences.getUI("UseKDEDialogs") and not sys.e4nokde:
     try:
@@ -157,9 +156,8 @@ if Preferences.getUI("UseKDEDialogs") and not sys.e4nokde:
                 
             return dlg.selectedFiles()
         
-        def __kdeGetExistingDirectory(parent = None, caption = QString(), 
-                                dir_ = QString(), 
-                                options = QFileDialog.Options(QFileDialog.ShowDirsOnly)):
+        def __kdeGetExistingDirectory(parent = None, caption = QString(), dir_ = QString(),
+                                    options = QFileDialog.Options(QFileDialog.ShowDirsOnly)):
             """
             Module function to get the name of a directory.
             
@@ -184,98 +182,10 @@ if Preferences.getUI("UseKDEDialogs") and not sys.e4nokde:
     except (ImportError, RuntimeError):
         sys.e4nokde = True
     
-def __qtReorderFilter(filter, selectedFilter = None):
-    """
-    Private function to reorder the file filter to cope with a KDE issue introduced
-    by distributors usage of KDE file dialogs.
-    
-    @param filter Qt file filter (QString or string)
-    @param selectedFilter this is set to the selected filter (QString or string)
-    @return the rearranged Qt file filter (QString)
-    """
-    if selectedFilter is not None and not Globals.isMacPlatform():
-        fileFilters = QStringList(filter.split(';;'))
-##        fileFilters.removeAll(selectedFilter)
-        fileFilters.prepend(selectedFilter)
-        return fileFilters.join(";;")
-    else:
-        return filter
-
-def __qtGetOpenFileName(parent = None, caption = QString(), dir_ = QString(),
-                        filter = QString(), selectedFilter = None, 
-                        options = QFileDialog.Options()):
-    """
-    Module function to get the name of a file for opening it.
-    
-    @param parent parent widget of the dialog (QWidget)
-    @param caption window title of the dialog (QString)
-    @param dir_ working directory of the dialog (QString)
-    @param filter filter string for the dialog (QString)
-    @param selectedFilter selected filter for the dialog (QString)
-    @param options various options for the dialog (QFileDialog.Options)
-    @return name of file to be opened (QString)
-    """
-    if Globals.isLinuxPlatform():
-        options |= QFileDialog.DontUseNativeDialog
-    newfilter = __qtReorderFilter(filter, selectedFilter)
-    return QFileDialog.getOpenFileName(parent, caption, dir_, 
-                                       newfilter, selectedFilter, options)
-
-def __qtGetOpenFileNames(parent = None, caption = QString(), dir_ = QString(),
-                         filter = QString(), selectedFilter = None, 
-                         options = QFileDialog.Options()):
-    """
-    Module function to get a list of names of files for opening.
-    
-    @param parent parent widget of the dialog (QWidget)
-    @param caption window title of the dialog (QString)
-    @param dir_ working directory of the dialog (QString)
-    @param filter filter string for the dialog (QString)
-    @param selectedFilter selected filter for the dialog (QString)
-    @param options various options for the dialog (QFileDialog.Options)
-    @return list of filenames to be opened (QStringList)
-    """
-    if Globals.isLinuxPlatform():
-        options |= QFileDialog.DontUseNativeDialog
-    newfilter = __qtReorderFilter(filter, selectedFilter)
-    return QFileDialog.getOpenFileNames(parent, caption, dir_, 
-                                        newfilter, selectedFilter, options)
-
-def __qtGetSaveFileName(parent = None, caption = QString(), dir_ = QString(),
-                        filter = QString(), selectedFilter = None, 
-                        options = QFileDialog.Options()):
-    """
-    Module function to get the name of a file for saving it.
-    
-    @param parent parent widget of the dialog (QWidget)
-    @param caption window title of the dialog (QString)
-    @param dir_ working directory of the dialog (QString)
-    @param filter filter string for the dialog (QString)
-    @param selectedFilter selected filter for the dialog (QString)
-    @param options various options for the dialog (QFileDialog.Options)
-    @return name of file to be saved (QString)
-    """
-    if Globals.isLinuxPlatform():
-        options |= QFileDialog.DontUseNativeDialog
-    newfilter = __qtReorderFilter(filter, selectedFilter)
-    return QFileDialog.getSaveFileName(parent, caption, dir_, 
-                                       newfilter, selectedFilter, options)
-
-def __qtGetExistingDirectory(parent = None, caption = QString(), 
-                             dir_ = QString(), 
-                             options = QFileDialog.Options(QFileDialog.ShowDirsOnly)):
-    """
-    Module function to get the name of a directory.
-    
-    @param parent parent widget of the dialog (QWidget)
-    @param caption window title of the dialog (QString)
-    @param dir_ working directory of the dialog (QString)
-    @param options various options for the dialog (QFileDialog.Options)
-    @return name of selected directory (QString)
-    """
-    if Globals.isLinuxPlatform():
-        options |= QFileDialog.DontUseNativeDialog
-    return QFileDialog.getExistingDirectory(parent, caption, dir_, options)
+__qtGetOpenFileName = QFileDialog.getOpenFileName
+__qtGetOpenFileNames = QFileDialog.getOpenFileNames
+__qtGetSaveFileName = QFileDialog.getSaveFileName
+__qtGetExistingDirectory = QFileDialog.getExistingDirectory
 
 ################################################################################
 
