@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 
@@ -15,12 +15,7 @@ import cStringIO
 
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
-from PyQt4.QtNetwork import QNetworkAccessManager, QNetworkRequest, QNetworkReply
-try:
-    from PyQt4.QtNetwork import QSslError
-    SSL_AVAILABLE = True
-except ImportError:
-    SSL_AVAILABLE = False
+from PyQt4.QtNetwork import QHttp, QNetworkProxy
 
 from KdeQt import KQMessageBox
 from KdeQt.KQMainWindow import KQMainWindow
@@ -74,25 +69,13 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         self.__downloadCancelButton.setEnabled(False)
         self.__installButton.setEnabled(False)
         
-        self.repositoryUrlEdit.setText(Preferences.getUI("PluginRepositoryUrl"))
-        
         self.repositoryList.headerItem().setText(self.repositoryList.columnCount(), "")
         self.repositoryList.header().setSortIndicator(0, Qt.AscendingOrder)
         
         self.pluginRepositoryFile = \
             os.path.join(Utilities.getConfigDir(), "PluginRepository")
         
-        # attributes for the network objects
-        self.__networkManager = QNetworkAccessManager(self)
-        self.connect(self.__networkManager, 
-            SIGNAL('proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)'),
-            self.__proxyAuthenticationRequired)
-        if SSL_AVAILABLE:
-            self.connect(self.__networkManager, 
-                SIGNAL('sslErrors(QNetworkReply *, const QList<QSslError> &)'), 
-                self.__sslErrors)
-        self.__replies = []
-        
+        self.__http = None
         self.__doneMethod = None
         self.__inDownload = False
         self.__pluginsToDownload = []
@@ -178,7 +161,7 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         """
         Private slot to download a new list and display the contents.
         """
-        url = self.repositoryUrlEdit.text()
+        url = Preferences.getUI("PluginRepositoryUrl")
         self.__downloadFile(url, 
                             self.pluginRepositoryFile, 
                             self.__downloadRepositoryFileDone)
@@ -320,15 +303,6 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
                 self.repositoryList.resizeColumnToContents(1)
                 self.repositoryList.resizeColumnToContents(2)
                 self.__resortRepositoryList()
-                
-                url = Preferences.getUI("PluginRepositoryUrl")
-                if url != self.repositoryUrlEdit.text():
-                    self.repositoryUrlEdit.setText(url)
-                    KQMessageBox.warning(self,
-                        self.trUtf8("Plugins Repository URL Changed"),
-                        self.trUtf8("""The URL of the Plugins Repository has"""
-                                    """ changed. Select the "Update" button to get"""
-                                    """ the new repository file."""))
             else:
                 KQMessageBox.critical(None,
                     self.trUtf8("Read plugins repository file"),
@@ -352,6 +326,39 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         @param filename local name of the file (string or QString)
         @param doneMethod method to be called when done
         """
+        if self.__http is None:
+            self.__http = QHttp()
+            self.connect(self.__http, SIGNAL("done(bool)"), self.__downloadFileDone)
+            self.connect(self.__http, SIGNAL("dataReadProgress(int, int)"), 
+                self.__dataReadProgress)
+            self.connect(self.__http, 
+                SIGNAL('proxyAuthenticationRequired(const QNetworkProxy &, QAuthenticator *)'),
+                self.__proxyAuthenticationRequired)
+            self.connect(self.__http, SIGNAL("sslErrors(const QList<QSslError>&)"), 
+                self.__sslErrors)
+        
+        if Preferences.getUI("UseProxy"):
+            host = Preferences.getUI("ProxyHost")
+            if host.isEmpty():
+                KQMessageBox.critical(None,
+                    self.trUtf8("Error downloading file"),
+                    self.trUtf8("""Proxy usage was activated"""
+                                """ but no proxy host configured."""))
+                return
+            else:
+                pProxyType = Preferences.getUI("ProxyType")
+                if pProxyType == 0:
+                    proxyType = QNetworkProxy.HttpProxy
+                elif pProxyType == 1:
+                    proxyType = QNetworkProxy.HttpCachingProxy
+                elif pProxyType == 2:
+                    proxyType = QNetworkProxy.Socks5Proxy
+                self.__proxy = QNetworkProxy(proxyType, host, 
+                    Preferences.getUI("ProxyPort"),
+                    Preferences.getUI("ProxyUser"),
+                    Preferences.getUI("ProxyPassword"))
+                self.__http.setProxy(self.__proxy)
+        
         self.__updateButton.setEnabled(False)
         self.__downloadButton.setEnabled(False)
         self.__downloadCancelButton.setEnabled(True)
@@ -364,37 +371,38 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         self.__downloadIODevice = QFile(self.__downloadFileName + ".tmp")
         self.__downloadCancelled = False
         
-        request = QNetworkRequest(QUrl(url))
-        request.setAttribute(QNetworkRequest.CacheLoadControlAttribute,
-                             QNetworkRequest.AlwaysNetwork)
-        reply = self.__networkManager.get(request)
-        self.connect(reply, SIGNAL("finished()"), self.__downloadFileDone)
-        self.connect(reply, SIGNAL("downloadProgress(qint64, qint64)"), 
-            self.__downloadProgress)
-        self.__replies.append(reply)
+        if QUrl(url).scheme().toLower() == 'https':
+            connectionMode = QHttp.ConnectionModeHttps
+        else:
+            connectionMode = QHttp.ConnectionModeHttp
+        self.__http.setHost(QUrl(url).host(), connectionMode, QUrl(url).port(0))
+        self.__http.get(QUrl(url).path(), self.__downloadIODevice)
     
-    def __downloadFileDone(self):
+    def __downloadFileDone(self, error):
         """
         Private method called, after the file has been downloaded
         from the internet.
+        
+        @param error flag indicating an error condition (boolean)
         """
         self.__updateButton.setEnabled(True)
         self.__downloadCancelButton.setEnabled(False)
         self.statusLabel.setText("  ")
         
         ok = True
-        reply = self.sender()
-        if reply in self.__replies:
-            self.__replies.remove(reply)
-        if reply.error() != QNetworkReply.NoError:
+        if error or self.__http.lastResponse().statusCode() != 200:
             ok = False
             if not self.__downloadCancelled:
+                if error:
+                    msg = self.__http.errorString()
+                else:
+                    msg = self.__http.lastResponse().reasonPhrase()
                 KQMessageBox.warning(None,
                     self.trUtf8("Error downloading file"),
                     self.trUtf8(
                         """<p>Could not download the requested file from %1.</p>"""
                         """<p>Error: %2</p>"""
-                    ).arg(self.__downloadURL).arg(reply.errorString())
+                    ).arg(self.__downloadURL).arg(msg)
                 )
             self.downloadProgress.setValue(0)
             self.__downloadURL = None
@@ -408,9 +416,6 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
                     self.__downloadButton.setEnabled(len(self.__selectedItems()))
             return
         
-        self.__downloadIODevice.open(QIODevice.WriteOnly)
-        self.__downloadIODevice.write(reply.readAll())
-        self.__downloadIODevice.close()
         if QFile.exists(self.__downloadFileName):
             QFile.remove(self.__downloadFileName)
         self.__downloadIODevice.rename(self.__downloadFileName)
@@ -424,22 +429,20 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         """
         Private slot to cancel the current download.
         """
-        if self.__replies:
-            reply = self.__replies[0]
+        if self.__http is not None:
             self.__downloadCancelled = True
             self.__pluginsToDownload = []
-            reply.abort()
+            self.__http.abort()
     
-    def __downloadProgress(self, done, total):
+    def __dataReadProgress(self, done, total):
         """
         Private slot to show the download progress.
         
         @param done number of bytes downloaded so far (integer)
         @param total total bytes to be downloaded (integer)
         """
-        if total:
-            self.downloadProgress.setMaximum(total)
-            self.downloadProgress.setValue(done)
+        self.downloadProgress.setMaximum(total)
+        self.downloadProgress.setValue(done)
     
     def addEntry(self, name, short, description, url, author, version, filename, status):
         """
@@ -533,7 +536,6 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
             .arg(Qt.escape(proxy.hostName()))
         
         dlg = AuthenticationDialog(info, proxy.user(), True)
-        dlg.setData(proxy.user(), proxy.password())
         if dlg.exec_() == QDialog.Accepted:
             username, password = dlg.getData()
             auth.setUser(username)
@@ -542,15 +544,14 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
                 Preferences.setUI("ProxyUser", username)
                 Preferences.setUI("ProxyPassword", password)
     
-    def __sslErrors(self, reply, errors):
+    def __sslErrors(self, sslErrors):
         """
         Private slot to handle SSL errors.
         
-        @param reply reference to the reply object (QNetworkReply)
-        @param errors list of SSL errors (list of QSslError)
+        @param sslErrors list of SSL errors (list of QSslError)
         """
         errorStrings = QStringList()
-        for err in errors:
+        for err in sslErrors:
             errorStrings.append(err.errorString())
         errorString = errorStrings.join('.<br />')
         ret = KQMessageBox.warning(self,
@@ -564,10 +565,10 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
                 QMessageBox.Yes),
             QMessageBox.No)
         if ret == QMessageBox.Yes:
-            reply.ignoreSslErrors()
+            self.__http.ignoreSslErrors()
         else:
             self.__downloadCancelled = True
-            reply.abort()
+            self.__http.abort()
     
     def getDownloadedPlugins(self):
         """
@@ -576,15 +577,6 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         @return list of plugin filenames (QStringList)
         """
         return self.__pluginsDownloaded
-    
-    @pyqtSignature("bool")
-    def on_repositoryUrlEditButton_toggled(self, checked):
-        """
-        Private slot to set the read only status of the repository URL line edit.
-        
-        @param checked state of the push button (boolean)
-        """
-        self.repositoryUrlEdit.setReadOnly(not checked)
 
 class PluginRepositoryDialog(QDialog):
     """
@@ -651,7 +643,7 @@ class PluginRepositoryWindow(KQMainWindow):
         Private slot to start the eric4 plugin installation dialog.
         """
         proc = QProcess()
-        applPath = os.path.join(getConfig("ericDir"), "eric4_plugininstall.py")
+        applPath = os.path.join(getConfig("ericDir"), "eric4-plugininstall.py")
         
         args = QStringList()
         args.append(applPath)
