@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -149,7 +149,7 @@ class PluginUninstallWidget(QWidget, Ui_PluginUninstallDialog):
                 self.trUtf8("Plugin Uninstallation"),
                 self.trUtf8("""<p>The plugin package <b>%1</b> could not be"""
                             """ removed. Aborting...</p>"""
-                            """<p>Reason: %2</p>""").arg(packageDir).arg(str(err)),
+                            """<p>Reason: %2</p>""").arg(packageDir).arg(unicode(err)),
                 QMessageBox.StandardButtons(\
                     QMessageBox.Ok))
             return False
