@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -29,7 +29,7 @@ aboutText = QApplication.translate("AboutDialog",
     """<p>To request a new feature please send an email to"""
     """ <a href="mailto:%4">%4</a>.</p>"""
     """<p>%1 uses third party software which is copyrighted"""
-    """ by its respective copyright holder. For details see"""
+    """ by it's respective copyright holder. For details see"""
     """ the copyright notice of the individual package.</p>"""
 ).arg(Program).arg(Homepage).arg(BugAddress).arg(FeatureAddress)
 
@@ -61,7 +61,6 @@ Xia WeiPeng
     Chinese translations
 
 Gianluca
-Leonardo Giordani
     Italian translations
 """
 )
@@ -70,7 +69,7 @@ thanksText = QString(
 u"""Phil Thompson for providing PyQt and QScintilla and pushing me into this business.
 
 Andrew Bushnell of Fluent Inc. for contributing the multithreading debugger
-and a bunch of fixes to enhance the platform independence.
+and a bunch of fixes to enhance the platform independance.
 
 Alexander Darovsky and Mikhail Terekhov for providing Russian translations.
 Julien Vienne for providing French translations.
@@ -751,7 +750,7 @@ class AboutDialog(QDialog, Ui_AboutDialog):
         self.setupUi(self)
         
         self.ericLabel.setText(titleText)
-        self.ericPixmap.setPixmap(UI.PixmapCache.getPixmap("eric.png").scaled(48, 48))
+        self.ericPixmap.setPixmap(UI.PixmapCache.getPixmap("eric.png"))
         
         ####################################################################
         ## ABOUT        
