@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -58,10 +58,8 @@ class TabnannyDialog(QDialog, Ui_TabnannyDialog):
         @param line linenumber of faulty source (integer or string)
         @param sourcecode faulty line of code (string)
         """
-        itm = QTreeWidgetItem(self.resultList)
-        itm.setData(0, Qt.DisplayRole, file)
-        itm.setData(1, Qt.DisplayRole, line)
-        itm.setData(2, Qt.DisplayRole, sourcecode)
+        itm = QTreeWidgetItem(self.resultList, QStringList() \
+            << file << str(line) << sourcecode)
         itm.setTextAlignment(1, Qt.AlignRight)
         
     def start(self, fn):
