@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
-Module implementing a dialog to enter the parameters for eric4_doc.
+Module implementing a dialog to enter the parameters for eric4-doc.
 """
 
 import sys
@@ -26,13 +26,13 @@ from eric4config import getConfig
 
 class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
     """
-    Class implementing a dialog to enter the parameters for eric4_doc.
+    Class implementing a dialog to enter the parameters for eric4-doc.
     """
-    def __init__(self, project, parms = None, parent = None):
+    def __init__(self, ppath, parms = None, parent = None):
         """
         Constructor
         
-        @param project reference to the project object (Project.Project)
+        @param ppath project path of the current project (string)
         @param parms parameters to set in the dialog
         @param parent parent widget of this dialog
         """
@@ -74,8 +74,7 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
                 else:
                     self.parameters[key] = parms[key]
         
-        self.ppath = project.getProjectPath()
-        self.project = project
+        self.ppath = ppath
         
         self.outputDirCompleter = E4DirCompleter(self.outputDirEdit)
         self.ignoreDirCompleter = E4DirCompleter(self.ignoreDirEdit)
@@ -148,7 +147,7 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         
         # 1. the program name
         args.append(sys.executable)
-        args.append(Utilities.normabsjoinpath(getConfig('ericDir'), "eric4_doc.py"))
+        args.append(Utilities.normabsjoinpath(getConfig('ericDir'), "eric4-doc.py"))
         
         # 2. the commandline options
         # 2a. general commandline options
@@ -250,7 +249,7 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         if not directory.isNull():
             # make it relative, if it is a subdirectory of the project path 
             dn = unicode(Utilities.toNativeSeparators(directory))
-            dn = self.project.getRelativePath(dn)
+            dn = dn.replace(self.ppath+os.sep, '')
             while dn.endswith(os.sep):
                 dn = dn[:-1]
             self.outputDirEdit.setText(dn)
@@ -275,7 +274,7 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         if not directory.isNull():
             # make it relative, if it is a subdirectory of the project path 
             dn = unicode(Utilities.toNativeSeparators(directory))
-            dn = self.project.getRelativePath(dn)
+            dn = dn.replace(self.ppath+os.sep, '')
             while dn.endswith(os.sep):
                 dn = dn[:-1]
             self.ignoreDirEdit.setText(dn)
@@ -288,10 +287,8 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         The directory in the ignore directories
         line edit is moved to the listbox above and the edit is cleared.
         """
-        basename = os.path.basename(unicode(self.ignoreDirEdit.text()))
-        if basename:
-            self.ignoreDirsList.addItem(basename)
-            self.ignoreDirEdit.clear()
+        self.ignoreDirsList.addItem(os.path.basename(unicode(self.ignoreDirEdit.text())))
+        self.ignoreDirEdit.clear()
 
     @pyqtSignature("")
     def on_deleteButton_clicked(self):
@@ -315,7 +312,7 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         if not cssFile.isEmpty():
             # make it relative, if it is in a subdirectory of the project path 
             cf = unicode(Utilities.toNativeSeparators(cssFile))
-            cf = self.project.getRelativePath(cf)
+            cf = cf.replace(self.ppath+os.sep, '')
             self.cssEdit.setText(cf)
 
     def __selectColor(self, colorKey):
@@ -463,7 +460,7 @@ class EricdocConfigDialog(QDialog, Ui_EricdocConfigDialog):
         if not directory.isNull():
             # make it relative, if it is a subdirectory of the project path 
             dn = unicode(Utilities.toNativeSeparators(directory))
-            dn = self.project.getRelativePath(dn)
+            dn = dn.replace(self.ppath+os.sep, '')
             while dn.endswith(os.sep):
                 dn = dn[:-1]
             self.qtHelpDirEdit.setText(dn)
