@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,7 +8,7 @@ Module implementing the About plugin.
 """
 
 from PyQt4.QtCore import QObject, SIGNAL, QString
-from PyQt4.QtGui import QMessageBox, QAction
+from PyQt4.QtGui import QMessageBox
 
 import KdeQt
 
@@ -88,7 +88,6 @@ class AboutPlugin(QObject):
             """<p>Display some information about this software.</p>"""
                              ).arg(Program))
         self.connect(self.aboutAct, SIGNAL('triggered()'), self.__about)
-        self.aboutAct.setMenuRole(QAction.AboutRole)
         acts.append(self.aboutAct)
         
         self.aboutQtAct = E4Action(self.trUtf8('About Qt'),
@@ -101,7 +100,6 @@ class AboutPlugin(QObject):
             """<p>Display some information about the Qt toolkit.</p>"""
         ))
         self.connect(self.aboutQtAct, SIGNAL('triggered()'), self.__aboutQt)
-        self.aboutQtAct.setMenuRole(QAction.AboutQtRole)
         acts.append(self.aboutQtAct)
         
         if KdeQt.isKDE():
