@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -47,7 +47,7 @@ def exeDisplayData():
     @return dictionary containing the data to query the presence of
         the executable
     """
-    exe = 'eric4_api'
+    exe = 'eric4-api'
     if Utilities.isWindowsPlatform():
         exe = os.path.join(getConfig("bindir"), exe +'.bat')
     
@@ -57,7 +57,7 @@ def exeDisplayData():
                                 "Eric4 API File Generator"), 
         "exe"               : exe, 
         "versionCommand"    : '--version', 
-        "versionStartsWith" : 'eric4_', 
+        "versionStartsWith" : 'eric4-', 
         "versionPosition"   : -2, 
         "version"           : "", 
         "versionCleanup"    : None, 
@@ -93,14 +93,14 @@ class EricapiPlugin(QObject):
         """
         menu = e4App().getObject("Project").getMenu("Apidoc")
         if menu:
-            self.__projectAct = E4Action(self.trUtf8('Generate API file (eric4_api)'),
-                    self.trUtf8('Generate &API file (eric4_api)'), 0, 0,
+            self.__projectAct = E4Action(self.trUtf8('Generate API file (eric4-api)'),
+                    self.trUtf8('Generate &API file (eric4-api)'), 0, 0,
                     self, 'doc_eric4_api')
             self.__projectAct.setStatusTip(\
-                self.trUtf8('Generate an API file using eric4_api'))
+                self.trUtf8('Generate an API file using eric4-api'))
             self.__projectAct.setWhatsThis(self.trUtf8(
                 """<b>Generate API file</b>"""
-                """<p>Generate an API file using eric4_api.</p>"""
+                """<p>Generate an API file using eric4-api.</p>"""
             ))
             self.connect(self.__projectAct, SIGNAL('triggered()'), self.__doEricapi)
             e4App().getObject("Project").addE4Actions([self.__projectAct])
@@ -140,7 +140,7 @@ class EricapiPlugin(QObject):
     
     def __doEricapi(self):
         """
-        Private slot to perform the eric4_api api generation.
+        Private slot to perform the eric4-api api generation.
         """
         project = e4App().getObject("Project")
         parms = project.getData('DOCUMENTATIONPARMS', "ERIC4API")
@@ -168,7 +168,7 @@ class EricapiPlugin(QObject):
                         root, ext = os.path.splitext(outputFileName)
                         outfile = "%s-%s%s" % (root, progLanguage.lower(), ext)
                 
-                outfile = project.getRelativePath(outfile)
+                outfile = outfile.replace(project.ppath+os.sep, '')
                 if outfile not in project.pdata['OTHERS']:
                     project.pdata['OTHERS'].append(outfile)
                     project.setDirty(True)
