@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -88,6 +88,34 @@ class SvnProjectHelper(VcsProjectHelper):
         self.connect(self.vcsCommitAct, SIGNAL('triggered()'), self._vcsCommit)
         self.actions.append(self.vcsCommitAct)
         
+        self.vcsAddAct = E4Action(self.trUtf8('Add to repository'),
+                UI.PixmapCache.getIcon("vcsAdd.png"),
+                self.trUtf8('&Add to repository...'), 0, 0, self, 'subversion_add')
+        self.vcsAddAct.setStatusTip(self.trUtf8(
+            'Add the local project to the VCS repository'
+        ))
+        self.vcsAddAct.setWhatsThis(self.trUtf8(
+            """<b>Add to repository</b>"""
+            """<p>This adds (imports) the local project to the VCS repository.</p>"""
+        ))
+        self.connect(self.vcsAddAct, SIGNAL('triggered()'), self._vcsImport)
+        self.actions.append(self.vcsAddAct)
+        
+        self.vcsRemoveAct = E4Action(self.trUtf8('Remove from repository (and disk)'),
+                UI.PixmapCache.getIcon("vcsRemove.png"),
+                self.trUtf8('&Remove from repository (and disk)'),
+                0, 0, self, 'subversion_remove')
+        self.vcsRemoveAct.setStatusTip(self.trUtf8(
+            'Remove the local project from the VCS repository (and  disk)'
+        ))
+        self.vcsRemoveAct.setWhatsThis(self.trUtf8(
+            """<b>Remove from repository</b>"""
+            """<p>This removes the local project from the VCS repository"""
+            """ (and disk).</p>"""
+        ))
+        self.connect(self.vcsRemoveAct, SIGNAL('triggered()'), self._vcsRemove)
+        self.actions.append(self.vcsRemoveAct)
+        
         self.vcsLogAct = E4Action(self.trUtf8('Show log'),
                 UI.PixmapCache.getIcon("vcsLog.png"),
                 self.trUtf8('Show &log'),
@@ -190,21 +218,6 @@ class SvnProjectHelper(VcsProjectHelper):
         self.connect(self.vcsStatusAct, SIGNAL('triggered()'), self._vcsStatus)
         self.actions.append(self.vcsStatusAct)
         
-        self.svnChangeListsAct = E4Action(self.trUtf8('Show change lists'),
-                UI.PixmapCache.getIcon("vcsChangeLists.png"),
-                self.trUtf8('Show change lists'),
-                0, 0, self, 'subversion_changelists')
-        self.svnChangeListsAct.setStatusTip(self.trUtf8(
-            'Show the change lists and associated files of the local project'
-        ))
-        self.svnChangeListsAct.setWhatsThis(self.trUtf8(
-            """<b>Show change lists</b>"""
-            """<p>This shows the change lists and associated files of the"""
-            """ local project.</p>"""
-        ))
-        self.connect(self.svnChangeListsAct, SIGNAL('triggered()'), self.__svnChangeLists)
-        self.actions.append(self.svnChangeListsAct)
-        
         self.svnRepoInfoAct = E4Action(self.trUtf8('Show repository info'), 
                 UI.PixmapCache.getIcon("vcsRepo.png"),
                 self.trUtf8('Show repository info'),
@@ -301,15 +314,15 @@ class SvnProjectHelper(VcsProjectHelper):
         self.connect(self.vcsSwitchAct, SIGNAL('triggered()'), self._vcsSwitch)
         self.actions.append(self.vcsSwitchAct)
         
-        self.vcsResolveAct = E4Action(self.trUtf8('Conflicts resolved'),
-                self.trUtf8('Con&flicts resolved'),
+        self.vcsResolveAct = E4Action(self.trUtf8('Resolve conflicts'),
+                self.trUtf8('Resolve con&flicts'),
                 0, 0, self, 'subversion_resolve')
         self.vcsResolveAct.setStatusTip(self.trUtf8(
-            'Mark all conflicts of the local project as resolved'
+            'Resolve all conflicts of the local project'
         ))
         self.vcsResolveAct.setWhatsThis(self.trUtf8(
-            """<b>Conflicts resolved</b>"""
-            """<p>This marks all conflicts of the local project as resolved.</p>"""
+            """<b>Resolve conflicts</b>"""
+            """<p>This resolves all conflicts of the local project.</p>"""
         ))
         self.connect(self.vcsResolveAct, SIGNAL('triggered()'), self.__svnResolve)
         self.actions.append(self.vcsResolveAct)
@@ -482,6 +495,9 @@ class SvnProjectHelper(VcsProjectHelper):
         menu.addAction(self.vcsNewAct)
         menu.addAction(self.vcsExportAct)
         menu.addSeparator()
+        menu.addAction(self.vcsAddAct)
+        menu.addAction(self.vcsRemoveAct)
+        menu.addSeparator()
         menu.addAction(self.vcsTagAct)
         if self.vcs.otherData["standardLayout"]:
             menu.addAction(self.svnTagListAct)
@@ -494,7 +510,6 @@ class SvnProjectHelper(VcsProjectHelper):
         menu.addAction(self.svnLogBrowserAct)
         menu.addSeparator()
         menu.addAction(self.vcsStatusAct)
-        menu.addAction(self.svnChangeListsAct)
         menu.addAction(self.svnRepoInfoAct)
         menu.addSeparator()
         menu.addAction(self.vcsDiffAct)
@@ -601,12 +616,6 @@ class SvnProjectHelper(VcsProjectHelper):
         
     def __svnConfigure(self):
         """
-        Private slot to open the configuration dialog.
+        Private method to open the configuration dialog.
         """
         e4App().getObject("UserInterface").showPreferences("zzz_subversionPage")
-        
-    def __svnChangeLists(self):
-        """
-        Private slot used to show a list of change lists.
-        """
-        self.vcs.svnShowChangelists(self.project.ppath)
