@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -23,11 +23,10 @@ class SvnCommitDialog(QWidget, Ui_SvnCommitDialog):
     @signal accepted() emitted, if the dialog was accepted
     @signal rejected() emitted, if the dialog was rejected
     """
-    def __init__(self, changelists, parent = None):
+    def __init__(self, parent = None):
         """
         Constructor
         
-        @param changelists list of available change lists (list of strings)
         @param parent parent widget (QWidget)
         """
         QWidget.__init__(self, parent, Qt.WindowFlags(Qt.Window))
@@ -35,8 +34,6 @@ class SvnCommitDialog(QWidget, Ui_SvnCommitDialog):
         
         if pysvn.svn_version < (1, 5, 0) or pysvn.version < (1, 6, 0):
             self.changeListsGroup.hide()
-        else:
-            self.changeLists.addItems(sorted(changelists))
         
     def showEvent(self, evt):
         """
@@ -76,7 +73,9 @@ class SvnCommitDialog(QWidget, Ui_SvnCommitDialog):
         
         @return flag indicating availability of changelists (boolean)
         """
-        return len(self.changeLists.selectedItems()) > 0
+        listsTxt = self.changeListsEdit.text()
+        return not listsTxt.isEmpty() and \
+               len(listsTxt.split(';', QString.SkipEmptyParts)) > 0
         
     def changelistsData(self):
         """
@@ -85,12 +84,15 @@ class SvnCommitDialog(QWidget, Ui_SvnCommitDialog):
         @return tuple containing the changelists (list of strings) and a flag
             indicating to keep changelists (boolean)
         """
-        slists = [unicode(l.text()).strip() for l in self.changeLists.selectedItems()
-                  if unicode(l.text()).strip() != ""]
+        listsTxt = self.changeListsEdit.text()
+        lists = listsTxt.split(';', QString.SkipEmptyParts)
         
-        if len(slists) == 0:
+        if len(lists) == 0:
             return [], False
         
+        slists = []
+        for list_ in lists:
+            slists.append(unicode(list_).strip())
         return slists, self.keepChangeListsCheckBox.isChecked()
         
     def on_buttonBox_clicked(self, button):
