@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -43,7 +43,6 @@ class SvnStatusMonitorThread(VcsStatusMonitorThread):
         <ul>
             <li>"A" path was added but not yet comitted</li>
             <li>"M" path has local changes</li>
-            <li>"O" path was removed</li>
             <li>"R" path was deleted and then re-added</li>
             <li>"U" path needs an update</li>
             <li>"Z" path contains a conflict</li>
@@ -73,11 +72,9 @@ class SvnStatusMonitorThread(VcsStatusMonitorThread):
             for file in allFiles:
                 uptodate = True
                 if file.repos_text_status != pysvn.wc_status_kind.none:
-                    uptodate = uptodate and \
-                        file.repos_text_status != pysvn.wc_status_kind.modified
+                    uptodate = uptodate and file.repos_text_status == file.text_status
                 if file.repos_prop_status != pysvn.wc_status_kind.none:
-                    uptodate = uptodate and \
-                        file.repos_prop_status != pysvn.wc_status_kind.modified
+                    uptodate = uptodate and file.repos_prop_status == file.prop_status
                 
                 status = ""
                 if not uptodate:
@@ -86,9 +83,6 @@ class SvnStatusMonitorThread(VcsStatusMonitorThread):
                 elif file.text_status == pysvn.wc_status_kind.conflicted or \
                    file.prop_status == pysvn.wc_status_kind.conflicted:
                     status = "Z"
-                elif file.text_status == pysvn.wc_status_kind.deleted or \
-                   file.prop_status == pysvn.wc_status_kind.deleted:
-                    status = "O"
                 elif file.text_status == pysvn.wc_status_kind.modified or \
                    file.prop_status == pysvn.wc_status_kind.modified:
                     status = "M"
