@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -46,9 +46,7 @@ from SvnInfoDialog import SvnInfoDialog
 from SvnRelocateDialog import SvnRelocateDialog
 from SvnUrlSelectionDialog import SvnUrlSelectionDialog
 from SvnRepoBrowserDialog import SvnRepoBrowserDialog
-from SvnChangeListsDialog import SvnChangeListsDialog
 from SvnStatusMonitorThread import SvnStatusMonitorThread
-from SvnUtilities import getConfigPath, amendConfig, createDefaultConfig
 
 from ProjectBrowserHelper import SvnProjectBrowserHelper
 from ProjectHelper import SvnProjectHelper
@@ -127,8 +125,6 @@ class Subversion(VersionControl):
         
         self.__commitData = {}
         self.__commitDialog = None
-        
-        self.__wcng = True      # assume new generation working copy metadata format
     
     def getPlugin(self):
         """
@@ -471,7 +467,7 @@ class Subversion(VersionControl):
         if not noDialog and msg.isEmpty():
             # call CommitDialog and get message from there
             if self.__commitDialog is None:
-                self.__commitDialog = SvnCommitDialog(self.svnGetChangelists(), self.__ui)
+                self.__commitDialog = SvnCommitDialog(self.__ui)
                 self.connect(self.__commitDialog, SIGNAL("accepted()"), 
                              self.__vcsCommit_Step2)
             self.__commitDialog.show()
@@ -624,49 +620,22 @@ class Subversion(VersionControl):
         names = []
         tree = []
         wdir = dname
-        if self.__wcng:
-            repodir = dname
-            while not os.path.isdir(os.path.join(repodir, self.adminDir)):
-                repodir = os.path.dirname(repodir)
-                if os.path.splitdrive(repodir)[1] == os.sep:
-                    return  # oops, project is not version controlled
-            while os.path.normcase(dname) != os.path.normcase(repodir) and \
-                  (os.path.normcase(dname) not in self.statusCache or \
-                   self.statusCache[os.path.normcase(dname)] == self.canBeAdded):
-                # add directories recursively, if they aren't in the repository already
-                tree.insert(-1, dname)
-                dname = os.path.dirname(dname)
-                wdir = dname
-        else:
-            while not os.path.exists(os.path.join(dname, self.adminDir)):
-                # add directories recursively, if they aren't in the repository already
-                tree.insert(-1, dname)
-                dname = os.path.dirname(dname)
-                wdir = dname
+        while not os.path.exists(os.path.join(dname, self.adminDir)):
+            # add directories recursively, if they aren't in the repository already
+            tree.insert(-1, dname)
+            dname = os.path.split(dname)[0]
+            wdir = dname
         names.extend(tree)
         
         if type(name) is types.ListType:
             tree2 = []
             for n in name:
-                d = os.path.dirname(n)
-                if self.__wcng:
-                    repodir = d
-                    while not os.path.isdir(os.path.join(repodir, self.adminDir)):
-                        repodir = os.path.dirname(repodir)
-                        if os.path.splitdrive(repodir)[1] == os.sep:
-                            return  # oops, project is not version controlled
-                    while os.path.normcase(d) != os.path.normcase(repodir) and \
-                          (d not in tree2 + tree) and \
-                          (os.path.normcase(d) not in self.statusCache or \
-                           self.statusCache[os.path.normcase(d)] == self.canBeAdded):
-                        tree2.append(d)
-                        d = os.path.dirname(d)
-                else:
-                    while not os.path.exists(os.path.join(d, self.adminDir)):
-                        if d in tree2 + tree:
-                            break
-                        tree2.append(d)
-                        d = os.path.dirname(d)
+                d = os.path.split(n)[0]
+                while not os.path.exists(os.path.join(d, self.adminDir)):
+                    if d in tree2 + tree:
+                        break
+                    tree2.append(d)
+                    d = os.path.split(d)[0]
             tree2.reverse()
             names.extend(tree2)
             names.extend(name)
@@ -727,48 +696,22 @@ class Subversion(VersionControl):
         if type(path) is types.ListType:
             dname, fnames = self.splitPathList(path)
             for n in path:
-                d = os.path.dirname(n)
-                if self.__wcng:
-                    repodir = d
-                    while not os.path.isdir(os.path.join(repodir, self.adminDir)):
-                        repodir = os.path.dirname(repodir)
-                        if os.path.splitdrive(repodir)[1] == os.sep:
-                            return  # oops, project is not version controlled
-                    while os.path.normcase(d) != os.path.normcase(repodir) and \
-                          (d not in tree) and \
-                          (os.path.normcase(d) not in self.statusCache or \
-                           self.statusCache[os.path.normcase(d)] == self.canBeAdded):
-                        tree.append(d)
-                        d = os.path.dirname(d)
-                else:
-                    while not os.path.exists(os.path.join(d, self.adminDir)):
-                        # add directories recursively, 
-                        # if they aren't in the repository already
-                        if d in tree:
-                            break
-                        tree.append(d)
-                        d = os.path.dirname(d)
+                d = os.path.split(n)[0]
+                while not os.path.exists(os.path.join(d, self.adminDir)):
+                    # add directories recursively, 
+                    # if they aren't in the repository already
+                    if d in tree:
+                        break
+                    tree.append(d)
+                    d = os.path.split(d)[0]
             tree.reverse()
         else:
             dname, fname = os.path.split(unicode(path))
-            if self.__wcng:
-                repodir = dname
-                while not os.path.isdir(os.path.join(repodir, self.adminDir)):
-                    repodir = os.path.dirname(repodir)
-                    if os.path.splitdrive(repodir)[1] == os.sep:
-                        return  # oops, project is not version controlled
-                while os.path.normcase(dname) != os.path.normcase(repodir) and \
-                      (os.path.normcase(dname) not in self.statusCache or \
-                       self.statusCache[os.path.normcase(dname)] == self.canBeAdded):
-                    # add directories recursively, if they aren't in the repository already
-                    tree.insert(-1, dname)
-                    dname = os.path.dirname(dname)
-            else:
-                while not os.path.exists(os.path.join(dname, self.adminDir)):
-                    # add directories recursively,
-                    # if they aren't in the repository already
-                    tree.insert(-1, dname)
-                    dname = os.path.dirname(dname)
+            while not os.path.exists(os.path.join(dname, self.adminDir)):
+                # add directories recursively,
+                # if they aren't in the repository already
+                tree.insert(-1, dname)
+                dname = os.path.split(dname)[0]
         if tree:
             self.vcsAdd(tree, True)
         
@@ -1065,8 +1008,8 @@ class Subversion(VersionControl):
         recurse = False
         if type(name) is not types.ListType:
             name = [name]
-        if len(name) == 1 and os.path.isdir(name[0]):
-            recurse = True
+            if os.path.isdir(name[0]):
+                recurse = True
         client = self.getClient()
         dlg = \
             SvnDialog(self.trUtf8('Reverting changes'),
@@ -1261,51 +1204,6 @@ class Subversion(VersionControl):
         """
         Public method used to get the registered state of a file in the vcs.
         
-        @param name filename to check (string or QString)
-        @return a combination of canBeCommited and canBeAdded
-        """
-        if self.__wcng:
-            return self.__vcsRegisteredState_wcng(name)
-        else:
-            return self.__vcsRegisteredState_wc(name)
-        
-    def __vcsRegisteredState_wcng(self, name):
-        """
-        Private method used to get the registered state of a file in the vcs.
-        
-        This is the variant for subversion installations using the new working copy
-        meta-data format.
-        
-        @param name filename to check (string or QString)
-        @return a combination of canBeCommited and canBeAdded
-        """
-        name = unicode(name)
-        if name.endswith(os.sep):
-            name = name[:-1]
-        name = os.path.normcase(name)
-        dname, fname = self.splitPath(name)
-        
-        if fname == '.' and os.path.isdir(os.path.join(dname, self.adminDir)):
-            return self.canBeCommitted
-        
-        if name in self.statusCache:
-            return self.statusCache[name]
-        
-        name = os.path.normcase(unicode(name))
-        states = { name : 0 }
-        states = self.vcsAllRegisteredStates(states, dname, False)
-        if states[name] == self.canBeCommitted:
-            return self.canBeCommitted
-        else:
-            return self.canBeAdded
-        
-    def __vcsRegisteredState_wc(self, name):
-        """
-        Private method used to get the registered state of a file in the vcs.
-        
-        This is the variant for subversion installations using the old working copy
-        meta-data format.
-        
         @param name filename to check (string or QString)
         @return a combination of canBeCommited and canBeAdded
         """
@@ -1333,106 +1231,6 @@ class Subversion(VersionControl):
         directory has been scanned already. If so, it is assumed, that the states for
         all files has been populated by the previous run.
         
-        @param names dictionary with all filenames to be checked as keys
-        @param dname directory to check in (string)
-        @param shortcut flag indicating a shortcut should be taken (boolean)
-        @return the received dictionary completed with a combination of 
-            canBeCommited and canBeAdded or None in order to signal an error
-        """
-        if self.__wcng:
-            return self.__vcsAllRegisteredStates_wcng(names, dname, shortcut)
-        else:
-            return self.__vcsAllRegisteredStates_wc(names, dname, shortcut)
-        
-    def __vcsAllRegisteredStates_wcng(self, names, dname, shortcut = True):
-        """
-        Private method used to get the registered states of a number of files in the vcs.
-        
-        This is the variant for subversion installations using the new working copy
-        meta-data format.
-        
-        <b>Note:</b> If a shortcut is to be taken, the code will only check, if the named
-        directory has been scanned already. If so, it is assumed, that the states for
-        all files has been populated by the previous run.
-        
-        @param names dictionary with all filenames to be checked as keys
-        @param dname directory to check in (string)
-        @param shortcut flag indicating a shortcut should be taken (boolean)
-        @return the received dictionary completed with a combination of 
-            canBeCommited and canBeAdded or None in order to signal an error
-        """
-        dname = unicode(dname)
-        if dname.endswith(os.sep):
-            dname = dname[:-1]
-        dname = os.path.normcase(dname)
-        
-        found = False
-        for name in self.statusCache.keys():
-            if names.has_key(name):
-                found = True
-                names[name] = self.statusCache[name]
-        
-        if not found:
-            # find the root of the repo
-            repodir = dname
-            while not os.path.isdir(os.path.join(repodir, self.adminDir)):
-                repodir = os.path.dirname(repodir)
-                if os.path.splitdrive(repodir)[1] == os.sep:
-                    return names
-            
-            from SvnDialogMixin import SvnDialogMixin
-            mixin = SvnDialogMixin()
-            client = self.getClient()
-            client.callback_get_login = \
-                mixin._clientLoginCallback
-            client.callback_ssl_server_trust_prompt = \
-                mixin._clientSslServerTrustPromptCallback
-            
-            try:
-                locker = QMutexLocker(self.vcsExecutionMutex)
-                allFiles = client.status(dname, recurse = True, get_all = True, 
-                                              ignore = True, update = False)
-                locker.unlock()
-                dirs = [x for x in names.keys() if os.path.isdir(x)]
-                for file in allFiles:
-                    name = os.path.normcase(file.path)
-                    if file.is_versioned:
-                        if names.has_key(name):
-                            names[name] = self.canBeCommitted
-                            dn = name
-                            while os.path.splitdrive(dn)[1] != os.sep and \
-                                  dn != repodir:
-                                dn = os.path.dirname(dn)
-                                if dn in self.statusCache and \
-                                   self.statusCache[dn] == self.canBeCommitted:
-                                    break
-                                self.statusCache[dn] = self.canBeCommitted
-                        self.statusCache[name] = self.canBeCommitted
-                        if dirs:
-                            for d in dirs:
-                                if name.startswith(d):
-                                    names[d] = self.canBeCommitted
-                                    self.statusCache[d] = self.canBeCommitted
-                                    dirs.remove(d)
-                                    break
-                    else:
-                        self.statusCache[name] = self.canBeAdded
-            except pysvn.ClientError, e:
-                locker.unlock()    # ignore pysvn errors
-        
-        return names
-        
-    def __vcsAllRegisteredStates_wc(self, names, dname, shortcut = True):
-        """
-        Private method used to get the registered states of a number of files in the vcs.
-        
-        This is the variant for subversion installations using the old working copy
-        meta-data format.
-        
-        <b>Note:</b> If a shortcut is to be taken, the code will only check, if the named
-        directory has been scanned already. If so, it is assumed, that the states for
-        all files has been populated by the previous run.
-        
         @param names dictionary with all filenames to be checked as keys
         @param dname directory to check in (string)
         @param shortcut flag indicating a shortcut should be taken (boolean)
@@ -1487,20 +1285,6 @@ class Subversion(VersionControl):
         """
         self.statusCache = {}
         
-    def vcsInitConfig(self, project):
-        """
-        Public method to initialize the VCS configuration.
-        
-        This method ensures, that eric specific files and directories are ignored.
-        
-        @param project reference to the project (Project)
-        """
-        configPath = getConfigPath()
-        if os.path.exists(configPath):
-            amendConfig()
-        else:
-            createDefaultConfig()
-    
     def vcsName(self):
         """
         Public method returning the name of the vcs.
@@ -1947,7 +1731,7 @@ class Subversion(VersionControl):
         
         @param name file/directory name to show the log of (string)
         """
-        noEntries, ok = KQInputDialog.getInt(\
+        noEntries, ok = KQInputDialog.getInteger(\
             None,
             self.trUtf8("Subversion Log"),
             self.trUtf8("Select number of entries to show."),
@@ -2013,7 +1797,7 @@ class Subversion(VersionControl):
         except pysvn.ClientError, e:
             dlg.showError(e.args[0])
         except AttributeError, e:
-            dlg.showError(str(e))
+            dlg.showError(unicode(e))
         locker.unlock()
         dlg.finish()
         dlg.exec_()
@@ -2050,7 +1834,7 @@ class Subversion(VersionControl):
         except pysvn.ClientError, e:
             dlg.showError(e.args[0])
         except AttributeError, e:
-            dlg.showError(str(e))
+            dlg.showError(unicode(e))
         locker.unlock()
         dlg.finish()
         dlg.exec_()
@@ -2122,7 +1906,7 @@ class Subversion(VersionControl):
         
     def svnRemoveFromChangelist(self, names):
         """
-        Public method to remove a file or directory from its changelist.
+        Public method to remove a file or directory from it's changelist.
         
         Note: Directories will be removed recursively.
         
@@ -2159,12 +1943,11 @@ class Subversion(VersionControl):
         if type(names) is not types.ListType:
             names = [names]
         
-        clname, ok = KQInputDialog.getItem(\
+        clname, ok = KQInputDialog.getText(\
             None,
             self.trUtf8("Add to changelist"),
             self.trUtf8("Enter name of the changelist:"),
-            sorted(self.svnGetChangelists()),
-            0, True)
+            QLineEdit.Normal)
         if not ok or clname.isEmpty():
             return
         clname = unicode(clname)
@@ -2184,40 +1967,6 @@ class Subversion(VersionControl):
         locker.unlock()
         dlg.finish()
         dlg.exec_()
-        
-    def svnShowChangelists(self, path):
-        """
-        Public method used to inspect the change lists defined for the project.
-        
-        @param path directory name to show change lists for (string)
-        """
-        self.changeLists = SvnChangeListsDialog(self)
-        self.changeLists.show()
-        QApplication.processEvents()
-        self.changeLists.start(path)
-        
-    def svnGetChangelists(self):
-        """
-        Public method to get a list of all defined change lists.
-        
-        @return list of defined change list names (list of strings)
-        """
-        changelists = []
-        client = self.getClient()
-        if hasattr(client, 'get_changelist'):
-            ppath = e4App().getObject("Project").getProjectPath()
-            locker = QMutexLocker(self.vcsExecutionMutex)
-            try:
-                entries = client.get_changelist(ppath, depth=pysvn.depth.infinity)
-                for entry in entries:
-                    changelist = entry[1]
-                    if changelist not in changelists:
-                        changelists.append(changelist)
-            except pysvn.ClientError:
-                pass
-            locker.unlock()
-        
-        return changelists
 
     ############################################################################
     ## Private Subversion specific methods are below.
@@ -2256,19 +2005,11 @@ class Subversion(VersionControl):
         @param url url string (string)
         @return properly normalized url for subversion
         """
-        protocol, url = url.split("://", 1)
-        if url.startswith("\\\\"):
-            url = url[2:]
-        if protocol == "file":
-            url = os.path.normcase(url)
-            if url[1] == ":":
-                url = url.replace(":", "|", 1)
         url = url.replace('\\', '/')
         if url.endswith('/'):
             url = url[:-1]
-        if not url.startswith("/") and url[1] in [":", "|"]:
-            url = "/%s" % url
-        return "%s://%s" % (protocol, url)
+        urll = url.split('//')
+        return "%s//%s" % (urll[0], '/'.join(urll[1:]))
 
     ############################################################################
     ## Methods to get the helper objects are below.
@@ -2295,9 +2036,6 @@ class Subversion(VersionControl):
         """
         helper = self.__plugin.getProjectHelper()
         helper.setObjects(self, project)
-        self.__wcng = \
-            os.path.exists(os.path.join(project.getProjectPath(), ".svn", "format")) or \
-            os.path.exists(os.path.join(project.getProjectPath(), "_svn", "format"))
         return helper
 
     ############################################################################
