@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -226,9 +226,9 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             self._VCSRemove)
         self.vcsMenuActions.append(act)
         menu.addSeparator()
-        act = menu.addAction(self.trUtf8('Copy'), self.__SVNCopy)
+        act = menu.addAction(self.trUtf8('Copy in repository'), self.__SVNCopy)
         self.vcsMenuActions.append(act)
-        act = menu.addAction(self.trUtf8('Move'), self.__SVNMove)
+        act = menu.addAction(self.trUtf8('Move in repository'), self.__SVNMove)
         self.vcsMenuActions.append(act)
         if self.vcs.versionStr >= '1.5.0':
             menu.addSeparator()
@@ -275,7 +275,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         act = menu.addAction(UI.PixmapCache.getIcon("vcsMerge.png"),
             self.trUtf8('Merge changes'), self._VCSMerge)
         self.vcsMenuActions.append(act)
-        act = menu.addAction(self.trUtf8('Conflict resolved'), self.__SVNResolve)
+        act = menu.addAction(self.trUtf8('Resolve conflict'), self.__SVNResolve)
         self.vcsMenuActions.append(act)
         if self.vcs.versionStr >= '1.2.0':
             menu.addSeparator()
@@ -384,7 +384,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         act = menu.addAction(UI.PixmapCache.getIcon("vcsRevert.png"),
             self.trUtf8('Revert changes'), self._VCSRevert)
         self.vcsMultiMenuActions.append(act)
-        act = menu.addAction(self.trUtf8('Conflict resolved'), self.__SVNResolve)
+        act = menu.addAction(self.trUtf8('Resolve conflict'), self.__SVNResolve)
         self.vcsMultiMenuActions.append(act)
         if self.vcs.versionStr >= '1.2.0':
             menu.addSeparator()
@@ -494,9 +494,9 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             self._VCSRemove)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
-        act = menu.addAction(self.trUtf8('Copy'), self.__SVNCopy)
+        act = menu.addAction(self.trUtf8('Copy in repository'), self.__SVNCopy)
         self.vcsDirMenuActions.append(act)
-        act = menu.addAction(self.trUtf8('Move'), self.__SVNMove)
+        act = menu.addAction(self.trUtf8('Move in repository'), self.__SVNMove)
         self.vcsDirMenuActions.append(act)
         if self.vcs.versionStr >= '1.5.0':
             menu.addSeparator()
@@ -540,7 +540,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         act = menu.addAction(UI.PixmapCache.getIcon("vcsMerge.png"),
             self.trUtf8('Merge changes'), self._VCSMerge)
         self.vcsDirMenuActions.append(act)
-        act = menu.addAction(self.trUtf8('Conflict resolved'), self.__SVNResolve)
+        act = menu.addAction(self.trUtf8('Resolve conflict'), self.__SVNResolve)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(self.trUtf8('Set Property'), self.__SVNSetProp)
@@ -634,7 +634,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
         act = menu.addAction(UI.PixmapCache.getIcon("vcsMerge.png"),
             self.trUtf8('Merge changes'), self._VCSMerge)
         self.vcsDirMenuActions.append(act)
-        act = menu.addAction(self.trUtf8('Conflict resolved'), self.__SVNResolve)
+        act = menu.addAction(self.trUtf8('Resolve conflict'), self.__SVNResolve)
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(self.trUtf8('Set Property'), self.__SVNSetProp)
