@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -18,11 +18,9 @@ from E4Gui.E4Completers import E4FileCompleter, E4DirCompleter
 
 from Ui_SvnCopyDialog import Ui_SvnCopyDialog
 
-import Utilities
-
 class SvnCopyDialog(QDialog, Ui_SvnCopyDialog):
     """
-    Class implementing a dialog to enter the data for a copy or rename operation.
+    Class implementing a dialog to enter the data for a copy operation.
     """
     def __init__(self, source, parent = None, move = False, force = False):
         """
@@ -50,8 +48,6 @@ class SvnCopyDialog(QDialog, Ui_SvnCopyDialog):
         
         self.sourceEdit.setText(source)
         
-        self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(False)
-        
     def getData(self):
         """
         Public method to retrieve the copy data.
@@ -59,12 +55,7 @@ class SvnCopyDialog(QDialog, Ui_SvnCopyDialog):
         @return the target name (QString) and a flag indicating
             the operation should be enforced (boolean)
         """
-        target = unicode(self.targetEdit.text())
-        if not os.path.isabs(target):
-            sourceDir = os.path.dirname(unicode(self.sourceEdit.text()))
-            target = os.path.join(sourceDir, target)
-        return (QString(Utilities.toNativeSeparators(target)),
-                self.forceCheckBox.isChecked())
+        return self.targetEdit.text(), self.forceCheckBox.isChecked()
         
     @pyqtSignature("")
     def on_dirButton_clicked(self):
@@ -88,15 +79,4 @@ class SvnCopyDialog(QDialog, Ui_SvnCopyDialog):
                 QFileDialog.Options(QFileDialog.DontConfirmOverwrite))
         
         if not target.isEmpty():
-            self.targetEdit.setText(Utilities.toNativeSeparators(target))
-    
-    @pyqtSignature("QString")
-    def on_targetEdit_textChanged(self, txt):
-        """
-        Private slot to handle changes of the target.
-        
-        @param txt contents of the target edit (QString)
-        """
-        txt = unicode(txt)
-        self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(
-            os.path.isabs(txt) or os.path.dirname(txt) == "")
+            self.targetEdit.setText(target)
