@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -60,15 +60,9 @@ class SvnDialog(QDialog, Ui_SvnDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
         
         self.inputGroup.setEnabled(False)
-        self.inputGroup.hide()
         
         self.proc = None
         
-        self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
-        self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
-        self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
-        self.buttonBox.button(QDialogButtonBox.Close).setFocus(Qt.OtherFocusReason)
-        
         if Preferences.getVCS("AutoClose") and \
            self.normal and \
            not self.errors.toPlainText().length() > 0:
@@ -95,13 +89,12 @@ class SvnDialog(QDialog, Ui_SvnDialog):
         self.normal = (exitStatus == QProcess.NormalExit) and (exitCode == 0)
         self.__finish()
         
-    def startProcess(self, args, workingDir = None, setLanguage = False):
+    def startProcess(self, args, workingDir = None):
         """
         Public slot used to start the process.
         
         @param args list of arguments for the process (QStringList)
         @param workingDir working directory for the process (string or QString)
-        @param setLanguage flag indicating to set the language to "C" (boolean)
         @return flag indicating a successful start of the process
         """
         self.errorGroup.hide()
@@ -111,10 +104,6 @@ class SvnDialog(QDialog, Ui_SvnDialog):
         self.__hasAddOrDelete = False
         
         self.proc = QProcess()
-        if setLanguage:
-            env = QProcessEnvironment.systemEnvironment()
-            env.insert("LANG", "C")
-            self.proc.setProcessEnvironment(env)
         nargs = QStringList()
         lastWasPwd = False
         for arg in args:
@@ -143,7 +132,6 @@ class SvnDialog(QDialog, Ui_SvnDialog):
         if not procStarted:
             self.buttonBox.setFocus()
             self.inputGroup.setEnabled(False)
-            self.inputGroup.hide()
             KQMessageBox.critical(None,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
@@ -152,7 +140,6 @@ class SvnDialog(QDialog, Ui_SvnDialog):
                 ).arg('svn'))
         else:
             self.inputGroup.setEnabled(True)
-            self.inputGroup.show()
         return procStarted
         
     def normalExit(self):
@@ -177,7 +164,7 @@ class SvnDialog(QDialog, Ui_SvnDialog):
             if not self.__hasAddOrDelete and len(s) > 0:
                 # check the output
                 for l in s.split(os.linesep, QString.SkipEmptyParts):
-                    if l[0:2] in ['A ', 'D ']:
+                    if l[0] in ['A', 'D']:
                         self.__hasAddOrDelete = True
                         break
         
