@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -44,12 +44,16 @@ class SvnOptionsDialog(QDialog, Ui_SvnOptionsDialog):
         
         self.protocolCombo.addItems(ConfigSvnProtocols)
         
-        self.vcs = vcs
-        
         hd = Utilities.toNativeSeparators(QDir.homePath())
         hd = os.path.join(unicode(hd), 'subversionroot')
         self.vcsUrlEdit.setText(hd)
         
+        self.vcs = vcs
+        
+        self.localPath = unicode(hd)
+        self.networkPath = "localhost/"
+        self.localProtocol = True
+        
     @pyqtSignature("")
     def on_vcsUrlButton_clicked(self):
         """
@@ -97,9 +101,12 @@ class SvnOptionsDialog(QDialog, Ui_SvnOptionsDialog):
         
         @return a dictionary containing the data entered
         """
+        scheme = str(self.protocolCombo.currentText())
+        url = unicode(self.vcsUrlEdit.text())
+        if scheme == "file://" and url[0] not in ["\\", "/"]:
+            url = "/%s" % url
         vcsdatadict = {
-            "url" : '%s%s' % (str(self.protocolCombo.currentText()),
-                              unicode(self.vcsUrlEdit.text())),
+            "url" : '%s%s' % (scheme, url),
             "message" : unicode(self.vcsLogEdit.text()),
             "standardLayout" : self.layoutCheckBox.isChecked(),
         }
