@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -106,21 +106,14 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         """
         path = repopath
         
-        if revision == "":
-            rev = ""
-        else:
-            rev = int(revision)
-        if size == "":
-            sz = ""
-        else:
-            sz = int(size)
-        
-        itm = QTreeWidgetItem(self.parentItem)
-        itm.setData(0, Qt.DisplayRole, path)
-        itm.setData(1, Qt.DisplayRole, rev)
-        itm.setData(2, Qt.DisplayRole, author)
-        itm.setData(3, Qt.DisplayRole, sz)
-        itm.setData(4, Qt.DisplayRole, date)
+        itm = QTreeWidgetItem(self.parentItem, 
+            QStringList() \
+            << path \
+            << revision \
+            << author \
+            << size \
+            << date
+        )
         
         if nodekind == "dir":
             itm.setIcon(0, self.__dirIcon)
@@ -247,7 +240,6 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         if not procStarted:
             self.__finish()
             self.inputGroup.setEnabled(False)
-            self.inputGroup.hide()
             KQMessageBox.critical(None,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
@@ -256,7 +248,6 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
                 ).arg('svn'))
         else:
             self.inputGroup.setEnabled(True)
-            self.inputGroup.show()
     
     def __normalizeUrl(self, url):
         """
@@ -354,8 +345,8 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
             self.process.waitForFinished(3000)
         
         self.inputGroup.setEnabled(False)
-        self.inputGroup.hide()
         
+        self.repoTree.doItemsLayout()
         self.__resizeColumns()
         self.__resort()
         QApplication.restoreOverrideCursor()
