@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -16,8 +16,6 @@ from PyQt4.QtGui import *
 from KdeQt import KQMessageBox
 from KdeQt.KQApplication import e4App
 
-from SvnDiffDialog import SvnDiffDialog
-
 from Ui_SvnStatusDialog import Ui_SvnStatusDialog
 
 import Preferences
@@ -36,16 +34,11 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         QWidget.__init__(self, parent)
         self.setupUi(self)
         
-        self.__toBeCommittedColumn = 0
-        self.__changelistColumn = 1
-        self.__statusColumn = 2
-        self.__propStatusColumn = 3
-        self.__lockedColumn = 4
-        self.__historyColumn = 5
-        self.__switchedColumn = 6
-        self.__lockinfoColumn = 7
-        self.__upToDateColumn = 8
-        self.__pathColumn = 12
+        self.__changelistColumn = 0
+        self.__statusColumn = 1
+        self.__propStatusColumn = 2
+        self.__lockinfoColumn = 6
+        self.__pathColumn = 11
         self.__lastColumn = self.statusList.columnCount()
         
         self.refreshButton = \
@@ -55,7 +48,6 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         
-        self.diff = None
         self.process = None
         self.vcs = vcs
         self.connect(self.vcs, SIGNAL("committed()"), self.__committed)
@@ -72,12 +64,8 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         self.menu.addSeparator()
         self.menuactions.append(self.menu.addAction(\
             self.trUtf8("Add to repository"), self.__add))
-        self.menuactions.append(self.menu.addAction(\
-            self.trUtf8("Show differences"), self.__diff))
         self.menuactions.append(self.menu.addAction(\
             self.trUtf8("Revert changes"), self.__revert))
-        self.menuactions.append(self.menu.addAction(\
-            self.trUtf8("Restore missing"), self.__restoreMissing))
         if self.vcs.versionStr >= '1.5.0':
             self.menu.addSeparator()
             self.menuactions.append(self.menu.addAction(
@@ -116,9 +104,6 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         self.lockedIndicators = QStringList()
         self.lockedIndicators.append(self.trUtf8('locked'))
         
-        self.missingIndicators = QStringList()
-        self.missingIndicators.append(self.trUtf8('missing'))
-        
         self.stealBreakLockIndicators = QStringList()
         self.stealBreakLockIndicators.append(self.trUtf8('other lock'))
         self.stealBreakLockIndicators.append(self.trUtf8('stolen lock'))
@@ -170,10 +155,10 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         }
         
         self.rx_status = \
-            QRegExp('(.{8,9})\\s+([0-9-]+)\\s+([0-9?]+)\\s+([\\w?]+)\\s+(.+)\\s*')
+            QRegExp('(.{8})\\s+([0-9-]+)\\s+([0-9?]+)\\s+([\\w?]+)\\s+(.+)\\s*')
             # flags (8 anything), revision, changed rev, author, path
         self.rx_status2 = \
-            QRegExp('(.{8,9})\\s+(.+)\\s*')
+            QRegExp('(.{8})\\s+(.+)\\s*')
             # flags (8 anything), path
         self.rx_changelist = \
             QRegExp('--- \\S+ .([\\w\\s]+).:\\s+')
@@ -223,63 +208,34 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
            self.currentChangelist == "":
             return
         
-        if revision == "":
-            rev = ""
-        else:
-            try:
-                rev = int(revision)
-            except ValueError:
-                rev = revision
-        if change == "":
-            chg = ""
-        else:
-            try:
-                chg = int(change)
-            except ValueError:
-                chg = change
-        statusText = self.status[status]
+        itm = QTreeWidgetItem(self.statusList, 
+            QStringList() \
+            << self.currentChangelist \
+            << self.status[status] \
+            << self.propStatus[propStatus] \
+            << self.locked[locked] \
+            << self.history[history] \
+            << self.switched[switched] \
+            << self.lockinfo[lockinfo] \
+            << self.uptodate[uptodate] \
+            << "%7s" % str(revision) \
+            << "%7s" % str(change) \
+            << author \
+            << path
+        )
         
-        itm = QTreeWidgetItem(self.statusList)
-        itm.setData(0, Qt.DisplayRole, "")
-        itm.setData(1, Qt.DisplayRole, self.currentChangelist)
-        itm.setData(2, Qt.DisplayRole, statusText)
-        itm.setData(3, Qt.DisplayRole, self.propStatus[propStatus])
-        itm.setData(4, Qt.DisplayRole, self.locked[locked])
-        itm.setData(5, Qt.DisplayRole, self.history[history])
-        itm.setData(6, Qt.DisplayRole, self.switched[switched])
-        itm.setData(7, Qt.DisplayRole, self.lockinfo[lockinfo])
-        itm.setData(8, Qt.DisplayRole, self.uptodate[uptodate])
-        itm.setData(9, Qt.DisplayRole, rev)
-        itm.setData(10, Qt.DisplayRole, chg)
-        itm.setData(11, Qt.DisplayRole, author)
-        itm.setData(12, Qt.DisplayRole, path)
-        
-        itm.setTextAlignment(1, Qt.AlignLeft)
+        itm.setTextAlignment(0, Qt.AlignLeft)
+        itm.setTextAlignment(1, Qt.AlignHCenter)
         itm.setTextAlignment(2, Qt.AlignHCenter)
         itm.setTextAlignment(3, Qt.AlignHCenter)
         itm.setTextAlignment(4, Qt.AlignHCenter)
         itm.setTextAlignment(5, Qt.AlignHCenter)
         itm.setTextAlignment(6, Qt.AlignHCenter)
         itm.setTextAlignment(7, Qt.AlignHCenter)
-        itm.setTextAlignment(8, Qt.AlignHCenter)
+        itm.setTextAlignment(8, Qt.AlignRight)
         itm.setTextAlignment(9, Qt.AlignRight)
-        itm.setTextAlignment(10, Qt.AlignRight)
+        itm.setTextAlignment(10, Qt.AlignLeft)
         itm.setTextAlignment(11, Qt.AlignLeft)
-        itm.setTextAlignment(12, Qt.AlignLeft)
-        
-        if status in "ADM" or propStatus in "M":
-            itm.setCheckState(self.__toBeCommittedColumn, Qt.Checked)
-        
-        self.hidePropertyStatusColumn = self.hidePropertyStatusColumn and \
-            propStatus == " "
-        self.hideLockColumns = self.hideLockColumns and \
-            locked == " " and lockinfo == " "
-        self.hideUpToDateColumn = self.hideUpToDateColumn and uptodate == " "
-        self.hideHistoryColumn = self.hideHistoryColumn and history == " "
-        self.hideSwitchedColumn = self.hideSwitchedColumn and switched == " "
-        
-        if statusText not in self.__statusFilters:
-            self.__statusFilters.append(statusText)
         
     def closeEvent(self, e):
         """
@@ -305,28 +261,9 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         self.errorGroup.hide()
         self.intercept = False
         self.args = fn
-        
-        for act in self.menuactions:
-            act.setEnabled(False)
-        
-        self.addButton.setEnabled(False)
-        self.commitButton.setEnabled(False)
-        self.diffButton.setEnabled(False)
-        self.revertButton.setEnabled(False)
-        self.restoreButton.setEnabled(False)
-        
-        self.statusFilterCombo.clear()
-        self.__statusFilters = []
-        
         self.currentChangelist = ""
         self.changelistFound = False
         
-        self.hidePropertyStatusColumn = True
-        self.hideLockColumns = True
-        self.hideUpToDateColumn = True
-        self.hideHistoryColumn = True
-        self.hideSwitchedColumn = True
-        
         if self.process:
             self.process.kill()
         else:
@@ -367,7 +304,6 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         procStarted = self.process.waitForStarted()
         if not procStarted:
             self.inputGroup.setEnabled(False)
-            self.inputGroup.hide()
             KQMessageBox.critical(None,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
@@ -376,7 +312,6 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
                 ).arg('svn'))
         else:
             self.inputGroup.setEnabled(True)
-            self.inputGroup.show()
         
     def __finish(self):
         """
@@ -391,41 +326,19 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
-        self.buttonBox.button(QDialogButtonBox.Close).setFocus(Qt.OtherFocusReason)
         
         self.inputGroup.setEnabled(False)
-        self.inputGroup.hide()
         self.refreshButton.setEnabled(True)
         
-        self.__statusFilters.sort()
-        self.__statusFilters.insert(0, "<%s>" % self.trUtf8("all"))
-        self.statusFilterCombo.addItems(self.__statusFilters)
-        
         for act in self.menuactions:
             act.setEnabled(True)
         
         self.process = None
         
+        self.statusList.doItemsLayout()
         self.__resort()
         self.__resizeColumns()
-        
-        self.statusList.setColumnHidden(self.__propStatusColumn, 
-                                        self.hidePropertyStatusColumn)
-        self.statusList.setColumnHidden(self.__lockedColumn, 
-                                        self.hideLockColumns)
-        self.statusList.setColumnHidden(self.__lockinfoColumn, 
-                                        self.hideLockColumns)
-        self.statusList.setColumnHidden(self.__upToDateColumn, 
-                                        self.hideUpToDateColumn)
-        self.statusList.setColumnHidden(self.__historyColumn, 
-                                        self.hideHistoryColumn)
-        self.statusList.setColumnHidden(self.__switchedColumn, 
-                                        self.hideSwitchedColumn)
-        self.statusList.setColumnHidden(self.__changelistColumn,
-                                        not self.changelistFound)
-        
-        self.__updateButtons()
-        self.__updateCommitButton()
+        self.statusList.setColumnHidden(self.__changelistColumn, not self.changelistFound)
         
     def on_buttonBox_clicked(self, button):
         """
@@ -469,13 +382,13 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
                     path = self.rx_status.cap(5).trimmed()
                     
                     self.__generateItem(flags[0], flags[1], flags[2], flags[3], flags[4], 
-                                        flags[5], flags[-1], rev, change, author, path)
+                                        flags[5], flags[7], rev, change, author, path)
                 elif self.rx_status2.exactMatch(s):
                     flags = str(self.rx_status2.cap(1))
                     path = self.rx_status2.cap(2).trimmed()
                     
                     self.__generateItem(flags[0], flags[1], flags[2], flags[3], flags[4], 
-                                        flags[5], flags[-1], "", "", "", path)
+                                        flags[5], flags[7], "", "", "", path)
                 elif self.rx_changelist.exactMatch(s):
                     self.currentChangelist = self.rx_changelist.cap(1)
                     self.changelistFound = True
@@ -553,102 +466,15 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         
         self.inputGroup.setEnabled(True)
-        self.inputGroup.show()
         self.refreshButton.setEnabled(False)
         
+        for act in self.menuactions:
+            act.setEnabled(False)
+        
         self.statusList.clear()
         
         self.start(self.args)
     
-    @pyqtSignature("")
-    def on_statusList_itemSelectionChanged(self):
-        """
-        Private slot to act upon changes of selected items.
-        """
-        self.__updateButtons()
-    
-    @pyqtSignature("QTreeWidgetItem*, int")
-    def on_statusList_itemChanged(self, item, column):
-        """
-        Private slot to act upon item changes.
-        
-        @param item reference to the changed item (QTreeWidgetItem)
-        @param column index of column that changed (integer)
-        """
-        if column == self.__toBeCommittedColumn:
-            self.__updateCommitButton()
-
-    def __updateButtons(self):
-        """
-        Private method to update the VCS buttons status.
-        """
-        modified = len(self.__getModifiedItems())
-        unversioned = len(self.__getUnversionedItems())
-        missing = len(self.__getMissingItems())
-
-        self.addButton.setEnabled(unversioned)
-        self.diffButton.setEnabled(modified)
-        self.revertButton.setEnabled(modified)
-        self.restoreButton.setEnabled(missing)
-    
-    def __updateCommitButton(self):
-        """
-        Private method to update the Commit button status.
-        """
-        commitable = len(self.__getCommitableItems())
-        self.commitButton.setEnabled(commitable)
-    
-    @pyqtSignature("")
-    def on_commitButton_clicked(self):
-        """
-        Private slot to handle the press of the Commit button.
-        """
-        self.__commit()
-    
-    @pyqtSignature("")
-    def on_addButton_clicked(self):
-        """
-        Private slot to handle the press of the Add button.
-        """
-        self.__add()
-    
-    @pyqtSignature("")
-    def on_diffButton_clicked(self):
-        """
-        Private slot to handle the press of the Differences button.
-        """
-        self.__diff()
-    
-    @pyqtSignature("")
-    def on_revertButton_clicked(self):
-        """
-        Private slot to handle the press of the Revert button.
-        """
-        self.__revert()
-    
-    @pyqtSignature("")
-    def on_restoreButton_clicked(self):
-        """
-        Private slot to handle the press of the Restore button.
-        """
-        self.__restoreMissing()
-    
-    @pyqtSignature("QString")
-    def on_statusFilterCombo_activated(self, txt):
-        """
-        Private slot to react to the selection of a status filter.
-        
-        @param txt selected status filter (QString)
-        """
-        if txt == "<%s>" % self.trUtf8("all"):
-            for topIndex in range(self.statusList.topLevelItemCount()):
-                topItem = self.statusList.topLevelItem(topIndex)
-                topItem.setHidden(False)
-        else:
-            for topIndex in range(self.statusList.topLevelItemCount()):
-                topItem = self.statusList.topLevelItem(topIndex)
-                topItem.setHidden(topItem.text(self.__statusColumn) != txt)
-    
     ############################################################################
     ## Context menu handling methods
     ############################################################################
@@ -666,11 +492,11 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         Private slot to handle the Commit context menu entry.
         """
         names = [os.path.join(self.dname, unicode(itm.text(self.__pathColumn))) \
-                 for itm in self.__getCommitableItems()]
+                 for itm in self.__getModifiedItems()]
         if not names:
             KQMessageBox.information(self,
                 self.trUtf8("Commit"),
-                self.trUtf8("""There are no items selected to be committed."""))
+                self.trUtf8("""There are no uncommitted changes available/selected."""))
             return
         
         if Preferences.getVCS("AutoSaveFiles"):
@@ -719,45 +545,9 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
             return
         
         self.vcs.vcsRevert(names)
-        self.raise_()
-        self.activateWindow()
         self.on_refreshButton_clicked()
         self.vcs.checkVCSStatus()
         
-    def __restoreMissing(self):
-        """
-        Private slot to handle the Restore Missing context menu entry.
-        """
-        names = [os.path.join(self.dname, unicode(itm.text(self.__pathColumn))) \
-                 for itm in self.__getMissingItems()]
-        if not names:
-            KQMessageBox.information(self,
-                self.trUtf8("Revert"),
-                self.trUtf8("""There are no missing items available/selected."""))
-            return
-        
-        self.vcs.vcsRevert(names)
-        self.on_refreshButton_clicked()
-        self.vcs.checkVCSStatus()
-        
-    def __diff(self):
-        """
-        Private slot to handle the Diff context menu entry.
-        """
-        names = [os.path.join(self.dname, unicode(itm.text(self.__pathColumn))) \
-                 for itm in self.__getModifiedItems()]
-        if not names:
-            KQMessageBox.information(self,
-                self.trUtf8("Differences"),
-                self.trUtf8("""There are no uncommitted changes available/selected."""))
-            return
-        
-        if self.diff is None:
-            self.diff = SvnDiffDialog(self.vcs)
-        self.diff.show()
-        QApplication.processEvents()
-        self.diff.start(names)
-        
     def __lock(self):
         """
         Private slot to handle the Lock context menu entry.
@@ -852,20 +642,7 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
             return
         self.vcs.svnRemoveFromChangelist(names)
         self.on_refreshButton_clicked()
-    
-    def __getCommitableItems(self):
-        """
-        Private method to retrieve all entries the user wants to commit.
-        
-        @return list of all items, the user has checked
-        """
-        commitableItems = []
-        for index in range(self.statusList.topLevelItemCount()):
-            itm = self.statusList.topLevelItem(index)
-            if itm.checkState(self.__toBeCommittedColumn) == Qt.Checked:
-                commitableItems.append(itm)
-        return commitableItems
-    
+
     def __getModifiedItems(self):
         """
         Private method to retrieve all entries, that have a modified status.
@@ -891,18 +668,6 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
                 unversionedItems.append(itm)
         return unversionedItems
         
-    def __getMissingItems(self):
-        """
-        Private method to retrieve all entries, that have a missing status.
-        
-        @return list of all items with a missing status
-        """
-        missingItems = []
-        for itm in self.statusList.selectedItems():
-            if self.missingIndicators.contains(itm.text(self.__statusColumn)):
-                missingItems.append(itm)
-        return missingItems
-        
     def __getLockActionItems(self, indicators):
         """
         Private method to retrieve all emtries, that have a locked status.
