@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -31,9 +31,9 @@ class SvnStatusMonitorThread(VcsStatusMonitorThread):
         self.__ioEncoding = str(Preferences.getSystem("IOEncoding"))
         
         self.rx_status1 = \
-            QRegExp('(.{8,9})\\s+([0-9-]+)\\s+(.+)\\s*')
+            QRegExp('(.{8})\\s+([0-9-]+)\\s+(.+)\\s*')
         self.rx_status2 = \
-            QRegExp('(.{8,9})\\s+([0-9-]+)\\s+([0-9?]+)\\s+([\\w?]+)\\s+(.+)\\s*')
+            QRegExp('(.{8})\\s+([0-9-]+)\\s+([0-9?]+)\\s+([\\w?]+)\\s+(.+)\\s*')
     
     def _performMonitor(self):
         """
@@ -46,7 +46,6 @@ class SvnStatusMonitorThread(VcsStatusMonitorThread):
         <ul>
             <li>"A" path was added but not yet comitted</li>
             <li>"M" path has local changes</li>
-            <li>"O" path was removed</li>
             <li>"R" path was deleted and then re-added</li>
             <li>"U" path needs an update</li>
             <li>"Z" path contains a conflict</li>
@@ -83,16 +82,14 @@ class SvnStatusMonitorThread(VcsStatusMonitorThread):
                         path = self.rx_status2.cap(5).trimmed()
                     else:
                         continue
-                    if flags[0] in "ACDMR" or \
-                       (flags[0] == " " and flags[-1] == "*"):
-                        if flags[-1] == "*":
+                    if flags[0] in "ACMR" or \
+                       (flags[0] == " " and flags[7] == "*"):
+                        if flags[7] == "*":
                             status = "U"
                         else:
                             status = flags[0]
                         if status == "C":
                             status = "Z"    # give it highest priority
-                        elif status == "D":
-                            status = "O"
                         if status == "U":
                             self.shouldUpdate = True
                         name = unicode(path)
