@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -41,9 +41,7 @@ from SvnBlameDialog import SvnBlameDialog
 from SvnRelocateDialog import SvnRelocateDialog
 from SvnUrlSelectionDialog import SvnUrlSelectionDialog
 from SvnRepoBrowserDialog import SvnRepoBrowserDialog
-from .SvnChangeListsDialog import SvnChangeListsDialog
 from SvnStatusMonitorThread import SvnStatusMonitorThread
-from SvnUtilities import getConfigPath, amendConfig, createDefaultConfig
 
 from ProjectBrowserHelper import SvnProjectBrowserHelper
 from ProjectHelper import SvnProjectHelper
@@ -124,8 +122,6 @@ class Subversion(VersionControl):
         self.__commitData = {}
         self.__commitDialog = None
         
-        self.__wcng = True      # assume new generation working copy metadata format
-        
     def getPlugin(self):
         """
         Public method to get a reference to the plugin object.
@@ -457,7 +453,7 @@ class Subversion(VersionControl):
             if self.__commitDialog.hasChangelists():
                 changelists, keepChangelists = self.__commitDialog.changelistsData()
             else:
-                changelists, keepChangelists = [], False
+                changelists, keepChangelists = QStringList(), False
             self.disconnect(self.__commitDialog, SIGNAL("accepted()"), 
                             self.__vcsCommit_Step2)
             self.__commitDialog = None
@@ -527,7 +523,7 @@ class Subversion(VersionControl):
             res = False
         else:
             dia = SvnDialog(self.trUtf8('Synchronizing with the Subversion repository'))
-            res = dia.startProcess(args, dname, True)
+            res = dia.startProcess(args, dname)
             if res:
                 dia.exec_()
                 res = dia.hasAddOrDelete()
@@ -562,49 +558,22 @@ class Subversion(VersionControl):
                 dname, fname = self.splitPath(name)
         tree = []
         wdir = dname
-        if self.__wcng:
-            repodir = dname
-            while not os.path.isdir(os.path.join(repodir, self.adminDir)):
-                repodir = os.path.dirname(repodir)
-                if os.path.splitdrive(repodir)[1] == os.sep:
-                    return  # oops, project is not version controlled
-            while os.path.normcase(dname) != os.path.normcase(repodir) and \
-                  (os.path.normcase(dname) not in self.statusCache or \
-                   self.statusCache[os.path.normcase(dname)] == self.canBeAdded):
-                # add directories recursively, if they aren't in the repository already
-                tree.insert(-1, dname)
-                dname = os.path.dirname(dname)
-                wdir = dname
-        else:
-            while not os.path.exists(os.path.join(dname, self.adminDir)):
-                # add directories recursively, if they aren't in the repository already
-                tree.insert(-1, dname)
-                dname = os.path.dirname(dname)
-                wdir = dname
+        while not os.path.exists(os.path.join(dname, self.adminDir)):
+            # add directories recursively, if they aren't in the repository already
+            tree.insert(-1, dname)
+            dname = os.path.split(dname)[0]
+            wdir = dname
         self.addArguments(args, tree)
         
         if type(name) is types.ListType:
             tree2 = []
             for n in name:
-                d = os.path.dirname(n)
-                if self.__wcng:
-                    repodir = d
-                    while not os.path.isdir(os.path.join(repodir, self.adminDir)):
-                        repodir = os.path.dirname(repodir)
-                        if os.path.splitdrive(repodir)[1] == os.sep:
-                            return  # oops, project is not version controlled
-                    while os.path.normcase(d) != os.path.normcase(repodir) and \
-                          (d not in tree2 + tree) and \
-                          (os.path.normcase(d) not in self.statusCache or \
-                           self.statusCache[os.path.normcase(d)] == self.canBeAdded):
-                        tree2.append(d)
-                        d = os.path.dirname(d)
-                else:
-                    while not os.path.exists(os.path.join(d, self.adminDir)):
-                        if d in tree2 + tree:
-                            break
-                        tree2.append(d)
-                        d = os.path.dirname(d)
+                d = os.path.split(n)[0]
+                while not os.path.exists(os.path.join(d, self.adminDir)):
+                    if d in tree2 + tree:
+                        break
+                    tree2.append(d)
+                    d = os.path.split(d)[0]
             tree2.reverse()
             self.addArguments(args, tree2)
             self.addArguments(args, name)
@@ -645,48 +614,22 @@ class Subversion(VersionControl):
         if type(path) is types.ListType:
             dname, fnames = self.splitPathList(path)
             for n in path:
-                d = os.path.dirname(n)
-                if self.__wcng:
-                    repodir = d
-                    while not os.path.isdir(os.path.join(repodir, self.adminDir)):
-                        repodir = os.path.dirname(repodir)
-                        if os.path.splitdrive(repodir)[1] == os.sep:
-                            return  # oops, project is not version controlled
-                    while os.path.normcase(d) != os.path.normcase(repodir) and \
-                          (d not in tree) and \
-                          (os.path.normcase(d) not in self.statusCache or \
-                           self.statusCache[os.path.normcase(d)] == self.canBeAdded):
-                        tree.append(d)
-                        d = os.path.dirname(d)
-                else:
-                    while not os.path.exists(os.path.join(d, self.adminDir)):
-                        # add directories recursively, 
-                        # if they aren't in the repository already
-                        if d in tree:
-                            break
-                        tree.append(d)
-                        d = os.path.dirname(d)
+                d = os.path.split(n)[0]
+                while not os.path.exists(os.path.join(d, self.adminDir)):
+                    # add directories recursively, 
+                    # if they aren't in the repository already
+                    if d in tree:
+                        break
+                    tree.append(d)
+                    d = os.path.split(d)[0]
             tree.reverse()
         else:
             dname, fname = os.path.split(unicode(path))
-            if self.__wcng:
-                repodir = dname
-                while not os.path.isdir(os.path.join(repodir, self.adminDir)):
-                    repodir = os.path.dirname(repodir)
-                    if os.path.splitdrive(repodir)[1] == os.sep:
-                        return  # oops, project is not version controlled
-                while os.path.normcase(dname) != os.path.normcase(repodir) and \
-                      (os.path.normcase(dname) not in self.statusCache or \
-                       self.statusCache[os.path.normcase(dname)] == self.canBeAdded):
-                    # add directories recursively, if they aren't in the repository already
-                    tree.insert(-1, dname)
-                    dname = os.path.dirname(dname)
-            else:
-                while not os.path.exists(os.path.join(dname, self.adminDir)):
-                    # add directories recursively,
-                    # if they aren't in the repository already
-                    tree.insert(-1, dname)
-                    dname = os.path.dirname(dname)
+            while not os.path.exists(os.path.join(dname, self.adminDir)):
+                # add directories recursively,
+                # if they aren't in the repository already
+                tree.insert(-1, dname)
+                dname = os.path.split(dname)[0]
         if tree:
             self.vcsAdd(tree, True)
         
@@ -941,8 +884,6 @@ class Subversion(VersionControl):
         args.append('revert')
         self.addArguments(args, self.options['global'])
         if type(name) is types.ListType:
-            if len(name) == 1 and os.path.isdir(name[0]):
-                args.append('--recursive')
             self.addArguments(args, name)
         else:
             if os.path.isdir(name):
@@ -1083,51 +1024,6 @@ class Subversion(VersionControl):
         """
         Public method used to get the registered state of a file in the vcs.
         
-        @param name filename to check (string or QString)
-        @return a combination of canBeCommited and canBeAdded
-        """
-        if self.__wcng:
-            return self.__vcsRegisteredState_wcng(name)
-        else:
-            return self.__vcsRegisteredState_wc(name)
-        
-    def __vcsRegisteredState_wcng(self, name):
-        """
-        Private method used to get the registered state of a file in the vcs.
-        
-        This is the variant for subversion installations using the new working copy
-        meta-data format.
-        
-        @param name filename to check (string or QString)
-        @return a combination of canBeCommited and canBeAdded
-        """
-        name = unicode(name)
-        if name.endswith(os.sep):
-            name = name[:-1]
-        name = os.path.normcase(name)
-        dname, fname = self.splitPath(name)
-        
-        if fname == '.' and os.path.isdir(os.path.join(dname, self.adminDir)):
-            return self.canBeCommitted
-        
-        if name in self.statusCache:
-            return self.statusCache[name]
-        
-        name = os.path.normcase(unicode(name))
-        states = { name : 0 }
-        states = self.vcsAllRegisteredStates(states, dname, False)
-        if states[name] == self.canBeCommitted:
-            return self.canBeCommitted
-        else:
-            return self.canBeAdded
-        
-    def __vcsRegisteredState_wc(self, name):
-        """
-        Private method used to get the registered state of a file in the vcs.
-        
-        This is the variant for subversion installations using the old working copy
-        meta-data format.
-        
         @param name filename to check (string or QString)
         @return a combination of canBeCommited and canBeAdded
         """
@@ -1155,97 +1051,6 @@ class Subversion(VersionControl):
         directory has been scanned already. If so, it is assumed, that the states for
         all files has been populated by the previous run.
         
-        @param names dictionary with all filenames to be checked as keys
-        @param dname directory to check in (string)
-        @param shortcut flag indicating a shortcut should be taken (boolean)
-        @return the received dictionary completed with a combination of 
-            canBeCommited and canBeAdded or None in order to signal an error
-        """
-        if self.__wcng:
-            return self.__vcsAllRegisteredStates_wcng(names, dname, shortcut)
-        else:
-            return self.__vcsAllRegisteredStates_wc(names, dname, shortcut)
-        
-    def __vcsAllRegisteredStates_wcng(self, names, dname, shortcut = True):
-        """
-        Private method used to get the registered states of a number of files in the vcs.
-        
-        This is the variant for subversion installations using the new working copy
-        meta-data format.
-        
-        <b>Note:</b> If a shortcut is to be taken, the code will only check, if the named
-        directory has been scanned already. If so, it is assumed, that the states for
-        all files has been populated by the previous run.
-        
-        @param names dictionary with all filenames to be checked as keys
-        @param dname directory to check in (string)
-        @param shortcut flag indicating a shortcut should be taken (boolean)
-        @return the received dictionary completed with a combination of 
-            canBeCommited and canBeAdded or None in order to signal an error
-        """
-        dname = unicode(dname)
-        if dname.endswith(os.sep):
-            dname = dname[:-1]
-        dname = os.path.normcase(dname)
-        
-        found = False
-        for name in self.statusCache.keys():
-            if names.has_key(name):
-                found = True
-                names[name] = self.statusCache[name]
-        
-        if not found:
-            # find the root of the repo
-            repodir = dname
-            while not os.path.isdir(os.path.join(repodir, self.adminDir)):
-                repodir = os.path.dirname(repodir)
-                if os.path.splitdrive(repodir)[1] == os.sep:
-                    return names
-            
-            ioEncoding = str(Preferences.getSystem("IOEncoding"))
-            process = QProcess()
-            args = QStringList()
-            args.append('status')
-            args.append('--verbose')
-            args.append('--non-interactive')
-            args.append(dname)
-            process.start('svn', args)
-            procStarted = process.waitForStarted()
-            if procStarted:
-                finished = process.waitForFinished(30000)
-                if finished and process.exitCode() == 0:
-                    output = \
-                        unicode(process.readAllStandardOutput(), ioEncoding, 'replace')
-                    for line in output.splitlines():
-                        if self.rx_status1.exactMatch(line):
-                            flags = str(self.rx_status1.cap(1))
-                            path = self.rx_status1.cap(5).trimmed()
-                        elif self.rx_status2.exactMatch(line):
-                            flags = str(self.rx_status2.cap(1))
-                            path = self.rx_status2.cap(2).trimmed()
-                        else:
-                            continue
-                        name = os.path.normcase(unicode(path))
-                        if flags[0] not in "?I":
-                            if names.has_key(name):
-                                names[name] = self.canBeCommitted
-                            self.statusCache[name] = self.canBeCommitted
-                        else:
-                            self.statusCache[name] = self.canBeAdded
-        
-        return names
-        
-    def __vcsAllRegisteredStates_wc(self, names, dname, shortcut = True):
-        """
-        Private method used to get the registered states of a number of files in the vcs.
-        
-        This is the variant for subversion installations using the old working copy
-        meta-data format.
-        
-        <b>Note:</b> If a shortcut is to be taken, the code will only check, if the named
-        directory has been scanned already. If so, it is assumed, that the states for
-        all files has been populated by the previous run.
-        
         @param names dictionary with all filenames to be checked as keys
         @param dname directory to check in (string)
         @param shortcut flag indicating a shortcut should be taken (boolean)
@@ -1307,20 +1112,6 @@ class Subversion(VersionControl):
         """
         self.statusCache = {}
         
-    def vcsInitConfig(self, project):
-        """
-        Public method to initialize the VCS configuration.
-        
-        This method ensures, that eric specific files and directories are ignored.
-        
-        @param project reference to the project (Project)
-        """
-        configPath = getConfigPath()
-        if os.path.exists(configPath):
-            amendConfig()
-        else:
-            createDefaultConfig()
-    
     def vcsName(self):
         """
         Public method returning the name of the vcs.
@@ -1775,7 +1566,7 @@ class Subversion(VersionControl):
         
         @param name file/directory name to show the log of (string)
         """
-        noEntries, ok = KQInputDialog.getInt(\
+        noEntries, ok = KQInputDialog.getInteger(\
             None,
             self.trUtf8("Subversion Log"),
             self.trUtf8("Select number of entries to show."),
@@ -1895,7 +1686,7 @@ class Subversion(VersionControl):
         
     def svnRemoveFromChangelist(self, names):
         """
-        Public method to remove a file or directory from its changelist.
+        Public method to remove a file or directory from it's changelist.
         
         Note: Directories will be removed recursively.
         
@@ -1928,12 +1719,11 @@ class Subversion(VersionControl):
         @param names name or list of names of file or directory to add
             (string or QString)
         """
-        clname, ok = KQInputDialog.getItem(\
+        clname, ok = KQInputDialog.getText(\
             None,
             self.trUtf8("Add to changelist"),
             self.trUtf8("Enter name of the changelist:"),
-            sorted(self.svnGetChangelists()),
-            0, True)
+            QLineEdit.Normal)
         if not ok or clname.isEmpty():
             return
 
@@ -1953,55 +1743,6 @@ class Subversion(VersionControl):
         res = dia.startProcess(args, dname)
         if res:
             dia.exec_()
-        
-    def svnShowChangelists(self, path):
-        """
-        Public method used to inspect the change lists defined for the project.
-        
-        @param path directory name to show change lists for (string)
-        """
-        self.changeLists = SvnChangeListsDialog(self)
-        self.changeLists.show()
-        QApplication.processEvents()
-        self.changeLists.start(path)
-        
-    def svnGetChangelists(self):
-        """
-        Public method to get a list of all defined change lists.
-        
-        @return list of defined change list names (list of strings)
-        """
-        changelists = []
-        rx_changelist = \
-            QRegExp('--- \\S+ .([\\w\\s]+).:\\s*')
-            # three dashes, Changelist (translated), quote,
-            # changelist name, quote, :
-        
-        args = []
-        args.append("status")
-        args.append("--non-interactive")
-        args.append(".")
-        
-        ppath = e4App().getObject("Project").getProjectPath()
-        process = QProcess()
-        process.setWorkingDirectory(ppath)
-        process.start('svn', args)
-        procStarted = process.waitForStarted()
-        if procStarted:
-            finished = process.waitForFinished(30000)
-            if finished and process.exitCode() == 0:
-                output = \
-                    unicode(process.readAllStandardOutput(),
-                            Preferences.getSystem("IOEncoding"),
-                            'replace')
-                if output:
-                    for line in output.splitlines():
-                        if rx_changelist.exactMatch(line):
-                            changelist = unicode(rx_changelist.cap(1))
-                            if changelist not in changelists:
-                                changelists.append(changelist)
-        
-        return changelists
 
     ############################################################################
     ## Private Subversion specific methods are below.
@@ -2040,17 +1781,11 @@ class Subversion(VersionControl):
         @param url url string (string)
         @return properly normalized url for subversion
         """
-        protocol, url = url.split("://", 1)
-        if url.startswith("\\\\"):
-            url = url[2:]
-        if protocol == "file":
-            url = os.path.normcase(url)
         url = url.replace('\\', '/')
         if url.endswith('/'):
             url = url[:-1]
-        if not url.startswith("/") and url[1] in [":", "|"]:
-            url = "/%s" % url
-        return "%s://%s" % (protocol, url)
+        urll = url.split('//')
+        return "%s//%s" % (urll[0], '/'.join(urll[1:]))
 
     ############################################################################
     ## Methods to get the helper objects are below.
@@ -2077,9 +1812,6 @@ class Subversion(VersionControl):
         """
         helper = self.__plugin.getProjectHelper()
         helper.setObjects(self, project)
-        self.__wcng = \
-            os.path.exists(os.path.join(project.getProjectPath(), ".svn", "format")) or \
-            os.path.exists(os.path.join(project.getProjectPath(), "_svn", "format"))
         return helper
 
     ############################################################################
