@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -14,8 +14,6 @@ from PyQt4.QtGui import *
 
 from KdeQt.KQApplication import e4App
 
-import Globals
-
 from E4Gui.E4Completers import E4FileCompleter, E4DirCompleter
 
 from Ui_FileDialogWizardDialog import Ui_FileDialogWizardDialog
@@ -72,8 +70,6 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 options = QFileDialog.Options(QFileDialog.DontResolveSymlinks)
             else:
                 options = QFileDialog.Options()
-            if Globals.isLinuxPlatform():
-                options |= QFileDialog.DontUseNativeDialog
             QFileDialog.getOpenFileName(\
                 None,
                 self.eCaption.text(),
@@ -86,8 +82,6 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 options = QFileDialog.Options(QFileDialog.DontResolveSymlinks)
             else:
                 options = QFileDialog.Options()
-            if Globals.isLinuxPlatform():
-                options |= QFileDialog.DontUseNativeDialog
             QFileDialog.getOpenFileNames(\
                 None,
                 self.eCaption.text(),
@@ -100,8 +94,6 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 options = QFileDialog.Options(QFileDialog.DontResolveSymlinks)
             else:
                 options = QFileDialog.Options()
-            if Globals.isLinuxPlatform():
-                options |= QFileDialog.DontUseNativeDialog
             QFileDialog.getSaveFileName(\
                 None,
                 self.eCaption.text(),
@@ -117,8 +109,6 @@ class FileDialogWizardDialog(QDialog, Ui_FileDialogWizardDialog):
                 options |= QFileDialog.Options(QFileDialog.ShowDirsOnly)
             else:
                 options |= QFileDialog.Options(QFileDialog.Option(0))
-            if Globals.isLinuxPlatform():
-                options |= QFileDialog.DontUseNativeDialog
             QFileDialog.getExistingDirectory(\
                 None,
                 self.eCaption.text(),
