@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -80,7 +80,7 @@ class InputDialogWizardDialog(QDialog, Ui_InputDialogWizardDialog):
                 echomode,
                 self.eTextDefault.text())
         elif self.rInteger.isChecked():
-            QInputDialog.getInt(\
+            QInputDialog.getInteger(\
                 None,
                 self.eCaption.text(),
                 self.eLabel.text(),
@@ -142,7 +142,7 @@ class InputDialogWizardDialog(QDialog, Ui_InputDialogWizardDialog):
                     (os.linesep, istring, unicode(self.eTextDefault.text()))
             code += ')%s' % os.linesep
         elif self.rInteger.isChecked():
-            code += 'getInt(\\%s%s' % (os.linesep, istring)
+            code += 'getInteger(\\%s%s' % (os.linesep, istring)
             code += 'None,%s%s' % (os.linesep, istring)
             code += 'self.trUtf8("%s"),%s%s' % \
                 (unicode(self.eCaption.text()), os.linesep, istring)
