@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -336,7 +336,7 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                 KQMessageBox.information(self,
                     self.trUtf8("Save regular expression"),
                     self.trUtf8("""<p>The regular expression could not be saved.</p>"""
-                                """<p>Reason: %1</p>""").arg(str(err)))
+                                """<p>Reason: %1</p>""").arg(unicode(err)))
     
     @pyqtSignature("")
     def on_loadButton_clicked(self):
@@ -359,7 +359,7 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                 KQMessageBox.information(self,
                     self.trUtf8("Save regular expression"),
                     self.trUtf8("""<p>The regular expression could not be saved.</p>"""
-                                """<p>Reason: %1</p>""").arg(str(err)))
+                                """<p>Reason: %1</p>""").arg(unicode(err)))
 
     @pyqtSignature("")
     def on_copyButton_clicked(self):
@@ -384,24 +384,21 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         regex = self.regexpTextEdit.toPlainText()
         if not regex.isEmpty():
             try:
-                flags = 0
-                if not self.caseSensitiveCheckBox.isChecked():
-                    flags |= re.IGNORECASE
-                if self.multilineCheckBox.isChecked():
-                    flags |= re.MULTILINE
-                if self.dotallCheckBox.isChecked():
-                    flags |= re.DOTALL
-                if self.verboseCheckBox.isChecked():
-                    flags |= re.VERBOSE
                 if self.py2Button.isChecked():
-                    if self.localeCheckBox.isChecked():
-                        flags |= re.LOCALE
-                    if self.unicodeCheckBox.isChecked():
-                        flags |= re.UNICODE
+                    regobj = re.compile(unicode(regex),
+                        (not self.caseSensitiveCheckBox.isChecked() and re.IGNORECASE or 0) | \
+                        self.multilineCheckBox.isChecked() and re.MULTILINE or 0 | \
+                        self.dotallCheckBox.isChecked() and re.DOTALL or 0 | \
+                        self.verboseCheckBox.isChecked() and re.VERBOSE or 0 | \
+                        self.localeCheckBox.isChecked() and re.LOCALE or 0 | \
+                        self.unicodeCheckBox.isChecked() and re.UNICODE or 0)
                 else:
-                    if self.unicodeCheckBox.isChecked():
-                        flags |= re.ASCII
-                re.compile(regex, flags)
+                    regobj = re.compile(unicode(regex),
+                        (not self.caseSensitiveCheckBox.isChecked() and re.IGNORECASE or 0) | \
+                        self.multilineCheckBox.isChecked() and re.MULTILINE or 0 | \
+                        self.dotallCheckBox.isChecked() and re.DOTALL or 0 | \
+                        self.verboseCheckBox.isChecked() and re.VERBOSE or 0 | \
+                        (not self.unicodeCheckBox.isChecked() and re.UNICODE or 0))
                 KQMessageBox.information(None,
                     self.trUtf8(""),
                     self.trUtf8("""The regular expression is valid."""))
@@ -409,7 +406,7 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                 KQMessageBox.critical(None,
                     self.trUtf8("Error"),
                     self.trUtf8("""Invalid regular expression: %1""")
-                        .arg(str(e)))
+                        .arg(unicode(e)))
                 return
             except IndexError:
                 KQMessageBox.critical(None,
@@ -435,24 +432,21 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
         text = self.textTextEdit.toPlainText()
         if not regex.isEmpty() and not text.isEmpty():
             try:
-                flags = 0
-                if not self.caseSensitiveCheckBox.isChecked():
-                    flags |= re.IGNORECASE
-                if self.multilineCheckBox.isChecked():
-                    flags |= re.MULTILINE
-                if self.dotallCheckBox.isChecked():
-                    flags |= re.DOTALL
-                if self.verboseCheckBox.isChecked():
-                    flags |= re.VERBOSE
                 if self.py2Button.isChecked():
-                    if self.localeCheckBox.isChecked():
-                        flags |= re.LOCALE
-                    if self.unicodeCheckBox.isChecked():
-                        flags |= re.UNICODE
+                    regobj = re.compile(unicode(regex),
+                        (not self.caseSensitiveCheckBox.isChecked() and re.IGNORECASE or 0) | \
+                        self.multilineCheckBox.isChecked() and re.MULTILINE or 0 | \
+                        self.dotallCheckBox.isChecked() and re.DOTALL or 0 | \
+                        self.verboseCheckBox.isChecked() and re.VERBOSE or 0 | \
+                        self.localeCheckBox.isChecked() and re.LOCALE or 0 | \
+                        self.unicodeCheckBox.isChecked() and re.UNICODE or 0)
                 else:
-                    if self.unicodeCheckBox.isChecked():
-                        flags |= re.ASCII
-                regobj = re.compile(regex, flags)
+                    regobj = re.compile(unicode(regex),
+                        (not self.caseSensitiveCheckBox.isChecked() and re.IGNORECASE or 0) | \
+                        self.multilineCheckBox.isChecked() and re.MULTILINE or 0 | \
+                        self.dotallCheckBox.isChecked() and re.DOTALL or 0 | \
+                        self.verboseCheckBox.isChecked() and re.VERBOSE or 0 | \
+                        (not self.unicodeCheckBox.isChecked() and re.UNICODE or 0))
                 matchobj = regobj.search(unicode(text), startpos)
                 if matchobj is not None:
                     captures = len(matchobj.groups())
@@ -539,7 +533,7 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                 KQMessageBox.critical(None,
                     self.trUtf8("Error"),
                     self.trUtf8("""Invalid regular expression: %1""")
-                        .arg(str(e)))
+                        .arg(unicode(e)))
                 return
             except IndexError:
                 KQMessageBox.critical(None,
