@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -249,7 +249,7 @@ class QRegExpWizardWidget(QWidget, Ui_QRegExpWizardDialog):
                 KQMessageBox.information(self,
                     self.trUtf8("Save regular expression"),
                     self.trUtf8("""<p>The regular expression could not be saved.</p>"""
-                                """<p>Reason: %1</p>""").arg(str(err)))
+                                """<p>Reason: %1</p>""").arg(unicode(err)))
     
     @pyqtSignature("")
     def on_loadButton_clicked(self):
@@ -272,7 +272,7 @@ class QRegExpWizardWidget(QWidget, Ui_QRegExpWizardDialog):
                 KQMessageBox.information(self,
                     self.trUtf8("Save regular expression"),
                     self.trUtf8("""<p>The regular expression could not be saved.</p>"""
-                                """<p>Reason: %1</p>""").arg(str(err)))
+                                """<p>Reason: %1</p>""").arg(unicode(err)))
 
     @pyqtSignature("")
     def on_copyButton_clicked(self):
@@ -352,7 +352,7 @@ class QRegExpWizardWidget(QWidget, Ui_QRegExpWizardDialog):
                         .arg(re.errorString()))
                 return
             offset = re.indexIn(text, startpos)
-            captures = re.captureCount()
+            captures = re.numCaptures()
             row = 0
             OFFSET = 5
             
