@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -17,10 +17,6 @@ from KdeQt import KQMessageBox
 from KdeQt.KQMainWindow import KQMainWindow
 from KdeQt.KQApplication import e4App
 
-from E4Gui.E4LineEdit import E4LineEdit
-
-from Globals import isMacPlatform
-
 import QScintilla.Lexers
 
 import Preferences
@@ -61,32 +57,20 @@ class ConfigurationWidget(QWidget):
     Class implementing a dialog for the configuration of eric4.
     
     @signal preferencesChanged emitted after settings have been changed
-    @signal accepted() emitted to indicate acceptance of the changes
-    @signal rejected() emitted to indicate rejection of the changes
     """
-    DefaultMode     = 0
-    HelpBrowserMode = 1
-    TrayStarterMode = 2
-    
-    def __init__(self, parent = None, fromEric = True, displayMode = DefaultMode):
+    def __init__(self, parent = None, fromEric = True, helpBrowserMode = False):
         """
         Constructor
         
         @param parent The parent widget of this dialog. (QWidget)
         @keyparam fromEric flag indicating a dialog generation from within the 
             eric4 ide (boolean)
-        @keyparam displayMode mode of the configuration dialog 
-            (DefaultMode, HelpBrowserMode, TrayStarterMode)
+        @keyparam helpBrowserMode flag indicating to show only help pages
+            for entries related to the help browser (boolean)
         """
-        assert displayMode in (
-            ConfigurationWidget.DefaultMode, 
-            ConfigurationWidget.HelpBrowserMode, 
-            ConfigurationWidget.TrayStarterMode
-        )
-        
         QWidget.__init__(self, parent)
         self.fromEric = fromEric
-        self.displayMode = displayMode
+        self.helpBrowserMode = helpBrowserMode
         
         self.__setupUi()
         
@@ -100,7 +84,7 @@ class ConfigurationWidget(QWidget):
                 self.pluginManager = PluginManager(self)
                 e4App().registerObject("PluginManager", self.pluginManager)
         
-        if displayMode == ConfigurationWidget.DefaultMode:
+        if not helpBrowserMode:
             self.configItems = {
                 # key : [display string, pixmap name, dialog module name or 
                 #        page creation function, parent key,
@@ -147,9 +131,9 @@ class ConfigurationWidget(QWidget):
                 "templatesPage" : \
                     [self.trUtf8("Templates"), "preferences-template.png",
                     "TemplatesPage", None, None],
-                "trayStarterPage" : \
-                    [self.trUtf8("Tray Starter"), "erict.png",
-                    "TrayStarterPage", None, None],
+                "terminalPage" : \
+                    [self.trUtf8("Terminal"), "terminal.png",
+                    "TerminalPage", None, None],
                 "vcsPage" : \
                     [self.trUtf8("Version Control Systems"), "preferences-vcs.png",
                     "VcsPage", None, None],
@@ -222,9 +206,6 @@ class ConfigurationWidget(QWidget):
                     [self.trUtf8("Styles"), 
                     "preferences-highlighting-styles.png",
                     "EditorHighlightingStylesPage", "1editorLexerPage", None],
-                "editorKeywordsPage" : \
-                    [self.trUtf8("Keywords"), "preferences-keywords.png", 
-                     "EditorKeywordsPage", "1editorLexerPage", None], 
                 "editorPropertiesPage" : \
                     [self.trUtf8("Properties"), "preferences-properties.png",
                     "EditorPropertiesPage", "1editorLexerPage", None],
@@ -243,7 +224,7 @@ class ConfigurationWidget(QWidget):
                     [self.trUtf8("Help Viewers"), "preferences-helpviewers.png",
                     "HelpViewersPage", "0helpPage", None],
                 "helpWebBrowserPage" : \
-                    [self.trUtf8("eric4 Web Browser"), "ericWeb.png",
+                    [self.trUtf8("Eric Web Browser"), "ericWeb.png",
                     "HelpWebBrowserPage", "0helpPage", None],
                 
                 "0projectPage" : \
@@ -272,7 +253,7 @@ class ConfigurationWidget(QWidget):
             
             self.configItems.update(
                 e4App().getObject("PluginManager").getPluginConfigData())
-        elif displayMode == ConfigurationWidget.HelpBrowserMode:
+        else:
             self.configItems = {
                 # key : [display string, pixmap name, dialog module name or 
                 #        page creation function, parent key,
@@ -283,9 +264,9 @@ class ConfigurationWidget(QWidget):
                 "networkPage" : \
                     [self.trUtf8("Network"), "preferences-network.png", 
                      "NetworkPage", None, None], 
-                "printerPage" : \
-                    [self.trUtf8("Printer"), "preferences-printer.png",
-                    "PrinterPage", None, None],
+                "pythonPage" : \
+                    [self.trUtf8("Python"), "preferences-python.png",
+                    "PythonPage", None, None],
                 
                 "0helpPage" : \
                     [self.trUtf8("Help"), "preferences-help.png",
@@ -297,24 +278,13 @@ class ConfigurationWidget(QWidget):
                     [self.trUtf8("Help Documentation"), 
                     "preferences-helpdocumentation.png",
                     "HelpDocumentationPage", "0helpPage", None],
+                "helpViewersPage" : \
+                    [self.trUtf8("Help Viewers"), "preferences-helpviewers.png",
+                    "HelpViewersPage", "0helpPage", None],
                 "helpWebBrowserPage" : \
-                    [self.trUtf8("eric4 Web Browser"), "ericWeb.png",
+                    [self.trUtf8("Eric Web Browser"), "ericWeb.png",
                     "HelpWebBrowserPage", "0helpPage", None],
             }
-        elif displayMode == ConfigurationWidget.TrayStarterMode:
-            self.configItems = {
-                # key : [display string, pixmap name, dialog module name or 
-                #        page creation function, parent key,
-                #        reference to configuration page (must always be last)]
-                # The dialog module must have the module function create to create
-                # the configuration page. This must have the method save to save 
-                # the settings.
-                "trayStarterPage" : \
-                    [self.trUtf8("Tray Starter"), "erict.png",
-                    "TrayStarterPage", None, None],
-            }
-        else:
-            raise RuntimeError("Illegal mode value: %d" % displayMode)
         
         # generate the list entries
         itemsToExpand = []
@@ -337,22 +307,8 @@ class ConfigurationWidget(QWidget):
             self.__showConfigurationPage)
         self.connect(self.configList, SIGNAL("itemClicked(QTreeWidgetItem *, int)"),
             self.__showConfigurationPage)
-        self.connect(self.buttonBox, SIGNAL("accepted()"), self.accept)
-        self.connect(self.buttonBox, SIGNAL("rejected()"), self, SIGNAL("rejected()"))
         
-        if displayMode != ConfigurationWidget.TrayStarterMode:
-            self.__initLexers()
-        
-    def accept(self):
-        """
-        Public slot to accept the buttonBox accept signal.
-        """
-        if not isMacPlatform():
-            wdg = self.focusWidget()
-            if wdg == self.configList:
-                return
-        
-        self.emit(SIGNAL("accepted()"))
+        self.__initLexers()
         
     def __setupUi(self):
         """
@@ -370,19 +326,8 @@ class ConfigurationWidget(QWidget):
         self.configSplitter.setOrientation(Qt.Horizontal)
         self.configSplitter.setObjectName("configSplitter")
         
-        self.configListWidget = QWidget(self.configSplitter)
-        self.leftVBoxLayout = QVBoxLayout(self.configListWidget)
-        self.leftVBoxLayout.setMargin(0)
-        self.leftVBoxLayout.setSpacing(0)
-        self.leftVBoxLayout.setObjectName("leftVBoxLayout")
-        self.configListFilter = E4LineEdit(self, self.trUtf8("Enter filter text..."))
-        self.configListFilter.setObjectName("configListFilter")
-        self.leftVBoxLayout.addWidget(self.configListFilter)
-        self.configList = QTreeWidget()
+        self.configList = QTreeWidget(self.configSplitter)
         self.configList.setObjectName("configList")
-        self.leftVBoxLayout.addWidget(self.configList)
-        self.connect(self.configListFilter, SIGNAL("textChanged(const QString &)"),
-            self.__filterTextChanged)
         
         self.scrollArea = QScrollArea(self.configSplitter)
         self.scrollArea.setFrameShape(QFrame.NoFrame)
@@ -428,7 +373,7 @@ class ConfigurationWidget(QWidget):
             QDialogButtonBox.Apply | QDialogButtonBox.Cancel | \
             QDialogButtonBox.Ok | QDialogButtonBox.Reset)
         self.buttonBox.setObjectName("buttonBox")
-        if not self.fromEric and self.displayMode == ConfigurationWidget.DefaultMode:
+        if not self.fromEric and not self.helpBrowserMode:
             self.buttonBox.button(QDialogButtonBox.Apply).hide()
         self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Reset).setEnabled(False)
@@ -446,38 +391,6 @@ class ConfigurationWidget(QWidget):
         self.setTabOrder(self.configList, self.configStack)
         
         self.configStack.setCurrentWidget(self.emptyPage)
-        
-        self.configList.setFocus()
-    
-    def __filterTextChanged(self, filter):
-        """
-        Private slot to handle a change of the filter.
-        
-        @param filter text of the filter line edit (string)
-        """
-        self.__filterChildItems(self.configList.invisibleRootItem(), filter)
-    
-    def __filterChildItems(self, parent, filter):
-        """
-        Private method to filter child items based on a filter string.
-        
-        @param parent reference to the parent item (QTreeWidgetItem)
-        @param filter filter string (string)
-        @return flag indicating a visible child item (boolean)
-        """
-        childVisible = False
-        for index in range(parent.childCount()):
-            itm = parent.child(index)
-            if itm.childCount() > 0:
-                visible = self.__filterChildItems(itm, filter)
-            else:
-                visible = filter.isEmpty() or \
-                          itm.text(0).contains(filter, Qt.CaseInsensitive)
-            if visible:
-                childVisible = True
-            itm.setHidden(not visible)
-        
-        return childVisible
     
     def __initLexers(self):
         """
@@ -538,10 +451,6 @@ class ConfigurationWidget(QWidget):
         if page is not None:
             self.configStack.addWidget(page)
             pageData[-1] = page
-            try:
-                page.setMode(self.displayMode)
-            except AttributeError:
-                pass
         return page
         
     def showConfigurationPageByName(self, pageName):
@@ -673,12 +582,8 @@ class ConfigurationDialog(QDialog):
     
     @signal preferencesChanged emitted after settings have been changed
     """
-    DefaultMode     = ConfigurationWidget.DefaultMode
-    HelpBrowserMode = ConfigurationWidget.HelpBrowserMode
-    TrayStarterMode = ConfigurationWidget.TrayStarterMode
-    
     def __init__(self, parent = None, name = None, modal = False, 
-                 fromEric = True, displayMode = ConfigurationWidget.DefaultMode):
+                 fromEric = True, helpBrowserMode = False):
         """
         Constructor
         
@@ -687,8 +592,8 @@ class ConfigurationDialog(QDialog):
         @param modal Flag indicating a modal dialog. (boolean)
         @keyparam fromEric flag indicating a dialog generation from within the 
             eric4 ide (boolean)
-        @keyparam displayMode mode of the configuration dialog 
-            (DefaultMode, HelpBrowserMode, TrayStarterMode)
+        @keyparam helpBrowserMode flag indicating to show only help pages
+            for entries related to the help browser (boolean)
         """
         QDialog.__init__(self, parent)
         if name:
@@ -699,13 +604,13 @@ class ConfigurationDialog(QDialog):
         self.layout.setSpacing(0)
         
         self.cw = ConfigurationWidget(self, fromEric = fromEric, 
-                                      displayMode = displayMode)
+                                      helpBrowserMode = helpBrowserMode)
         size = self.cw.size()
         self.layout.addWidget(self.cw)
         self.resize(size)
         
-        self.connect(self.cw, SIGNAL("accepted()"), self.accept)
-        self.connect(self.cw, SIGNAL("rejected()"), self.reject)
+        self.connect(self.cw.buttonBox, SIGNAL("accepted()"), self.accept)
+        self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.reject)
         self.connect(self.cw, SIGNAL('preferencesChanged'), 
                      self.__preferencesChanged)
         
@@ -746,8 +651,8 @@ class ConfigurationWindow(KQMainWindow):
         self.setCentralWidget(self.cw)
         self.resize(size)
         
-        self.connect(self.cw, SIGNAL("accepted()"), self.accept)
-        self.connect(self.cw, SIGNAL("rejected()"), self.close)
+        self.connect(self.cw.buttonBox, SIGNAL("accepted()"), self.accept)
+        self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.close)
         
     def showConfigurationPageByName(self, pageName):
         """
