@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -129,8 +129,6 @@ class DebuggerGeneralPage(ConfigurationPageBase, Ui_DebuggerGeneralPage):
             Preferences.getDebugger("SuppressClientExit"))
         self.exceptionBreakCheckBox.setChecked(\
             Preferences.getDebugger("BreakAlways"))
-        self.autoViewSourcecodeCheckBox.setChecked(\
-            Preferences.getDebugger("AutoViewSourceCode"))
         
     def save(self):
         """
@@ -191,8 +189,6 @@ class DebuggerGeneralPage(ConfigurationPageBase, Ui_DebuggerGeneralPage):
             int(self.dontShowClientExitCheckBox.isChecked()))
         Preferences.setDebugger("BreakAlways",
             int(self.exceptionBreakCheckBox.isChecked()))
-        Preferences.setDebugger("AutoViewSourceCode",
-            int(self.autoViewSourcecodeCheckBox.isChecked()))
         
     def on_allowedHostsList_currentItemChanged(self, current, previous):
         """
