@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,8 +10,8 @@ Module implementing the Editor Highlighting Styles configuration page.
 import os
 import cStringIO
 
-from PyQt4.QtCore import QString, QStringList, pyqtSignature, QFileInfo, QVariant
-from PyQt4.QtGui import QPalette, QFileDialog, QMenu, QFont
+from PyQt4.QtCore import QString, QStringList, pyqtSignature, QFileInfo
+from PyQt4.QtGui import QPalette, QFileDialog
 
 from KdeQt import KQColorDialog, KQFontDialog, KQInputDialog, KQFileDialog, KQMessageBox
 
@@ -30,11 +30,6 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
     """
     Class implementing the Editor Highlighting Styles configuration page.
     """
-    FAMILYONLY    = 0
-    SIZEONLY      = 1
-    FAMILYANDSIZE = 2
-    FONT          = 99
-    
     def __init__(self, lexers):
         """
         Constructor
@@ -45,32 +40,6 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
         self.setupUi(self)
         self.setObjectName("EditorHighlightingStylesPage")
         
-        self.__fontButtonMenu = QMenu()
-        act = self.__fontButtonMenu.addAction(self.trUtf8("Font"))
-        act.setData(QVariant(self.FONT))
-        self.__fontButtonMenu.addSeparator()
-        act = self.__fontButtonMenu.addAction(self.trUtf8("Family and Size only"))
-        act.setData(QVariant(self.FAMILYANDSIZE))
-        act = self.__fontButtonMenu.addAction(self.trUtf8("Family only"))
-        act.setData(QVariant(self.FAMILYONLY))
-        act = self.__fontButtonMenu.addAction(self.trUtf8("Size only"))
-        act.setData(QVariant(self.SIZEONLY))
-        self.__fontButtonMenu.triggered.connect(self.__fontButtonMenuTriggered)
-        self.fontButton.setMenu(self.__fontButtonMenu)
-        
-        self.__allFontsButtonMenu = QMenu()
-        act = self.__allFontsButtonMenu.addAction(self.trUtf8("Font"))
-        act.setData(QVariant(self.FONT))
-        self.__allFontsButtonMenu.addSeparator()
-        act = self.__allFontsButtonMenu.addAction(self.trUtf8("Family and Size only"))
-        act.setData(QVariant(self.FAMILYANDSIZE))
-        act = self.__allFontsButtonMenu.addAction(self.trUtf8("Family only"))
-        act.setData(QVariant(self.FAMILYONLY))
-        act = self.__allFontsButtonMenu.addAction(self.trUtf8("Size only"))
-        act.setData(QVariant(self.SIZEONLY))
-        self.__allFontsButtonMenu.triggered.connect(self.__allFontsButtonMenuTriggered)
-        self.allFontsButton.setMenu(self.__allFontsButtonMenu)
-        
         self.lexer = None
         self.lexers = lexers
         
@@ -191,89 +160,31 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
             for style in self.lexer.ind2style.values():
                 self.lexer.setPaper(colour, style)
         
-    def __changeFont(self, doAll, familyOnly, sizeOnly):
+    @pyqtSignature("")
+    def on_fontButton_clicked(self):
         """
-        Private slot to change the highlighter font.
-        
-        @param doAll flag indicating to change the font for all styles (boolean)
-        @param familyOnly flag indicating to set the font family only (boolean)
-        @param sizeOnly flag indicating to set the font size only (boolean
+        Private method used to select the font of the selected style and lexer.
         """
-        def setFont(font, style, familyOnly, sizeOnly):
-            """
-            Local function to set the font.
-            
-            @param font font to be set (QFont)
-            @param style style to set the font for (integer)
-            @param familyOnly flag indicating to set the font family only (boolean)
-            @param sizeOnly flag indicating to set the font size only (boolean
-            """
-            if familyOnly or sizeOnly:
-                newFont = QFont(self.lexer.font(style))
-                if familyOnly:
-                    newFont.setFamily(font.family())
-                if sizeOnly:
-                    newFont.setPointSize(font.pointSize())
-                self.lexer.setFont(newFont, style)
-            else:
-                self.lexer.setFont(font, style)
-        
-        def setSampleFont(font, familyOnly, sizeOnly):
-            """
-            Local function to set the font of the sample text.
-            
-            @param font font to be set (QFont)
-            @param familyOnly flag indicating to set the font family only (boolean)
-            @param sizeOnly flag indicating to set the font size only (boolean
-            """
-            if familyOnly or sizeOnly:
-                newFont = QFont(self.lexer.font(self.style))
-                if familyOnly:
-                    newFont.setFamily(font.family())
-                if sizeOnly:
-                    newFont.setPointSize(font.pointSize())
-                self.sampleText.setFont(newFont)
-            else:
-                self.sampleText.setFont(font)
-        
         font, ok = KQFontDialog.getFont(self.lexer.font(self.style))
         if ok:
-            setSampleFont(font, familyOnly, sizeOnly)
-            if doAll:
-                for style in list(self.lexer.ind2style.values()):
-                    setFont(font, style, familyOnly, sizeOnly)
-            elif len(self.styleElementList.selectedItems()) > 1:
+            self.sampleText.setFont(font)
+            if len(self.styleElementList.selectedItems()) > 1:
                 for selItem in self.styleElementList.selectedItems():
                     style = self.lexer.ind2style[self.styleElementList.row(selItem)]
-                    setFont(font, style, familyOnly, sizeOnly)
+                    self.lexer.setFont(font, style)
             else:
-                setFont(font, self.style, familyOnly, sizeOnly)
+                self.lexer.setFont(font, self.style)
         
-    def __fontButtonMenuTriggered(self, act):
+    @pyqtSignature("")
+    def on_allFontsButton_clicked(self):
         """
-        Private slot used to select the font of the selected style and lexer.
-        
-        @param act reference to the triggering action (QAction)
+        Private method used to change the font of all styles of a selected lexer.
         """
-        if act is None:
-            return
-        
-        familyOnly = act.data().toInt()[0] in [self.FAMILYANDSIZE, self.FAMILYONLY]
-        sizeOnly = act.data().toInt()[0] in [self.FAMILYANDSIZE, self.SIZEONLY]
-        self.__changeFont(False, familyOnly, sizeOnly)
-        
-    def __allFontsButtonMenuTriggered(self, act):
-        """
-        Private slot used to change the font of all styles of a selected lexer.
-        
-        @param act reference to the triggering action (QAction)
-        """
-        if act is None:
-            return
-        
-        familyOnly = act.data().toInt()[0] in [self.FAMILYANDSIZE, self.FAMILYONLY]
-        sizeOnly = act.data().toInt()[0] in [self.FAMILYANDSIZE, self.SIZEONLY]
-        self.__changeFont(True, familyOnly, sizeOnly)
+        font, ok = KQFontDialog.getFont(self.lexer.font(self.style))
+        if ok:
+            self.sampleText.setFont(font)
+            for style in self.lexer.ind2style.values():
+                self.lexer.setFont(font, style)
         
     def on_eolfillCheckBox_toggled(self, b):
         """
@@ -305,7 +216,7 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
     @pyqtSignature("")
     def on_defaultButton_clicked(self):
         """
-        Private method to set the current style to its default values.
+        Private method to set the current style to it's default values.
         """
         if len(self.styleElementList.selectedItems()) > 1:
             for selItem in self.styleElementList.selectedItems():
@@ -326,7 +237,7 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
         
     def __setToDefault(self, style):
         """
-        Private method to set a specific style to its default values.
+        Private method to set a specific style to it's default values.
         
         @param style style to be reset (integer)
         """
@@ -398,7 +309,7 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
                 self.trUtf8("""<p>The highlighting styles could not be exported"""
                             """ to file <b>%1</b>.</p><p>Reason: %2</p>""")\
                     .arg(fn)\
-                    .arg(str(err))
+                    .arg(unicode(err))
             )
         
     def __importStyles(self, lexers):
@@ -432,7 +343,7 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
                 self.trUtf8("""<p>The highlighting styles could not be read"""
                             """ from file <b>%1</b>.</p><p>Reason: %2</p>""")\
                     .arg(fn)\
-                    .arg(str(err))
+                    .arg(unicode(err))
             )
             return
         
@@ -463,7 +374,7 @@ class EditorHighlightingStylesPage(ConfigurationPageBase, Ui_EditorHighlightingS
                 self.trUtf8("""<p>The highlighting styles could not be read"""
                             """ from file <b>%1</b>.</p><p>Reason: %2</p>""")\
                     .arg(fn)\
-                    .arg(str(err))
+                    .arg(unicode(err))
             )
             return
         except XMLFatalParseError:
