@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -52,7 +52,6 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
             Preferences.getUI("BrowsersHideNonPublic"))
         self.uiBrowsersSortByOccurrenceCheckBox.setChecked(
             Preferences.getUI("BrowsersListContentsByOccurrence"))
-        self.fileFiltersEdit.setText(Preferences.getUI("BrowsersFileFilters"))
         
         self.lvAutoRaiseCheckBox.setChecked(
             Preferences.getUI("LogViewerAutoRaise"))
@@ -111,19 +110,13 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
             self.tabsCloseButtonCheckBox.setChecked(
                 Preferences.getUI("SingleCloseButton"))
         
-        if Utilities.isMacPlatform() or Utilities.isWindowsPlatform():
-            self.uiKdeDialogsCheckBox.setChecked(False)
-            self.dialogsGroupBox.hide()
-        else:
-            self.uiKdeDialogsCheckBox.setChecked(\
-                Preferences.getUI("UseKDEDialogs"))
+        self.uiKdeDialogsCheckBox.setChecked(\
+            Preferences.getUI("UseKDEDialogs"))
         
         self.uiColours["LogStdErrColour"] = \
             self.initColour("LogStdErrColour", self.stderrTextColourButton, 
                 Preferences.getUI)
         
-        self.delaySpinBox.setValue(Preferences.getUI("SidebarDelay"))
-        
     def save(self):
         """
         Public slot to save the Interface configuration.
@@ -140,9 +133,6 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
             int(self.uiBrowsersHideNonPublicCheckBox.isChecked()))
         Preferences.setUI("BrowsersListContentsByOccurrence", 
             int(self.uiBrowsersSortByOccurrenceCheckBox.isChecked()))
-        Preferences.setUI("BrowsersFileFilters",
-            self.fileFiltersEdit.text())
-        
         Preferences.setUI("LogViewerAutoRaise", 
             int(self.lvAutoRaiseCheckBox.isChecked()))
         Preferences.setUI("CaptionShowsFilename",
@@ -201,8 +191,6 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
         Preferences.setUI("UseKDEDialogs",
             int(self.uiKdeDialogsCheckBox.isChecked()))
         
-        Preferences.setUI("SidebarDelay", self.delaySpinBox.value())
-        
         for key in self.uiColours.keys():
             Preferences.setUI(key, self.uiColours[key])
         
