@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -58,9 +58,6 @@ class VcsPage(ConfigurationPageBase, Ui_VcsPage):
         self.projectBrowserColours["VcsConflict"] = \
             self.initColour("VcsConflict", self.pbVcsConflictButton, 
                 Preferences.getProjectBrowserColour)
-        self.projectBrowserColours["VcsRemoved"] = \
-            self.initColour("VcsRemoved", self.pbVcsRemovedButton, 
-                Preferences.getProjectBrowserColour)
     
     def save(self):
         """
@@ -91,7 +88,7 @@ class VcsPage(ConfigurationPageBase, Ui_VcsPage):
         self.projectBrowserColours["VcsAdded"] = \
             self.selectColour(self.pbVcsAddedButton, 
                 self.projectBrowserColours["VcsAdded"])
-    
+        
     @pyqtSignature("")
     def on_pbVcsConflictButton_clicked(self):
         """
@@ -101,7 +98,7 @@ class VcsPage(ConfigurationPageBase, Ui_VcsPage):
         self.projectBrowserColours["VcsConflict"] = \
             self.selectColour(self.pbVcsConflictButton, 
                 self.projectBrowserColours["VcsConflict"])
-    
+        
     @pyqtSignature("")
     def on_pbVcsModifiedButton_clicked(self):
         """
@@ -111,7 +108,7 @@ class VcsPage(ConfigurationPageBase, Ui_VcsPage):
         self.projectBrowserColours["VcsModified"] = \
             self.selectColour(self.pbVcsModifiedButton, 
                 self.projectBrowserColours["VcsModified"])
-    
+        
     @pyqtSignature("")
     def on_pbVcsReplacedButton_clicked(self):
         """
@@ -121,17 +118,7 @@ class VcsPage(ConfigurationPageBase, Ui_VcsPage):
         self.projectBrowserColours["VcsReplaced"] = \
             self.selectColour(self.pbVcsReplacedButton, 
                 self.projectBrowserColours["VcsReplaced"])
-    
-    @pyqtSignature("")
-    def on_pbVcsRemovedButton_clicked(self):
-        """
-        Private slot to set the background colour for entries with VCS 
-        status "removed".
-        """
-        self.projectBrowserColours["VcsRemoved"] = \
-            self.selectColour(self.pbVcsRemovedButton, 
-                self.projectBrowserColours["VcsRemoved"])
-    
+        
     @pyqtSignature("")
     def on_pbVcsUpdateButton_clicked(self):
         """
