@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -16,7 +16,6 @@ from PyQt4.Qsci import QsciLexer, QsciScintilla
 import QScintilla.Lexers
 
 import Preferences
-import Globals
 
 class PreferencesLexerError(Exception):
     """
@@ -72,14 +71,6 @@ class PreferencesLexer(QsciLexer):
         """
         QsciLexer.__init__(self, parent)
         
-        # These default font families are taken from QScintilla
-        if Globals.isWindowsPlatform():
-            self.__defaultFontFamily = "Courier New"
-        elif Globals.isMacPlatform():
-            self.__defaultFontFamily = "Courier"
-        else:
-            self.__defaultFontFamily = "Bitstream Vera Sans Mono"
-        
         # instantiate a lexer object for the given language
         language = unicode(language)
         lex = QScintilla.Lexers.getLexer(language)
@@ -114,15 +105,11 @@ class PreferencesLexer(QsciLexer):
                 self.papers[i] = lex.defaultPaper(i)
                 self.eolFills[i] = lex.defaultEolFill(i)
                 self.fonts[i] = lex.defaultFont(i)
-                # Override QScintilla's default font family to
-                # always use a monospaced font
-                self.fonts[i].setFamily(self.__defaultFontFamily)
                 
                 self.defaultColours[i] = lex.defaultColor(i)
                 self.defaultPapers[i] = lex.defaultPaper(i)
                 self.defaultEolFills[i] = lex.defaultEolFill(i)
                 self.defaultFonts[i] = lex.defaultFont(i)
-                self.defaultFonts[i].setFamily(self.__defaultFontFamily)
                 
                 self.ind2style[index] = i
                 index += 1
