@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -22,6 +22,8 @@ from Ui_ProgramsDialog import Ui_ProgramsDialog
 import Preferences
 import Utilities
 
+from eric4config import getConfig
+
 class ProgramsDialog(QDialog, Ui_ProgramsDialog):
     """
     Class implementing the Programs page.
@@ -82,28 +84,19 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         version = self.__createProgramEntry(self.trUtf8("Translation Converter (Qt4)"), 
                     exe, '-version', 'lrelease', -1)
         # 1b. Qt4 Designer
-        if Utilities.isWindowsPlatform():
-            exe = "%s.exe" % Utilities.generateQtToolName("designer")
-        elif Utilities.isMacPlatform():
-            exe = unicode(Utilities.getQtMacBundle("designer"))
-        else:
-            exe = Utilities.generateQtToolName("designer")
+        exe = Utilities.isWindowsPlatform() and \
+            "%s.exe" % Utilities.generateQtToolName("designer") or \
+            Utilities.generateQtToolName("designer")
         self.__createProgramEntry(self.trUtf8("Qt4 Designer"), exe, version = version)
         # 1c. Qt4 Linguist
-        if Utilities.isWindowsPlatform():
-            exe = "%s.exe" % Utilities.generateQtToolName("linguist")
-        elif Utilities.isMacPlatform():
-            exe = unicode(Utilities.getQtMacBundle("linguist"))
-        else:
-            exe = Utilities.generateQtToolName("linguist")
+        exe = Utilities.isWindowsPlatform() and \
+            "%s.exe" % Utilities.generateQtToolName("linguist") or \
+            Utilities.generateQtToolName("linguist")
         self.__createProgramEntry(self.trUtf8("Qt4 Linguist"), exe, version = version)
         # 1d. Qt4 Assistant
-        if Utilities.isWindowsPlatform():
-            exe = "%s.exe" % Utilities.generateQtToolName("assistant")
-        elif Utilities.isMacPlatform():
-            exe = unicode(Utilities.getQtMacBundle("assistant"))
-        else:
-            exe = Utilities.generateQtToolName("assistant")
+        exe = Utilities.isWindowsPlatform() and \
+            "%s.exe" % Utilities.generateQtToolName("assistant") or \
+            Utilities.generateQtToolName("assistant")
         self.__createProgramEntry(self.trUtf8("Qt4 Assistant"), exe, version = version)
         
         # 2. do the PyQt programs
@@ -123,15 +116,15 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         # 3. do the PySide programs
         # 3a. Translation Extractor PySide
         self.__createProgramEntry(self.trUtf8("Translation Extractor (Python, PySide)"), 
-            Utilities.generatePySideToolPath("pyside-lupdate"), 
+            Utilities.isWindowsPlatform() and "pyside-lupdate.exe" or "pyside-lupdate", 
             '-version', '', -1, versionRe = 'lupdate')
         # 3b. Forms Compiler PySide
         self.__createProgramEntry(self.trUtf8("Forms Compiler (Python, PySide)"), 
-            Utilities.generatePySideToolPath("pyside-uic"), 
-            '--version', 'PySide User', 5, versionCleanup=(0, -1))
+            Utilities.isWindowsPlatform() and "pyside-uic.bat" or "pyside-uic", 
+            '--version', 'Python User', 4)
         # 3.c Resource Compiler PySide
         self.__createProgramEntry(self.trUtf8("Resource Compiler (Python, PySide)"), 
-            Utilities.generatePySideToolPath("pyside-rcc"), 
+            Utilities.isWindowsPlatform() and "pyside-rcc4.exe" or "pyside-rcc4", 
             '-version', 'Resource Compiler', -1)
         
         # 4. do the Ruby programs
@@ -144,15 +137,29 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
             Utilities.isWindowsPlatform() and "rbrcc.exe" or "rbrcc", 
             '-version', 'Ruby Resource Compiler', -1)
         
-        # 5. do the CORBA programs
-        # 5a. omniORB
+        # 5. do the Eric4 programs
+        # 5a. Translation Previewer
+        self.__createProgramEntry(self.trUtf8("Eric4 Translation Previewer"), 
+            Utilities.isWindowsPlatform() and \
+                os.path.join(getConfig("bindir"), "eric4-trpreviewer.bat") or \
+                "eric4-trpreviewer", 
+            '--version', 'Eric4', -2)
+        # 5b. Forms Previewer
+        self.__createProgramEntry(self.trUtf8("Eric4 Forms Previewer"), 
+            Utilities.isWindowsPlatform() and \
+                os.path.join(getConfig("bindir"), "eric4-uipreviewer.bat") or \
+                "eric4-uipreviewer", 
+            '--version', 'Eric4', -2)
+        
+        # 6. do the CORBA programs
+        # 6a. omniORB
         exe = unicode(Preferences.getCorba("omniidl"))
         if Utilities.isWindowsPlatform():
             exe += ".exe"
         self.__createProgramEntry(self.trUtf8("CORBA IDL Compiler"), exe,
             '-V', 'omniidl', -1)
         
-        # 6. do the spell checking entry
+        # 7. do the spell checking entry
         try:
             import enchant
             try:
