@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -362,7 +362,7 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
             for act in actions:
                 if txt == act.objectName():
                     act.setShortcut(QKeySequence(itm.text(1)))
-                    act.setAlternateShortcut(QKeySequence(itm.text(2)), removeEmpty=True)
+                    act.setAlternateShortcut(QKeySequence(itm.text(2)))
                     break
         
     def on_buttonBox_accepted(self):
