@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -28,7 +28,7 @@ from PyQt4.QtWebKit import QWebSettings
 import QScintilla.Lexers
 
 from Globals import settingsNameOrganization, settingsNameGlobal, settingsNameRecent, \
-    isWindowsPlatform, getPyQt4ModulesDirectory
+    isWindowsPlatform
 
 from Project.ProjectBrowserFlags import SourcesBrowserFlag, FormsBrowserFlag, \
     ResourcesBrowserFlag, TranslationsBrowserFlag, InterfacesBrowserFlag, \
@@ -80,7 +80,6 @@ class Prefs(object):
         "PathTranslationRemote" : "",
         "PathTranslationLocal" : "",
         "NetworkInterface" : "127.0.0.1",
-        "AutoViewSourceCode" : 0, 
     }
     debuggerDefaults["AllowedHosts"] = \
         QtCore.QStringList("127.0.0.1") << QtCore.QString("0:0:0:0:0:0:0:1%0")
@@ -90,8 +89,7 @@ class Prefs(object):
         "Style" : "System",
         "StyleSheet" : "",
         "ViewManager" : "tabview",
-        "LayoutType" : "Sidebars",
-        "SidebarDelay": 200,
+        "LayoutType" : "Toolboxes",
         # allowed values are "DockWindows", "FloatingWindows", "Toolboxes" and "Sidebars"
         "LayoutShellEmbedded" : 0,          # 0 = separate
                                             # 1 = embedded in debug browser
@@ -101,7 +99,6 @@ class Prefs(object):
         "BrowsersListFoldersFirst" : 1,
         "BrowsersHideNonPublic" : 0,
         "BrowsersListContentsByOccurrence" : 0, 
-        "BrowsersFileFilters" : "*.py[co];*.so;*.dll",
         "LogViewerAutoRaise" : 1, 
         "SingleApplicationMode" : 0,
         "CaptionShowsFilename" : 1,
@@ -155,7 +152,7 @@ class Prefs(object):
         "ToolbarManagerState" : QtCore.QByteArray(), 
         "ShowSplash" : 1,
         "UseKDEDialogs" : 0, 
-        "SingleCloseButton" : 0, 
+        "SingleCloseButton" : 1, 
         
         "PerformVersionCheck" : 4,      # 0 = off
                                         # 1 = at startup
@@ -163,7 +160,6 @@ class Prefs(object):
                                         # 3 = weekly
                                         # 4 = monthly
         "UseProxy" : 0,
-        "UseSystemProxy" : 1, 
         "ProxyHost" : "",
         "ProxyPort" : 80,
         "ProxyUser" : "",
@@ -173,9 +169,9 @@ class Prefs(object):
                                     # 2 = SOCKS5 proxy
         
         "PluginRepositoryUrl" : \
-            "http://eric-ide.python-projects.org/plugins4/repository.xml",
+            "http://die-offenbachs.homelinux.org/eric/plugins/repository.xml",
         "VersionsUrls" : QtCore.QStringList() \
-            << "http://die-offenbachs.homelinux.org:48888/eric/snapshots4/versions" \
+            << "http://die-offenbachs.homelinux.org/eric/snapshots4/versions" \
             << "http://eric-ide.python-projects.org/snapshots4/versions", 
         
         "OpenOnStartup" : 0,        # 0 = nothing
@@ -201,6 +197,7 @@ class Prefs(object):
         "AutosaveInterval" : 0,
         "TabWidth" : 4,
         "IndentWidth" : 4,
+        "LinenoWidth" : 4,
         "IndentationGuides" : 1,
         "UnifiedMargins" : 0, 
         "LinenoMargin" : 1,
@@ -211,7 +208,6 @@ class Prefs(object):
         "ConvertTabsOnLoad" : 0,
         "AutomaticEOLConversion" : 1,
         "ShowWhitespace" : 0,
-        "WhitespaceSize" : 1, 
         "ShowEOL" : 0,
         "UseMonospacedFont" : 0,
         "WrapLongLines" : 0,
@@ -219,7 +215,6 @@ class Prefs(object):
         "ClearBreaksOnClose" : 1,
         "StripTrailingWhitespace" : 0, 
         "CommentColumn0" : 1, 
-        "OverrideEditAreaColours": 0,
         
         "EdgeMode" : Qsci.QsciScintilla.EdgeNone,
         "EdgeColumn" : 80,
@@ -269,12 +264,8 @@ class Prefs(object):
         "SpellCheckingPersonalExcludeList" : "", 
         
         "DefaultEncoding" : "utf-8",
-        "DefaultOpenFilter" : QtGui.QApplication.translate('Lexers', 
-                                'Python Files (*.py *.py3)'),
-        "DefaultSaveFilter" : QtGui.QApplication.translate('Lexers', 
-                                "Python Files (*.py)"),
-        "AdditionalOpenFilters" : QtCore.QStringList(), 
-        "AdditionalSaveFilters" : QtCore.QStringList(), 
+        "DefaultOpenFilter" : "",
+        "DefaultSaveFilter" : "",
         
         # All (most) lexers
         "AllFoldCompact" : 1,
@@ -293,8 +284,6 @@ class Prefs(object):
         "CppIndentOpeningBrace" : 0,
         "CppIndentClosingBrace" : 0,
         "CppDollarsAllowed" : 1, 
-        "CppStylePreprocessor": 0, 
-        "CppHighlightTripleQuotedStrings": 0,
         
         # CSS specifics
         "CssFoldComment" : 1,
@@ -310,8 +299,6 @@ class Prefs(object):
         "HtmlFoldScriptComments" : 0, 
         "HtmlFoldScriptHeredocs" : 0, 
         "HtmlCaseSensitiveTags" : 0,
-        "HtmlDjangoTemplates": 0,
-        "HtmlMakoTemplates": 0, 
         
         # Pascal specifics
         "PascalFoldComment" : 1, 
@@ -322,7 +309,6 @@ class Prefs(object):
         "PerlFoldComment" : 1,
         "PerlFoldPackages" : 1, 
         "PerlFoldPODBlocks" : 1, 
-        "PerlFoldAtElse": 0,
         
         # PostScript specifics
         "PostScriptTokenize" : 0, 
@@ -333,9 +319,6 @@ class Prefs(object):
         "PovFoldComment" : 1,
         "PovFoldDirectives" : 0,
         
-        # Properties specifics
-        "PropertiesInitialSpaces": 1, 
-        
         # Python specifics
         "PythonBadIndentation" : 1,
         "PythonFoldComment" : 1,
@@ -344,29 +327,10 @@ class Prefs(object):
         "PythonAllowV2Unicode" : 1, 
         "PythonAllowV3Binary" : 1, 
         "PythonAllowV3Bytes" : 1, 
-        "PythonFoldQuotes": 0,
-        "PythonStringsOverNewLineAllowed": 0,
-        "PythonHighlightSubidentifier": 1,
-        
-        # Ruby specifics
-        "RubyFoldComment": 0,
         
         # SQL specifics
         "SqlFoldComment" : 1,
         "SqlBackslashEscapes" : 0,
-        "SqlDottedWords": 0,
-        "SqlFoldAtElse": 0,
-        "SqlFoldOnlyBegin": 0,
-        "SqlHashComments": 0,
-        "SqlQuotedIdentifiers": 0,
-        
-        # TCL specifics
-        "TclFoldComment": 0,
-        
-        # TeX specifics
-        "TexFoldComment": 0,
-        "TexProcessComments": 0,
-        "TexProcessIf": 1,
         
         # VHDL specifics
         "VHDLFoldComment" : 1,
@@ -404,12 +368,6 @@ class Prefs(object):
         "MarginsForeground"    : QtGui.QColor(QtCore.Qt.black),
         "FoldmarginBackground" : QtGui.QColor(230, 230, 230),
         "SpellingMarkers"      : QtGui.QColor(QtCore.Qt.red),
-        "WhitespaceForeground" : QtGui.QColor(QtCore.Qt.darkGray),
-        "WhitespaceBackground" : QtGui.QColor(QtCore.Qt.white),
-        "EditAreaForeground"   : QtGui.QApplication.palette().color(
-            QtGui.QPalette.Active, QtGui.QPalette.Base),
-        "EditAreaBackground"   : QtGui.QApplication.palette().color(
-            QtGui.QPalette.Active, QtGui.QPalette.Text),
     }
     
     editorOtherFontsDefaults = {
@@ -421,7 +379,7 @@ class Prefs(object):
     editorTypingDefaults = {
         "Python/EnabledTypingAids"  : 1, 
         "Python/InsertClosingBrace" : 1,
-        "Python/IndentBrace"        : 0,
+        "Python/IndentBrace"        : 1,
         "Python/SkipBrace"          : 1,
         "Python/InsertQuote"        : 1,
         "Python/DedentElse"         : 1,
@@ -505,7 +463,6 @@ class Prefs(object):
         "OpenMasterAutomatically" : 1, 
         "XMLTimestamp" : 1,
         "RecentNumber" : 9, 
-        "Workspace": "",
     }
     
     # defaults for the project browser flags settings
@@ -568,7 +525,6 @@ class Prefs(object):
         "VcsModified" : QtGui.QColor(QtCore.Qt.yellow),
         "VcsReplaced" : QtGui.QColor(QtCore.Qt.cyan), 
         "VcsUpdate"   : QtGui.QColor(QtCore.Qt.green),
-        "VcsRemoved"  : QtGui.QColor(QtCore.Qt.magenta)
     }
     
     # defaults for the help settings
@@ -600,41 +556,31 @@ class Prefs(object):
         "SavePasswords" : 0, 
         "AdBlockEnabled" : 0, 
         "AdBlockSubscriptions" : QtCore.QStringList(), 
-        "SearchLanguage": QtCore.QLocale().language(),
     }
     
-    @classmethod
-    def initWebSettingsDefaults(cls):
-        """
-        Class method to initialize the web settings related defaults.
-        """
-        websettings = QWebSettings.globalSettings()
-        fontFamily = websettings.fontFamily(QWebSettings.StandardFont)
-        fontSize = websettings.fontSize(QWebSettings.DefaultFontSize)
-        cls.helpDefaults["StandardFont"] = QtGui.QFont(fontFamily, fontSize).toString()
-        fontFamily = websettings.fontFamily(QWebSettings.FixedFont)
-        fontSize = websettings.fontSize(QWebSettings.DefaultFixedFontSize)
-        cls.helpDefaults["FixedFont"] = QtGui.QFont(fontFamily, fontSize).toString()
-        cls.helpDefaults.update({
-            "AutoLoadImages" : 
-                websettings.testAttribute(QWebSettings.AutoLoadImages), 
-            "UserStyleSheet" : "", 
-            "SaveUrlColor" : QtGui.QColor(248, 248, 210), 
-            "JavaEnabled" : 
-                websettings.testAttribute(QWebSettings.JavaEnabled), 
-            "JavaScriptEnabled" : 
-                websettings.testAttribute(QWebSettings.JavascriptEnabled), 
-            "JavaScriptCanOpenWindows" : 
-                websettings.testAttribute(QWebSettings.JavascriptCanOpenWindows), 
-            "JavaScriptCanAccessClipboard" : 
-                websettings.testAttribute(QWebSettings.JavascriptCanAccessClipboard), 
-            "PluginsEnabled" :
-                websettings.testAttribute(QWebSettings.PluginsEnabled), 
-        })
-        
-        cls.webSettingsIntitialized = True
-    
-    webSettingsIntitialized = False
+    websettings = QWebSettings.globalSettings()
+    fontFamily = websettings.fontFamily(QWebSettings.StandardFont)
+    fontSize = websettings.fontSize(QWebSettings.DefaultFontSize)
+    helpDefaults["StandardFont"] = QtGui.QFont(fontFamily, fontSize).toString()
+    fontFamily = websettings.fontFamily(QWebSettings.FixedFont)
+    fontSize = websettings.fontSize(QWebSettings.DefaultFixedFontSize)
+    helpDefaults["FixedFont"] = QtGui.QFont(fontFamily, fontSize).toString()
+    helpDefaults.update({
+        "AutoLoadImages" : 
+            websettings.testAttribute(QWebSettings.AutoLoadImages), 
+        "UserStyleSheet" : "", 
+        "SaveUrlColor" : QtGui.QColor(248, 248, 210), 
+        "JavaEnabled" : 
+            websettings.testAttribute(QWebSettings.JavaEnabled), 
+        "JavaScriptEnabled" : 
+            websettings.testAttribute(QWebSettings.JavascriptEnabled), 
+        "JavaScriptCanOpenWindows" : 
+            websettings.testAttribute(QWebSettings.JavascriptCanOpenWindows), 
+        "JavaScriptCanAccessClipboard" : 
+            websettings.testAttribute(QWebSettings.JavascriptCanAccessClipboard), 
+        "PluginsEnabled" :
+            websettings.testAttribute(QWebSettings.PluginsEnabled), 
+    })
 
     # defaults for system settings
     if isWindowsPlatform():
@@ -650,6 +596,7 @@ class Prefs(object):
     
     # defaults for the shell settings
     shellDefaults = {
+        "LinenoWidth" : 4,
         "LinenoMargin" : 1,
         "AutoCompletionEnabled" : 1,
         "CallTipsEnabled" : 1,
@@ -662,6 +609,21 @@ class Prefs(object):
         "MarginsFont" : "Sans Serif,10,-1,5,50,0,0,0,0,0",
     }
 
+    # defaults for the terminal settings
+    terminalDefaults = {
+        "LinenoWidth" : 4,
+        "LinenoMargin" : 1,
+        "MaxHistoryEntries" : 100,
+        "SyntaxHighlightingEnabled" : 1,
+        "Shell" : "", 
+        "ShellInteractive" : 1, 
+        "UseMonospacedFont" : 0,
+        "MonospacedFont" : "Courier,10,-1,5,50,0,0,0,0,0", 
+        "MarginsFont" : "Sans Serif,10,-1,5,50,0,0,0,0,0",
+    }
+    if sys.platform.lower().startswith("linux"):
+        terminalDefaults["Shell"] = "bash"
+
     # defaults for Qt related stuff
     qtDefaults = {
         "Qt4TranslationsDir" : "",
@@ -707,7 +669,6 @@ class Prefs(object):
         "TasksBugfixColour"    : QtGui.QColor(QtCore.Qt.red),
         "TasksBgColour"        : QtGui.QColor(QtCore.Qt.white),
         "TasksProjectBgColour" : QtGui.QColor(QtCore.Qt.lightGray),
-        "ClearOnFileClose": 1,
     }
     
     # defaults for templates related stuff
@@ -734,12 +695,6 @@ class Prefs(object):
         "IconEditorState" : QtCore.QByteArray(), 
     }
     
-    # defaults for tray starter
-    trayStarterDefaults = {
-        "TrayStarterIcon" : "erict.png",
-        # valid values are: erict.png, erict-hc.png, erict-bw.png, erict-bwi.png
-    }
-    
     # defaults for geometry
     geometryDefaults = {
         "HelpViewerGeometry" : QtCore.QByteArray(),
@@ -883,21 +838,14 @@ def exportPreferences(prefClass = Prefs):
     """
     from KdeQt import KQFileDialog
 
-    selectedFilter = QtCore.QString('')
     filename = KQFileDialog.getSaveFileName(\
         None,
         QtCore.QCoreApplication.translate("Preferences", "Export Preferences"),
         QtCore.QString(),
-        QtCore.QCoreApplication.translate("Preferences", 
-            "Properties File (*.ini);;All Files (*)"),
-        selectedFilter,
+        QtCore.QString(),
+        None,
         QtGui.QFileDialog.Options(QtGui.QFileDialog.DontConfirmOverwrite))
     if not filename.isEmpty():
-        ext = QtCore.QFileInfo(filename).suffix()
-        if ext.isEmpty():
-            ex = selectedFilter.section('(*',1,1).section(')',0,0)
-            if not ex.isEmpty():
-                filename.append(ex)
         settingsFile = unicode(prefClass.settings.fileName())
         prefClass.settings = None
         shutil.copy(settingsFile, unicode(filename))
@@ -916,8 +864,7 @@ def importPreferences(prefClass = Prefs):
         None,
         QtCore.QCoreApplication.translate("Preferences", "Import Preferences"),
         QtCore.QString(),
-        QtCore.QCoreApplication.translate("Preferences", 
-            "Properties File (*.ini);;All Files (*)"),
+        QtCore.QString(),
         None)
     if not filename.isEmpty():
         settingsFile = unicode(prefClass.settings.fileName())
@@ -991,7 +938,6 @@ def getDebugger(key, prefClass = Prefs):
                 "ConsoleDbgEnabled", "PathTranslation", 
                 "Autosave", "ThreeStateBreakPoints", 
                 "SuppressClientExit", "BreakAlways", 
-                "AutoViewSourceCode", 
               ]:
         return prefClass.settings.value("Debugger/" + key,
             QtCore.QVariant(prefClass.debuggerDefaults[key])).toInt()[0]
@@ -1144,18 +1090,17 @@ def getUI(key, prefClass = Prefs):
                 "CaptionShowsFilename", "CaptionFilenameLength",
                 "RecentNumber", "UseKDEDialogs", "ShowSplash", 
                 "PerformVersionCheck", "SingleCloseButton", 
-                "UseProxy", "ProxyPort", "ProxyType", "UseSystemProxy", 
+                "UseProxy", "ProxyPort", "ProxyType", 
                 "TopLeftByLeft", "BottomLeftByLeft", 
                 "TopRightByRight", "BottomRightByRight", 
                 "OpenOnStartup", "RequestDownloadFilename", 
                 "LayoutShellEmbedded", "LayoutFileBrowserEmbedded", 
-                "CheckErrorLog", "SidebarDelay"]:
+                "CheckErrorLog"]:
         return prefClass.settings.value("UI/" + key,
             QtCore.QVariant(prefClass.uiDefaults[key])).toInt()[0]
     if key in ["Style", "StyleSheet", 
                 "ProxyHost", "ProxyUser", 
-                "PluginRepositoryUrl", "DownloadPath", 
-                "BrowsersFileFilters"]:
+                "PluginRepositoryUrl", "DownloadPath"]:
         return prefClass.settings.value("UI/" + key,
             QtCore.QVariant(prefClass.uiDefaults[key])).toString()
     if key == "ProxyPassword":
@@ -1262,9 +1207,6 @@ def getEditor(key, prefClass = Prefs):
                "SpellCheckingPersonalExcludeList"]:
         return prefClass.settings.value("Editor/" + key,
             QtCore.QVariant(prefClass.editorDefaults[key])).toString()
-    elif key in ["AdditionalOpenFilters", "AdditionalSaveFilters"]:
-        return prefClass.settings.value("Editor/" + key, 
-            QtCore.QVariant(prefClass.editorDefaults[key])).toStringList()
     else:
         return prefClass.settings.value("Editor/" + key,
             QtCore.QVariant(prefClass.editorDefaults[key])).toInt()[0]
@@ -1355,30 +1297,6 @@ def setEditorAPI(key, apilist, prefClass = Prefs):
     """
     prefClass.settings.setValue("Editor/APIs/" + key, QtCore.QVariant(apilist))
     
-def getEditorKeywords(key, prefClass = Prefs):
-    """
-    Module function to retrieve the various lists of language keywords.
-    
-    @param key the key of the value to get
-    @param prefClass preferences class used as the storage area
-    @return the requested list of language keywords (QStringList)
-    """
-    keywords = prefClass.settings.value("Editor/Keywords/" + key)
-    if keywords.isValid():
-        return keywords.toStringList()
-    else:
-        return QtCore.QStringList()
-    
-def setEditorKeywords(key, keywordsLists, prefClass = Prefs):
-    """
-    Module function to store the various lists of language keywords.
-    
-    @param key the key of the api to be set
-    @param keywordsLists the list of language keywords (QStringList)
-    @param prefClass preferences class used as the storage area
-    """
-    prefClass.settings.setValue("Editor/Keywords/" + key, QtCore.QVariant(keywordsLists))
-    
 def getEditorLexerAssocs(prefClass = Prefs):
     """
     Module function to retrieve all lexer associations.
@@ -1408,12 +1326,12 @@ def getEditorLexerAssocs(prefClass = Prefs):
             editorLexerAssoc[key] = \
                 prefClass.settings.value("Editor/LexerAssociations/" + key,
                     QtCore.QVariant(defaultValue)).toString()
-        
-        # check for new default lexer associations
-        for key in editorLexerAssocDefaults.keys():
-            if not editorLexerAssoc.has_key(key):
-                editorLexerAssoc[key] = \
-                    QtCore.QString(editorLexerAssocDefaults[key])
+        if len(editorLexerAssoc.keys()) < len(editorLexerAssocDefaults.keys()):
+            # new default lexer associations
+            for key in editorLexerAssocDefaults.keys():
+                if not editorLexerAssoc.has_key(key):
+                    editorLexerAssoc[key] = \
+                        QtCore.QString(editorLexerAssocDefaults[key])
     return editorLexerAssoc
     
 def setEditorLexerAssocs(assocs, prefClass = Prefs):
@@ -1573,6 +1491,40 @@ def setShell(key, value, prefClass = Prefs):
     else:
         prefClass.settings.setValue("Shell/" + key, QtCore.QVariant(value))
 
+def getTerminal(key, prefClass = Prefs):
+    """
+    Module function to retrieve the various terminal settings.
+    
+    @param key the key of the value to get
+    @param prefClass preferences class used as the storage area
+    @return the requested shell setting
+    """
+    if key in ["Shell"]:
+        return prefClass.settings.value("Terminal/" + key,
+            QtCore.QVariant(prefClass.terminalDefaults[key])).toString()
+    elif key in ["MonospacedFont", "MarginsFont"]:
+        f = QtGui.QFont()
+        f.fromString(prefClass.settings.value("Terminal/" + key,
+            QtCore.QVariant(prefClass.terminalDefaults[key])).toString())
+        return f
+    else:
+        return prefClass.settings.value("Terminal/" + key,
+            QtCore.QVariant(prefClass.terminalDefaults[key])).toInt()[0]
+
+def setTerminal(key, value, prefClass = Prefs):
+    """
+    Module function to store the various terminal settings.
+    
+    @param key the key of the setting to be set
+    @param value the value to be set
+    @param prefClass preferences class used as the storage area
+    """
+    if key in ["MonospacedFont", "MarginsFont"]:
+        prefClass.settings.setValue("Terminal/" + key,
+            QtCore.QVariant(value.toString()))
+    else:
+        prefClass.settings.setValue("Terminal/" + key, QtCore.QVariant(value))
+
 def getProject(key, prefClass = Prefs):
     """
     Module function to retrieve the various project handling settings.
@@ -1671,12 +1623,8 @@ def getMultiProject(key, prefClass = Prefs):
     @param prefClass preferences class used as the storage area
     @return the requested project setting
     """
-    if key in ["OpenMasterAutomatically", "XMLTimestamp", "RecentNumber"]:
-        return prefClass.settings.value("MultiProject/" + key,
-            QtCore.QVariant(prefClass.multiProjectDefaults[key])).toInt()[0]
-    else:
-        return prefClass.settings.value("MultiProject/" + key,
-            QtCore.QVariant(prefClass.multiProjectDefaults[key])).toString()
+    return prefClass.settings.value("MultiProject/" + key,
+        QtCore.QVariant(prefClass.multiProjectDefaults[key])).toInt()[0]
     
 def setMultiProject(key, value, prefClass = Prefs):
     """
@@ -1695,13 +1643,12 @@ def getQt4DocDir(prefClass = Prefs):
     @param prefClass preferences class used as the storage area
     @return the requested Qt4DocDir setting (string)
     """
-    s = unicode(prefClass.settings.value("Help/Qt4DocDir",
-        QtCore.QVariant(prefClass.helpDefaults["Qt4DocDir"])).toString())
-    if s == "":
-        s = os.getenv("QT4DOCDIR", "")
-    if s == "":
-        s = unicode(QtCore.QLibraryInfo.location(QtCore.QLibraryInfo.DocumentationPath))
-    return s
+    s = prefClass.settings.value("Help/Qt4DocDir",
+        QtCore.QVariant(prefClass.helpDefaults["Qt4DocDir"])).toString()
+    if s.isEmpty():
+        return os.getenv("QT4DOCDIR", "")
+    else:
+        return unicode(s)
     
 def getHelp(key, prefClass = Prefs):
     """
@@ -1711,9 +1658,6 @@ def getHelp(key, prefClass = Prefs):
     @param prefClass preferences class used as the storage area
     @return the requested help setting
     """
-    if not prefClass.webSettingsIntitialized:
-        prefClass.initWebSettingsDefaults()
-    
     if key in ["CustomViewer", \
                "PythonDocDir", "QtDocDir", "Qt4DocDir", "PyQt4DocDir", "PyKDE4DocDir", 
                "UserStyleSheet", "WebSearchEngine", "HomePage", "PySideDocDir", 
@@ -1816,10 +1760,9 @@ def getQt4TranslationsDir(prefClass = Prefs):
         QtCore.QVariant(prefClass.qtDefaults["Qt4TranslationsDir"])).toString())
     if s == "":
         s = os.getenv("QT4TRANSLATIONSDIR", "")
-    if s == "":
-        s = unicode(QtCore.QLibraryInfo.location(QtCore.QLibraryInfo.TranslationsPath))
     if s == "" and isWindowsPlatform():
-        transPath = os.path.join(getPyQt4ModulesDirectory(), "translations")
+        from PyQt4 import pyqtconfig
+        transPath = os.path.join(pyqtconfig._pkg_config["pyqt_mod_dir"], "translations")
         if os.path.exists(transPath):
             s = transPath
     return s
@@ -1838,11 +1781,8 @@ def getQt(key, prefClass = Prefs):
         return prefClass.settings.value("Qt/" + key, 
             QtCore.QVariant(prefClass.qtDefaults[key])).toString()
     elif key in ["Qt4Dir"]:
-        p = unicode(prefClass.settings.value("Qt/" + key, 
+        return unicode(prefClass.settings.value("Qt/" + key, 
             QtCore.QVariant(prefClass.qtDefaults[key])).toString())
-        if p == "":
-            p = unicode(QtCore.QLibraryInfo.location(QtCore.QLibraryInfo.BinariesPath))
-        return p
     else: 
         return prefClass.settings.value("Qt/" + key, 
             QtCore.QVariant(prefClass.qtDefaults[key])).toInt()[0]
@@ -1949,9 +1889,6 @@ def getTasks(key, prefClass = Prefs):
             return QtGui.QColor(col.toString())
         else:
             return prefClass.tasksDefaults[key]
-    elif key in ["ClearOnFileClose"]:
-        return prefClass.settings.value("Tasks/" + key,
-            QtCore.QVariant(prefClass.tasksDefaults[key])).toInt()[0]
     else:
         return prefClass.settings.value("Tasks/" + key,
             QtCore.QVariant(prefClass.tasksDefaults[key])).toString()
@@ -2074,27 +2011,6 @@ def setIconEditor(key, value, prefClass = Prefs):
     @param prefClass preferences class used as the storage area
     """
     prefClass.settings.setValue("IconEditor/" + key, QtCore.QVariant(value))
-
-def getTrayStarter(key, prefClass = Prefs):
-    """
-    Module function to retrieve the tray starter related settings.
-    
-    @param key the key of the value to get
-    @param prefClass preferences class used as the storage area
-    @return the requested user setting
-    """
-    return prefClass.settings.value("TrayStarter/" + key,
-            QtCore.QVariant(prefClass.trayStarterDefaults[key])).toString()
-    
-def setTrayStarter(key, value, prefClass = Prefs):
-    """
-    Module function to store the tray starter related settings.
-    
-    @param key the key of the setting to be set
-    @param value the value to be set
-    @param prefClass preferences class used as the storage area
-    """
-    prefClass.settings.setValue("TrayStarter/" + key, QtCore.QVariant(value))
     
 def getGeometry(key, prefClass = Prefs):
     """
