@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -186,8 +186,5 @@ class AddFileDialog(QDialog, Ui_AddFileDialog):
             source files, the target directory and a flag telling, whether
             the files shall be added as source code
         """
-        return (
-            [unicode(Utilities.toNativeSeparators(f))
-                for f in unicode(self.sourceFileEdit.text()).split(os.pathsep)],
-            unicode(Utilities.toNativeSeparators(self.targetDirEdit.text())),
-            self.sourcecodeCheckBox.isChecked())
+        return (unicode(self.sourceFileEdit.text()).split(os.pathsep), 
+            unicode(self.targetDirEdit.text()), self.sourcecodeCheckBox.isChecked())
