@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -195,6 +195,15 @@ class ProjectBaseBrowser(Browser):
         """
         self._resizeColumns(parent)
         
+    def __modelDataChanged(self, startIndex, endIndex):
+        """
+        Private slot called after data has been changed in the model.
+        
+        @param startIndex start index of the changed data (QModelIndex)
+        @param endIndex end index of the changed data (QModelIndex)
+        """
+        self._resizeColumns(startIndex)
+        
     def _projectClosed(self):
         """
         Protected slot to handle the projectClosed signal.
@@ -300,7 +309,7 @@ class ProjectBaseBrowser(Browser):
         @param fn filename of file to be highlighted (string or QString)
         """
         newfn = os.path.abspath(unicode(fn))
-        newfn = self.project.getRelativePath(newfn)
+        newfn = newfn.replace(self.project.ppath + os.sep, '')
         sindex = self._model.itemIndexByName(newfn)
         if sindex.isValid():
             index = self.model().mapFromSource(sindex)
