@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -122,11 +122,7 @@ class ProjectBrowserSimpleDirectoryItem(BrowserItem, ProjectBrowserItemMixin):
             self._dirName = os.path.dirname(self._dirName)
         
         self.type_ = ProjectBrowserItemSimpleDirectory
-        if os.path.lexists(self._dirName) and os.path.islink(self._dirName):
-            self.symlink = True
-            self.icon = UI.PixmapCache.getSymlinkIcon("dirClosed.png")
-        else:
-            self.icon = UI.PixmapCache.getIcon("dirClosed.png")
+        self.icon = UI.PixmapCache.getIcon("dirClosed.png")
     
     def setName(self, dinfo, full = True):
         """
@@ -222,11 +218,6 @@ class ProjectBrowserModel(BrowserModel):
         self.progDir = None
         self.project = parent
         
-        self.watchedItems = {}
-        self.watcher = QFileSystemWatcher(self)
-        self.connect(self.watcher, SIGNAL("directoryChanged(const QString&)"), 
-                     self.directoryChanged)
-        
         self.inRefresh = False
         
         self.projectBrowserTypes = {
@@ -241,7 +232,6 @@ class ProjectBrowserModel(BrowserModel):
         self.colorNames = {
             "A" : "VcsAdded",
             "M" : "VcsModified",
-            "O" : "VcsRemoved", 
             "R" : "VcsReplaced", 
             "U" : "VcsUpdate",
             "Z" : "VcsConflict",
@@ -250,7 +240,6 @@ class ProjectBrowserModel(BrowserModel):
             " " : QColor(),
             "A" : Preferences.getProjectBrowserColour(self.colorNames["A"]),
             "M" : Preferences.getProjectBrowserColour(self.colorNames["M"]),
-            "O" : Preferences.getProjectBrowserColour(self.colorNames["O"]),
             "R" : Preferences.getProjectBrowserColour(self.colorNames["R"]),
             "U" : Preferences.getProjectBrowserColour(self.colorNames["U"]),
             "Z" : Preferences.getProjectBrowserColour(self.colorNames["Z"]),
@@ -315,8 +304,6 @@ class ProjectBrowserModel(BrowserModel):
         @param parentItem reference to the directory item to be populated
         @param repopulate flag indicating a repopulation (boolean)
         """
-        self._addWatchedItem(parentItem)
-        
         qdir = QDir(parentItem.dirName())
         
         entryInfoList = \
@@ -361,11 +348,6 @@ class ProjectBrowserModel(BrowserModel):
         """
         self.__vcsStatus = {}
         
-        self.watchedItems = {}
-        watchedDirs = self.watcher.directories()
-        if len(watchedDirs) != 0:
-            self.watcher.removePaths(watchedDirs)
-        
         self.rootItem.removeChildren()
         self.reset()
         
@@ -386,7 +368,22 @@ class ProjectBrowserModel(BrowserModel):
                     states[os.path.normcase(os.path.join(self.project.ppath, fn))] = 0
             
             self.project.vcs.clearStatusCache()
-            states = self.project.vcs.vcsAllRegisteredStates(states, self.project.ppath)
+            for dir in self.project.subdirs:
+                states = self.project.vcs.vcsAllRegisteredStates(states, 
+                    os.path.join(self.project.ppath, dir))
+            
+            for dir in self.project.otherssubdirs:
+                if not os.path.isabs(dir):
+                    dir = os.path.join(self.project.ppath, dir)
+                states = self.project.vcs.vcsAllRegisteredStates(states, dir)
+            
+            if self.project.pdata["TRANSLATIONPATTERN"]:
+                dir = os.path.join(self.project.ppath, 
+                                   self.project.pdata["TRANSLATIONPATTERN"][0])\
+                      .split("%language%")[0]
+                if not os.path.isdir(dir):
+                    dir = os.path.dirname(dir)
+                states = self.project.vcs.vcsAllRegisteredStates(states, dir)
         
         self.inRefresh = True
         for key in keys:
@@ -425,7 +422,7 @@ class ProjectBrowserModel(BrowserModel):
 
     def findParentItemByName(self, type_, name, dontSplit = False):
         """
-        Public method to find an item given its name.
+        Public method to find an item given it's name.
         
         <b>Note</b>: This method creates all necessary parent items, if they
         don't exist.
@@ -547,14 +544,14 @@ class ProjectBrowserModel(BrowserModel):
     
     def findItem(self, name):
         """
-        Public method to find an item given its name.
+        Public method to find an item given it's name.
         
         @param name name of the item (string or QString)
         @return reference to the item found
         """
         name = QString(name)
         if QDir.isAbsolutePath(name):
-            name = self.project.getRelativePath(name)
+            name = name.replace(self.project.ppath + os.sep, "")
         pathlist = name.split(QRegExp(r'/|\\'))
         if len(pathlist) > 0:
             olditem = self.rootItem
@@ -569,7 +566,7 @@ class ProjectBrowserModel(BrowserModel):
     
     def itemIndexByName(self, name):
         """
-        Public method to find an item's index given its name.
+        Public method to find an item's index given it's name.
         
         @param name name of the item (string or QString)
         @return index of the item found (QModelIndex)
@@ -581,80 +578,6 @@ class ProjectBrowserModel(BrowserModel):
             index =  self.createIndex(itm.row(), 0, itm)
         return index
     
-    def directoryChanged(self, path):
-        """
-        Public slot to handle the directoryChanged signal of the watcher.
-        
-        @param path path of the directory (string)
-        """
-        path = unicode(path)
-        if path not in self.watchedItems:
-            # just ignore the situation we don't have a reference to the item
-            return
-        
-        for itm in self.watchedItems[path]:
-            oldCnt = itm.childCount()
-            
-            qdir = QDir(itm.dirName())
-            
-            entryInfoList = qdir.entryInfoList(
-                QDir.Filters(QDir.AllEntries | QDir.NoDotAndDotDot))
-            
-            # step 1: check for new entries
-            children = itm.children()
-            for f in entryInfoList:
-                fpath = unicode(Utilities.toNativeSeparators(f.absoluteFilePath()))
-                childFound = False
-                for child in children:
-                    if child.name() == fpath:
-                        childFound = True
-                        children.remove(child)
-                        break
-                if childFound:
-                    continue
-                
-                cnt = itm.childCount()
-                self.beginInsertRows(self.createIndex(itm.row(), 0, itm),
-                    cnt, cnt)
-                if f.isDir():
-                    node = ProjectBrowserDirectoryItem(itm,
-                        unicode(Utilities.toNativeSeparators(f.absoluteFilePath())), 
-                        itm.getProjectTypes()[0], 
-                        False)
-                else:
-                    node = ProjectBrowserFileItem(itm,
-                        unicode(Utilities.toNativeSeparators(f.absoluteFilePath())), 
-                        itm.getProjectTypes()[0])
-                self._addItem(node, itm)
-                if self.project.vcs is not None:
-                    self.project.vcs.clearStatusCache()
-                    state = self.project.vcs.vcsRegisteredState(node.name())
-                    if state == self.project.vcs.canBeCommitted:
-                        node.addVcsStatus(self.project.vcs.vcsName())
-                    else:
-                        node.addVcsStatus(self.trUtf8("local"))
-                self.endInsertRows()
-            
-            # step 2: check for removed entries
-            if len(entryInfoList) != itm.childCount():
-                for row in range(oldCnt - 1, -1, -1):
-                    child = itm.child(row)
-                    childname = Utilities.fromNativeSeparators(child.name())
-                    entryFound = False
-                    for f in entryInfoList:
-                        if unicode(f.absoluteFilePath()) == childname:
-                            entryFound = True
-                            entryInfoList.remove(f)
-                            break
-                    if entryFound:
-                        continue
-                    
-                    self._removeWatchedItem(child)
-                    self.beginRemoveRows(self.createIndex(itm.row(), 0, itm),
-                        row, row)
-                    itm.removeChild(child)
-                    self.endRemoveRows()
-    
     def __addVCSStatus(self, item, name):
         """
         Private method used to set the vcs status of a node.
@@ -677,7 +600,7 @@ class ProjectBrowserModel(BrowserModel):
         
         @param item item to work on
         @param name filename belonging to this item (string)
-        @keyparam recursive flag indicating a recursive update (boolean)
+        @param recursive flag indicating a recursive update (boolean)
         """
         if self.project.vcs is not None:
             self.project.vcs.clearStatusCache()
