@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -88,14 +88,10 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         
         # templates for Qt4
         # these two lists have to stay in sync
-        # TODO: extend this like in eric5
         self.templates4 = ['dialog4.tmpl', 'widget4.tmpl', 'mainwindow4.tmpl',
             'dialogbuttonboxbottom4.tmpl', 'dialogbuttonboxright4.tmpl',
             'dialogbuttonsbottom4.tmpl', 'dialogbuttonsbottomcenter4.tmpl',
-            'dialogbuttonsright4.tmpl', '', 'wizard4.tmpl', 'wizardpage4.tmpl',
-            'qdockwidget4.tmpl', 'qframe4.tmpl', 'qgroupbox4.tmpl',
-            'qscrollarea4.tmpl', 'qmdiarea4.tmpl', 'qtabwidget4.tmpl',
-            'qtoolbox4.tmpl', 'qstackedwidget4.tmpl']
+            'dialogbuttonsright4.tmpl']
         self.templateTypes4 = [ \
             unicode(self.trUtf8("Dialog")),
             unicode(self.trUtf8("Widget")),
@@ -105,17 +101,6 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             unicode(self.trUtf8("Dialog with Buttons (Bottom)")),
             unicode(self.trUtf8("Dialog with Buttons (Bottom-Center)")),
             unicode(self.trUtf8("Dialog with Buttons (Right)")),
-            '',
-            unicode(self.trUtf8("QWizard")),
-            unicode(self.trUtf8("QWizardPage")),
-            unicode(self.trUtf8("QDockWidget")),
-            unicode(self.trUtf8("QFrame")),
-            unicode(self.trUtf8("QGroupBox")),
-            unicode(self.trUtf8("QScrollArea")),
-            unicode(self.trUtf8("QMdiArea")),
-            unicode(self.trUtf8("QTabWidget")),
-            unicode(self.trUtf8("QToolBox")),
-            unicode(self.trUtf8("QStackedWidget")),
         ]
         self.formTypeList4 = QStringList()
         for tType in self.templateTypes4:
@@ -567,7 +552,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             self.project.getProjectType() in ["Qt4", "Kde4", "E4Plugin", "PySide"] and \
                 self.formTypeList4 or self.formTypeList,
             0, False)
-        if not ok or selectedForm.isEmpty():
+        if not ok:
             # user pressed cancel
             return
         
@@ -576,7 +561,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                 self.templateTypes4.index(unicode(selectedForm)) or \
                 self.templateTypes.index(unicode(selectedForm))
         templateFile = os.path.join(getConfig('ericTemplatesDir'),
-            self.project.getProjectType() in ["Qt4", "Kde4", "E4Plugin", "PySide"] and \
+            self.project.getProjectType() in ["Qt4", "Kde4", "E4Plugin""PySide"] and \
             self.templates4[templateIndex] or \
             self.templates[templateIndex])
         
@@ -618,7 +603,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             KQMessageBox.critical(self,
                 self.trUtf8("New Form"),
                 self.trUtf8("<p>The new form file <b>%1</b> could not be created.<br>"
-                    "Problem: %2</p>").arg(fname).arg(str(e)))
+                    "Problem: %2</p>").arg(fname).arg(unicode(e)))
             return
         
         self.project.appendFile(fname)
@@ -635,7 +620,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         for itm in itmList:
             fn2 = unicode(itm.fileName())
             fullNames.append(fn2)
-            fn = self.project.getRelativePath(fn2)
+            fn = fn2.replace(self.project.ppath+os.sep, '')
             files.append(fn)
         
         dlg = DeleteFilesConfirmationDialog(self.parent(),
@@ -695,7 +680,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             ofn = os.path.join(self.project.ppath, self.compiledFile)
             try:
                 f = open(ofn, "wb")
-                for line in unicode(self.buf, "utf8").splitlines():
+                for line in unicode(self.buf).splitlines():
                     f.write(line.encode("utf8") + os.linesep)
                 f.close()
                 if self.compiledFile not in self.project.pdata["SOURCES"]:
@@ -710,7 +695,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                     KQMessageBox.information(None,
                         self.trUtf8("Form Compilation"),
                         self.trUtf8("<p>The compilation of the form file failed.</p>"
-                            "<p>Reason: %1</p>").arg(str(msg)))
+                            "<p>Reason: %1</p>").arg(unicode(msg)))
         else:
             if not self.noDialog:
                 KQMessageBox.information(None,
@@ -746,7 +731,10 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                     uic = self.uicompiler
             elif self.project.getProjectType() == "PySide":
                 self.uicompiler = 'pyside-uic'
-                uic = Utilities.generatePySideToolPath(self.uicompiler)
+                if Utilities.isWindowsPlatform():
+                    uic = self.uicompiler + '.bat'
+                else:
+                    uic = self.uicompiler
             else:
                 return None
         elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
@@ -815,7 +803,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         fn = unicode(itm.fileName())
         
         if self.hooks["generateDialogCode"] is not None:
-            self.hooks["generateDialogCode"](fn)
+            self.hooks["generateDialogCode"](filename)
         else:
             from CreateDialogCodeDialog import CreateDialogCodeDialog
             
@@ -838,7 +826,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         """
         itm = self.model().item(self.currentIndex())
         fn2 = unicode(itm.fileName())
-        fn = self.project.getRelativePath(fn2)
+        fn = fn2.replace(self.project.ppath+os.sep, '')
         self.__compileUI(fn, subclass = True)
         
     def __compileForm(self):
@@ -889,7 +877,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         Private method to compile selected forms to source files.
         """
         items = self.getSelectedItems()
-        files = [self.project.getRelativePath(unicode(itm.fileName())) \
+        files = [unicode(itm.fileName()).replace(self.project.ppath+os.sep, '') \
                  for itm in items]
         
         if self.hooks["compileSelectedForms"] is not None:
