@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -538,13 +538,11 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
         for itm in itmList:
             if isinstance(itm, BrowserFileItem):
                 if itm.isPythonFile():
-                    self.emit(SIGNAL('sourceFile'), itm.fileName(), -1, "Python")
-                elif itm.isPython3File():
-                    self.emit(SIGNAL('sourceFile'), itm.fileName(), -1, "Python3")
+                    self.emit(SIGNAL('sourceFile'), itm.fileName(), 1, "Python")
                 elif itm.isRubyFile():
-                    self.emit(SIGNAL('sourceFile'), itm.fileName(), -1, "Ruby")
+                    self.emit(SIGNAL('sourceFile'), itm.fileName(), 1, "Ruby")
                 elif itm.isDFile():
-                    self.emit(SIGNAL('sourceFile'), itm.fileName(), -1, "D")
+                    self.emit(SIGNAL('sourceFile'), itm.fileName(), 1, "D")
                 else:
                     self.emit(SIGNAL('sourceFile'), itm.fileName())
             elif isinstance(itm, BrowserClassItem):
@@ -572,7 +570,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
         else:
             dn = ""
         
-        dn = self.project.getRelativePath(dn)
+        dn = dn.replace(self.project.ppath, "")
         if dn.startswith(os.sep):
             dn = dn[1:]
         dlg = NewPythonPackageDialog(dn, self)
@@ -586,13 +584,13 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
                 if not os.path.exists(packagePath):
                     try:
                         os.mkdir(packagePath)
-                    except OSError, err:
+                    except IOError, err:
                         KQMessageBox.critical(None,
                             self.trUtf8("Add new Python package"),
                             self.trUtf8("""<p>The package directory <b>%1</b> could"""
                                         """ not be created. Aborting...</p>"""
                                         """<p>Reason: %2</p>""")\
-                                .arg(packagePath).arg(str(err)),
+                                .arg(packagePath).arg(unicode(err)),
                             QMessageBox.StandardButtons(\
                                 QMessageBox.Ok))
                         return
@@ -607,7 +605,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
                             self.trUtf8("""<p>The package file <b>%1</b> could"""
                                         """ not be created. Aborting...</p>"""
                                         """<p>Reason: %2</p>""")\
-                                .arg(packageFile).arg(str(err)),
+                                .arg(packageFile).arg(unicode(err)),
                             QMessageBox.StandardButtons(\
                                 QMessageBox.Ok))
                         return
@@ -658,7 +656,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
         for itm in itmList:
             fn2 = unicode(itm.fileName())
             fullNames.append(fn2)
-            fn = self.project.getRelativePath(fn2)
+            fn = fn2.replace(self.project.ppath+os.sep, '')
             files.append(fn)
         
         dlg = DeleteFilesConfirmationDialog(self.parent(),
