@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -115,17 +115,15 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
                 self.vcsLabel.setText(\
                     self.trUtf8("The project is not version controlled."))
                 self.vcsInfoButton.hide()
-            self.vcsCheckBox.hide()
         else:
             self.projectTypeComboBox.setCurrentIndex(\
                 self.projectTypeComboBox.findText(projectTypes["Qt4"]))
-            hp = Preferences.getMultiProject("Workspace") or Utilities.getHomeDir()
+            hp = os.getcwd()
+            hp = hp + os.sep
             self.dirEdit.setText(hp)
             self.versionEdit.setText('0.1')
             self.vcsLabel.hide()
             self.vcsInfoButton.hide()
-            if not self.project.vcsSoftwareAvailable():
-                self.vcsCheckBox.hide()
         
     @pyqtSignature("")
     def on_dirButton_clicked(self):
@@ -242,7 +240,7 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         self.project.pdata["VERSION"] = [unicode(self.versionEdit.text())]
         fn = self.mainscriptEdit.text()
         if not fn.isEmpty():
-            fn = self.project.getRelativePath(unicode(fn))
+            fn = unicode(fn).replace(self.project.ppath+os.sep, "")
             self.project.pdata["MAINSCRIPT"] = [fn]
             self.project.translationsRoot = os.path.splitext(fn)[0]
         else:
@@ -258,8 +256,6 @@ class PropertiesDialog(QDialog, Ui_PropertiesDialog):
         if projectType is not None:
             self.project.pdata["PROJECTTYPE"] = [projectType]
         
-        self.project.vcsRequested = self.vcsCheckBox.isChecked()
-        
         if self.spellPropertiesDlg is not None:
             self.spellPropertiesDlg.storeData()
         
