@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -142,11 +142,12 @@ class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
         """
         Private slot to add the shown exception to the listwidget.
         """
-        texcept = unicode(self.exceptionEdit.text())
         if self.project.ppath == '':
-            texcept = texcept.replace(self.parent.getPPath() + os.sep, "")
+            ppath = self.parent.getPPath()
         else:
-            texcept = self.project.getRelativePath(texcept)
+            ppath = self.project.ppath
+        texcept = unicode(self.exceptionEdit.text())
+        texcept = texcept.replace(ppath + os.sep, "")
         if texcept.endswith(os.sep):
             texcept = texcept[:-1]
         if texcept:
@@ -207,14 +208,14 @@ class TranslationPropertiesDialog(QDialog, Ui_TranslationPropertiesDialog):
         """
         tp = Utilities.toNativeSeparators(self.transPatternEdit.text())
         if not tp.isEmpty():
-            tp = self.project.getRelativePath(unicode(tp))
+            tp = unicode(tp).replace(self.project.ppath+os.sep, "")
             self.project.pdata["TRANSLATIONPATTERN"] = [tp]
             self.project.translationsRoot = tp.split("%language%")[0]
         else:
             self.project.pdata["TRANSLATIONPATTERN"] = []
         tp = Utilities.toNativeSeparators(self.transBinPathEdit.text())
         if not tp.isEmpty():
-            tp = self.project.getRelativePath(unicode(tp))
+            tp = unicode(tp).replace(self.project.ppath+os.sep, "")
             self.project.pdata["TRANSLATIONSBINPATH"] = [tp]
         else:
             self.project.pdata["TRANSLATIONSBINPATH"] = []
