@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -38,17 +38,14 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
     
     @signal unittestFile(string,int,int) emitted to show the source of a unittest file
     """
-    def __init__(self, prog = None, dbs = None, ui = None, fromEric=False, parent = None,
-                 name = None):
+    def __init__(self,prog = None,dbs = None,ui = None,parent = None,name = None):
         """
         Constructor
         
         @param prog filename of the program to open
         @param dbs reference to the debug server object. It is an indication
-            whether we were called from within the eric4 IDE
+                whether we were called from within the eric4 IDE
         @param ui reference to the UI object
-        @param fromEric flag indicating an instantiation from within the
-            eric IDE (boolean)
         @param parent parent widget of this dialog (QWidget)
         @param name name of this dialog (string or QString)
         """
@@ -73,7 +70,6 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         self.startButton.setDefault(True)
         
         self.dbs = dbs
-        self.__fromEric = fromEric
         
         self.setWindowFlags(\
             self.windowFlags() | Qt.WindowFlags(Qt.WindowContextHelpButtonHint))
@@ -114,16 +110,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
                 self.testFailed)
             self.connect(self.dbs, SIGNAL('utTestErrored'),
                 self.testErrored)
-    
-    def keyPressEvent(self, evt):
-        """
-        Protected slot to handle key press events.
         
-        @param evt key press event to handle (QKeyEvent)
-        """
-        if evt.key() == Qt.Key_Escape and self.__fromEric:
-            self.close()
-    
     def __setProgressColor(self, color):
         """
         Private methode to set the color of the progress color label.
@@ -235,12 +222,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         self.sbLabel.setText(self.trUtf8("Preparing Testsuite"))
         QApplication.processEvents()
         
-        
-        testFunctionName = unicode(self.testComboBox.currentText())
-        if testFunctionName:
-            self.insertTestName(testFunctionName)
-        else:
-            testFunctionName = "suite"
+        testFunctionName = unicode(self.testComboBox.currentText()) or "suite"
         
         # build the module name from the filename without extension
         self.testName = os.path.splitext(os.path.basename(prog))[0]
@@ -292,8 +274,6 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
                     project = e4App().getObject("Project")
                     if project.isOpen() and project.isProjectSource(prog):
                         mainScript = project.getMainScript(True)
-                        if not mainScript:
-                            mainScript = os.path.abspath(prog)
                     else:
                         mainScript = os.path.abspath(prog)
                 else:
