@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -165,7 +165,8 @@ class APIs(QObject):
         """
         if self.__apis is not None:
             if Utilities.isWindowsPlatform():
-                qsciPath = os.path.join(Utilities.getPyQt4ModulesDirectory(), "qsci")
+                from PyQt4 import pyqtconfig
+                qsciPath = os.path.join(pyqtconfig._pkg_config["pyqt_mod_dir"], "qsci")
                 if os.path.exists(qsciPath):
                     # it's the installer
                     apidir = os.path.join(qsciPath, "api", self.__lexer.lexer())
