@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -361,7 +361,7 @@ class ExporterHTML(ExporterBase):
                     self.trUtf8(\
                         """<p>The source could not be exported to <b>%1</b>.</p>"""
                         """<p>Reason: %2</p>""")\
-                        .arg(filename).arg(str(err)),
+                        .arg(filename).arg(unicode(err)),
                     QMessageBox.StandardButtons(\
                         QMessageBox.Ok))
         finally:
