@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -202,20 +202,3 @@ class Lexer(object):
         @return flag indicating a string style (boolean)
         """
         return True
-    
-    def keywords(self, kwSet):
-        """
-        Public method to get the keywords.
-        
-        @param kwSet number of the keyword set (integer)
-        @return string giving the keywords (string) or None
-        """
-        keywords_ = Preferences.getEditorKeywords(self.language())
-        if not keywords_.isEmpty():
-            kw = unicode(keywords_[kwSet])
-            if kw == "":
-                return None
-            else:
-                return kw
-        else:
-            return self.defaultKeywords(kwSet)
