@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -59,12 +59,3 @@ class LexerFortran(QsciLexerFortran, Lexer):
         return style in [QsciLexerFortran.DoubleQuotedString, 
                          QsciLexerFortran.SingleQuotedString, 
                          QsciLexerFortran.UnclosedString]
-    
-    def defaultKeywords(self, kwSet):
-        """
-        Public method to get the default keywords.
-        
-        @param kwSet number of the keyword set (integer)
-        @return string giving the keywords (string) or None
-        """
-        return QsciLexerFortran.keywords(self, kwSet)
