@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -73,12 +73,3 @@ class LexerJavaScript(QsciLexerJavaScript, Lexer):
                          QsciLexerJavaScript.SingleQuotedString, 
                          QsciLexerJavaScript.UnclosedString, 
                          QsciLexerJavaScript.VerbatimString]
-    
-    def defaultKeywords(self, kwSet):
-        """
-        Public method to get the default keywords.
-        
-        @param kwSet number of the keyword set (integer)
-        @return string giving the keywords (string) or None
-        """
-        return QsciLexerJavaScript.keywords(self, kwSet)
