@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -60,12 +60,3 @@ class LexerLua(QsciLexerLua, Lexer):
         return style in [QsciLexerLua.String, 
                          QsciLexerLua.LiteralString, 
                          QsciLexerLua.UnclosedString]
-    
-    def defaultKeywords(self, kwSet):
-        """
-        Public method to get the default keywords.
-        
-        @param kwSet number of the keyword set (integer)
-        @return string giving the keywords (string) or None
-        """
-        return QsciLexerLua.keywords(self, kwSet)
