@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -320,11 +320,10 @@ class LexerPygments(LexerContainer):
             # step 1: guess based on filename and text
             if self.editor is not None:
                 fn = self.editor.getFileName()
-                if fn:
-                    try:
-                        lexer = guess_lexer_for_filename(fn, text)
-                    except ClassNotFound:
-                        pass
+                try:
+                    lexer = guess_lexer_for_filename(fn, text)
+                except ClassNotFound:
+                    pass
             
             # step 2: guess on text only
             if lexer is None:
@@ -368,17 +367,9 @@ class LexerPygments(LexerContainer):
         @param end position of last character to be styled (integer)
         """
         text = unicode(self.editor.text())[:end + 1].encode('utf-8')
-        textLen = len(text)
         self.__lexer = self.__guessLexer(text)
         
         cpos = 0
-        # adjust start position because pygments ignores empty line at start of text
-        for c in text:
-            if c == "\n":
-                cpos += 1
-            else:
-                break
-        
         self.editor.startStyling(cpos, 0x3f)
         if self.__lexer is None:
             self.editor.setStyling(len(text), PYGMENTS_DEFAULT)
@@ -387,15 +378,12 @@ class LexerPygments(LexerContainer):
             for token, txt in self.__lexer.get_tokens(text):
                 style = TOKEN_MAP.get(token, PYGMENTS_DEFAULT)
                 
-##                tlen = len(txt.encode('utf-8'))
                 tlen = len(txt)
                 if eolLen > 1:
                     tlen += txt.count('\n')
-                cpos += tlen
-                if tlen and cpos < textLen:
+                if tlen:
                     self.editor.setStyling(tlen, style)
-                if cpos >= textLen:
-                    break
+                cpos += tlen
             self.editor.startStyling(cpos, 0x3f)
     
     def isCommentStyle(self, style):
@@ -415,12 +403,3 @@ class LexerPygments(LexerContainer):
         return style in [PYGMENTS_STRING, PYGMENTS_DOCSTRING, PYGMENTS_OTHER, 
                          PYGMENTS_HEADING, PYGMENTS_SUBHEADING, PYGMENTS_EMPHASIZE, 
                          PYGMENTS_STRONG]
-    
-    def defaultKeywords(self, kwSet):
-        """
-        Public method to get the default keywords.
-        
-        @param kwSet number of the keyword set (integer)
-        @return string giving the keywords (string) or None
-        """
-        return None
