@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -33,14 +33,7 @@ class LexerTCL(QsciLexerTCL, Lexer):
         """
         Public slot to initialize the properties.
         """
-        try:
-            self.setFoldCompact(Preferences.getEditor("AllFoldCompact"))
-        except AttributeError:
-            pass
-        try:
-            self.setFoldComments(Preferences.getEditor("TclFoldComment"))
-        except AttributeError:
-            pass
+        self.setFoldCompact(Preferences.getEditor("AllFoldCompact"))
     
     def isCommentStyle(self, style):
         """
@@ -60,12 +53,3 @@ class LexerTCL(QsciLexerTCL, Lexer):
         @return flag indicating a string style (boolean)
         """
         return style in [QsciLexerTCL.QuotedString]
-    
-    def defaultKeywords(self, kwSet):
-        """
-        Public method to get the default keywords.
-        
-        @param kwSet number of the keyword set (integer)
-        @return string giving the keywords (string) or None
-        """
-        return QsciLexerTCL.keywords(self, kwSet)
