@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -56,12 +56,3 @@ class LexerVHDL(QsciLexerVHDL, Lexer):
         """
         return style in [QsciLexerVHDL.String, 
                          QsciLexerVHDL.UnclosedString]
-    
-    def defaultKeywords(self, kwSet):
-        """
-        Public method to get the default keywords.
-        
-        @param kwSet number of the keyword set (integer)
-        @return string giving the keywords (string) or None
-        """
-        return QsciLexerVHDL.keywords(self, kwSet)
