@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -37,7 +37,7 @@ def registerLexer(name, displayString, filenameSample, getLexerFunc,
     @param displayString display string (QString)
     @param filenameSample dummy filename to derive lexer name (string)
     @param getLexerFunc reference to a function instantiating the specific lexer.
-        This function must take a reference to the parent as its only argument.
+        This function must take a reference to the parent as it's only argument.
     @keyparam openFilters list of open file filters (QStringList)
     @keyparam saveFilters list of save file filters (QStringList)
     @keyparam defaultAssocs default lexer associations (list of strings of filename 
@@ -95,21 +95,19 @@ def getSupportedLanguages():
     }
     
     if QSCINTILLA_VERSION() >= 0x020201:
-        supportedLanguages.update({
-            "TCL"        : [QApplication.translate('Lexers', "TCL"), 'dummy.tcl'], 
-            "Fortran"    : [QApplication.translate('Lexers', "Fortran"), 'dummy.f95'], 
-            "Fortran77"  : [QApplication.translate('Lexers', "Fortran77"), 'dummy.f'], 
-            "Pascal"     : [QApplication.translate('Lexers', "Pascal"), 'dummy.pas'], 
-            "PostScript" : [QApplication.translate('Lexers', "PostScript"), 'dummy.ps'], 
-            "XML"        : [QApplication.translate('Lexers', "XML"), 'dummy.xml'], 
-            "YAML"       : [QApplication.translate('Lexers', "YAML"), 'dummy.yml'], 
-        })
-    
-    if QSCINTILLA_VERSION() >= 0x020501:
-        supportedLanguages.update({
-            "Matlab": [QApplication.translate('Lexers', "Matlab"), 'dummy.m.matlab'],
-            "Octave": [QApplication.translate('Lexers', "Octave"), 'dummy.m.octave'],
-        })
+        supportedLanguages["TCL"] = [QApplication.translate('Lexers', "TCL"), 'dummy.tcl']
+        supportedLanguages["Fortran"] = \
+            [QApplication.translate('Lexers', "Fortran"), 'dummy.f95']
+        supportedLanguages["Fortran77"] = \
+            [QApplication.translate('Lexers', "Fortran77"), 'dummy.f']
+        supportedLanguages["Pascal"] = \
+            [QApplication.translate('Lexers', "Pascal"), 'dummy.pas']
+        supportedLanguages["PostScript"] = \
+            [QApplication.translate('Lexers', "PostScript"), 'dummy.ps']
+        supportedLanguages["XML"] = \
+            [QApplication.translate('Lexers', "XML"), 'dummy.xml']
+        supportedLanguages["YAML"] = \
+            [QApplication.translate('Lexers', "YAML"), 'dummy.yml']
     
     for name in LexerRegistry:
         supportedLanguages[name] = LexerRegistry[name][:2]
@@ -218,12 +216,6 @@ def getLexer(language, parent = None, pyname = ""):
             elif language == "YAML":
                 from LexerYAML import LexerYAML
                 return LexerYAML(parent)
-            elif language == "Matlab":
-                from .LexerMatlab import LexerMatlab
-                return LexerMatlab(parent)
-            elif language == "Octave":
-                from .LexerOctave import LexerOctave
-                return LexerOctave(parent)
             
             elif language in LexerRegistry:
                 return LexerRegistry[language][2](parent)
@@ -250,7 +242,7 @@ def __getPygmentsLexer(parent, name = ""):
     else:
         return None
     
-def getOpenFileFiltersList(includeAll = False, asString = False, withAdditional = True):
+def getOpenFileFiltersList(includeAll = False, asString = False):
     """
     Module function to get the file filter list for an open file operation.
     
@@ -258,8 +250,6 @@ def getOpenFileFiltersList(includeAll = False, asString = False, withAdditional
         All Files filter (boolean)
     @param asString flag indicating the list should be returned 
         as a string (boolean)
-    @keyparam withAdditional flag indicating to include additional filters
-        defined by the user (boolean)
     @return file filter list (QStringList or QString)
     """
     openFileFiltersList = QStringList() \
@@ -341,19 +331,9 @@ def getOpenFileFiltersList(includeAll = False, asString = False, withAdditional
             << QApplication.translate('Lexers', 
                 'YAML Files (*.yaml *.yml)')
     
-    if QSCINTILLA_VERSION() >= 0x020501:
-        openFileFiltersList \
-            << QApplication.translate('Lexers',
-                'Matlab Files (*.m *.m.matlab)') \
-            << QApplication.translate('Lexers',
-                'Octave Files (*.m *.m.octave)')
-    
     for name in LexerRegistry:
         openFileFiltersList << LexerRegistry[name][3]
     
-    if withAdditional:
-        openFileFiltersList += Preferences.getEditor("AdditionalOpenFilters")
-    
     openFileFiltersList.sort()
     if includeAll:
         openFileFiltersList.append(QApplication.translate('Lexers', 'All Files (*)'))
@@ -363,7 +343,7 @@ def getOpenFileFiltersList(includeAll = False, asString = False, withAdditional
     else:
         return openFileFiltersList
 
-def getSaveFileFiltersList(includeAll = False, asString = False, withAdditional = True):
+def getSaveFileFiltersList(includeAll = False, asString = False):
     """
     Module function to get the file filter list for a save file operation.
     
@@ -371,8 +351,6 @@ def getSaveFileFiltersList(includeAll = False, asString = False, withAdditional
         All Files filter (boolean)
     @param asString flag indicating the list should be returned 
         as a string (boolean)
-    @keyparam withAdditional flag indicating to include additional filters
-        defined by the user (boolean)
     @return file filter list (QStringList or QString)
     """
     saveFileFiltersList = QStringList() \
@@ -478,19 +456,9 @@ def getSaveFileFiltersList(includeAll = False, asString = False, withAdditional
             << QApplication.translate('Lexers', 
                 'YAML Files (*.yml)')
     
-    if QSCINTILLA_VERSION() >= 0x020501:
-        saveFileFiltersList \
-            << QApplication.translate('Lexers',
-                'Matlab Files (*.m)') \
-            << QApplication.translate('Lexers',
-                'Octave Files (*.m.octave)')
-    
     for name in LexerRegistry:
         saveFileFiltersList << LexerRegistry[name][4]
     
-    if withAdditional:
-        saveFileFiltersList += Preferences.getEditor("AdditionalSaveFilters")
-    
     saveFileFiltersList.sort()
     
     if includeAll:
@@ -502,11 +470,6 @@ def getSaveFileFiltersList(includeAll = False, asString = False, withAdditional
         return saveFileFiltersList
 
 def getDefaultLexerAssociations():
-    """
-    Module function to get a dictionary with the default associations.
-    
-    @return dictionary with the default lexer associations
-    """
     assocs = {
         '*.sh'              : "Bash",
         '*.bash'            : "Bash",
@@ -600,39 +563,30 @@ def getDefaultLexerAssociations():
     }
     
     if QSCINTILLA_VERSION() >= 0x020201:
-        assocs.update({
-            "*.tcl"  : "TCL", 
-            "*.tk"   : "TCL", 
-            "*.f"    : "Fortran77", 
-            "*.for"  : "Fortran77", 
-            "*.f90"  : "Fortran", 
-            "*.f95"  : "Fortran", 
-            "*.f2k"  : "Fortran", 
-            "*.dpr"  : "Pascal", 
-            "*.dpk"  : "Pascal", 
-            "*.pas"  : "Pascal", 
-            "*.dfm"  : "Pascal", 
-            "*.inc"  : "Pascal", 
-            "*.pp"   : "Pascal", 
-            "*.ps"   : "PostScript", 
-            "*.xml"  : "XML", 
-            "*.xsl"  : "XML", 
-            "*.svg"  : "XML", 
-            "*.xsd"  : "XML", 
-            "*.xslt" : "XML", 
-            "*.dtd"  : "XML", 
-            "*.rdf"  : "XML", 
-            "*.xul"  : "XML", 
-            "*.yaml" : "YAML", 
-            "*.yml"  : "YAML", 
-        })
-    
-    if QSCINTILLA_VERSION() >= 0x020501:
-        assocs.update({
-            '*.m': "Matlab", 
-            '*.m.matlab': "Matlab", 
-            '*.m.octave': "Octave", 
-        })
+        assocs["*.tcl"]  = "TCL"
+        assocs["*.tk"]   = "TCL"
+        assocs["*.f"]    = "Fortran77"
+        assocs["*.for"]  = "Fortran77"
+        assocs["*.f90"]  = "Fortran"
+        assocs["*.f95"]  = "Fortran"
+        assocs["*.f2k"]  = "Fortran"
+        assocs["*.dpr"]  = "Pascal"
+        assocs["*.dpk"]  = "Pascal"
+        assocs["*.pas"]  = "Pascal"
+        assocs["*.dfm"]  = "Pascal"
+        assocs["*.inc"]  = "Pascal"
+        assocs["*.pp"]   = "Pascal"
+        assocs["*.ps"]   = "PostScript"
+        assocs["*.xml"]  = "XML"
+        assocs["*.xsl"]  = "XML"
+        assocs["*.svg"]  = "XML"
+        assocs["*.xsd"]  = "XML"
+        assocs["*.xslt"] = "XML"
+        assocs["*.dtd"]  = "XML"
+        assocs["*.rdf"]  = "XML"
+        assocs["*.xul"]  = "XML"
+        assocs["*.yaml"] = "YAML"
+        assocs["*.yml"]  = "YAML"
     
     for name in LexerRegistry:
         for pattern in LexerRegistry[name][5]:
