@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,8 +12,7 @@ import sys
 from PyQt4.QtCore import Qt, SIGNAL, QString
 from PyQt4.QtGui import QApplication, QPalette
 from PyQt4.Qsci import QsciScintilla, \
-    QSCINTILLA_VERSION as QsciQSCINTILLA_VERSION, QSCINTILLA_VERSION_STR, \
-    QsciScintillaBase
+    QSCINTILLA_VERSION as QsciQSCINTILLA_VERSION, QSCINTILLA_VERSION_STR
 
 
 #####################################################################################
@@ -100,21 +99,11 @@ class QsciScintillaCompat(QsciScintilla):
         except AttributeError:
             rangeHigh = range(40, 128)
         
-        f = font.family()
+        f = str(font.family())
         ps = font.pointSize()
-        weight = -font.weight()
-        italic = font.italic()
-        underline = font.underline()
-        bold = font.bold()
         for style in rangeLow + rangeHigh:
-            self.SendScintilla(QsciScintilla.SCI_STYLESETFONT, style, f.toLatin1().data())
+            self.SendScintilla(QsciScintilla.SCI_STYLESETFONT, style, f)
             self.SendScintilla(QsciScintilla.SCI_STYLESETSIZE, style, ps)
-            try:
-                self.SendScintilla(QsciScintilla.SCI_STYLESETWEIGHT, style, weight)
-            except AttributeError:
-                self.SendScintilla(QsciScintilla.SCI_STYLESETBOLD, style, bold)
-            self.SendScintilla(QsciScintilla.SCI_STYLESETITALIC, style, italic);
-            self.SendScintilla(QsciScintilla.SCI_STYLESETUNDERLINE, style, underline);
     
     def linesOnScreen(self):
         """
@@ -464,25 +453,6 @@ class QsciScintillaCompat(QsciScintilla):
         """
         self.SendScintilla(QsciScintilla.SCI_LINEENDEXTEND)
     
-    def hasSelection(self):
-        """
-        Public method to check for a selection.
-        
-        @return flag indicating the presence of a selection (boolean)
-        """
-        return self.getSelection()[0] != -1
-    
-    def selectionIsRectangle(self):
-        """
-        Public method to check, if the current selection is rectangular.
-        
-        @return flag indicating a rectangular selection (boolean)
-        """
-        startLine, startIndex, endLine, endIndex = self.getSelection()
-        return startLine != -1 and \
-               startLine != endLine and \
-               self.SendScintilla(QsciScintilla.SCI_SELECTIONISRECTANGLE)
-    
     def getLineSeparator(self):
         """
         Public method to get the line separator for the current eol mode.
@@ -537,11 +507,12 @@ class QsciScintillaCompat(QsciScintilla):
         @param txt text from which to determine the eol string (string)
         @return eol string (string)
         """
-        if len(txt.split("\r\n", 1)) == 2:
+        utxt = unicode(txt)
+        if len(utxt.split("\r\n", 1)) == 2:
             return '\r\n'
-        elif len(txt.split("\n", 1)) == 2:
+        elif len(utxt.split("\n", 1)) == 2:
             return '\n'
-        elif len(txt.split("\r", 1)) == 2:
+        elif len(utxt.split("\r", 1)) == 2:
             return '\r'
         else:
             return None
@@ -669,14 +640,9 @@ class QsciScintillaCompat(QsciScintilla):
         self.SendScintilla(QsciScintilla.SCI_SETTARGETSTART, self.__targetSearchStart)
         self.SendScintilla(QsciScintilla.SCI_SETTARGETEND, self.__targetSearchEnd)
         self.SendScintilla(QsciScintilla.SCI_SETSEARCHFLAGS, self.__targetSearchFlags)
-        
-        if self.isUtf8():
-            targetSearchExpr = QString(self.__targetSearchExpr).toUtf8().data()
-        else:
-            targetSearchExpr = QString(self.__targetSearchExpr).toLatin1().data()
         pos = self.SendScintilla(QsciScintilla.SCI_SEARCHINTARGET, 
-                                 len(targetSearchExpr), 
-                                 targetSearchExpr)
+                                 len(self.__targetSearchExpr), 
+                                 self.__targetSearchExpr)
         
         if pos == -1:
             self.__targetSearchActive = False
@@ -936,23 +902,12 @@ class QsciScintillaCompat(QsciScintilla):
         """
         Public method called when the editor loses focus.
         
-        @param event event object (QFocusEvent)
+        @param event the event object (QFocusEvent)
         """
         if self.isListActive():
             self.cancelList()
         
         QsciScintilla.focusOutEvent(self, event)
-    
-    def event(self, evt):
-        """
-        Public method to handle events.
-        
-        Note: We are not interested in the standard QsciScintilla event handling
-        because we do it our self.
-        
-        @param evt event object to handle (QEvent)
-        """
-        return QsciScintillaBase.event(self, evt)
 
     #####################################################################################
     # interface methods to the mini editor
