@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -70,7 +70,7 @@ expression, special characters interpreted are:</p>
 <tr><td><code>.</code></td><td>Matches any character</td></tr>
 <tr><td><code>\(</code></td><td>This marks the start of a region for tagging a match.</td></tr>
 <tr><td><code>\)</code></td><td>This marks the end of a tagged region.</td></tr>
-<tr><td><code>\\n</code></td>
+<tr><td><code>\n</code></td>
 <td>Where <code>n</code> is 1 through 9 refers to the first through ninth tagged region
 when replacing. For example, if the search string was <code>Fred\([1-9]\)XXX</code> and
 the replace string was <code>Sam\1YYY</code>, when applied to <code>Fred2XXX</code> this
@@ -79,9 +79,9 @@ would generate <code>Sam2YYY</code>.</td></tr>
 <td>This matches the start of a word using Scintilla's definitions of words.</td></tr>
 <tr><td><code>\&gt;</code></td>
 <td>This matches the end of a word using Scintilla's definition of words.</td></tr>
-<tr><td><code>\\x</code></td>
+<tr><td><code>\x</code></td>
 <td>This allows you to use a character x that would otherwise have a special meaning. For
-example, \\[ would be interpreted as [ and not as the start of a character set.</td></tr>
+example, \[ would be interpreted as [ and not as the start of a character set.</td></tr>
 <tr><td><code>[...]</code></td>
 <td>This indicates a set of characters, for example, [abc] means any of the characters a,
 b or c. You can also use ranges, for example [a-z] for any lower case character.</td></tr>
@@ -107,12 +107,8 @@ character except an alphabetic character.</td></tr>
         self.ui.findNextButton.setIcon(UI.PixmapCache.getIcon("1rightarrow.png"))
         
         if replace:
-            self.ui.replaceButton.setIcon(
-                UI.PixmapCache.getIcon("editReplace.png"))
-            self.ui.replaceSearchButton.setIcon(
-                UI.PixmapCache.getIcon("editReplaceSearch.png"))
-            self.ui.replaceAllButton.setIcon(
-                UI.PixmapCache.getIcon("editReplaceAll.png"))
+            self.ui.replaceButton.setIcon(UI.PixmapCache.getIcon("editReplace.png"))
+            self.ui.replaceAllButton.setIcon(UI.PixmapCache.getIcon("editReplaceAll.png"))
         
         self.connect(self.ui.findtextCombo.lineEdit(), SIGNAL("returnPressed()"), 
                      self.__findByReturnPressed)
@@ -135,14 +131,12 @@ character except an alphabetic character.</td></tr>
             self.ui.findPrevButton.setEnabled(False)
             if self.replace:
                 self.ui.replaceButton.setEnabled(False)
-                self.ui.replaceSearchButton.setEnabled(False)
                 self.ui.replaceAllButton.setEnabled(False)
         else:
             self.ui.findNextButton.setEnabled(True)
             self.ui.findPrevButton.setEnabled(True)
             if self.replace:
                 self.ui.replaceButton.setEnabled(False)
-                self.ui.replaceSearchButton.setEnabled(False)
                 self.ui.replaceAllButton.setEnabled(True)
 
     @pyqtSignature("")
@@ -175,7 +169,6 @@ character except an alphabetic character.</td></tr>
         if ok:
             if self.replace:
                 self.ui.replaceButton.setEnabled(True)
-                self.ui.replaceSearchButton.setEnabled(True)
         else:
             KQMessageBox.information(self, self.windowTitle(),
                 self.trUtf8("'%1' was not found.").arg(txt))
@@ -210,7 +203,6 @@ character except an alphabetic character.</td></tr>
         if ok:
             if self.replace:
                 self.ui.replaceButton.setEnabled(True)
-                self.ui.replaceSearchButton.setEnabled(True)
         else:
             KQMessageBox.information(self, self.windowTitle(),
                 self.trUtf8("'%1' was not found.").arg(txt))
@@ -249,8 +241,6 @@ character except an alphabetic character.</td></tr>
                 lineFrom, indexFrom, lineTo, indexTo)
         while ok:
             tgtPos, tgtLen = aw.getFoundTarget()
-            if tgtLen == 0:
-                break
             aw.setSearchIndicator(tgtPos, tgtLen)
             ok = aw.findNextTarget()
     
@@ -279,13 +269,8 @@ character except an alphabetic character.</td></tr>
                 line = self.__selection[2]
                 index = self.__selection[3]
             else:
-                if (lineFrom, indexFrom) == (-1, -1):
-                    # no selection present
-                    line = cline
-                    index = cindex
-                else:
-                    line = lineFrom
-                    index = indexFrom
+                line = lineFrom
+                index = indexFrom - 1
             if self.ui.selectionCheckBox.isChecked() and \
                line == self.__selection[0] and \
                index >= 0 and \
@@ -390,7 +375,6 @@ character except an alphabetic character.</td></tr>
         self.ui.findtextCombo.setEditText(text)
         self.ui.findtextCombo.lineEdit().selectAll()
         self.ui.findtextCombo.setFocus()
-        self.on_findtextCombo_editTextChanged(text)
         
         self.ui.caseCheckBox.setChecked(False)
         self.ui.wordCheckBox.setChecked(False)
@@ -417,7 +401,7 @@ character except an alphabetic character.</td></tr>
         @param editor reference to the editor (Editor)
         """
         if not self.__finding:
-            if editor.hasSelectedText() and not editor.selectionIsRectangle():
+            if editor.hasSelectedText():
                 line1, index1, line2, index2 = editor.getSelection()
                 if line1 != line2:
                     self.ui.selectionCheckBox.setEnabled(True)
@@ -434,26 +418,10 @@ character except an alphabetic character.</td></tr>
         """
         Private slot to replace one occurrence of text.
         """
-        self.__doReplace(False)
-    
-    @pyqtSignature("")
-    def on_replaceSearchButton_clicked(self):
-        """
-        Private slot to replace one occurrence of text and search for the next one.
-        """
-        self.__doReplace(True)
-    
-    def __doReplace(self, searchNext):
-        """
-        Private method to replace one occurrence of text.
-        
-        @param searchNext flag indicating to search for the next occurrence (boolean).
-        """
         self.__finding = True
         
         # Check enabled status due to dual purpose usage of this method
-        if not self.ui.replaceButton.isEnabled() and \
-           not self.ui.replaceSearchButton.isEnabled():
+        if not self.ui.replaceButton.isEnabled():
             return
         
         ftxt = self.ui.findtextCombo.currentText()
@@ -468,20 +436,15 @@ character except an alphabetic character.</td></tr>
         
         aw = self.viewmanager.activeWindow()
         aw.replace(rtxt)
+        ok = self.__findNextPrev(ftxt, self.__findBackwards)
         
-        if searchNext:
-            ok = self.__findNextPrev(ftxt, self.__findBackwards)
-            if not ok:
-                self.ui.replaceButton.setEnabled(False)
-                self.ui.replaceSearchButton.setEnabled(False)
-                KQMessageBox.information(self, self.windowTitle(),
-                    self.trUtf8("'%1' was not found.").arg(ftxt))
-        else:
+        if not ok:
             self.ui.replaceButton.setEnabled(False)
-            self.ui.replaceSearchButton.setEnabled(False)
+            KQMessageBox.information(self, self.windowTitle(),
+                self.trUtf8("'%1' was not found.").arg(ftxt))
         
         self.__finding = False
-    
+        
     @pyqtSignature("")
     def on_replaceAllButton_clicked(self):
         """
@@ -545,7 +508,6 @@ character except an alphabetic character.</td></tr>
         if wordWrap:
             self.ui.wrapCheckBox.setChecked(True)
         self.ui.replaceButton.setEnabled(False)
-        self.ui.replaceSearchButton.setEnabled(False)
         
         if found:
             KQMessageBox.information(self, self.windowTitle(),
@@ -574,7 +536,6 @@ character except an alphabetic character.</td></tr>
         self.ui.findtextCombo.setEditText(text)
         self.ui.findtextCombo.lineEdit().selectAll()
         self.ui.findtextCombo.setFocus()
-        self.on_findtextCombo_editTextChanged(text)
         
         self.ui.replacetextCombo.clear()
         self.ui.replacetextCombo.addItems(self.replaceHistory)
