@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -83,7 +83,6 @@ class Shell(QsciScintillaCompat):
         
         self.connect(self, SIGNAL('userListActivated(int, const QString)'),
                      self.__completionListSelected)
-        self.connect(self, SIGNAL("linesChanged()"), self.__resizeLinenoMargin)
         
         self.__showStdOutErr = Preferences.getShell("ShowStdOutErr")
         if self.__showStdOutErr:
@@ -100,7 +99,7 @@ class Shell(QsciScintillaCompat):
         self.connect(dbs, SIGNAL('clientSyntaxError'), self.__clientError)
         self.dbs = dbs
         
-        # Initialize instance variables.
+        # Initialise instance variables.
         self.__initialise()
         self.prline = 0
         self.prcol = 0
@@ -257,9 +256,6 @@ class Shell(QsciScintillaCompat):
             if api is not None:
                 self.lexer_.setAPIs(api)
         
-        self.lexer_.setDefaultColor(self.lexer_.color(0))
-        self.lexer_.setDefaultPaper(self.lexer_.paper(0))
-        
     def __setMargin0(self):
         """
         Private method to configure margin 0.
@@ -273,7 +269,7 @@ class Shell(QsciScintillaCompat):
         linenoMargin = Preferences.getShell("LinenoMargin")
         self.setMarginLineNumbers(0, linenoMargin)
         if linenoMargin:
-            self.__resizeLinenoMargin()
+            self.setMarginWidth(0, ' ' + '8' * Preferences.getShell("LinenoWidth"))
         else:
             self.setMarginWidth(0, 0)
         
@@ -281,14 +277,6 @@ class Shell(QsciScintillaCompat):
         self.setMarginWidth(1, 0)
         self.setMarginWidth(2, 0)
         
-    def __resizeLinenoMargin(self):
-        """
-        Private slot to resize the line numbers margin.
-        """
-        linenoMargin = Preferences.getShell("LinenoMargin")
-        if linenoMargin:
-            self.setMarginWidth(0, '8' * (len(str(self.lines())) + 1))
-        
     def __setTextDisplay(self):
         """
         Private method to configure the text display.
@@ -296,16 +284,6 @@ class Shell(QsciScintillaCompat):
         self.setTabWidth(Preferences.getEditor("TabWidth"))
         if Preferences.getEditor("ShowWhitespace"):
             self.setWhitespaceVisibility(QsciScintilla.WsVisible)
-            try:
-                self.setWhitespaceForegroundColor(
-                    Preferences.getEditorColour("WhitespaceForeground"))
-                self.setWhitespaceBackgroundColor(
-                    Preferences.getEditorColour("WhitespaceBackground"))
-                self.setWhitespaceSize(
-                    Preferences.getEditor("WhitespaceSize"))
-            except AttributeError:
-                # QScintilla before 2.5 doesn't support this
-                pass
         else:
             self.setWhitespaceVisibility(QsciScintilla.WsInvisible)
         self.setEolVisibility(Preferences.getEditor("ShowEOL"))
@@ -352,10 +330,6 @@ class Shell(QsciScintillaCompat):
         
         self.setCursorFlashTime(QApplication.cursorFlashTime())
         
-        if Preferences.getEditor("OverrideEditAreaColours"):
-            self.setColor(Preferences.getEditorColour("EditAreaForeground"))
-            self.setPaper(Preferences.getEditorColour("EditAreaBackground"))
-        
     def __setMonospaced(self, on):
         """
         Private method to set/reset a monospaced font.
@@ -422,8 +396,6 @@ class Shell(QsciScintillaCompat):
         self.inRawMode = False
         self.echoInput = True
         self.clientCapabilities = 0
-        self.inCommandExecution = False
-        self.interruptCommandExecution = False
         
     def __clientCapabilities(self, cap, clType):
         """
@@ -436,7 +408,6 @@ class Shell(QsciScintillaCompat):
         if clType != self.clientType:
             self.clientType = clType
             self.__bindLexer(clType)
-            self.__setTextDisplay()
             self.__setMargin0()
             self.__setAutoCompletion(clType)
             self.__setCallTips(clType)
@@ -601,7 +572,7 @@ class Shell(QsciScintillaCompat):
         @return tuple of two values (int, int) giving the line and column
         """
         line = self.lines() - 1
-        return (line, self.text(line).length())
+        return (line, self.lineLength(line))
         
     def __write(self, s):
         """
