@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -36,7 +36,7 @@ class Task(QTreeWidgetItem):
     """
     def __init__(self, description, priority = 1, filename = "", lineno = 0, 
                  completed = False, _time = 0, isProjectTask = False, 
-                 isBugfixTask = False, project = None, longtext = ""):
+                 isBugfixTask = False, ppath = "", longtext = ""):
         """
         Constructor
         
@@ -50,11 +50,9 @@ class Task(QTreeWidgetItem):
         @param isProjectTask flag indicating a task related to the current project
             (boolean)
         @param isBugfixTask flag indicating a bugfix task (boolean)
-        @param project reference to the project object (Project)
+        @param ppath the project path (string or QString)
         @param longtext explanatory text of the task (string or QString)
         """
-        QTreeWidgetItem.__init__(self)
-        
         self.description = unicode(description)
         self.longtext = unicode(longtext)
         if priority in [0, 1, 2]:
@@ -67,16 +65,14 @@ class Task(QTreeWidgetItem):
         self.created = _time and _time or time.time()
         self._isProjectTask = isProjectTask
         self.isBugfixTask = isBugfixTask
-        self.project = project
+        self.ppath = unicode(ppath)
         
         if isProjectTask:
-            self.filename = self.project.getRelativePath(self.filename)
+            self.filename = self.filename.replace(self.ppath + os.sep, "")
             
-        self.setData(0, Qt.DisplayRole, "")
-        self.setData(1, Qt.DisplayRole, "")
-        self.setData(2, Qt.DisplayRole, self.description)
-        self.setData(3, Qt.DisplayRole, self.filename)
-        self.setData(4, Qt.DisplayRole, self.lineno or "")
+        QTreeWidgetItem.__init__(self,  
+            QStringList() << "" << "" << self.description << self.filename \
+                          << (self.lineno and "%6d" % self.lineno or ""))
         
         if self.completed:
             self.setIcon(0, UI.PixmapCache.getIcon("taskCompleted.png"))
@@ -173,7 +169,7 @@ class Task(QTreeWidgetItem):
         @return filename (string)
         """
         if self._isProjectTask and self.filename:
-            return os.path.join(self.project.getProjectPath(), self.filename)
+            return os.path.join(self.ppath, self.filename)
         else:
             return self.filename
     
@@ -201,14 +197,6 @@ class Task(QTreeWidgetItem):
         @return flag indicating the project relation status (boolean)
         """
         return self._isProjectTask
-    
-    def isProjectFileTask(self):
-        """
-        Public slot to get an indication, if this task is related to a project file.
-        
-        @return flag indicating a project file task (boolean)
-        """
-        return self._isProjectTask and self.filename != ""
 
 class TaskFilter(object):
     """
@@ -548,7 +536,8 @@ class TaskViewer(QTreeWidget):
         """
         task = Task(description, priority, filename, lineno, completed, 
                    _time, isProjectTask, isBugfixTask, 
-                   self.project, longtext)
+                   self.project and self.project.ppath or "", 
+                   longtext)
         self.tasks.append(task)
         if self.taskFilter.showTask(task):
             self.addTopLevelItem(task)
@@ -596,16 +585,12 @@ class TaskViewer(QTreeWidget):
         self.tasks = []
         self.clear()
         
-    def clearProjectTasks(self, fileOnly=False):
+    def clearProjectTasks(self):
         """
         Public slot to clear project related tasks.
-        
-        @keyparam fileOnly flag indicating to clear only file related
-            project tasks (boolean)
         """
         for task in self.tasks[:]:
-            if (fileOnly and task.isProjectFileTask()) or \
-               (not fileOnly and task.isProjectTask()):
+            if task.isProjectTask():
                 if self.copyTask == task:
                     self.copyTask = None
                 index = self.indexOfTopLevelItem(task)
@@ -613,21 +598,13 @@ class TaskViewer(QTreeWidget):
                 self.tasks.remove(task)
                 del task
         
-    def clearFileTasks(self, filename, conditionally=False):
+    def clearFileTasks(self, filename):
         """
         Public slot to clear all tasks related to a file.
         
         @param filename name of the file (string or QString)
-        @param conditionally flag indicating to clear the tasks of the file
-            checking some conditions (boolean)
         """
         filename = unicode(filename)
-        if conditionally:
-            if self.project and self.project.isProjectSource(filename):
-                # project related tasks will not be cleared
-                return
-            if not Preferences.getTasks("ClearOnFileClose"):
-                return
         for task in self.tasks[:]:
             if task.getFilename() == filename:
                 if self.copyTask == task:
@@ -780,7 +757,7 @@ class TaskViewer(QTreeWidget):
         files = self.project.pdata["SOURCES"]
         
         # remove all project tasks
-        self.clearProjectTasks(fileOnly=True)
+        self.clearProjectTasks()
         
         # now process them
         progress = KQProgressDialog(self.trUtf8("Extracting project tasks..."), 
