@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -582,7 +582,8 @@ class TemplateViewer(QTreeWidget):
                         """<p><b>Template entries</b> are the actual templates."""
                         """ They are grouped by the template groups. Help about"""
                         """ how to define them is available in the template edit"""
-                        """ dialog.</p>"""))
+                        """ dialog. There is an example template available in the"""
+                        """ Examples subdirectory of the eric4 distribution.</p>"""))
 
     def __getPredefinedVars(self):
         """
@@ -672,23 +673,13 @@ class TemplateViewer(QTreeWidget):
             editor.endUndoAction()
             editor.setFocus()
 
-    def applyNamedTemplate(self, templateName, groupName=""):
+    def applyNamedTemplate(self, templateName):
         """
         Public method to apply a template given a template name.
         
         @param templateName name of the template item to apply (string or QString)
-        @param groupName name of the group to get the entry from (string or QString).
-            Empty means to apply the first template found with the given name.
         """
-        groupName = unicode(groupName)
-        if groupName:
-            if self.hasGroup(groupName):
-                groups = [self.groups[groupName]]
-            else:
-                return
-        else:
-            groups = self.groups.values()
-        for group in groups:
+        for group in self.groups.values():
             template = group.getEntry(templateName)
             if template is not None:
                 self.applyTemplate(template)
@@ -707,16 +698,7 @@ class TemplateViewer(QTreeWidget):
         self.groups[unicode(groupName)].addEntry(unicode(name), unicode(description), 
                                                  unicode(template), quiet = quiet)
         self.__resort()
-    
-    def hasGroup(self, name):
-        """
-        Public method to check, if a group with the given name exists.
         
-        @param name name of the group to be checked for (string or QString)
-        @return flag indicating an existing group (boolean)
-        """
-        return unicode(name) in self.groups
-    
     def addGroup(self, name, language = "All"):
         """
         Public method to add a group.
@@ -911,47 +893,27 @@ class TemplateViewer(QTreeWidget):
         """
         e4App().getObject("UserInterface").showPreferences("templatesPage")
     
-    def hasTemplate(self, entryName, groupName=""):
+    def hasTemplate(self, entryName):
         """
         Public method to check, if an entry of the given name exists.
         
         @param entryName name of the entry to check for (string or QString)
-        @param groupName name of the group to check the entry (string or QString).
-            Empty means to check all groups.
         @return flag indicating the existence (boolean)
         """
-        groupName = unicode(groupName)
-        if groupName:
-            if self.hasGroup(groupName):
-                groups = [self.groups[groupName]]
-            else:
-                groups = []
-        else:
-            groups = self.groups.values()
-        for group in groups:
+        for group in self.groups.values():
             if group.hasEntry(entryName):
                 return True
         
         return False
     
-    def getTemplateNames(self, start, groupName=""):
+    def getTemplateNames(self, start):
         """
         Public method to get the names of templates starting with the given string.
         
         @param start start string of the name (string or QString)
-        @param groupName name of the group to get the entry from (string or QString).
-            Empty means to look in all groups.
         @return sorted list of matching template names (list of strings)
         """
         names = []
-        groupName = unicode(groupName)
-        if groupName:
-            if self.hasGroup(groupName):
-                groups = [self.groups[groupName]]
-            else:
-                groups = []
-        else:
-            groups = self.groups.values()
-        for group in groups:
+        for group in self.groups.values():
             names.extend(group.getEntryNames(start))
         return sorted(names)
