@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,14 +12,12 @@ import os
 
 from PyQt4.QtCore import SIGNAL, QStringList, QProcess, QSettings, QFileInfo, \
                          QVariant
-from PyQt4.QtGui  import QSystemTrayIcon, QMenu, qApp, QCursor, QMessageBox, \
-                         QApplication, QDialog
+from PyQt4.QtGui  import QSystemTrayIcon, QMenu, qApp, QCursor, QMessageBox
 
 import Globals
 import UI.PixmapCache
 
 import Utilities
-import Preferences
 
 from eric4config import getConfig
 
@@ -31,9 +29,7 @@ class TrayStarter(QSystemTrayIcon):
         """
         Constructor
         """
-        QSystemTrayIcon.__init__(self, 
-            UI.PixmapCache.getIcon(
-                unicode(Preferences.getTrayStarter("TrayStarterIcon"))))
+        QSystemTrayIcon.__init__(self, UI.PixmapCache.getIcon("erict.png"))
         
         self.maxMenuFilePathLen = 75
         
@@ -73,8 +69,7 @@ class TrayStarter(QSystemTrayIcon):
         self.connect(self.recentFilesMenu, SIGNAL('triggered(QAction *)'),
                      self.__openRecent)
         
-        act = self.__menu.addAction(
-            self.trUtf8("Eric4 tray starter"), self.__about)
+        act = self.__menu.addAction(self.trUtf8("Eric4 tray starter"))
         font = act.font()
         font.setBold(True)
         act.setFont(font)
@@ -91,7 +86,7 @@ class TrayStarter(QSystemTrayIcon):
         self.__menu.addAction(UI.PixmapCache.getIcon("unittest.png"),
             self.trUtf8("Unittest"), self.__startUnittest)
         self.__menu.addAction(UI.PixmapCache.getIcon("ericWeb.png"),
-            self.trUtf8("eric4 Web Browser"), self.__startHelpViewer)
+            self.trUtf8("Web Browser"), self.__startHelpViewer)
         self.__menu.addSeparator()
         
         self.__menu.addAction(UI.PixmapCache.getIcon("diffFiles.png"),
@@ -104,10 +99,6 @@ class TrayStarter(QSystemTrayIcon):
             self.trUtf8("SQL Browser"), self.__startSqlBrowser)
         self.__menu.addSeparator()
         
-        self.__menu.addAction(UI.PixmapCache.getIcon("iconEditor.png"), 
-            self.trUtf8("Icon Editor"), self.__startIconEditor)
-        self.__menu.addSeparator()
-        
         self.__menu.addAction(UI.PixmapCache.getIcon("pluginInstall.png"),
             self.trUtf8("Install Plugin"), self.__startPluginInstall)
         self.__menu.addAction(UI.PixmapCache.getIcon("pluginUninstall.png"),
@@ -124,10 +115,6 @@ class TrayStarter(QSystemTrayIcon):
             self.trUtf8("eric4 Mini Editor"), self.__startMiniEditor)
         self.__menu.addSeparator()
         
-        self.__menu.addAction(UI.PixmapCache.getIcon("configure.png"),
-            self.trUtf8('Preferences (tray starter)'), self.__showPreferences)
-        self.__menu.addSeparator()
-        
         # recent files
         self.menuRecentFilesAct = self.__menu.addMenu(self.recentFilesMenu)
         # recent multi projects
@@ -225,7 +212,7 @@ class TrayStarter(QSystemTrayIcon):
         """
         Private slot to start the eric4 Mini Editor.
         """
-        self.__startProc("eric4_editor.py", "--config=%s" % Utilities.getConfigDir())
+        self.__startProc("eric4-editor.py", "--config=%s" % Utilities.getConfigDir())
     
     def __startEric(self):
         """
@@ -237,88 +224,82 @@ class TrayStarter(QSystemTrayIcon):
         """
         Private slot to start the eric4 configuration dialog.
         """
-        self.__startProc("eric4_configure.py", "--config=%s" % Utilities.getConfigDir())
+        self.__startProc("eric4-configure.py", "--config=%s" % Utilities.getConfigDir())
 
     def __startPluginInstall(self):
         """
         Private slot to start the eric4 plugin installation dialog.
         """
-        self.__startProc("eric4_plugininstall.py", 
+        self.__startProc("eric4-plugininstall.py", 
                          "--config=%s" % Utilities.getConfigDir())
 
     def __startPluginUninstall(self):
         """
         Private slot to start the eric4 plugin uninstallation dialog.
         """
-        self.__startProc("eric4_pluginuninstall.py", 
+        self.__startProc("eric4-pluginuninstall.py", 
                          "--config=%s" % Utilities.getConfigDir())
 
     def __startPluginRepository(self):
         """
         Private slot to start the eric4 plugin repository dialog.
         """
-        self.__startProc("eric4_pluginrepository.py", 
+        self.__startProc("eric4-pluginrepository.py", 
                          "--config=%s" % Utilities.getConfigDir())
 
     def __startHelpViewer(self):
         """
         Private slot to start the eric4 web browser.
         """
-        self.__startProc("eric4_webbrowser.py", "--config=%s" % Utilities.getConfigDir())
+        self.__startProc("eric4-webbrowser.py", "--config=%s" % Utilities.getConfigDir())
 
     def __startUIPreviewer(self):
         """
         Private slot to start the eric4 UI previewer.
         """
-        self.__startProc("eric4_uipreviewer.py", "--config=%s" % Utilities.getConfigDir())
+        self.__startProc("eric4-uipreviewer.py", "--config=%s" % Utilities.getConfigDir())
 
     def __startTRPreviewer(self):
         """
         Private slot to start the eric4 translations previewer.
         """
-        self.__startProc("eric4_trpreviewer.py", "--config=%s" % Utilities.getConfigDir())
+        self.__startProc("eric4-trpreviewer.py", "--config=%s" % Utilities.getConfigDir())
 
     def __startUnittest(self):
         """
         Private slot to start the eric4 unittest dialog.
         """
-        self.__startProc("eric4_unittest.py", "--config=%s" % Utilities.getConfigDir())
+        self.__startProc("eric4-unittest.py", "--config=%s" % Utilities.getConfigDir())
 
     def __startDiff(self):
         """
         Private slot to start the eric4 diff dialog.
         """
-        self.__startProc("eric4_diff.py", "--config=%s" % Utilities.getConfigDir())
+        self.__startProc("eric4-diff.py", "--config=%s" % Utilities.getConfigDir())
 
     def __startCompare(self):
         """
         Private slot to start the eric4 compare dialog.
         """
-        self.__startProc("eric4_compare.py", "--config=%s" % Utilities.getConfigDir())
+        self.__startProc("eric4-compare.py", "--config=%s" % Utilities.getConfigDir())
     
     def __startSqlBrowser(self):
         """
         Private slot to start the eric4 sql browser dialog.
         """
-        self.__startProc("eric4_sqlbrowser.py", "--config=%s" % Utilities.getConfigDir())
-
-    def __startIconEditor(self):
-        """
-        Private slot to start the eric4 icon editor dialog.
-        """
-        self.__startProc("eric4_iconeditor.py", "--config=%s" % Utilities.getConfigDir())
+        self.__startProc("eric4-sqlbrowser.py", "--config=%s" % Utilities.getConfigDir())
 
     def __startQRegExp(self):
         """
         Private slot to start the eric4 QRegExp editor dialog.
         """
-        self.__startProc("eric4_qregexp.py", "--config=%s" % Utilities.getConfigDir())
+        self.__startProc("eric4-qregexp.py", "--config=%s" % Utilities.getConfigDir())
 
     def __startPyRe(self):
         """
         Private slot to start the eric4 Python re editor dialog.
         """
-        self.__startProc("eric4_re.py", "--config=%s" % Utilities.getConfigDir())
+        self.__startProc("eric4-re.py", "--config=%s" % Utilities.getConfigDir())
 
     def __showRecentProjectsMenu(self):
         """
@@ -396,37 +377,3 @@ class TrayStarter(QSystemTrayIcon):
         filename = unicode(act.data().toString())
         if filename:
             self.__startProc("eric4.py", filename)
-    
-    def __showPreferences(self):
-        """
-        Private slot to set the preferences.
-        """
-        from Preferences.ConfigurationDialog import ConfigurationDialog
-        dlg = ConfigurationDialog(None, 'Configuration', True, 
-                                  fromEric = True, 
-                                  displayMode = ConfigurationDialog.TrayStarterMode)
-        self.connect(dlg, SIGNAL('preferencesChanged'), self.preferencesChanged)
-        dlg.show()
-        dlg.showConfigurationPageByName("trayStarterPage")
-        dlg.exec_()
-        QApplication.processEvents()
-        if dlg.result() == QDialog.Accepted:
-            dlg.setPreferences()
-            Preferences.syncPreferences()
-            self.preferencesChanged()
-    
-    def preferencesChanged(self):
-        """
-        Public slot to handle a change of preferences.
-        """
-        self.setIcon(
-            UI.PixmapCache.getIcon(
-                unicode(Preferences.getTrayStarter("TrayStarterIcon"))))
-
-    def __about(self):
-        """
-        Private slot to handle the About dialog.
-        """
-        from Plugins.AboutPlugin.AboutDialog import AboutDialog
-        dlg = AboutDialog()
-        dlg.exec_()
