@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -39,7 +39,6 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
     startRole   = Qt.UserRole + 2
     endRole     = Qt.UserRole + 3
     replaceRole = Qt.UserRole + 4
-    md5Role     = Qt.UserRole + 5
     
     def __init__(self, project, replaceMode = False, parent=None):
         """
@@ -73,16 +72,8 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         
         self.findProgressLabel.setMaximumWidth(550)
         
-        self.searchHistory = Preferences.Prefs.settings.value(
-            "FindFileDialog/SearchHistory").toStringList()
-        self.replaceHistory = Preferences.Prefs.settings.value(
-            "FindFileDialog/ReplaceHistory").toStringList()
-        self.dirHistory = Preferences.Prefs.settings.value(
-            "FindFileDialog/DirectoryHistory").toStringList()
-        self.findtextCombo.addItems(self.searchHistory)
-        self.replacetextCombo.addItems(self.replaceHistory)
-        self.dirCombo.addItems(self.dirHistory)
-        
+        self.searchHistory = QStringList()
+        self.replaceHistory = QStringList()
         self.project = project
         
         self.findList.headerItem().setText(self.findList.columnCount(), "")
@@ -117,7 +108,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         self.connect(self, SIGNAL("customContextMenuRequested(const QPoint &)"), 
                      self.__contextMenuRequested)
         
-    def __createItem(self, file, line, text, start, end, replTxt = "", md5 = ""):
+    def __createItem(self, file, line, text, start, end, replTxt = ""):
         """
         Private method to create an entry in the file list.
         
@@ -126,8 +117,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         @param text text found (string or QString)
         @param start start position of match (integer)
         @param end end position of match (integer)
-        @param replTxt text with replacements applied (string or QString)
-        @param md5 MD5 hash of the file (string or QString)
+        @param replTxt text with replacements applied (string or QString
         """
         if self.__lastFileItem is None:
             # It's a new file
@@ -139,12 +129,9 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                     Qt.ItemFlags(Qt.ItemIsUserCheckable | Qt.ItemIsTristate))
                 # Qt bug: 
                 # item is not user checkable if setFirstColumnSpanned is True (< 4.5.0)
-            self.__lastFileItem.setData(0, self.md5Role, QVariant(md5))
         
-        itm = QTreeWidgetItem(self.__lastFileItem)
+        itm = QTreeWidgetItem(self.__lastFileItem, [' %5d ' % line, text])
         itm.setTextAlignment(0,  Qt.AlignRight)
-        itm.setData(0, Qt.DisplayRole, line)
-        itm.setData(1, Qt.DisplayRole, text)
         itm.setData(0, self.lineRole, QVariant(line))
         itm.setData(0, self.startRole, QVariant(start))
         itm.setData(0, self.endRole, QVariant(end))
@@ -192,9 +179,9 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         """
         self.__enableFindButton()
         
-    def on_dirCombo_editTextChanged(self, text):
+    def on_dirEdit_textChanged(self, text):
         """
-        Private slot to handle the textChanged signal of the directory combo box.
+        Private slot to handle the textChanged signal of the directory edit.
         
         @param text (ignored)
         """
@@ -237,9 +224,8 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         if self.findtextCombo.currentText().isEmpty() or \
            (self.__replaceMode and self.replacetextCombo.currentText().isEmpty()) or \
            (self.dirButton.isChecked() and \
-            (self.dirCombo.currentText().isEmpty() or \
-             not os.path.exists(
-                os.path.abspath(unicode(self.dirCombo.currentText()))))) or \
+            (self.dirEdit.text().isEmpty() or \
+             not os.path.exists(os.path.abspath(unicode(self.dirEdit.text()))))) or \
            (self.filterCheckBox.isChecked() and self.filterEdit.text().isEmpty()):
             self.findButton.setEnabled(False)
             self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
@@ -258,15 +244,6 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         elif button == self.stopButton:
             self.__stopSearch()
         
-    def __stripEol(self, txt):
-        """
-        Private method to strip the eol part.
-        
-        @param txt line of text that should be treated (string)
-        @return text with eol stripped (string)
-        """
-        return txt.replace("\r", "").replace("\n", "")
-        
     def __stopSearch(self):
         """
         Private slot to handle the stop button being pressed.
@@ -293,9 +270,8 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         
         if self.projectButton.isChecked():
             if self.filterCheckBox.isChecked():
-                files = [self.project.getRelativePath(file) \
-                         for file in \
-                         self.__getFileList(self.project.getProjectPath(), filterRe)]
+                files = [file.replace(self.project.ppath+os.sep, "") \
+                         for file in self.__getFileList(self.project.ppath, filterRe)]
             else:
                 files = []
                 if self.sourcesCheckBox.isChecked():
@@ -323,8 +299,8 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                     filters.append(self.filterResources)
                 filterString = "|".join(filters)
                 filterRe = re.compile(filterString)
-            files = self.__getFileList(
-                os.path.abspath(unicode(self.dirCombo.currentText())), filterRe)
+            files = self.__getFileList(os.path.abspath(unicode(self.dirEdit.text())), 
+                                       filterRe)
         elif self.openFilesButton.isChecked():
             files = e4App().getObject("ViewManager").getOpenFilenames()
         
@@ -353,7 +329,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
             QMessageBox.critical(None,
                 self.trUtf8("Invalid search expression"),
                 self.trUtf8("""<p>The search expression is not valid.</p>"""
-                            """<p>Error: %1</p>""").arg(str(why)))
+                            """<p>Error: %1</p>""").arg(unicode(why)))
             self.stopButton.setEnabled(False)
             self.findButton.setEnabled(True)
             self.findButton.setDefault(True)
@@ -364,26 +340,12 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         self.searchHistory.prepend(ct)
         self.findtextCombo.clear()
         self.findtextCombo.addItems(self.searchHistory)
-        Preferences.Prefs.settings.setValue("FindFileDialog/SearchHistory", 
-                                            self.searchHistory[:30])
-        
         if self.__replaceMode:
             replTxt = unicode(self.replacetextCombo.currentText())
             self.replaceHistory.removeAll(replTxt)
             self.replaceHistory.prepend(replTxt)
             self.replacetextCombo.clear()
             self.replacetextCombo.addItems(self.replaceHistory)
-            Preferences.Prefs.settings.setValue("FindFileDialog/ReplaceHistory", 
-                                                self.replaceHistory[:30])
-        
-        if self.dirButton.isChecked():
-            searchDir = self.dirCombo.currentText()
-            self.dirHistory.removeAll(searchDir)
-            self.dirHistory.insert(0, searchDir)
-            self.dirCombo.clear()
-            self.dirCombo.addItems(self.dirHistory)
-            Preferences.Prefs.settings.setValue("FindFileDialog/DirectoryHistory", 
-                                                self.dirHistory[:30])
         
         # now go through all the files
         self.__populating = True
@@ -404,8 +366,8 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
             # read the file and split it into textlines
             try:
                 f = open(fn, 'rb')
-                text, encoding, hash = Utilities.decodeWithHash(f.read())
-                lines = text.splitlines(True)
+                text, encoding = Utilities.decode(f.read())
+                lines = text.splitlines()
                 f.close()
             except IOError:
                 progress += 1
@@ -427,15 +389,13 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                         rline = search.sub(replTxt, line)
                     else:
                         rline = ""
-                    line = self.__stripEol(line)
                     if len(line) > 1024:
                         line = "%s ..." % line[:1024]
                     if self.__replaceMode:
                         if len(rline) > 1024:
                             rline = "%s ..." % line[:1024]
-                        line = "- %s\n+ %s" % (
-                            line, self.__stripEol(rline))
-                    self.__createItem(file, count, line, start, end, rline, hash)
+                        line = "- %s\n+ %s" % (line, rline)
+                    self.__createItem(file, count, line, start, end, rline)
                     
                     if self.feelLikeCheckBox.isChecked():
                         fn = os.path.join(self.project.ppath, unicode(file))
@@ -508,11 +468,11 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         directory = KQFileDialog.getExistingDirectory(\
             self,
             self.trUtf8("Select directory"),
-            self.dirCombo.currentText(),
+            self.dirEdit.text(),
             QFileDialog.Options(QFileDialog.ShowDirsOnly))
             
         if not directory.isEmpty():
-            self.dirCombo.setEditText(Utilities.toNativeSeparators(directory))
+            self.dirEdit.setText(Utilities.toNativeSeparators(directory))
         
     def __getFileList(self, path, filterRe):
         """
@@ -538,7 +498,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         @param searchDir name of the directory to search in (string or QString)
         """
         self.dirButton.setChecked(True)
-        self.dirCombo.setEditText(Utilities.toNativeSeparators(searchDir))
+        self.dirEdit.setText(Utilities.toNativeSeparators(searchDir))
         
     @pyqtSignature("")
     def on_replaceButton_clicked(self):
@@ -553,7 +513,6 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
             itm = self.findList.topLevelItem(index)
             if itm.checkState(0) in [Qt.PartiallyChecked, Qt.Checked]:
                 file = unicode(itm.text(0))
-                origHash = itm.data(0, self.md5Role).toString()
                 
                 self.findProgressLabel.setPath(file)
                 
@@ -565,29 +524,15 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                 # read the file and split it into textlines
                 try:
                     f = open(fn, 'rb')
-                    text, encoding, hash = Utilities.decodeWithHash(f.read())
-                    lines = text.splitlines(True)
+                    text, encoding = Utilities.decode(f.read())
+                    lines = text.splitlines()
                     f.close()
                 except IOError, err:
                     KQMessageBox.critical(self,
                         self.trUtf8("Replace in Files"),
                         self.trUtf8("""<p>Could not read the file <b>%1</b>."""
                                     """ Skipping it.</p><p>Reason: %2</p>""")\
-                            .arg(fn).arg(str(err))
-                    )
-                    progress += 1
-                    self.findProgress.setValue(progress)
-                    continue
-                
-                # Check the original and the current hash. Skip the file,
-                # if hashes are different.
-                if origHash != hash:
-                    KQMessageBox.critical(self,
-                        self.trUtf8("Replace in Files"),
-                        self.trUtf8("""<p>The current and the original hash of the"""
-                                    """ file <b>%1</b> are different. Skipping it."""
-                                    """</p><p>Hash 1: %2</p><p>Hash 2: %3</p>""")\
-                            .arg(fn).arg(origHash).arg(hash)
+                            .arg(fn).arg(unicode(err))
                     )
                     progress += 1
                     self.findProgress.setValue(progress)
@@ -602,7 +547,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                         lines[line - 1] = unicode(rline)
                 
                 # write the file
-                txt = "".join(lines)
+                txt = Utilities.linesep().join(lines)
                 txt, encoding = Utilities.encode(txt, encoding)
                 try:
                     f = open(fn, 'wb')
@@ -613,7 +558,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                         self.trUtf8("Replace in Files"),
                         self.trUtf8("""<p>Could not save the file <b>%1</b>."""
                                     """ Skipping it.</p><p>Reason: %2</p>""")\
-                            .arg(fn).arg(str(err))
+                            .arg(fn).arg(unicode(err))
                     )
             
             progress += 1
