@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -51,7 +51,6 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
         self.stopButton.setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Open).setToolTip(\
             self.trUtf8("Opens the selected file"))
-        self.buttonBox.button(QDialogButtonBox.Open).setEnabled(False)
         
         self.project = project
         self.extsepLabel.setText(os.extsep)
@@ -69,25 +68,24 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
         elif button == self.buttonBox.button(QDialogButtonBox.Open):
             self.__openFile()
     
-    def __openFile(self, itm=None):
+    def __openFile(self):
         """
         Private slot to open a file. 
         
-        It emits the signal sourceFile or designerFile depending on the
-        file extension.
-        
-        @param itm item to be opened (QTreeWidgetItem)
+        It emits the signal
+        sourceFile or designerFile depending on the file extension.
         """
-        if itm is None:
-            itm = self.fileList.currentItem()
-        if itm is not None:
-            fileName = unicode(itm.text(0))
-            filePath = unicode(itm.text(1))
-            
-            if fileName.endswith('.ui'):
-                self.emit(SIGNAL('designerFile'), os.path.join(filePath, fileName))
-            else:
-                self.emit(SIGNAL('sourceFile'), os.path.join(filePath, fileName))
+        itm = self.fileList.currentItem()
+        fileName = unicode(itm.text(0))
+        filePath = unicode(itm.text(1))
+        
+        if fileName.endswith('.ui'):
+            self.emit(SIGNAL('designerFile'), os.path.join(filePath, fileName))
+        elif fileName.endswith('.ui.h'):
+            fn = os.path.splitext(fileName)
+            self.emit(SIGNAL('designerFile'), os.path.join(filePath, fn))
+        else:
+            self.emit(SIGNAL('sourceFile'), os.path.join(filePath, fileName))
 
     def __searchFile(self):
         """
@@ -95,17 +93,12 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
         """
         fileName = unicode(self.fileNameEdit.text())
         if not fileName:
-            self.fileList.clear()
             return
         fileExt = unicode(self.fileExtEdit.text())
-        if not fileExt and Utilities.isWindowsPlatform():
-            self.fileList.clear()
-            return
-        
         patternFormat = fileExt and "%s%s%s*" or "%s*%s%s"
         fileNamePattern = patternFormat % (fileName, os.extsep,
             fileExt and fileExt or '*')
-        
+            
         searchPaths = []
         if self.searchDirCheckBox.isChecked() and \
            not self.searchDirEdit.text().isEmpty():
@@ -114,7 +107,7 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
             searchPaths.append(self.project.ppath)
         if self.syspathCheckBox.isChecked():
             searchPaths.extend(sys.path)
-        
+            
         found = False
         self.fileList.clear()
         locations = {}
@@ -140,12 +133,10 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
                     QApplication.processEvents()
             
         del locations
+        self.buttonBox.button(QDialogButtonBox.Open).setEnabled(found)
         self.stopButton.setEnabled(False)
         self.fileList.header().resizeSections(QHeaderView.ResizeToContents)
         self.fileList.header().setStretchLastSection(True)
-        
-        if found:
-            self.fileList.setCurrentItem(self.fileList.topLevelItem(0))
 
     def checkStop(self):
         """
@@ -182,6 +173,7 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
         if self.searchDirCheckBox.isChecked():
             self.__searchFile()
         
+        
     @pyqtSignature("")
     def on_searchDirButton_clicked(self):
         """
@@ -225,22 +217,13 @@ class FindFileNameDialog(QWidget, Ui_FindFileNameDialog):
         """
         Private slot to handle the double click on a file item. 
         
-        It emits the signal sourceFile or designerFile depending on the
-        file extension.
+        It emits the signal
+        sourceFile or designerFile depending on the file extension.
         
         @param itm the double clicked listview item (QTreeWidgetItem)
         @param column column that was double clicked (integer) (ignored)
         """
-        self.__openFile(itm)
-        
-    def on_fileList_currentItemChanged(self, current, previous):
-        """
-        Private slot handling a change of the current item.
-        
-        @param current current item (QTreeWidgetItem)
-        @param previous prevoius current item (QTreeWidgetItem)
-        """
-        self.buttonBox.button(QDialogButtonBox.Open).setEnabled(current is not None)
+        self.__openFile()
         
     def show(self):
         """
