@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -52,12 +52,6 @@ _getnext = re.compile(r"""
         \]
     )
 
-|   (?P<MethodModifier>
-        ^
-        (?P<MethodModifierIndent> [ \t]* )
-        (?P<MethodModifierType> @classmethod | @staticmethod )
-    )
-
 |   (?P<Method>
         ^
         (?P<MethodIndent> [ \t]* )
@@ -145,8 +139,7 @@ class Function(ClbrBaseClasses.Function, VisibilityMixin):
     """
     Class to represent a Python function.
     """
-    def __init__(self, module, name, file, lineno, signature = '', separator = ',',
-                 modifierType=ClbrBaseClasses.Function.General):
+    def __init__(self, module, name, file, lineno, signature = '', separator = ','):
         """
         Constructor
         
@@ -156,10 +149,9 @@ class Function(ClbrBaseClasses.Function, VisibilityMixin):
         @param lineno linenumber of the class definition
         @param signature parameterlist of the method
         @param separator string separating the parameters
-        @param modifierType type of the function
         """
         ClbrBaseClasses.Function.__init__(self, module, name, file, lineno, 
-                                          signature, separator, modifierType)
+                                          signature, separator)
         VisibilityMixin.__init__(self)
 
 class Attribute(ClbrBaseClasses.Attribute, VisibilityMixin):
@@ -260,19 +252,13 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
 
     lineno, last_lineno_pos = 1, 0
     i = 0
-    modifierType = ClbrBaseClasses.Function.General
-    modifierIndent = -1
     while 1:
         m = _getnext(src, i)
         if not m:
             break
         start, i = m.span()
 
-        if m.start("MethodModifier") >= 0:
-            modifierIndent = _indent(m.group("MethodModifierIndent"))
-            modifierType = m.group("MethodModifierType")
-        
-        elif m.start("Method") >= 0:
+        if m.start("Method") >= 0:
             # found a method definition or function
             thisindent = _indent(m.group("MethodIndent"))
             meth_name = m.group("MethodName")
@@ -281,15 +267,6 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
             meth_sig = _commentsub('', meth_sig)
             lineno = lineno + src.count('\n', last_lineno_pos, start)
             last_lineno_pos = start
-            if modifierType and modifierIndent == thisindent:
-                if modifierType == "@staticmethod":
-                    modifier = ClbrBaseClasses.Function.Static
-                elif modifierType == "@classmethod":
-                    modifier = ClbrBaseClasses.Function.Class
-                else:
-                    modifier = ClbrBaseClasses.Function.General
-            else:
-                modifier = ClbrBaseClasses.Function.General
             # modify indentation level for conditional defines
             if conditionalsstack:
                 if thisindent > conditionalsstack[-1]:
@@ -315,12 +292,12 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
                 if cur_class:
                     # it's a method/nested def
                     f = Function(None, meth_name,
-                                 file, lineno, meth_sig, modifierType=modifier)
+                                 file, lineno, meth_sig)
                     cur_class._addmethod(meth_name, f)
             else:
                 # it's a function
                 f = Function(module, meth_name,
-                             file, lineno, meth_sig, modifierType=modifier)
+                             file, lineno, meth_sig)
                 if dict_counts.has_key(meth_name):
                     dict_counts[meth_name] += 1
                     meth_name = "%s_%d" % (meth_name, dict_counts[meth_name])
@@ -328,10 +305,6 @@ def readmodule_ex(module, path=[], inpackage = False, isPyFile = False):
                     dict_counts[meth_name] = 0
                 dict[meth_name] = f
             classstack.append((f, thisindent)) # Marker for nested fns
-            
-            # reset the modifier settings
-            modifierType = ClbrBaseClasses.Function.General
-            modifierIndent = -1
 
         elif m.start("String") >= 0:
             pass
