@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -86,7 +86,7 @@ def version(appinfo):
 
 %(description)s
 
-Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 This is free software; see LICENSE.GPL3 for copying conditions.
 There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A
 PARTICULAR PURPOSE.""" % appinfo
@@ -192,7 +192,8 @@ def setLibraryPaths():
     Module function to set the Qt library paths correctly for windows systems.
     """
     if Utilities.isWindowsPlatform():
-        libPath = os.path.join(Utilities.getPyQt4ModulesDirectory(), "plugins")
+        from PyQt4 import pyqtconfig
+        libPath = os.path.join(pyqtconfig._pkg_config["pyqt_mod_dir"], "plugins")
         if os.path.exists(libPath):
             libPath = Utilities.fromNativeSeparators(libPath)
             libraryPaths = QApplication.libraryPaths()
@@ -201,7 +202,7 @@ def setLibraryPaths():
                 QApplication.setLibraryPaths(libraryPaths)
 
 def simpleAppStartup(argv, appinfo, mwFactory, kqOptions = [], 
-                     quitOnLastWindowClosed = True, raiseIt = True):
+                     quitOnLastWindowClosed = True):
     """
     Function to start up an application that doesn't need a specialized start up.
     
@@ -220,8 +221,6 @@ def simpleAppStartup(argv, appinfo, mwFactory, kqOptions = [],
         successfully.
     @keyparam quitOnLastWindowClosed flag indicating to quit the application,
         if the last window was closed (boolean)
-    @keyparam raiseIt flag indicating to raise the generated application window
-        (boolean)
     """
     ddindex = handleArgs(argv, appinfo)
     app = KQApplication(argv, kqOptions)
@@ -245,10 +244,7 @@ def simpleAppStartup(argv, appinfo, mwFactory, kqOptions = [],
     )
     
     w = mwFactory(argv)
-    if quitOnLastWindowClosed:
-        app.connect(app, SIGNAL("lastWindowClosed()"), app, SLOT("quit()"))
+    app.connect(app, SIGNAL("lastWindowClosed()"), app, SLOT("quit()"))
     w.show()
-    if raiseIt:
-        w.raise_()
     
     return app.exec_()
