@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -268,7 +268,8 @@ class VcsProjectBrowserHelper(QObject):
                 names = [unicode(itm.dirName()) for itm in items]
             else:
                 names = [unicode(itm.fileName()) for itm in items]
-            files = [self.browser.project.getRelativePath(name) \
+            files = [\
+                name.replace(self.browser.project.ppath+os.sep, '') \
                 for name in names]
             
             dlg = DeleteFilesConfirmationDialog(self.parent(),
