@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -49,8 +49,6 @@ class VcsProjectHelper(QObject):
         
         self.actions = []
         
-        self.vcsAddAct = None
-        
         self.initActions()
         
     def setObjects(self, vcsObject, projectObject):
@@ -121,8 +119,7 @@ class VcsProjectHelper(QObject):
         """
         Public slot called before the vcs menu is shown.
         """
-        if self.vcsAddAct:
-            self.vcsAddAct.setEnabled(self.project.isOpen())
+        self.vcsAddAct.setEnabled(self.project.isOpen())
 
     def _vcsCheckout(self, export = False):
         """
@@ -136,10 +133,6 @@ class VcsProjectHelper(QObject):
         
         vcsSystemsDict = e4App().getObject("PluginManager")\
             .getPluginDisplayStrings("version_control")
-        if not vcsSystemsDict:
-            # no version control system found
-            return
-        
         vcsSystemsDisplay = QStringList()
         keys = vcsSystemsDict.keys()
         keys.sort()
@@ -157,14 +150,12 @@ class VcsProjectHelper(QObject):
             if vcsSystemDisplay == vcsSelected:
                 break
         
-        if not self.project.closeProject():
-            return
-        
         self.project.pdata["VCS"] = [vcsSystem]
         self.project.vcs = self.project.initVCS(vcsSystem)
         if self.project.vcs is not None:
             vcsdlg = self.project.vcs.vcsNewProjectOptionsDialog()
             if vcsdlg.exec_() == QDialog.Accepted:
+                self.project.closeProject()
                 projectdir, vcsDataDict = vcsdlg.getData()
                 self.project.pdata["VCS"] = [vcsSystem]
                 self.project.vcs = self.project.initVCS(vcsSystem)
@@ -314,10 +305,6 @@ class VcsProjectHelper(QObject):
         vcsHelper = self.project.vcsProjectHelper
         vcsSystemsDict = e4App().getObject("PluginManager")\
             .getPluginDisplayStrings("version_control")
-        if not vcsSystemsDict:
-            # no version control system found
-            return
-        
         vcsSystemsDisplay = QStringList()
         keys = vcsSystemsDict.keys()
         keys.sort()
@@ -331,45 +318,43 @@ class VcsProjectHelper(QObject):
             0, False)
         if not ok:
             return
-        vcsSystem = None
         for vcsSystem, vcsSystemDisplay in vcsSystemsDict.items():
             if vcsSystemDisplay == vcsSelected:
                 break
         
-        if vcsSystem:
-            self.project.pdata["VCS"] = [vcsSystem]
-            self.project.vcs = self.project.initVCS(vcsSystem)
-            if self.project.vcs is not None:
-                vcsdlg = self.project.vcs.vcsOptionsDialog(self.project, self.project.name, 1)
-                if vcsdlg.exec_() == QDialog.Accepted:
-                    vcsDataDict = vcsdlg.getData()
-                    # edit VCS command options
-                    vcores = KQMessageBox.question(None,
-                        self.trUtf8("Import Project"),
-                        self.trUtf8("""Would you like to edit the VCS command options?"""),
-                        QMessageBox.StandardButtons(\
-                            QMessageBox.No | \
-                            QMessageBox.Yes),
-                        QMessageBox.No)
-                    if vcores == QMessageBox.Yes:
-                        codlg = vcsCommandOptionsDialog(self.project.vcs)
-                        if codlg.exec_() == QDialog.Accepted:
-                            self.project.vcs.vcsSetOptions(codlg.getOptions())
-                    self.project.setDirty(True)
-                    self.project.vcs.vcsSetDataFromDict(vcsDataDict)
-                    self.project.saveProject()
-                    isVcsControlled = \
-                        self.project.vcs.vcsImport(vcsDataDict, self.project.ppath)[0]
-                    if isVcsControlled:
-                        # reopen the project
-                        self.project.openProject(self.project.pfile)
-                    else:
-                        # revert the changes to the local project 
-                        # because the project dir is not a VCS directory
-                        revertChanges()
+        self.project.pdata["VCS"] = [vcsSystem]
+        self.project.vcs = self.project.initVCS(vcsSystem)
+        if self.project.vcs is not None:
+            vcsdlg = self.project.vcs.vcsOptionsDialog(self.project, self.project.name, 1)
+            if vcsdlg.exec_() == QDialog.Accepted:
+                vcsDataDict = vcsdlg.getData()
+                # edit VCS command options
+                vcores = KQMessageBox.question(None,
+                    self.trUtf8("Import Project"),
+                    self.trUtf8("""Would you like to edit the VCS command options?"""),
+                    QMessageBox.StandardButtons(\
+                        QMessageBox.No | \
+                        QMessageBox.Yes),
+                    QMessageBox.No)
+                if vcores == QMessageBox.Yes:
+                    codlg = vcsCommandOptionsDialog(self.project.vcs)
+                    if codlg.exec_() == QDialog.Accepted:
+                        self.project.vcs.vcsSetOptions(codlg.getOptions())
+                self.project.setDirty(True)
+                self.project.vcs.vcsSetDataFromDict(vcsDataDict)
+                self.project.saveProject()
+                isVcsControlled = \
+                    self.project.vcs.vcsImport(vcsDataDict, self.project.ppath)[1]
+                if isVcsControlled:
+                    # reopen the project
+                    self.project.openProject(self.project.pfile)
                 else:
-                    # revert the changes because user cancelled
+                    # revert the changes to the local project 
+                    # because the project dir is not a VCS directory
                     revertChanges()
+            else:
+                # revert the changes because user cancelled
+                revertChanges()
 
     def _vcsUpdate(self):
         """
