@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -430,17 +430,6 @@ class VersionControl(QObject):
         """
         pass
         
-    def vcsInitConfig(self, project):
-        """
-        Public method to initialize the VCS configuration.
-        
-        This method could ensure, that certain files or directories are
-        exclude from being version controlled.
-        
-        @param project reference to the project (Project)
-        """
-        pass
-        
     def vcsDefaultOptions(self):
         """
         Public method used to retrieve the default options for the vcs.
