@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -17,16 +17,20 @@ import os
 sys.e4nokde = False
 if "--nokde" in sys.argv:
     del sys.argv[sys.argv.index("--nokde")]
-    os.environ["e4nokde"] = "1"
     sys.e4nokde = True
 else:
     sys.e4nokde = os.getenv("e4nokde") is not None and os.getenv("e4nokde") == "1"
 
+for arg in sys.argv:
+    if arg.startswith("--config="):
+        import Utilities
+        configDir = arg.replace("--config=", "")
+        Utilities.setConfigDir(configDir)
+        sys.argv.remove(arg)
+        break
+
 from Utilities import Startup
 
-import PluginManager
-
-
 def createMainWidget(argv):
     """
     Function to create the main widget.
@@ -42,6 +46,8 @@ def main():
     Main entry point into the application.
     """
     options = [\
+        ("--config=configDir", 
+         "use the given directory as the one containing the config files"), 
         ("--nokde" , "don't use KDE widgets"),
     ]
     appinfo = Startup.makeAppInfo(sys.argv,
