@@ -1,13 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Eric4 QRegExp
 
-This is the main Python script that performs the neccessary initialization
+This is the main Python script that performs the necessary initialization
 of the QRegExp wizard module and starts the Qt event loop. This is a standalone 
 version of the integrated QRegExp wizard.
 """
@@ -19,11 +19,18 @@ import os
 sys.e4nokde = False
 if "--nokde" in sys.argv:
     del sys.argv[sys.argv.index("--nokde")]
-    os.environ["e4nokde"] = "1"
     sys.e4nokde = True
 else:
     sys.e4nokde = os.getenv("e4nokde") is not None and os.getenv("e4nokde") == "1"
 
+for arg in sys.argv:
+    if arg.startswith("--config="):
+        import Utilities
+        configDir = arg.replace("--config=", "")
+        Utilities.setConfigDir(configDir)
+        sys.argv.remove(arg)
+        break
+
 from Utilities import Startup
 
 
@@ -43,6 +50,8 @@ def main():
     Main entry point into the application.
     """
     options = [\
+        ("--config=configDir", 
+         "use the given directory as the one containing the config files"), 
         ("--nokde" , "don't use KDE widgets"),
     ]
     appinfo = Startup.makeAppInfo(sys.argv,
