@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002-2013 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002-2010 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the install script for eric4.
 
@@ -21,7 +21,6 @@ import distutils.sysconfig
 
 # Define the globals.
 progName = None
-currDir = os.getcwd()
 modDir = None
 pyModDir = None
 platBinDir = None
@@ -31,50 +30,6 @@ doCleanup = True
 doCompile = True
 cfg = {}
 progLanguages = ["Python", "Ruby"]
-sourceDir = "eric"
-configName = 'eric4config.py'
-
-# Define blacklisted versions of the prerequisites
-BlackLists = {
-    "sip"         : ["4.11", "4.12.3"], 
-    "PyQt4"       : ["4.7.5"], 
-    "QScintilla2" : [], 
-}
-PlatformsBlackLists = {
-    "windows": {
-        "sip": [],
-        "PyQt4": ["4.9.2", "4.9.3"],
-        "QScintilla2": [],
-    },
-    
-    "linux": {
-        "sip": [],
-        "PyQt4": [],
-        "QScintilla2": [],
-    },
-    
-    "mac": {
-        "sip": [],
-        "PyQt4": ["4.9.2", "4.9.3"],
-        "QScintilla2": [],
-    },
-}
- 
-def exit(rcode=0):
-    """
-    Exit the install script.
-    """
-    global currDir
-    
-    if sys.platform.startswith("win"):
-        try:
-            raw_input("Press enter to continue...")
-        except EOFError:
-            pass
-    
-    os.chdir(currDir)
-    
-    sys.exit(rcode)
 
 def usage(rcode = 2):
     """
@@ -114,7 +69,7 @@ def usage(rcode = 2):
     print "These define the directories for the installation of the various parts of"\
           " eric4."
 
-    exit(rcode)
+    sys.exit(rcode)
 
 
 def initGlobals():
@@ -133,16 +88,11 @@ def initGlobals():
     modDir = distutils.sysconfig.get_python_lib(True)
     pyModDir = modDir
     
-    pyqtDataDir = os.path.join(modDir, "PyQt4")
-    if os.path.exists(os.path.join(pyqtDataDir, "qsci")):
-        # it's the installer
-        qtDataDir = pyqtDataDir
-    else:
-        try:
-            from PyQt4.QtCore import QLibraryInfo
-            qtDataDir = unicode(QLibraryInfo.location(QLibraryInfo.DataPath))
-        except ImportError:
-            qtDataDir = None
+    try:
+        from PyQt4 import pyqtconfig
+        qtDataDir = pyqtconfig._pkg_config["qt_data_dir"]
+    except (AttributeError, ImportError):
+        qtDataDir = None
     if qtDataDir:
         apisDir = os.path.join(qtDataDir, "qsci", "api")
     else:
@@ -156,7 +106,7 @@ def copyToFile(name, text):
     @param name the name of the file.
     @param text the contents to copy to the file.
     """
-    f = open(name, "w")
+    f = open(name,"w")
     f.write(text)
     f.close()
 
@@ -177,32 +127,21 @@ def wrapperName(dname, wfile):
     return wname
 
 
-def createPyWrapper(pydir, wfile, isGuiScript = True):
+def createPyWrapper(pydir, wfile):
     """
     Create an executable wrapper for a Python script.
 
     @param pydir the name of the directory where the Python script will eventually
         be installed
     @param wfile the basename of the wrapper
-    @param isGuiScript flag indicating a wrapper script for a GUI
-        application (boolean)
     @return the platform specific name of the wrapper
     """
     # all kinds of Windows systems
     if sys.platform.startswith("win"):
         wname = wfile + ".bat"
-        if isGuiScript:
-            wrapper = \
-                '''@echo off\r\n''' \
-                '''set PYDIR=%%~dp0\r\n''' \
-                '''start "" "%%PYDIR%%\\pythonw.exe"''' \
-                ''' "%s\\%s.pyw"''' \
-                ''' %%1 %%2 %%3 %%4 %%5 %%6 %%7 %%8 %%9\r\n''' % (pydir, wfile)
-        else:
-            wrapper = \
-                '''@"%s\\python.exe" "%s\\%s.py"''' \
-                ''' %%1 %%2 %%3 %%4 %%5 %%6 %%7 %%8 %%9\r\n''' % (
-                    platBinDir, pydir, wfile)
+        wrapper = \
+'''@"%s\\pythonw" "%s\\%s.py" %%1 %%2 %%3 %%4 %%5 %%6 %%7 %%8 %%9
+''' % (platBinDir, pydir, wfile)
 
     # Mac OS X
     elif sys.platform == "darwin":
@@ -228,7 +167,7 @@ exec "%s" "%s/%s.py" "$@"
     return wname
 
 
-def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
+def copyTree(src, dst, filters, excludeDirs=[]):
     """
     Copy Python, translation, documentation, wizards configuration,
     designer template files and DTDs of a directory tree.
@@ -237,7 +176,6 @@ def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
     @param dst name of the destination directory
     @param filters list of filter pattern determining the files to be copied
     @param excludeDirs list of (sub)directories to exclude from copying
-    @keyparam excludePatterns list of filter pattern determining the files to be skipped
     """
     try:
         names = os.listdir(src)
@@ -245,24 +183,17 @@ def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
         return      # ignore missing directories (most probably the i18n directory)
     
     for name in names:
-        skipIt = False
-        for excludePattern in excludePatterns:
-            if fnmatch.fnmatch(name, excludePattern):
-                skipIt = True
+        srcname = os.path.join(src, name)
+        dstname = os.path.join(dst, name)
+        for filter in filters:
+            if fnmatch.fnmatch(srcname, filter):
+                if not os.path.isdir(dst):
+                    os.makedirs(dst)
+                shutil.copy2(srcname, dstname)
                 break
-        if not skipIt:
-            srcname = os.path.join(src, name)
-            dstname = os.path.join(dst, name)
-            for filter in filters:
-                if fnmatch.fnmatch(srcname, filter):
-                    if not os.path.isdir(dst):
-                        os.makedirs(dst)
-                    shutil.copy2(srcname, dstname)
-                    os.chmod(dstname, 0o644)
-                    break
-            else:
-                if os.path.isdir(srcname) and not srcname in excludeDirs:
-                    copyTree(srcname, dstname, filters, excludePatterns=excludePatterns)
+        else:
+            if os.path.isdir(srcname) and not srcname in excludeDirs:
+                copyTree(srcname, dstname, filters)
 
 
 def createGlobalPluginsDir():
@@ -286,7 +217,6 @@ Package containing the global plugins.
 '''        
         )
         f.close()
-        os.chmod(fname, 0o644)
 
 
 def cleanUp():
@@ -312,110 +242,68 @@ def cleanUp():
         "eric4-tray", "eric4-editor", 
         "eric4-plugininstall", "eric4-pluginuninstall", 
         "eric4-pluginrepository", "eric4-sqlbrowser", 
-        "eric4-webbrowser", "eric4-iconeditor", 
-        "eric4_api", "eric4_compare",
-        "eric4_configure", "eric4_diff",
-        "eric4_doc", "eric4_helpviewer",
-        "eric4_qregexp", "eric4_re", 
-        "eric4_trpreviewer", "eric4_uipreviewer",
-        "eric4_unittest", "eric4",
-        "eric4_tray", "eric4_editor", 
-        "eric4_plugininstall", "eric4_pluginuninstall", 
-        "eric4_pluginrepository", "eric4_sqlbrowser", 
-        "eric4_webbrowser", "eric4_iconeditor", 
+        "eric4-webbrowser", 
     ]
+    for rem_wname in rem_wnames:
+        rwname = wrapperName(getConfig('bindir'), rem_wname)
+        if os.path.exists(rwname):
+            os.remove(rwname)
     
+    # Cleanup our config file(s)
+    for name in ['eric4config.py', 'eric4config.pyc', 'eric4.pth']:
+        e4cfile = os.path.join(pyModDir, name)
+        if os.path.exists(e4cfile):
+            os.remove(e4cfile)
+        
+    # Cleanup the install directories
+    for name in ['ericExamplesDir', 'ericDocDir', 'ericDTDDir', 'ericCSSDir',
+                 'ericIconDir', 'ericPixDir', 'ericDir', 'ericTemplatesDir',
+                 'ericCodeTemplatesDir', 'ericOthersDir', 'ericStylesDir']:
+        if os.path.exists(getConfig(name)):
+            shutil.rmtree(getConfig(name), True)
+    
+    # Cleanup translations
+    for name in glob.glob(os.path.join(getConfig('ericTranslationsDir'), 'eric4_*.qm')):
+        if os.path.exists(name):
+            os.remove(name)
+    
+    # Cleanup API files
     try:
-        for rem_wname in rem_wnames:
-            rwname = wrapperName(getConfig('bindir'), rem_wname)
-            if os.path.exists(rwname):
-                os.remove(rwname)
-        
-        # Cleanup our config file(s)
-        for name in ['eric4config.py', 'eric4config.pyc', 'eric4.pth']:
-            e4cfile = os.path.join(pyModDir, name)
-            if os.path.exists(e4cfile):
-                os.remove(e4cfile)
-            
-        # Cleanup the install directories
-        for name in ['ericExamplesDir', 'ericDocDir', 'ericDTDDir', 'ericCSSDir',
-                     'ericIconDir', 'ericPixDir', 'ericDir', 'ericTemplatesDir',
-                     'ericCodeTemplatesDir', 'ericOthersDir', 'ericStylesDir']:
-            if os.path.exists(getConfig(name)):
-                shutil.rmtree(getConfig(name), True)
-        
-        # Cleanup translations
-        for name in glob.glob(os.path.join(getConfig('ericTranslationsDir'), 'eric4_*.qm')):
-            if os.path.exists(name):
-                os.remove(name)
-        
-        # Cleanup API files
-        try:
-            apidir = getConfig('apidir')
-            for progLanguage in progLanguages:
-                for name in getConfig('apis'):
-                    apiname = os.path.join(apidir, progLanguage, name)
-                    if os.path.exists(apiname):
-                        os.remove(apiname)
-        except AttributeError:
-            pass
-        
-        if sys.platform == "darwin":
-            # delete the Mac app bundle
-            if os.path.exists("/Developer/Applications/Eric4"):
-                shutil.rmtree("/Developer/Applications/Eric4")
-            if os.path.exists("/Applications/eric4.app"):
-                shutil.rmtree("/Applications/eric4.app")
-        
-    except IOError, msg:
-        sys.stderr.write('IOError: %s\nTry install with admin rights.\n' % msg)
-        exit(7)
-        
-    except OSError, msg:
-        sys.stderr.write('OSError: %s\nTry install with admin rights.\n' % msg)
-        exit(7)
-
-
-def shutilCopy(src, dst, perm=0o644):
-    """
-    Wrapper function around shutil.copy() to ensure the permissions.
-    
-    @param src source file name (string)
-    @param dst destination file name or directory name (string)
-    @keyparam perm permissions to be set (integer)
-    """
-    shutil.copy(src, dst)
-    if os.path.isdir(dst):
-        dst = os.path.join(dst, os.path.basename(src))
-    os.chmod(dst, perm)
+        apidir = getConfig('apidir')
+        for progLanguage in progLanguages:
+            for name in getConfig('apis'):
+                apiname = os.path.join(apidir, progLanguage, name)
+                if os.path.exists(apiname):
+                    os.remove(apiname)
+    except AttributeError:
+        pass
 
 
 def installEric():
     """
     Actually perform the installation steps.
     """
-    global distDir, doCleanup, cfg, progLanguages, sourceDir, configName
+    global distDir, doCleanup, cfg, progLanguages
     
     # Create the platform specific wrappers.
     wnames = []
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_api", False))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_compare"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_configure"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_diff"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_doc", False))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_editor"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_iconeditor"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_plugininstall"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_pluginrepository"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_pluginuninstall"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_qregexp"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_re"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_sqlbrowser"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_tray"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_trpreviewer"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_uipreviewer"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_unittest"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_webbrowser"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-api"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-compare"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-configure"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-diff"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-doc"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-webbrowser"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-qregexp"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-re"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-trpreviewer"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-uipreviewer"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-unittest"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-tray"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-editor"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-plugininstall"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-pluginuninstall"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-pluginrepository"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-sqlbrowser"))
     wnames.append(createPyWrapper(cfg['ericDir'], "eric4"))
     
     # set install prefix, if not None
@@ -432,175 +320,86 @@ def installEric():
         
         # copy the eric4 config file
         if distDir:
-            shutilCopy(configName, cfg['mdir'])
-            if os.path.exists(configName + 'c'):
-                shutilCopy(configName + 'c', cfg['mdir'])
+            shutil.copy('eric4config.py', cfg['mdir'])
+            if os.path.exists('eric4config.pyc'):
+                shutil.copy('eric4config.pyc', cfg['mdir'])
         else:
-            shutilCopy(configName, modDir)
-            if os.path.exists(configName + 'c'):
-                shutilCopy(configName + 'c', modDir)
+            shutil.copy('eric4config.py', modDir)
+            if os.path.exists('eric4config.pyc'):
+                shutil.copy('eric4config.pyc', modDir)
         
         # copy the eric4.pth file
         if distDir:
-            shutilCopy('%s%seric4.pth' % (sourceDir, os.sep), cfg['mdir'])
+            shutil.copy('eric%seric4.pth' % os.sep, cfg['mdir'])
         else:
-            shutilCopy('%s%seric4.pth' % (sourceDir, os.sep), modDir)
+            shutil.copy('eric%seric4.pth' % os.sep, modDir)
         
         # copy the various parts of eric4
-        copyTree(sourceDir, cfg['ericDir'], ['*.py', '*.pyc', '*.pyo', '*.pyw'], 
-            ['%s%sExamples' % (sourceDir, os.sep)],
-            excludePatterns=["eric4config.py*"])
-        copyTree(sourceDir, cfg['ericDir'], ['*.rb'], 
-            ['%s%sExamples' % (sourceDir, os.sep)])
-        copyTree('%s%sPlugins' % (sourceDir, os.sep), 
-            '%s%sPlugins' % (cfg['ericDir'], os.sep), 
+        copyTree('eric', cfg['ericDir'], ['*.py', '*.pyc', '*.pyo', '*.pyw'], 
+            ['eric%sExamples' % os.sep])
+        copyTree('eric', cfg['ericDir'], ['*.rb'], 
+            ['eric%sExamples' % os.sep])
+        copyTree('eric%sPlugins' % os.sep, '%s%sPlugins' % (cfg['ericDir'], os.sep), 
             ['*.png'])
-        copyTree('%s%sDocumentation' % (sourceDir, os.sep), 
-                 cfg['ericDocDir'], ['*.html', '*.qch'])
-        copyTree('%s%sDTDs' % (sourceDir, os.sep), 
-                 cfg['ericDTDDir'], ['*.dtd'])
-        copyTree('%s%sCSSs' % (sourceDir, os.sep), 
-                 cfg['ericCSSDir'], ['*.css'])
-        copyTree('%s%sStyles' % (sourceDir, os.sep), 
-                 cfg['ericStylesDir'], ['*.qss'])
-        copyTree('%s%si18n' % (sourceDir, os.sep), 
-                 cfg['ericTranslationsDir'], ['*.qm'])
-        copyTree('%s%sicons' % (sourceDir, os.sep), 
-                 cfg['ericIconDir'], ['*.png', 'LICENSE*.*'])
-        copyTree('%s%spixmaps' % (sourceDir, os.sep), 
-                 cfg['ericPixDir'], ['*.png', '*.xpm', '*.ico'])
-        copyTree('%s%sDesignerTemplates' % (sourceDir, os.sep), 
-                 cfg['ericTemplatesDir'], ['*.tmpl'])
-        copyTree('%s%sCodeTemplates' % (sourceDir, os.sep), 
-                 cfg['ericCodeTemplatesDir'], ['*.tmpl'])
-        copyTree('%s%sExamples' % (sourceDir, os.sep), cfg['ericExamplesDir'], 
+        copyTree('eric%sDocumentation' % os.sep, cfg['ericDocDir'], ['*.html', '*.qch'])
+        copyTree('eric%sDTDs' % os.sep, cfg['ericDTDDir'], ['*.dtd'])
+        copyTree('eric%sCSSs' % os.sep, cfg['ericCSSDir'], ['*.css'])
+        copyTree('eric%sStyles' % os.sep, cfg['ericStylesDir'], ['*.qss'])
+        copyTree('eric%si18n' % os.sep, cfg['ericTranslationsDir'], ['*.qm'])
+        copyTree('eric%sicons' % os.sep, cfg['ericIconDir'], ['*.png', 'LICENSE*.*'])
+        copyTree('eric%spixmaps' % os.sep, cfg['ericPixDir'], ['*.png', '*.xpm', '*.ico'])
+        copyTree('eric%sDesignerTemplates' % os.sep, cfg['ericTemplatesDir'], ['*.tmpl'])
+        copyTree('eric%sCodeTemplates' % os.sep, cfg['ericCodeTemplatesDir'], ['*.tmpl'])
+        copyTree('eric%sExamples' % os.sep, cfg['ericExamplesDir'], 
                  ['*.py', '*.pyc', '*.pyo'])
         
         # copy the wrappers
         for wname in wnames:
-            shutilCopy(wname, cfg['bindir'], perm=0o755)
-            os.remove(wname)
+            shutil.copy(wname, cfg['bindir'])
         
         # copy the license file
-        shutilCopy('%s%sLICENSE.GPL3' % (sourceDir, os.sep), cfg['ericDir'])
+        shutil.copy('eric%sLICENSE.GPL3' % os.sep, cfg['ericDir'])
         
         # create the global plugins directory
         createGlobalPluginsDir()
         
     except IOError, msg:
-        sys.stderr.write('IOError: %s\nTry install with admin rights.\n' % msg)
-        exit(7)
+        sys.stderr.write('IOError: %s\nTry install as root.\n' % msg)
+        sys.exit(7)
         
     except OSError, msg:
         sys.stderr.write('OSError: %s\nTry install with admin rights.\n' % msg)
-        exit(7)
+        sys.exit(7)
     
     # copy some text files to the doc area
     for name in ["LICENSE.GPL3", "THANKS", "changelog"]:
         try:
-            shutilCopy('%s%s%s' % (sourceDir, os.sep, name), cfg['ericDocDir'])
+            shutil.copy('eric%s%s' % (os.sep, name), cfg['ericDocDir'])
         except EnvironmentError:
-            print "Could not install '%s%s%s'." % (sourceDir, os.sep, name)
-    for name in glob.glob(os.path.join(sourceDir, 'README*.*')):
+            print "Could not install 'eric%s%s'." % (os.sep, name)
+    for name in glob.glob(os.path.join('eric', 'README*.*')):
         try:
-            shutilCopy(name, cfg['ericDocDir'])
+            shutil.copy(name, cfg['ericDocDir'])
         except EnvironmentError:
-            print "Could not install '%s%s%s'." % (sourceDir, os.sep, name)
+            print "Could not install 'eric%s%s'." % (os.sep, name)
    
     # copy some more stuff
-    for name in ['default.e4k', 'default_Mac.e4k']:
+    for name in ['default.e4k']:
         try:
-            shutilCopy('%s%s%s' % (sourceDir, os.sep, name), cfg['ericOthersDir'])
+            shutil.copy('eric%s%s' % (os.sep, name), cfg['ericOthersDir'])
         except EnvironmentError:
-            print "Could not install '%s%s%s'." % (sourceDir, os.sep, name)
+            print "Could not install 'eric%s%s'." % (os.sep, name)
     
     # install the API file
     for progLanguage in progLanguages:
         apidir = os.path.join(cfg['apidir'], progLanguage.lower())
         if not os.path.exists(apidir):
             os.makedirs(apidir)
-        for apiName in glob.glob(os.path.join(sourceDir, "APIs", progLanguage, "*.api")):
+        for apiName in glob.glob(os.path.join("eric", "APIs", progLanguage, "*.api")):
             try:
-                shutilCopy(apiName, apidir)
+                shutil.copy(apiName, apidir)
             except EnvironmentError:
                 print "Could not install '%s'." % apiName
-    
-    # Create a Mac application bundle
-    if sys.platform == "darwin":
-        createMacAppBundle(cfg['ericDir'])
-
-
-def createMacAppBundle(pydir):
-    """
-    Create a Mac application bundle.
-
-    @param pydir the name of the directory where the Python script will eventually
-        be installed
-    """
-    global cfg, sourceDir
-    
-    dirs = {"contents": "/Applications/eric4.app/Contents/",
-            "exe": "/Applications/eric4.app/Contents/MacOS",
-            "icns": "/Applications/eric4.app/Contents/Resources"}
-    os.makedirs(dirs["contents"])
-    os.mkdir(dirs["exe"])
-    os.mkdir(dirs["icns"])
-    
-    starter = os.path.join(dirs["exe"], "eric")
-    os.symlink(
-        "%s/Resources/Python.app/Contents/MacOS/Python" % sys.exec_prefix,
-        starter)
-    
-    wname = os.path.join(dirs["exe"], "eric4")
-    path = os.getenv("PATH", "")
-    if path:
-        pybin = os.path.join(sys.exec_prefix, "bin")
-        pathlist = path.split(os.pathsep)
-        if pybin not in pathlist:
-            pathlist.insert(0, pybin)
-        path = os.pathsep.join(pathlist)
-        wrapper = \
-'''#!/bin/sh
-
-PATH=%s
-exec "%s" "%s/%s.py" "$@"
-''' % (path, starter, pydir, "eric4")
-    else:
-        wrapper = \
-'''#!/bin/sh
-
-exec "%s" "%s/%s.py" "$@"
-''' % (starter, pydir, "eric4")
-    copyToFile(wname, wrapper)
-    os.chmod(wname, 0755)
-    
-    shutilCopy(os.path.join(sourceDir, "pixmaps", "eric_2.icns"),
-               os.path.join(dirs["icns"], "eric.icns"))
-    
-    copyToFile(os.path.join(dirs["contents"], "Info.plist"),
-'''<?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN"
-          "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
-<plist version="1.0">
-<dict>
-    <key>CFBundleExecutable</key>
-    <string>eric4</string>
-    <key>CFBundleIconFile</key>
-    <string>eric.icns</string>
-    <key>CFBundleInfoDictionaryVersion</key>
-    <string>1.0</string>
-    <key>CFBundleName</key>
-    <string>eric4</string>
-    <key>CFBundlePackageType</key>
-    <string>APPL</string>
-    <key>CFBundleSignature</key>
-    <string>????</string>
-    <key>CFBundleVersion</key>
-    <string>1.0</string>
-</dict>
-</plist>
-'''        
-    )
 
 
 def createInstallConfig():
@@ -631,17 +430,16 @@ def createInstallConfig():
     else:
         cfg['apidir'] = os.path.join(ericdir, "api")
 configLength = 15
-
-
+    
 def createConfig():
     """
     Create a config file with the respective config entries.
     """
-    global cfg, sourceDir
+    global cfg
     
     apis = []
     for progLanguage in progLanguages:
-        for apiName in glob.glob(os.path.join(sourceDir, "APIs", progLanguage, "*.api")):
+        for apiName in glob.glob(os.path.join("eric", "APIs", progLanguage, "*.api")):
             apis.append(os.path.basename(apiName))
     
     fn = 'eric4config.py'
@@ -692,7 +490,6 @@ def getConfig(name):
        cfg['apidir'], apis)
     copyToFile(fn, config)
 
-
 def doDependancyChecks():    
     """
     Perform some dependency checks.
@@ -700,77 +497,39 @@ def doDependancyChecks():
     print 'Checking dependencies'
     
     # perform dependency checks
-    if sys.version_info < (2, 6, 0):
-        print 'Sorry, you must have Python 2.6.0 or higher.'
-        exit(5)
+    if sys.version_info < (2, 5, 0):
+        print 'Sorry, you must have Python 2.5.0 or higher.'
+        sys.exit(5)
     if sys.version_info > (2, 9, 9):
         print 'Sorry, eric4 requires Python 2 for running.'
-        exit(5)
+        sys.exit(5)
     print "Python Version: %d.%d.%d" % sys.version_info[:3]
     
-    try:
-        import xml.etree
-    except ImportError, msg:
-        print('Your Python installation is missing the XML module.')
-        print('Please install it and try again.')
-        exit(5)
-    
     try:
         from PyQt4.QtCore import qVersion, PYQT_VERSION
     except ImportError, msg:
         print 'Sorry, please install PyQt4.'
         print 'Error: %s' % msg
-        exit(1)
-    print "Found PyQt4"
-    
-    try:
-        import PyQt4.QtHelp
-    except ImportError, msg:
-        print 'Sorry, please install QtHelp.'
-        print 'Error: %s' % msg
-        exit(1)
-    print "Found QtHelp"
+        sys.exit(1)
+    print "Found PyQt"
     
     try:
         from PyQt4 import Qsci
     except ImportError, msg:
         print "Sorry, please install QScintilla2 and"
-        print "its PyQt4 wrapper."
+        print "it's PyQt4 wrapper."
         print 'Error: %s' % msg
-        exit(1)
+        sys.exit(1)
     print "Found QScintilla2"
     
-    # determine the platform dependent black list
-    if sys.platform.startswith("win"):
-        PlatformBlackLists = PlatformsBlackLists["windows"]
-    elif sys.platform.startswith("linux"):
-        PlatformBlackLists = PlatformsBlackLists["linux"]
-    else:
-        PlatformBlackLists = PlatformsBlackLists["mac"]
-    
     # check version of Qt
     qtMajor = int(qVersion().split('.')[0])
     qtMinor = int(qVersion().split('.')[1])
-    if qtMajor < 4 or (qtMajor == 4 and qtMinor < 6):
-        print 'Sorry, you must have Qt version 4.6.0 or higher.'
-        exit(2)
+    if qtMajor < 4 or (qtMajor == 4 and qtMinor < 4):
+        print 'Sorry, you must have Qt version 4.4.0 or higher.'
+        sys.exit(2)
     print "Qt Version: %s" % qVersion()
     
-    # check version of sip
-    try:
-        import sipconfig
-        sipVersion = sipconfig.Configuration().sip_version_str
-        # always assume, that snapshots are new enough
-        if "snapshot" not in sipVersion:
-            # check for blacklisted versions
-            for vers in BlackLists["sip"] + PlatformBlackLists["sip"]:
-                if vers == sipVersion:
-                    print 'Sorry, sip version %s is not compatible with eric4.' % vers
-                    print 'Please install another version.'
-                    exit(3)
-    except ImportError:
-        pass
-    
     #check version of PyQt
     from PyQt4.QtCore import PYQT_VERSION_STR
     pyqtVersion = PYQT_VERSION_STR
@@ -782,16 +541,10 @@ def doDependancyChecks():
         maj = int(maj)
         min = int(min)
         pat = int(pat)
-        if maj < 4 or (maj == 4 and min < 6):
-            print 'Sorry, you must have PyQt 4.6.0 or higher or' \
+        if maj < 4 or (maj == 4 and min < 3):
+            print 'Sorry, you must have PyQt 4.3.0 or higher or' \
                   ' a recent snapshot release.'
-            exit(4)
-        # check for blacklisted versions
-        for vers in BlackLists["PyQt4"] + PlatformBlackLists["PyQt4"]:
-            if vers == pyqtVersion:
-                print 'Sorry, PyQt4 version %s is not compatible with eric4.' % vers
-                print 'Please install another version.'
-                exit(4)
+            sys.exit(3)
     print "PyQt Version: ", pyqtVersion
     
     #check version of QScintilla
@@ -805,26 +558,18 @@ def doDependancyChecks():
         maj = int(maj)
         min = int(min)
         pat = int(pat)
-        if maj < 2 or (maj == 2 and min < 3):
-            print 'Sorry, you must have QScintilla 2.3.0 or higher or' \
+        if maj < 2 or (maj == 2 and min < 2):
+            print 'Sorry, you must have QScintilla 2.2.0 or higher or' \
                   ' a recent snapshot release.'
-            exit(5)
-        # check for blacklisted versions
-        for vers in BlackLists["QScintilla2"] + PlatformBlackLists["QScintilla2"]:
-            if vers == scintillaVersion:
-                print 'Sorry, QScintilla2 version %s is not compatible with eric4.' % vers
-                print 'Please install another version.'
-                exit(5)
+            sys.exit(4)
     print "QScintilla Version: ", QSCINTILLA_VERSION_STR
     print "All dependencies ok."
     print
 
-
 def compileUiFiles():
     """
     Compile the .ui files to Python sources.
     """
-    global sourceDir
     try:
         from PyQt4.uic import compileUiDir
     except ImportError:
@@ -903,8 +648,7 @@ def compileUiFiles():
         """
         return py_dir, "Ui_%s" % py_file
     
-    compileUiDir(sourceDir, True, pyName)
-
+    compileUiDir("eric", True, pyName)
 
 def main(argv):
     """
@@ -916,12 +660,7 @@ def main(argv):
 
     # Parse the command line.
     global progName, modDir, doCleanup, doCompile, distDir, cfg, apisDir
-    global sourceDir, configName
-    
     progName = os.path.basename(argv[0])
-    
-    if os.path.dirname(argv[0]):
-      os.chdir(os.path.dirname(argv[0]))
 
     initGlobals()
 
@@ -960,15 +699,10 @@ def main(argv):
                 if len(cfg) != configLength:
                     print "The configuration dictionary in '%s' is incorrect. Aborting"\
                         % arg
-                    exit(6)
+                    sys.exit(6)
             except:
                 cfg = {}
     
-    installFromSource = not os.path.isdir(sourceDir)
-    if installFromSource:
-        sourceDir = os.path.dirname(__file__) or "."
-        configName = os.path.join(sourceDir, "eric4config.py")
-    
     if len(cfg) == 0:
         createInstallConfig()
     
@@ -977,17 +711,11 @@ def main(argv):
     
     # get rid of development config file, if it exists
     try:
-        if installFromSource:
-            os.rename(configName, configName + ".orig")
-            configNameC = configName + 'c'
-            if os.path.exists(configNameC):
-                os.remove(configNameC)
-        os.remove(configName)
+        os.remove(os.path.join("eric", "eric4config.py"))
     except EnvironmentError:
         pass
     
     # cleanup old installation
-    print "Cleaning up old installation ..."
     try:
         if doCleanup:
             if distDir:
@@ -998,48 +726,30 @@ def main(argv):
         sys.stderr.write('IOError: %s\nTry install as root.\n' % msg)
 
     # Create a config file and delete the default one
-    print "\nCreating configuration file ..."
     createConfig()
 
     # Compile .ui files
-    print "\nCompiling user interface files ..."
-    # step 1: remove old Ui_*.py files
-    for root, _, files in os.walk(sourceDir):
-        for file in [f for f in files if fnmatch.fnmatch(f, 'Ui_*.py')]:
-            os.remove(os.path.join(root, file))
-    # step 2: compile the forms
+    print "Compiling user interface files..."
     compileUiFiles()
     
     if doCompile:
-        print "\nCompiling source files ..."
+        print "\nCompiling source files..."
         if distDir:
-            compileall.compile_dir(sourceDir, 
+            compileall.compile_dir("eric", 
                                    ddir = os.path.join(distDir, modDir, cfg['ericDir']), 
                                    rx = re.compile("Python3"), 
                                    quiet = True)
-            py_compile.compile(configName, 
+            py_compile.compile("eric4config.py", 
                                dfile = os.path.join(distDir, modDir, "eric4config.py"))
         else:
-            compileall.compile_dir(sourceDir, 
+            compileall.compile_dir("eric", 
                                    ddir = os.path.join(modDir, cfg['ericDir']), 
                                    rx = re.compile("Python3"), 
                                    quiet = True)
-            py_compile.compile(configName, 
+            py_compile.compile("eric4config.py", 
                                dfile = os.path.join(modDir, "eric4config.py"))
     print "\nInstalling eric4 ..."
     installEric()
-    
-    # do some cleanup
-    try:
-        if installFromSource:
-            os.remove(configName)
-            configNameC = configName + 'c'
-            if os.path.exists(configNameC):
-                os.remove(configNameC)
-            os.rename(configName + ".orig", configName)
-    except EnvironmentError:
-        pass
-    
     print "\nInstallation complete."
     print
     
@@ -1055,12 +765,9 @@ def main(argv):
                     (v[0], v[1], v[2])
                 print "    with foreign characters. Please see 'README-PyXML.txt' for"
                 print "    details."
-                try:
-                    res = raw_input("    Shall pyXML be patched now (y/n)? ")
-                    if res in ["Y", "y"]:
-                        patchPyXML()
-                except EOFError:
-                    pass
+                res = raw_input("    Shall pyXML be patched now (y/n)? ")
+                if res in ["Y", "y"]:
+                    patchPyXML()
     except ImportError:
         pass
     
@@ -1082,10 +789,7 @@ def main(argv):
     
     print
     if sys.platform.startswith("win"):
-        try:
-            raw_input("Press enter to continue...")
-        except EOFError:
-            pass
+        raw_input("Press enter to continue...")
     
     
 if __name__ == "__main__":
